# Generated by Django 4.2.19 on 2025-03-30 14:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0011_alter_characternote_options_alter_skillcheck_options_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='approvedskills',
            old_name='hull',
            new_name='ship',
        ),
        migrations.AlterField(
            model_name='approvedimplantset',
            name='set',
            field=models.CharField(choices=[('Amulet', 'Amulet'), ('Ascendancy ', 'Ascendancy '), ('None', 'None')], default='Amulet', max_length=16, verbose_name='Set Type'),
        ),
    ]
