# Generated by Django 4.2.19 on 2025-03-30 11:44

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('incursions', '0010_activefleet_announcement_approvedfitting_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='characternote',
            options={'default_permissions': (), 'ordering': ['-logged_at'], 'verbose_name': 'Waitlist - Character Note', 'verbose_name_plural': 'Waitlist - Character Notes'},
        ),
        migrations.AlterModelOptions(
            name='skillcheck',
            options={'default_permissions': (), 'verbose_name': 'Waitlist - Skill Check', 'verbose_name_plural': 'Waitlist - Skill Checks'},
        ),
        migrations.AlterField(
            model_name='announcement',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created At'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Created By'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='is_alert',
            field=models.BooleanField(default=False, verbose_name='Is Alert'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='message',
            field=models.TextField(verbose_name='Message'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='pages',
            field=models.TextField(blank=True, null=True, verbose_name='Pages'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='revoked_at',
            field=models.DateTimeField(blank=True, default=None, null=True, verbose_name='Revoked At'),
        ),
        migrations.AlterField(
            model_name='announcement',
            name='revoked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Revoked By'),
        ),
        migrations.AlterField(
            model_name='approvedfitting',
            name='description',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='approvedfitting',
            name='dna',
            field=models.TextField(max_length=1024, unique=True, verbose_name='DNA String'),
        ),
        migrations.AlterField(
            model_name='approvedfitting',
            name='implants',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='incursions.approvedimplantset', verbose_name='Implant Set'),
        ),
        migrations.AlterField(
            model_name='approvedfitting',
            name='name',
            field=models.CharField(max_length=25, unique=True, verbose_name='Fitting Name'),
        ),
        migrations.AlterField(
            model_name='approvedfitting',
            name='tier',
            field=models.CharField(choices=[('Basic', 'Sponge'), ('Mainline', 'Mainline'), ('Alt', 'Alt'), ('Other', 'Other')], default='Mainline', max_length=16, verbose_name='Tier'),
        ),
        migrations.AlterField(
            model_name='approvedimplantset',
            name='implants',
            field=models.CharField(max_length=255, unique=True, verbose_name='Implant List'),
        ),
        migrations.AlterField(
            model_name='approvedimplantset',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Set Name'),
        ),
        migrations.AlterField(
            model_name='approvedimplantset',
            name='set',
            field=models.CharField(choices=[('Amulet', 'Amulet'), ('Ascendency', 'Ascendency'), ('None', 'None')], default='Amulet', max_length=16, verbose_name='Set Type'),
        ),
        migrations.AlterField(
            model_name='badge',
            name='exclude_badge',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='excluded_by', to='incursions.badge', verbose_name='Mutually Exclusive With'),
        ),
        migrations.AlterField(
            model_name='badge',
            name='name',
            field=models.CharField(max_length=64, unique=True, verbose_name='Badge Name'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='entity_alliance',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.eveallianceinfo', verbose_name='Alliance'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='entity_character',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='entity_corporation',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecorporationinfo', verbose_name='Corporation'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='entity_type',
            field=models.CharField(choices=[('Character', 'Character'), ('Corporation', 'Corporation'), ('Alliance', 'Alliance')], default='Character', max_length=12, verbose_name='Entity Type'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='issued_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Issued At'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='issued_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Issued By'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='public_reason',
            field=models.CharField(blank=True, max_length=512, null=True, verbose_name='Public Reason'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='reason',
            field=models.CharField(max_length=512, verbose_name='Internal Reason'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='revoked_at',
            field=models.DateTimeField(blank=True, default=None, null=True, verbose_name='Revoked At'),
        ),
        migrations.AlterField(
            model_name='ban',
            name='revoked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Revoked By'),
        ),
        migrations.AlterField(
            model_name='characterbadges',
            name='badge',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.badge', verbose_name='Badge'),
        ),
        migrations.AlterField(
            model_name='characterbadges',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='characterbadges',
            name='granted_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Granted At'),
        ),
        migrations.AlterField(
            model_name='characterbadges',
            name='granted_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Granted By'),
        ),
        migrations.AlterField(
            model_name='characternote',
            name='author',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Author'),
        ),
        migrations.AlterField(
            model_name='characternote',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='characternote',
            name='logged_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Logged At'),
        ),
        migrations.AlterField(
            model_name='characternote',
            name='note',
            field=models.TextField(verbose_name='Note'),
        ),
        migrations.AlterField(
            model_name='characterroles',
            name='character',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='characterroles',
            name='granted_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Granted At'),
        ),
        migrations.AlterField(
            model_name='characterroles',
            name='granted_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='eveonline.evecharacter', verbose_name='Granted By'),
        ),
        migrations.AlterField(
            model_name='fitting',
            name='dna',
            field=models.TextField(max_length=1024, unique=True, verbose_name='DNA String'),
        ),
        migrations.AlterField(
            model_name='fittinghistory',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='fittinghistory',
            name='fit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.fitting', verbose_name='Fitting'),
        ),
        migrations.AlterField(
            model_name='fittinghistory',
            name='implant_set',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.implantset', verbose_name='Implant Set'),
        ),
        migrations.AlterField(
            model_name='fittinghistory',
            name='logged_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Logged At'),
        ),
        migrations.AlterField(
            model_name='fleet',
            name='boss',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Fleet Boss'),
        ),
        migrations.AlterField(
            model_name='fleet',
            name='is_updating',
            field=models.BooleanField(default=False, verbose_name='Is Updating'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='first_seen',
            field=models.DateTimeField(auto_now_add=True, verbose_name='First Seen'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='fleet',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='incursions.fleet', verbose_name='Fleet'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='has_left',
            field=models.BooleanField(default=False, verbose_name='Has Left'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='is_boss',
            field=models.BooleanField(default=False, verbose_name='Is Boss'),
        ),
        migrations.AlterField(
            model_name='fleetactivity',
            name='last_seen',
            field=models.DateTimeField(auto_now=True, verbose_name='Last Seen'),
        ),
        migrations.AlterField(
            model_name='fleetsquad',
            name='fleet',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.fleet', verbose_name='Fleet'),
        ),
        migrations.AlterField(
            model_name='fleetsquad',
            name='squad_id',
            field=models.BigIntegerField(verbose_name='Squad ID'),
        ),
        migrations.AlterField(
            model_name='fleetsquad',
            name='wing_id',
            field=models.BigIntegerField(verbose_name='Wing ID'),
        ),
        migrations.AlterField(
            model_name='implantset',
            name='implants',
            field=models.CharField(max_length=255, unique=True, verbose_name='Implant String'),
        ),
        migrations.AlterField(
            model_name='role',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Role Description'),
        ),
        migrations.AlterField(
            model_name='role',
            name='name',
            field=models.CharField(max_length=64, unique=True, verbose_name='Role Name'),
        ),
        migrations.AlterField(
            model_name='role',
            name='power',
            field=models.IntegerField(default=0, help_text='Bigger is better, user can assign a power level lower than this', verbose_name='Role Power'),
        ),
        migrations.AlterField(
            model_name='skillcheck',
            name='elite',
            field=models.IntegerField(default=4, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(5)], verbose_name='Elite Level'),
        ),
        migrations.AlterField(
            model_name='skillcheck',
            name='gold',
            field=models.IntegerField(default=5, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(5)], verbose_name='Gold Level'),
        ),
        migrations.AlterField(
            model_name='skillcheck',
            name='min',
            field=models.IntegerField(default=3, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(5)], verbose_name='Minimum Required'),
        ),
        migrations.AlterField(
            model_name='skillhistory',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='skillhistory',
            name='logged_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Logged At'),
        ),
        migrations.AlterField(
            model_name='skillhistory',
            name='new_level',
            field=models.IntegerField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(5)], verbose_name='New Level'),
        ),
        migrations.AlterField(
            model_name='skillhistory',
            name='old_level',
            field=models.IntegerField(validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(5)], verbose_name='Old Level'),
        ),
        migrations.AlterField(
            model_name='waitlist',
            name='is_open',
            field=models.BooleanField(default=False, verbose_name='Is Open'),
        ),
        migrations.AlterField(
            model_name='waitlist',
            name='name',
            field=models.CharField(default='Waitlist', max_length=255, verbose_name='Waitlist Name'),
        ),
        migrations.AlterField(
            model_name='waitlistcategory',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Category Name'),
        ),
        migrations.AlterField(
            model_name='waitlistentry',
            name='joined_at',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Joined At'),
        ),
        migrations.AlterField(
            model_name='waitlistentry',
            name='main_character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Main Character'),
        ),
        migrations.AlterField(
            model_name='waitlistentry',
            name='waitlist',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.waitlist', verbose_name='Waitlist'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='approved',
            field=models.BooleanField(default=False, verbose_name='Approved'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='cached_time_in_fleet',
            field=models.BigIntegerField(verbose_name='Cached Time In Fleet'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='character',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecharacter', verbose_name='Character'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='fit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.fitting', verbose_name='Fitting'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='fit_analysis',
            field=models.JSONField(blank=True, null=True, verbose_name='Fit Analysis'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='implant_set',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.implantset', verbose_name='Implant Set'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='is_alt',
            field=models.BooleanField(default=False, verbose_name='Is Alt'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='messagexup',
            field=models.TextField(blank=True, null=True, verbose_name='Message XUP'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='review_comment',
            field=models.TextField(blank=True, null=True, verbose_name='Review Comment'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='tags',
            field=models.CharField(help_text='Comma Separated List', max_length=255, verbose_name='Tags'),
        ),
        migrations.AlterField(
            model_name='waitlistentryfit',
            name='waitlist_entry',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='incursions.waitlistentry', verbose_name='Waitlist Entry'),
        ),
        migrations.AlterUniqueTogether(
            name='characterbadges',
            unique_together={('character', 'badge')},
        ),
        migrations.AddIndex(
            model_name='waitlistcategory',
            index=models.Index(fields=['name'], name='incursions__name_73cfa5_idx'),
        ),
    ]
