# Generated by Django 4.2.19 on 2025-04-02 13:31

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0017_alter_incursionsconfig_status_webhooks_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='fleet',
            name='closed',
            field=models.DateTimeField(blank=True, default=None, null=True, verbose_name='Closed'),
        ),
        migrations.AddField(
            model_name='fleet',
            name='last_updated',
            field=models.DateTimeField(auto_now=True, verbose_name='Last Updated'),
        ),
        migrations.AddField(
            model_name='fleet',
            name='open',
            field=models.BooleanField(default=False, verbose_name='Is Open'),
        ),
        migrations.AddField(
            model_name='fleet',
            name='opened',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Opened'),
            preserve_default=False,
        ),
    ]
