var Qp=Object.defineProperty;var Vp=(i,r,d)=>r in i?Qp(i,r,{enumerable:!0,configurable:!0,writable:!0,value:d}):i[r]=d;var Nu=(i,r,d)=>Vp(i,typeof r!="symbol"?r+"":r,d);import{j as l,L as fc,M as Rm,N as jt,u as sn,J as Zp,X as Kp,C as Jp,R as hc,a as mc,b as Fp,c as Wp,d as je,B as Ip,e as Pp}from"./@react-libs-Be4_VkjC.js";import{P as Um,g as e0,d as T,r as w,R as K,Q as t0,l as n0,_ as ue,T as Oa,U as km,V as a0,W as l0,X as i0,Y as s0,Z as c0,$ as r0,a0 as u0,a1 as o0,a2 as d0,a3 as f0,a4 as h0,a5 as m0,a6 as x0,a7 as $u,a8 as Lm,a9 as g0,aa as p0,O as y0}from"./@app-libs-BSBCEBGY.js";import{F as ie,f as Ri,a as v0,b as j0,c as b0,d as S0,e as w0,g as Zu,h as _0,i as Hm,j as T0,k as qm,l as $m,m as C0,n as A0,o as Gm,p as E0,q as Ym,r as D0,s as O0,t as xc,u as M0,v as z0,w as Ku,x as B0,y as N0,z as Xm,A as Qm,B as Vm}from"./@fontawesome-libs-DxILGqN0.js";import{u as k,w as R0,i as U0,B as k0,a as L0,b as H0}from"./@lang-libs-xI_kOUGH.js";(function(){const r=document.createElement("link").relList;if(r&&r.supports&&r.supports("modulepreload"))return;for(const o of document.querySelectorAll('link[rel="modulepreload"]'))u(o);new MutationObserver(o=>{for(const f of o)if(f.type==="childList")for(const m of f.addedNodes)m.tagName==="LINK"&&m.rel==="modulepreload"&&u(m)}).observe(document,{childList:!0,subtree:!0});function d(o){const f={};return o.integrity&&(f.integrity=o.integrity),o.referrerPolicy&&(f.referrerPolicy=o.referrerPolicy),o.crossOrigin==="use-credentials"?f.credentials="include":o.crossOrigin==="anonymous"?f.credentials="omit":f.credentials="same-origin",f}function u(o){if(o.ep)return;o.ep=!0;const f=d(o);fetch(o.href,f)}})();var Ru={exports:{}},wi={},Uu={exports:{}},ku={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var cm;function q0(){return cm||(cm=1,function(i){function r(N,H){var F=N.length;N.push(H);e:for(;0<F;){var Se=F-1>>>1,we=N[Se];if(0<o(we,H))N[Se]=H,N[F]=we,F=Se;else break e}}function d(N){return N.length===0?null:N[0]}function u(N){if(N.length===0)return null;var H=N[0],F=N.pop();if(F!==H){N[0]=F;e:for(var Se=0,we=N.length,ft=we>>>1;Se<ft;){var Ae=2*(Se+1)-1,me=N[Ae],Ie=Ae+1,Jt=N[Ie];if(0>o(me,F))Ie<we&&0>o(Jt,me)?(N[Se]=Jt,N[Ie]=F,Se=Ie):(N[Se]=me,N[Ae]=F,Se=Ae);else if(Ie<we&&0>o(Jt,F))N[Se]=Jt,N[Ie]=F,Se=Ie;else break e}}return H}function o(N,H){var F=N.sortIndex-H.sortIndex;return F!==0?F:N.id-H.id}if(i.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var f=performance;i.unstable_now=function(){return f.now()}}else{var m=Date,g=m.now();i.unstable_now=function(){return m.now()-g}}var p=[],y=[],j=1,E=null,O=3,M=!1,L=!1,q=!1,U=!1,G=typeof setTimeout=="function"?setTimeout:null,Q=typeof clearTimeout=="function"?clearTimeout:null,be=typeof setImmediate<"u"?setImmediate:null;function te(N){for(var H=d(y);H!==null;){if(H.callback===null)u(y);else if(H.startTime<=N)u(y),H.sortIndex=H.expirationTime,r(p,H);else break;H=d(y)}}function W(N){if(q=!1,te(N),!L)if(d(p)!==null)L=!0,de||(de=!0,zt());else{var H=d(y);H!==null&&cn(W,H.startTime-N)}}var de=!1,We=-1,bt=5,Re=-1;function ca(){return U?!0:!(i.unstable_now()-Re<bt)}function za(){if(U=!1,de){var N=i.unstable_now();Re=N;var H=!0;try{e:{L=!1,q&&(q=!1,Q(We),We=-1),M=!0;var F=O;try{t:{for(te(N),E=d(p);E!==null&&!(E.expirationTime>N&&ca());){var Se=E.callback;if(typeof Se=="function"){E.callback=null,O=E.priorityLevel;var we=Se(E.expirationTime<=N);if(N=i.unstable_now(),typeof we=="function"){E.callback=we,te(N),H=!0;break t}E===d(p)&&u(p),te(N)}else u(p);E=d(p)}if(E!==null)H=!0;else{var ft=d(y);ft!==null&&cn(W,ft.startTime-N),H=!1}}break e}finally{E=null,O=F,M=!1}H=void 0}}finally{H?zt():de=!1}}}var zt;if(typeof be=="function")zt=function(){be(za)};else if(typeof MessageChannel<"u"){var qi=new MessageChannel,Tl=qi.port2;qi.port1.onmessage=za,zt=function(){Tl.postMessage(null)}}else zt=function(){G(za,0)};function cn(N,H){We=G(function(){N(i.unstable_now())},H)}i.unstable_IdlePriority=5,i.unstable_ImmediatePriority=1,i.unstable_LowPriority=4,i.unstable_NormalPriority=3,i.unstable_Profiling=null,i.unstable_UserBlockingPriority=2,i.unstable_cancelCallback=function(N){N.callback=null},i.unstable_forceFrameRate=function(N){0>N||125<N?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):bt=0<N?Math.floor(1e3/N):5},i.unstable_getCurrentPriorityLevel=function(){return O},i.unstable_next=function(N){switch(O){case 1:case 2:case 3:var H=3;break;default:H=O}var F=O;O=H;try{return N()}finally{O=F}},i.unstable_requestPaint=function(){U=!0},i.unstable_runWithPriority=function(N,H){switch(N){case 1:case 2:case 3:case 4:case 5:break;default:N=3}var F=O;O=N;try{return H()}finally{O=F}},i.unstable_scheduleCallback=function(N,H,F){var Se=i.unstable_now();switch(typeof F=="object"&&F!==null?(F=F.delay,F=typeof F=="number"&&0<F?Se+F:Se):F=Se,N){case 1:var we=-1;break;case 2:we=250;break;case 5:we=1073741823;break;case 4:we=1e4;break;default:we=5e3}return we=F+we,N={id:j++,callback:H,priorityLevel:N,startTime:F,expirationTime:we,sortIndex:-1},F>Se?(N.sortIndex=F,r(y,N),d(p)===null&&N===d(y)&&(q?(Q(We),We=-1):q=!0,cn(W,F-Se))):(N.sortIndex=we,r(p,N),L||M||(L=!0,de||(de=!0,zt()))),N},i.unstable_shouldYield=ca,i.unstable_wrapCallback=function(N){var H=O;return function(){var F=O;O=H;try{return N.apply(this,arguments)}finally{O=F}}}}(ku)),ku}var rm;function $0(){return rm||(rm=1,Uu.exports=q0()),Uu.exports}var Lu={exports:{}},ot={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var um;function G0(){if(um)return ot;um=1;var i=Um();function r(p){var y="https://react.dev/errors/"+p;if(1<arguments.length){y+="?args[]="+encodeURIComponent(arguments[1]);for(var j=2;j<arguments.length;j++)y+="&args[]="+encodeURIComponent(arguments[j])}return"Minified React error #"+p+"; visit "+y+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function d(){}var u={d:{f:d,r:function(){throw Error(r(522))},D:d,C:d,L:d,m:d,X:d,S:d,M:d},p:0,findDOMNode:null},o=Symbol.for("react.portal");function f(p,y,j){var E=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:o,key:E==null?null:""+E,children:p,containerInfo:y,implementation:j}}var m=i.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function g(p,y){if(p==="font")return"";if(typeof y=="string")return y==="use-credentials"?y:""}return ot.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=u,ot.createPortal=function(p,y){var j=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!y||y.nodeType!==1&&y.nodeType!==9&&y.nodeType!==11)throw Error(r(299));return f(p,y,null,j)},ot.flushSync=function(p){var y=m.T,j=u.p;try{if(m.T=null,u.p=2,p)return p()}finally{m.T=y,u.p=j,u.d.f()}},ot.preconnect=function(p,y){typeof p=="string"&&(y?(y=y.crossOrigin,y=typeof y=="string"?y==="use-credentials"?y:"":void 0):y=null,u.d.C(p,y))},ot.prefetchDNS=function(p){typeof p=="string"&&u.d.D(p)},ot.preinit=function(p,y){if(typeof p=="string"&&y&&typeof y.as=="string"){var j=y.as,E=g(j,y.crossOrigin),O=typeof y.integrity=="string"?y.integrity:void 0,M=typeof y.fetchPriority=="string"?y.fetchPriority:void 0;j==="style"?u.d.S(p,typeof y.precedence=="string"?y.precedence:void 0,{crossOrigin:E,integrity:O,fetchPriority:M}):j==="script"&&u.d.X(p,{crossOrigin:E,integrity:O,fetchPriority:M,nonce:typeof y.nonce=="string"?y.nonce:void 0})}},ot.preinitModule=function(p,y){if(typeof p=="string")if(typeof y=="object"&&y!==null){if(y.as==null||y.as==="script"){var j=g(y.as,y.crossOrigin);u.d.M(p,{crossOrigin:j,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0})}}else y==null&&u.d.M(p)},ot.preload=function(p,y){if(typeof p=="string"&&typeof y=="object"&&y!==null&&typeof y.as=="string"){var j=y.as,E=g(j,y.crossOrigin);u.d.L(p,j,{crossOrigin:E,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0,type:typeof y.type=="string"?y.type:void 0,fetchPriority:typeof y.fetchPriority=="string"?y.fetchPriority:void 0,referrerPolicy:typeof y.referrerPolicy=="string"?y.referrerPolicy:void 0,imageSrcSet:typeof y.imageSrcSet=="string"?y.imageSrcSet:void 0,imageSizes:typeof y.imageSizes=="string"?y.imageSizes:void 0,media:typeof y.media=="string"?y.media:void 0})}},ot.preloadModule=function(p,y){if(typeof p=="string")if(y){var j=g(y.as,y.crossOrigin);u.d.m(p,{as:typeof y.as=="string"&&y.as!=="script"?y.as:void 0,crossOrigin:j,integrity:typeof y.integrity=="string"?y.integrity:void 0})}else u.d.m(p)},ot.requestFormReset=function(p){u.d.r(p)},ot.unstable_batchedUpdates=function(p,y){return p(y)},ot.useFormState=function(p,y,j){return m.H.useFormState(p,y,j)},ot.useFormStatus=function(){return m.H.useHostTransitionStatus()},ot.version="19.1.0",ot}var om;function Zm(){if(om)return Lu.exports;om=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(r){console.error(r)}}return i(),Lu.exports=G0(),Lu.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var dm;function Y0(){if(dm)return wi;dm=1;var i=$0(),r=Um(),d=Zm();function u(e){var t="https://react.dev/errors/"+e;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var n=2;n<arguments.length;n++)t+="&args[]="+encodeURIComponent(arguments[n])}return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function o(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function f(e){var t=e,n=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do t=e,(t.flags&4098)!==0&&(n=t.return),e=t.return;while(e)}return t.tag===3?n:null}function m(e){if(e.tag===13){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function g(e){if(f(e)!==e)throw Error(u(188))}function p(e){var t=e.alternate;if(!t){if(t=f(e),t===null)throw Error(u(188));return t!==e?null:e}for(var n=e,a=t;;){var s=n.return;if(s===null)break;var c=s.alternate;if(c===null){if(a=s.return,a!==null){n=a;continue}break}if(s.child===c.child){for(c=s.child;c;){if(c===n)return g(s),e;if(c===a)return g(s),t;c=c.sibling}throw Error(u(188))}if(n.return!==a.return)n=s,a=c;else{for(var h=!1,x=s.child;x;){if(x===n){h=!0,n=s,a=c;break}if(x===a){h=!0,a=s,n=c;break}x=x.sibling}if(!h){for(x=c.child;x;){if(x===n){h=!0,n=c,a=s;break}if(x===a){h=!0,a=c,n=s;break}x=x.sibling}if(!h)throw Error(u(189))}}if(n.alternate!==a)throw Error(u(190))}if(n.tag!==3)throw Error(u(188));return n.stateNode.current===n?e:t}function y(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e;for(e=e.child;e!==null;){if(t=y(e),t!==null)return t;e=e.sibling}return null}var j=Object.assign,E=Symbol.for("react.element"),O=Symbol.for("react.transitional.element"),M=Symbol.for("react.portal"),L=Symbol.for("react.fragment"),q=Symbol.for("react.strict_mode"),U=Symbol.for("react.profiler"),G=Symbol.for("react.provider"),Q=Symbol.for("react.consumer"),be=Symbol.for("react.context"),te=Symbol.for("react.forward_ref"),W=Symbol.for("react.suspense"),de=Symbol.for("react.suspense_list"),We=Symbol.for("react.memo"),bt=Symbol.for("react.lazy"),Re=Symbol.for("react.activity"),ca=Symbol.for("react.memo_cache_sentinel"),za=Symbol.iterator;function zt(e){return e===null||typeof e!="object"?null:(e=za&&e[za]||e["@@iterator"],typeof e=="function"?e:null)}var qi=Symbol.for("react.client.reference");function Tl(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===qi?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case L:return"Fragment";case U:return"Profiler";case q:return"StrictMode";case W:return"Suspense";case de:return"SuspenseList";case Re:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case M:return"Portal";case be:return(e.displayName||"Context")+".Provider";case Q:return(e._context.displayName||"Context")+".Consumer";case te:var t=e.render;return e=e.displayName,e||(e=t.displayName||t.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case We:return t=e.displayName||null,t!==null?t:Tl(e.type)||"Memo";case bt:t=e._payload,e=e._init;try{return Tl(e(t))}catch{}}return null}var cn=Array.isArray,N=r.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,H=d.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,F={pending:!1,data:null,method:null,action:null},Se=[],we=-1;function ft(e){return{current:e}}function Ae(e){0>we||(e.current=Se[we],Se[we]=null,we--)}function me(e,t){we++,Se[we]=e.current,e.current=t}var Ie=ft(null),Jt=ft(null),Mn=ft(null),$i=ft(null);function Gi(e,t){switch(me(Mn,t),me(Jt,e),me(Ie,null),t.nodeType){case 9:case 11:e=(e=t.documentElement)&&(e=e.namespaceURI)?Rh(e):0;break;default:if(e=t.tagName,t=t.namespaceURI)t=Rh(t),e=Uh(t,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}Ae(Ie),me(Ie,e)}function Ba(){Ae(Ie),Ae(Jt),Ae(Mn)}function vc(e){e.memoizedState!==null&&me($i,e);var t=Ie.current,n=Uh(t,e.type);t!==n&&(me(Jt,e),me(Ie,n))}function Yi(e){Jt.current===e&&(Ae(Ie),Ae(Jt)),$i.current===e&&(Ae($i),yi._currentValue=F)}var jc=Object.prototype.hasOwnProperty,bc=i.unstable_scheduleCallback,Sc=i.unstable_cancelCallback,wx=i.unstable_shouldYield,_x=i.unstable_requestPaint,Ft=i.unstable_now,Tx=i.unstable_getCurrentPriorityLevel,mo=i.unstable_ImmediatePriority,xo=i.unstable_UserBlockingPriority,Xi=i.unstable_NormalPriority,Cx=i.unstable_LowPriority,go=i.unstable_IdlePriority,Ax=i.log,Ex=i.unstable_setDisableYieldValue,Cl=null,St=null;function zn(e){if(typeof Ax=="function"&&Ex(e),St&&typeof St.setStrictMode=="function")try{St.setStrictMode(Cl,e)}catch{}}var wt=Math.clz32?Math.clz32:Mx,Dx=Math.log,Ox=Math.LN2;function Mx(e){return e>>>=0,e===0?32:31-(Dx(e)/Ox|0)|0}var Qi=256,Vi=4194304;function ra(e){var t=e&42;if(t!==0)return t;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return e&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function Zi(e,t,n){var a=e.pendingLanes;if(a===0)return 0;var s=0,c=e.suspendedLanes,h=e.pingedLanes;e=e.warmLanes;var x=a&134217727;return x!==0?(a=x&~c,a!==0?s=ra(a):(h&=x,h!==0?s=ra(h):n||(n=x&~e,n!==0&&(s=ra(n))))):(x=a&~c,x!==0?s=ra(x):h!==0?s=ra(h):n||(n=a&~e,n!==0&&(s=ra(n)))),s===0?0:t!==0&&t!==s&&(t&c)===0&&(c=s&-s,n=t&-t,c>=n||c===32&&(n&4194048)!==0)?t:s}function Al(e,t){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&t)===0}function zx(e,t){switch(e){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function po(){var e=Qi;return Qi<<=1,(Qi&4194048)===0&&(Qi=256),e}function yo(){var e=Vi;return Vi<<=1,(Vi&62914560)===0&&(Vi=4194304),e}function wc(e){for(var t=[],n=0;31>n;n++)t.push(e);return t}function El(e,t){e.pendingLanes|=t,t!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function Bx(e,t,n,a,s,c){var h=e.pendingLanes;e.pendingLanes=n,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=n,e.entangledLanes&=n,e.errorRecoveryDisabledLanes&=n,e.shellSuspendCounter=0;var x=e.entanglements,v=e.expirationTimes,C=e.hiddenUpdates;for(n=h&~n;0<n;){var z=31-wt(n),R=1<<z;x[z]=0,v[z]=-1;var A=C[z];if(A!==null)for(C[z]=null,z=0;z<A.length;z++){var D=A[z];D!==null&&(D.lane&=-536870913)}n&=~R}a!==0&&vo(e,a,0),c!==0&&s===0&&e.tag!==0&&(e.suspendedLanes|=c&~(h&~t))}function vo(e,t,n){e.pendingLanes|=t,e.suspendedLanes&=~t;var a=31-wt(t);e.entangledLanes|=t,e.entanglements[a]=e.entanglements[a]|1073741824|n&4194090}function jo(e,t){var n=e.entangledLanes|=t;for(e=e.entanglements;n;){var a=31-wt(n),s=1<<a;s&t|e[a]&t&&(e[a]|=t),n&=~s}}function _c(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function Tc(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function bo(){var e=H.p;return e!==0?e:(e=window.event,e===void 0?32:tm(e.type))}function Nx(e,t){var n=H.p;try{return H.p=e,t()}finally{H.p=n}}var Bn=Math.random().toString(36).slice(2),rt="__reactFiber$"+Bn,mt="__reactProps$"+Bn,Na="__reactContainer$"+Bn,Cc="__reactEvents$"+Bn,Rx="__reactListeners$"+Bn,Ux="__reactHandles$"+Bn,So="__reactResources$"+Bn,Dl="__reactMarker$"+Bn;function Ac(e){delete e[rt],delete e[mt],delete e[Cc],delete e[Rx],delete e[Ux]}function Ra(e){var t=e[rt];if(t)return t;for(var n=e.parentNode;n;){if(t=n[Na]||n[rt]){if(n=t.alternate,t.child!==null||n!==null&&n.child!==null)for(e=qh(e);e!==null;){if(n=e[rt])return n;e=qh(e)}return t}e=n,n=e.parentNode}return null}function Ua(e){if(e=e[rt]||e[Na]){var t=e.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return e}return null}function Ol(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e.stateNode;throw Error(u(33))}function ka(e){var t=e[So];return t||(t=e[So]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Pe(e){e[Dl]=!0}var wo=new Set,_o={};function ua(e,t){La(e,t),La(e+"Capture",t)}function La(e,t){for(_o[e]=t,e=0;e<t.length;e++)wo.add(t[e])}var kx=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),To={},Co={};function Lx(e){return jc.call(Co,e)?!0:jc.call(To,e)?!1:kx.test(e)?Co[e]=!0:(To[e]=!0,!1)}function Ki(e,t,n){if(Lx(t))if(n===null)e.removeAttribute(t);else{switch(typeof n){case"undefined":case"function":case"symbol":e.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){e.removeAttribute(t);return}}e.setAttribute(t,""+n)}}function Ji(e,t,n){if(n===null)e.removeAttribute(t);else{switch(typeof n){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(t);return}e.setAttribute(t,""+n)}}function rn(e,t,n,a){if(a===null)e.removeAttribute(n);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(n);return}e.setAttributeNS(t,n,""+a)}}var Ec,Ao;function Ha(e){if(Ec===void 0)try{throw Error()}catch(n){var t=n.stack.trim().match(/\n( *(at )?)/);Ec=t&&t[1]||"",Ao=-1<n.stack.indexOf(`
    at`)?" (<anonymous>)":-1<n.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Ec+e+Ao}var Dc=!1;function Oc(e,t){if(!e||Dc)return"";Dc=!0;var n=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var R=function(){throw Error()};if(Object.defineProperty(R.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(R,[])}catch(D){var A=D}Reflect.construct(e,[],R)}else{try{R.call()}catch(D){A=D}e.call(R.prototype)}}else{try{throw Error()}catch(D){A=D}(R=e())&&typeof R.catch=="function"&&R.catch(function(){})}}catch(D){if(D&&A&&typeof D.stack=="string")return[D.stack,A.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var s=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");s&&s.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var c=a.DetermineComponentFrameRoot(),h=c[0],x=c[1];if(h&&x){var v=h.split(`
`),C=x.split(`
`);for(s=a=0;a<v.length&&!v[a].includes("DetermineComponentFrameRoot");)a++;for(;s<C.length&&!C[s].includes("DetermineComponentFrameRoot");)s++;if(a===v.length||s===C.length)for(a=v.length-1,s=C.length-1;1<=a&&0<=s&&v[a]!==C[s];)s--;for(;1<=a&&0<=s;a--,s--)if(v[a]!==C[s]){if(a!==1||s!==1)do if(a--,s--,0>s||v[a]!==C[s]){var z=`
`+v[a].replace(" at new "," at ");return e.displayName&&z.includes("<anonymous>")&&(z=z.replace("<anonymous>",e.displayName)),z}while(1<=a&&0<=s);break}}}finally{Dc=!1,Error.prepareStackTrace=n}return(n=e?e.displayName||e.name:"")?Ha(n):""}function Hx(e){switch(e.tag){case 26:case 27:case 5:return Ha(e.type);case 16:return Ha("Lazy");case 13:return Ha("Suspense");case 19:return Ha("SuspenseList");case 0:case 15:return Oc(e.type,!1);case 11:return Oc(e.type.render,!1);case 1:return Oc(e.type,!0);case 31:return Ha("Activity");default:return""}}function Eo(e){try{var t="";do t+=Hx(e),e=e.return;while(e);return t}catch(n){return`
Error generating stack: `+n.message+`
`+n.stack}}function Bt(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function Do(e){var t=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function qx(e){var t=Do(e)?"checked":"value",n=Object.getOwnPropertyDescriptor(e.constructor.prototype,t),a=""+e[t];if(!e.hasOwnProperty(t)&&typeof n<"u"&&typeof n.get=="function"&&typeof n.set=="function"){var s=n.get,c=n.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return s.call(this)},set:function(h){a=""+h,c.call(this,h)}}),Object.defineProperty(e,t,{enumerable:n.enumerable}),{getValue:function(){return a},setValue:function(h){a=""+h},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}function Fi(e){e._valueTracker||(e._valueTracker=qx(e))}function Oo(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var n=t.getValue(),a="";return e&&(a=Do(e)?e.checked?"true":"false":e.value),e=a,e!==n?(t.setValue(e),!0):!1}function Wi(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var $x=/[\n"\\]/g;function Nt(e){return e.replace($x,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function Mc(e,t,n,a,s,c,h,x){e.name="",h!=null&&typeof h!="function"&&typeof h!="symbol"&&typeof h!="boolean"?e.type=h:e.removeAttribute("type"),t!=null?h==="number"?(t===0&&e.value===""||e.value!=t)&&(e.value=""+Bt(t)):e.value!==""+Bt(t)&&(e.value=""+Bt(t)):h!=="submit"&&h!=="reset"||e.removeAttribute("value"),t!=null?zc(e,h,Bt(t)):n!=null?zc(e,h,Bt(n)):a!=null&&e.removeAttribute("value"),s==null&&c!=null&&(e.defaultChecked=!!c),s!=null&&(e.checked=s&&typeof s!="function"&&typeof s!="symbol"),x!=null&&typeof x!="function"&&typeof x!="symbol"&&typeof x!="boolean"?e.name=""+Bt(x):e.removeAttribute("name")}function Mo(e,t,n,a,s,c,h,x){if(c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(e.type=c),t!=null||n!=null){if(!(c!=="submit"&&c!=="reset"||t!=null))return;n=n!=null?""+Bt(n):"",t=t!=null?""+Bt(t):n,x||t===e.value||(e.value=t),e.defaultValue=t}a=a??s,a=typeof a!="function"&&typeof a!="symbol"&&!!a,e.checked=x?e.checked:!!a,e.defaultChecked=!!a,h!=null&&typeof h!="function"&&typeof h!="symbol"&&typeof h!="boolean"&&(e.name=h)}function zc(e,t,n){t==="number"&&Wi(e.ownerDocument)===e||e.defaultValue===""+n||(e.defaultValue=""+n)}function qa(e,t,n,a){if(e=e.options,t){t={};for(var s=0;s<n.length;s++)t["$"+n[s]]=!0;for(n=0;n<e.length;n++)s=t.hasOwnProperty("$"+e[n].value),e[n].selected!==s&&(e[n].selected=s),s&&a&&(e[n].defaultSelected=!0)}else{for(n=""+Bt(n),t=null,s=0;s<e.length;s++){if(e[s].value===n){e[s].selected=!0,a&&(e[s].defaultSelected=!0);return}t!==null||e[s].disabled||(t=e[s])}t!==null&&(t.selected=!0)}}function zo(e,t,n){if(t!=null&&(t=""+Bt(t),t!==e.value&&(e.value=t),n==null)){e.defaultValue!==t&&(e.defaultValue=t);return}e.defaultValue=n!=null?""+Bt(n):""}function Bo(e,t,n,a){if(t==null){if(a!=null){if(n!=null)throw Error(u(92));if(cn(a)){if(1<a.length)throw Error(u(93));a=a[0]}n=a}n==null&&(n=""),t=n}n=Bt(t),e.defaultValue=n,a=e.textContent,a===n&&a!==""&&a!==null&&(e.value=a)}function $a(e,t){if(t){var n=e.firstChild;if(n&&n===e.lastChild&&n.nodeType===3){n.nodeValue=t;return}}e.textContent=t}var Gx=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function No(e,t,n){var a=t.indexOf("--")===0;n==null||typeof n=="boolean"||n===""?a?e.setProperty(t,""):t==="float"?e.cssFloat="":e[t]="":a?e.setProperty(t,n):typeof n!="number"||n===0||Gx.has(t)?t==="float"?e.cssFloat=n:e[t]=(""+n).trim():e[t]=n+"px"}function Ro(e,t,n){if(t!=null&&typeof t!="object")throw Error(u(62));if(e=e.style,n!=null){for(var a in n)!n.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?e.setProperty(a,""):a==="float"?e.cssFloat="":e[a]="");for(var s in t)a=t[s],t.hasOwnProperty(s)&&n[s]!==a&&No(e,s,a)}else for(var c in t)t.hasOwnProperty(c)&&No(e,c,t[c])}function Bc(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Yx=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Xx=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ii(e){return Xx.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}var Nc=null;function Rc(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var Ga=null,Ya=null;function Uo(e){var t=Ua(e);if(t&&(e=t.stateNode)){var n=e[mt]||null;e:switch(e=t.stateNode,t.type){case"input":if(Mc(e,n.value,n.defaultValue,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name),t=n.name,n.type==="radio"&&t!=null){for(n=e;n.parentNode;)n=n.parentNode;for(n=n.querySelectorAll('input[name="'+Nt(""+t)+'"][type="radio"]'),t=0;t<n.length;t++){var a=n[t];if(a!==e&&a.form===e.form){var s=a[mt]||null;if(!s)throw Error(u(90));Mc(a,s.value,s.defaultValue,s.defaultValue,s.checked,s.defaultChecked,s.type,s.name)}}for(t=0;t<n.length;t++)a=n[t],a.form===e.form&&Oo(a)}break e;case"textarea":zo(e,n.value,n.defaultValue);break e;case"select":t=n.value,t!=null&&qa(e,!!n.multiple,t,!1)}}}var Uc=!1;function ko(e,t,n){if(Uc)return e(t,n);Uc=!0;try{var a=e(t);return a}finally{if(Uc=!1,(Ga!==null||Ya!==null)&&(ks(),Ga&&(t=Ga,e=Ya,Ya=Ga=null,Uo(t),e)))for(t=0;t<e.length;t++)Uo(e[t])}}function Ml(e,t){var n=e.stateNode;if(n===null)return null;var a=n[mt]||null;if(a===null)return null;n=a[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(e=e.type,a=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!a;break e;default:e=!1}if(e)return null;if(n&&typeof n!="function")throw Error(u(231,t,typeof n));return n}var un=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),kc=!1;if(un)try{var zl={};Object.defineProperty(zl,"passive",{get:function(){kc=!0}}),window.addEventListener("test",zl,zl),window.removeEventListener("test",zl,zl)}catch{kc=!1}var Nn=null,Lc=null,Pi=null;function Lo(){if(Pi)return Pi;var e,t=Lc,n=t.length,a,s="value"in Nn?Nn.value:Nn.textContent,c=s.length;for(e=0;e<n&&t[e]===s[e];e++);var h=n-e;for(a=1;a<=h&&t[n-a]===s[c-a];a++);return Pi=s.slice(e,1<a?1-a:void 0)}function es(e){var t=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&t===13&&(e=13)):e=t,e===10&&(e=13),32<=e||e===13?e:0}function ts(){return!0}function Ho(){return!1}function xt(e){function t(n,a,s,c,h){this._reactName=n,this._targetInst=s,this.type=a,this.nativeEvent=c,this.target=h,this.currentTarget=null;for(var x in e)e.hasOwnProperty(x)&&(n=e[x],this[x]=n?n(c):c[x]);return this.isDefaultPrevented=(c.defaultPrevented!=null?c.defaultPrevented:c.returnValue===!1)?ts:Ho,this.isPropagationStopped=Ho,this}return j(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var n=this.nativeEvent;n&&(n.preventDefault?n.preventDefault():typeof n.returnValue!="unknown"&&(n.returnValue=!1),this.isDefaultPrevented=ts)},stopPropagation:function(){var n=this.nativeEvent;n&&(n.stopPropagation?n.stopPropagation():typeof n.cancelBubble!="unknown"&&(n.cancelBubble=!0),this.isPropagationStopped=ts)},persist:function(){},isPersistent:ts}),t}var oa={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},ns=xt(oa),Bl=j({},oa,{view:0,detail:0}),Qx=xt(Bl),Hc,qc,Nl,as=j({},Bl,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Gc,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==Nl&&(Nl&&e.type==="mousemove"?(Hc=e.screenX-Nl.screenX,qc=e.screenY-Nl.screenY):qc=Hc=0,Nl=e),Hc)},movementY:function(e){return"movementY"in e?e.movementY:qc}}),qo=xt(as),Vx=j({},as,{dataTransfer:0}),Zx=xt(Vx),Kx=j({},Bl,{relatedTarget:0}),$c=xt(Kx),Jx=j({},oa,{animationName:0,elapsedTime:0,pseudoElement:0}),Fx=xt(Jx),Wx=j({},oa,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),Ix=xt(Wx),Px=j({},oa,{data:0}),$o=xt(Px),eg={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},tg={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},ng={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function ag(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):(e=ng[e])?!!t[e]:!1}function Gc(){return ag}var lg=j({},Bl,{key:function(e){if(e.key){var t=eg[e.key]||e.key;if(t!=="Unidentified")return t}return e.type==="keypress"?(e=es(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?tg[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Gc,charCode:function(e){return e.type==="keypress"?es(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?es(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),ig=xt(lg),sg=j({},as,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Go=xt(sg),cg=j({},Bl,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Gc}),rg=xt(cg),ug=j({},oa,{propertyName:0,elapsedTime:0,pseudoElement:0}),og=xt(ug),dg=j({},as,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),fg=xt(dg),hg=j({},oa,{newState:0,oldState:0}),mg=xt(hg),xg=[9,13,27,32],Yc=un&&"CompositionEvent"in window,Rl=null;un&&"documentMode"in document&&(Rl=document.documentMode);var gg=un&&"TextEvent"in window&&!Rl,Yo=un&&(!Yc||Rl&&8<Rl&&11>=Rl),Xo=" ",Qo=!1;function Vo(e,t){switch(e){case"keyup":return xg.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Zo(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var Xa=!1;function pg(e,t){switch(e){case"compositionend":return Zo(t);case"keypress":return t.which!==32?null:(Qo=!0,Xo);case"textInput":return e=t.data,e===Xo&&Qo?null:e;default:return null}}function yg(e,t){if(Xa)return e==="compositionend"||!Yc&&Vo(e,t)?(e=Lo(),Pi=Lc=Nn=null,Xa=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Yo&&t.locale!=="ko"?null:t.data;default:return null}}var vg={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Ko(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t==="input"?!!vg[e.type]:t==="textarea"}function Jo(e,t,n,a){Ga?Ya?Ya.push(a):Ya=[a]:Ga=a,t=Ys(t,"onChange"),0<t.length&&(n=new ns("onChange","change",null,n,a),e.push({event:n,listeners:t}))}var Ul=null,kl=null;function jg(e){Oh(e,0)}function ls(e){var t=Ol(e);if(Oo(t))return e}function Fo(e,t){if(e==="change")return t}var Wo=!1;if(un){var Xc;if(un){var Qc="oninput"in document;if(!Qc){var Io=document.createElement("div");Io.setAttribute("oninput","return;"),Qc=typeof Io.oninput=="function"}Xc=Qc}else Xc=!1;Wo=Xc&&(!document.documentMode||9<document.documentMode)}function Po(){Ul&&(Ul.detachEvent("onpropertychange",ed),kl=Ul=null)}function ed(e){if(e.propertyName==="value"&&ls(kl)){var t=[];Jo(t,kl,e,Rc(e)),ko(jg,t)}}function bg(e,t,n){e==="focusin"?(Po(),Ul=t,kl=n,Ul.attachEvent("onpropertychange",ed)):e==="focusout"&&Po()}function Sg(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return ls(kl)}function wg(e,t){if(e==="click")return ls(t)}function _g(e,t){if(e==="input"||e==="change")return ls(t)}function Tg(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var _t=typeof Object.is=="function"?Object.is:Tg;function Ll(e,t){if(_t(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;var n=Object.keys(e),a=Object.keys(t);if(n.length!==a.length)return!1;for(a=0;a<n.length;a++){var s=n[a];if(!jc.call(t,s)||!_t(e[s],t[s]))return!1}return!0}function td(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function nd(e,t){var n=td(e);e=0;for(var a;n;){if(n.nodeType===3){if(a=e+n.textContent.length,e<=t&&a>=t)return{node:n,offset:t-e};e=a}e:{for(;n;){if(n.nextSibling){n=n.nextSibling;break e}n=n.parentNode}n=void 0}n=td(n)}}function ad(e,t){return e&&t?e===t?!0:e&&e.nodeType===3?!1:t&&t.nodeType===3?ad(e,t.parentNode):"contains"in e?e.contains(t):e.compareDocumentPosition?!!(e.compareDocumentPosition(t)&16):!1:!1}function ld(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var t=Wi(e.document);t instanceof e.HTMLIFrameElement;){try{var n=typeof t.contentWindow.location.href=="string"}catch{n=!1}if(n)e=t.contentWindow;else break;t=Wi(e.document)}return t}function Vc(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&(t==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||t==="textarea"||e.contentEditable==="true")}var Cg=un&&"documentMode"in document&&11>=document.documentMode,Qa=null,Zc=null,Hl=null,Kc=!1;function id(e,t,n){var a=n.window===n?n.document:n.nodeType===9?n:n.ownerDocument;Kc||Qa==null||Qa!==Wi(a)||(a=Qa,"selectionStart"in a&&Vc(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Hl&&Ll(Hl,a)||(Hl=a,a=Ys(Zc,"onSelect"),0<a.length&&(t=new ns("onSelect","select",null,t,n),e.push({event:t,listeners:a}),t.target=Qa)))}function da(e,t){var n={};return n[e.toLowerCase()]=t.toLowerCase(),n["Webkit"+e]="webkit"+t,n["Moz"+e]="moz"+t,n}var Va={animationend:da("Animation","AnimationEnd"),animationiteration:da("Animation","AnimationIteration"),animationstart:da("Animation","AnimationStart"),transitionrun:da("Transition","TransitionRun"),transitionstart:da("Transition","TransitionStart"),transitioncancel:da("Transition","TransitionCancel"),transitionend:da("Transition","TransitionEnd")},Jc={},sd={};un&&(sd=document.createElement("div").style,"AnimationEvent"in window||(delete Va.animationend.animation,delete Va.animationiteration.animation,delete Va.animationstart.animation),"TransitionEvent"in window||delete Va.transitionend.transition);function fa(e){if(Jc[e])return Jc[e];if(!Va[e])return e;var t=Va[e],n;for(n in t)if(t.hasOwnProperty(n)&&n in sd)return Jc[e]=t[n];return e}var cd=fa("animationend"),rd=fa("animationiteration"),ud=fa("animationstart"),Ag=fa("transitionrun"),Eg=fa("transitionstart"),Dg=fa("transitioncancel"),od=fa("transitionend"),dd=new Map,Fc="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Fc.push("scrollEnd");function Xt(e,t){dd.set(e,t),ua(t,[e])}var fd=new WeakMap;function Rt(e,t){if(typeof e=="object"&&e!==null){var n=fd.get(e);return n!==void 0?n:(t={value:e,source:t,stack:Eo(t)},fd.set(e,t),t)}return{value:e,source:t,stack:Eo(t)}}var Ut=[],Za=0,Wc=0;function is(){for(var e=Za,t=Wc=Za=0;t<e;){var n=Ut[t];Ut[t++]=null;var a=Ut[t];Ut[t++]=null;var s=Ut[t];Ut[t++]=null;var c=Ut[t];if(Ut[t++]=null,a!==null&&s!==null){var h=a.pending;h===null?s.next=s:(s.next=h.next,h.next=s),a.pending=s}c!==0&&hd(n,s,c)}}function ss(e,t,n,a){Ut[Za++]=e,Ut[Za++]=t,Ut[Za++]=n,Ut[Za++]=a,Wc|=a,e.lanes|=a,e=e.alternate,e!==null&&(e.lanes|=a)}function Ic(e,t,n,a){return ss(e,t,n,a),cs(e)}function Ka(e,t){return ss(e,null,null,t),cs(e)}function hd(e,t,n){e.lanes|=n;var a=e.alternate;a!==null&&(a.lanes|=n);for(var s=!1,c=e.return;c!==null;)c.childLanes|=n,a=c.alternate,a!==null&&(a.childLanes|=n),c.tag===22&&(e=c.stateNode,e===null||e._visibility&1||(s=!0)),e=c,c=c.return;return e.tag===3?(c=e.stateNode,s&&t!==null&&(s=31-wt(n),e=c.hiddenUpdates,a=e[s],a===null?e[s]=[t]:a.push(t),t.lane=n|536870912),c):null}function cs(e){if(50<oi)throw oi=0,lu=null,Error(u(185));for(var t=e.return;t!==null;)e=t,t=e.return;return e.tag===3?e.stateNode:null}var Ja={};function Og(e,t,n,a){this.tag=e,this.key=n,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Tt(e,t,n,a){return new Og(e,t,n,a)}function Pc(e){return e=e.prototype,!(!e||!e.isReactComponent)}function on(e,t){var n=e.alternate;return n===null?(n=Tt(e.tag,t,e.key,e.mode),n.elementType=e.elementType,n.type=e.type,n.stateNode=e.stateNode,n.alternate=e,e.alternate=n):(n.pendingProps=t,n.type=e.type,n.flags=0,n.subtreeFlags=0,n.deletions=null),n.flags=e.flags&65011712,n.childLanes=e.childLanes,n.lanes=e.lanes,n.child=e.child,n.memoizedProps=e.memoizedProps,n.memoizedState=e.memoizedState,n.updateQueue=e.updateQueue,t=e.dependencies,n.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},n.sibling=e.sibling,n.index=e.index,n.ref=e.ref,n.refCleanup=e.refCleanup,n}function md(e,t){e.flags&=65011714;var n=e.alternate;return n===null?(e.childLanes=0,e.lanes=t,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=n.childLanes,e.lanes=n.lanes,e.child=n.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=n.memoizedProps,e.memoizedState=n.memoizedState,e.updateQueue=n.updateQueue,e.type=n.type,t=n.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),e}function rs(e,t,n,a,s,c){var h=0;if(a=e,typeof e=="function")Pc(e)&&(h=1);else if(typeof e=="string")h=zp(e,n,Ie.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case Re:return e=Tt(31,n,t,s),e.elementType=Re,e.lanes=c,e;case L:return ha(n.children,s,c,t);case q:h=8,s|=24;break;case U:return e=Tt(12,n,t,s|2),e.elementType=U,e.lanes=c,e;case W:return e=Tt(13,n,t,s),e.elementType=W,e.lanes=c,e;case de:return e=Tt(19,n,t,s),e.elementType=de,e.lanes=c,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case G:case be:h=10;break e;case Q:h=9;break e;case te:h=11;break e;case We:h=14;break e;case bt:h=16,a=null;break e}h=29,n=Error(u(130,e===null?"null":typeof e,"")),a=null}return t=Tt(h,n,t,s),t.elementType=e,t.type=a,t.lanes=c,t}function ha(e,t,n,a){return e=Tt(7,e,a,t),e.lanes=n,e}function er(e,t,n){return e=Tt(6,e,null,t),e.lanes=n,e}function tr(e,t,n){return t=Tt(4,e.children!==null?e.children:[],e.key,t),t.lanes=n,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}var Fa=[],Wa=0,us=null,os=0,kt=[],Lt=0,ma=null,dn=1,fn="";function xa(e,t){Fa[Wa++]=os,Fa[Wa++]=us,us=e,os=t}function xd(e,t,n){kt[Lt++]=dn,kt[Lt++]=fn,kt[Lt++]=ma,ma=e;var a=dn;e=fn;var s=32-wt(a)-1;a&=~(1<<s),n+=1;var c=32-wt(t)+s;if(30<c){var h=s-s%5;c=(a&(1<<h)-1).toString(32),a>>=h,s-=h,dn=1<<32-wt(t)+s|n<<s|a,fn=c+e}else dn=1<<c|n<<s|a,fn=e}function nr(e){e.return!==null&&(xa(e,1),xd(e,1,0))}function ar(e){for(;e===us;)us=Fa[--Wa],Fa[Wa]=null,os=Fa[--Wa],Fa[Wa]=null;for(;e===ma;)ma=kt[--Lt],kt[Lt]=null,fn=kt[--Lt],kt[Lt]=null,dn=kt[--Lt],kt[Lt]=null}var ht=null,Be=null,ce=!1,ga=null,Wt=!1,lr=Error(u(519));function pa(e){var t=Error(u(418,""));throw Gl(Rt(t,e)),lr}function gd(e){var t=e.stateNode,n=e.type,a=e.memoizedProps;switch(t[rt]=e,t[mt]=a,n){case"dialog":ae("cancel",t),ae("close",t);break;case"iframe":case"object":case"embed":ae("load",t);break;case"video":case"audio":for(n=0;n<fi.length;n++)ae(fi[n],t);break;case"source":ae("error",t);break;case"img":case"image":case"link":ae("error",t),ae("load",t);break;case"details":ae("toggle",t);break;case"input":ae("invalid",t),Mo(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0),Fi(t);break;case"select":ae("invalid",t);break;case"textarea":ae("invalid",t),Bo(t,a.value,a.defaultValue,a.children),Fi(t)}n=a.children,typeof n!="string"&&typeof n!="number"&&typeof n!="bigint"||t.textContent===""+n||a.suppressHydrationWarning===!0||Nh(t.textContent,n)?(a.popover!=null&&(ae("beforetoggle",t),ae("toggle",t)),a.onScroll!=null&&ae("scroll",t),a.onScrollEnd!=null&&ae("scrollend",t),a.onClick!=null&&(t.onclick=Xs),t=!0):t=!1,t||pa(e)}function pd(e){for(ht=e.return;ht;)switch(ht.tag){case 5:case 13:Wt=!1;return;case 27:case 3:Wt=!0;return;default:ht=ht.return}}function ql(e){if(e!==ht)return!1;if(!ce)return pd(e),ce=!0,!1;var t=e.tag,n;if((n=t!==3&&t!==27)&&((n=t===5)&&(n=e.type,n=!(n!=="form"&&n!=="button")||ju(e.type,e.memoizedProps)),n=!n),n&&Be&&pa(e),pd(e),t===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(u(317));e:{for(e=e.nextSibling,t=0;e;){if(e.nodeType===8)if(n=e.data,n==="/$"){if(t===0){Be=Vt(e.nextSibling);break e}t--}else n!=="$"&&n!=="$!"&&n!=="$?"||t++;e=e.nextSibling}Be=null}}else t===27?(t=Be,Fn(e.type)?(e=_u,_u=null,Be=e):Be=t):Be=ht?Vt(e.stateNode.nextSibling):null;return!0}function $l(){Be=ht=null,ce=!1}function yd(){var e=ga;return e!==null&&(yt===null?yt=e:yt.push.apply(yt,e),ga=null),e}function Gl(e){ga===null?ga=[e]:ga.push(e)}var ir=ft(null),ya=null,hn=null;function Rn(e,t,n){me(ir,t._currentValue),t._currentValue=n}function mn(e){e._currentValue=ir.current,Ae(ir)}function sr(e,t,n){for(;e!==null;){var a=e.alternate;if((e.childLanes&t)!==t?(e.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),e===n)break;e=e.return}}function cr(e,t,n,a){var s=e.child;for(s!==null&&(s.return=e);s!==null;){var c=s.dependencies;if(c!==null){var h=s.child;c=c.firstContext;e:for(;c!==null;){var x=c;c=s;for(var v=0;v<t.length;v++)if(x.context===t[v]){c.lanes|=n,x=c.alternate,x!==null&&(x.lanes|=n),sr(c.return,n,e),a||(h=null);break e}c=x.next}}else if(s.tag===18){if(h=s.return,h===null)throw Error(u(341));h.lanes|=n,c=h.alternate,c!==null&&(c.lanes|=n),sr(h,n,e),h=null}else h=s.child;if(h!==null)h.return=s;else for(h=s;h!==null;){if(h===e){h=null;break}if(s=h.sibling,s!==null){s.return=h.return,h=s;break}h=h.return}s=h}}function Yl(e,t,n,a){e=null;for(var s=t,c=!1;s!==null;){if(!c){if((s.flags&524288)!==0)c=!0;else if((s.flags&262144)!==0)break}if(s.tag===10){var h=s.alternate;if(h===null)throw Error(u(387));if(h=h.memoizedProps,h!==null){var x=s.type;_t(s.pendingProps.value,h.value)||(e!==null?e.push(x):e=[x])}}else if(s===$i.current){if(h=s.alternate,h===null)throw Error(u(387));h.memoizedState.memoizedState!==s.memoizedState.memoizedState&&(e!==null?e.push(yi):e=[yi])}s=s.return}e!==null&&cr(t,e,n,a),t.flags|=262144}function ds(e){for(e=e.firstContext;e!==null;){if(!_t(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function va(e){ya=e,hn=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function ut(e){return vd(ya,e)}function fs(e,t){return ya===null&&va(e),vd(e,t)}function vd(e,t){var n=t._currentValue;if(t={context:t,memoizedValue:n,next:null},hn===null){if(e===null)throw Error(u(308));hn=t,e.dependencies={lanes:0,firstContext:t},e.flags|=524288}else hn=hn.next=t;return n}var Mg=typeof AbortController<"u"?AbortController:function(){var e=[],t=this.signal={aborted:!1,addEventListener:function(n,a){e.push(a)}};this.abort=function(){t.aborted=!0,e.forEach(function(n){return n()})}},zg=i.unstable_scheduleCallback,Bg=i.unstable_NormalPriority,Ve={$$typeof:be,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function rr(){return{controller:new Mg,data:new Map,refCount:0}}function Xl(e){e.refCount--,e.refCount===0&&zg(Bg,function(){e.controller.abort()})}var Ql=null,ur=0,Ia=0,Pa=null;function Ng(e,t){if(Ql===null){var n=Ql=[];ur=0,Ia=du(),Pa={status:"pending",value:void 0,then:function(a){n.push(a)}}}return ur++,t.then(jd,jd),t}function jd(){if(--ur===0&&Ql!==null){Pa!==null&&(Pa.status="fulfilled");var e=Ql;Ql=null,Ia=0,Pa=null;for(var t=0;t<e.length;t++)(0,e[t])()}}function Rg(e,t){var n=[],a={status:"pending",value:null,reason:null,then:function(s){n.push(s)}};return e.then(function(){a.status="fulfilled",a.value=t;for(var s=0;s<n.length;s++)(0,n[s])(t)},function(s){for(a.status="rejected",a.reason=s,s=0;s<n.length;s++)(0,n[s])(void 0)}),a}var bd=N.S;N.S=function(e,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&Ng(e,t),bd!==null&&bd(e,t)};var ja=ft(null);function or(){var e=ja.current;return e!==null?e:ve.pooledCache}function hs(e,t){t===null?me(ja,ja.current):me(ja,t.pool)}function Sd(){var e=or();return e===null?null:{parent:Ve._currentValue,pool:e}}var Vl=Error(u(460)),wd=Error(u(474)),ms=Error(u(542)),dr={then:function(){}};function _d(e){return e=e.status,e==="fulfilled"||e==="rejected"}function xs(){}function Td(e,t,n){switch(n=e[n],n===void 0?e.push(t):n!==t&&(t.then(xs,xs),t=n),t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Ad(e),e;default:if(typeof t.status=="string")t.then(xs,xs);else{if(e=ve,e!==null&&100<e.shellSuspendCounter)throw Error(u(482));e=t,e.status="pending",e.then(function(a){if(t.status==="pending"){var s=t;s.status="fulfilled",s.value=a}},function(a){if(t.status==="pending"){var s=t;s.status="rejected",s.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,Ad(e),e}throw Zl=t,Vl}}var Zl=null;function Cd(){if(Zl===null)throw Error(u(459));var e=Zl;return Zl=null,e}function Ad(e){if(e===Vl||e===ms)throw Error(u(483))}var Un=!1;function fr(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function hr(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function kn(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function Ln(e,t,n){var a=e.updateQueue;if(a===null)return null;if(a=a.shared,(fe&2)!==0){var s=a.pending;return s===null?t.next=t:(t.next=s.next,s.next=t),a.pending=t,t=cs(e),hd(e,null,n),t}return ss(e,a,t,n),cs(e)}function Kl(e,t,n){if(t=t.updateQueue,t!==null&&(t=t.shared,(n&4194048)!==0)){var a=t.lanes;a&=e.pendingLanes,n|=a,t.lanes=n,jo(e,n)}}function mr(e,t){var n=e.updateQueue,a=e.alternate;if(a!==null&&(a=a.updateQueue,n===a)){var s=null,c=null;if(n=n.firstBaseUpdate,n!==null){do{var h={lane:n.lane,tag:n.tag,payload:n.payload,callback:null,next:null};c===null?s=c=h:c=c.next=h,n=n.next}while(n!==null);c===null?s=c=t:c=c.next=t}else s=c=t;n={baseState:a.baseState,firstBaseUpdate:s,lastBaseUpdate:c,shared:a.shared,callbacks:a.callbacks},e.updateQueue=n;return}e=n.lastBaseUpdate,e===null?n.firstBaseUpdate=t:e.next=t,n.lastBaseUpdate=t}var xr=!1;function Jl(){if(xr){var e=Pa;if(e!==null)throw e}}function Fl(e,t,n,a){xr=!1;var s=e.updateQueue;Un=!1;var c=s.firstBaseUpdate,h=s.lastBaseUpdate,x=s.shared.pending;if(x!==null){s.shared.pending=null;var v=x,C=v.next;v.next=null,h===null?c=C:h.next=C,h=v;var z=e.alternate;z!==null&&(z=z.updateQueue,x=z.lastBaseUpdate,x!==h&&(x===null?z.firstBaseUpdate=C:x.next=C,z.lastBaseUpdate=v))}if(c!==null){var R=s.baseState;h=0,z=C=v=null,x=c;do{var A=x.lane&-536870913,D=A!==x.lane;if(D?(le&A)===A:(a&A)===A){A!==0&&A===Ia&&(xr=!0),z!==null&&(z=z.next={lane:0,tag:x.tag,payload:x.payload,callback:null,next:null});e:{var J=e,V=x;A=t;var pe=n;switch(V.tag){case 1:if(J=V.payload,typeof J=="function"){R=J.call(pe,R,A);break e}R=J;break e;case 3:J.flags=J.flags&-65537|128;case 0:if(J=V.payload,A=typeof J=="function"?J.call(pe,R,A):J,A==null)break e;R=j({},R,A);break e;case 2:Un=!0}}A=x.callback,A!==null&&(e.flags|=64,D&&(e.flags|=8192),D=s.callbacks,D===null?s.callbacks=[A]:D.push(A))}else D={lane:A,tag:x.tag,payload:x.payload,callback:x.callback,next:null},z===null?(C=z=D,v=R):z=z.next=D,h|=A;if(x=x.next,x===null){if(x=s.shared.pending,x===null)break;D=x,x=D.next,D.next=null,s.lastBaseUpdate=D,s.shared.pending=null}}while(!0);z===null&&(v=R),s.baseState=v,s.firstBaseUpdate=C,s.lastBaseUpdate=z,c===null&&(s.shared.lanes=0),Vn|=h,e.lanes=h,e.memoizedState=R}}function Ed(e,t){if(typeof e!="function")throw Error(u(191,e));e.call(t)}function Dd(e,t){var n=e.callbacks;if(n!==null)for(e.callbacks=null,e=0;e<n.length;e++)Ed(n[e],t)}var el=ft(null),gs=ft(0);function Od(e,t){e=bn,me(gs,e),me(el,t),bn=e|t.baseLanes}function gr(){me(gs,bn),me(el,el.current)}function pr(){bn=gs.current,Ae(el),Ae(gs)}var Hn=0,P=null,xe=null,Ge=null,ps=!1,tl=!1,ba=!1,ys=0,Wl=0,nl=null,Ug=0;function Ue(){throw Error(u(321))}function yr(e,t){if(t===null)return!1;for(var n=0;n<t.length&&n<e.length;n++)if(!_t(e[n],t[n]))return!1;return!0}function vr(e,t,n,a,s,c){return Hn=c,P=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,N.H=e===null||e.memoizedState===null?mf:xf,ba=!1,c=n(a,s),ba=!1,tl&&(c=zd(t,n,a,s)),Md(e),c}function Md(e){N.H=_s;var t=xe!==null&&xe.next!==null;if(Hn=0,Ge=xe=P=null,ps=!1,Wl=0,nl=null,t)throw Error(u(300));e===null||et||(e=e.dependencies,e!==null&&ds(e)&&(et=!0))}function zd(e,t,n,a){P=e;var s=0;do{if(tl&&(nl=null),Wl=0,tl=!1,25<=s)throw Error(u(301));if(s+=1,Ge=xe=null,e.updateQueue!=null){var c=e.updateQueue;c.lastEffect=null,c.events=null,c.stores=null,c.memoCache!=null&&(c.memoCache.index=0)}N.H=Yg,c=t(n,a)}while(tl);return c}function kg(){var e=N.H,t=e.useState()[0];return t=typeof t.then=="function"?Il(t):t,e=e.useState()[0],(xe!==null?xe.memoizedState:null)!==e&&(P.flags|=1024),t}function jr(){var e=ys!==0;return ys=0,e}function br(e,t,n){t.updateQueue=e.updateQueue,t.flags&=-2053,e.lanes&=~n}function Sr(e){if(ps){for(e=e.memoizedState;e!==null;){var t=e.queue;t!==null&&(t.pending=null),e=e.next}ps=!1}Hn=0,Ge=xe=P=null,tl=!1,Wl=ys=0,nl=null}function gt(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Ge===null?P.memoizedState=Ge=e:Ge=Ge.next=e,Ge}function Ye(){if(xe===null){var e=P.alternate;e=e!==null?e.memoizedState:null}else e=xe.next;var t=Ge===null?P.memoizedState:Ge.next;if(t!==null)Ge=t,xe=e;else{if(e===null)throw P.alternate===null?Error(u(467)):Error(u(310));xe=e,e={memoizedState:xe.memoizedState,baseState:xe.baseState,baseQueue:xe.baseQueue,queue:xe.queue,next:null},Ge===null?P.memoizedState=Ge=e:Ge=Ge.next=e}return Ge}function wr(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Il(e){var t=Wl;return Wl+=1,nl===null&&(nl=[]),e=Td(nl,e,t),t=P,(Ge===null?t.memoizedState:Ge.next)===null&&(t=t.alternate,N.H=t===null||t.memoizedState===null?mf:xf),e}function vs(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return Il(e);if(e.$$typeof===be)return ut(e)}throw Error(u(438,String(e)))}function _r(e){var t=null,n=P.updateQueue;if(n!==null&&(t=n.memoCache),t==null){var a=P.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(s){return s.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),n===null&&(n=wr(),P.updateQueue=n),n.memoCache=t,n=t.data[t.index],n===void 0)for(n=t.data[t.index]=Array(e),a=0;a<e;a++)n[a]=ca;return t.index++,n}function xn(e,t){return typeof t=="function"?t(e):t}function js(e){var t=Ye();return Tr(t,xe,e)}function Tr(e,t,n){var a=e.queue;if(a===null)throw Error(u(311));a.lastRenderedReducer=n;var s=e.baseQueue,c=a.pending;if(c!==null){if(s!==null){var h=s.next;s.next=c.next,c.next=h}t.baseQueue=s=c,a.pending=null}if(c=e.baseState,s===null)e.memoizedState=c;else{t=s.next;var x=h=null,v=null,C=t,z=!1;do{var R=C.lane&-536870913;if(R!==C.lane?(le&R)===R:(Hn&R)===R){var A=C.revertLane;if(A===0)v!==null&&(v=v.next={lane:0,revertLane:0,action:C.action,hasEagerState:C.hasEagerState,eagerState:C.eagerState,next:null}),R===Ia&&(z=!0);else if((Hn&A)===A){C=C.next,A===Ia&&(z=!0);continue}else R={lane:0,revertLane:C.revertLane,action:C.action,hasEagerState:C.hasEagerState,eagerState:C.eagerState,next:null},v===null?(x=v=R,h=c):v=v.next=R,P.lanes|=A,Vn|=A;R=C.action,ba&&n(c,R),c=C.hasEagerState?C.eagerState:n(c,R)}else A={lane:R,revertLane:C.revertLane,action:C.action,hasEagerState:C.hasEagerState,eagerState:C.eagerState,next:null},v===null?(x=v=A,h=c):v=v.next=A,P.lanes|=R,Vn|=R;C=C.next}while(C!==null&&C!==t);if(v===null?h=c:v.next=x,!_t(c,e.memoizedState)&&(et=!0,z&&(n=Pa,n!==null)))throw n;e.memoizedState=c,e.baseState=h,e.baseQueue=v,a.lastRenderedState=c}return s===null&&(a.lanes=0),[e.memoizedState,a.dispatch]}function Cr(e){var t=Ye(),n=t.queue;if(n===null)throw Error(u(311));n.lastRenderedReducer=e;var a=n.dispatch,s=n.pending,c=t.memoizedState;if(s!==null){n.pending=null;var h=s=s.next;do c=e(c,h.action),h=h.next;while(h!==s);_t(c,t.memoizedState)||(et=!0),t.memoizedState=c,t.baseQueue===null&&(t.baseState=c),n.lastRenderedState=c}return[c,a]}function Bd(e,t,n){var a=P,s=Ye(),c=ce;if(c){if(n===void 0)throw Error(u(407));n=n()}else n=t();var h=!_t((xe||s).memoizedState,n);h&&(s.memoizedState=n,et=!0),s=s.queue;var x=Ud.bind(null,a,s,e);if(Pl(2048,8,x,[e]),s.getSnapshot!==t||h||Ge!==null&&Ge.memoizedState.tag&1){if(a.flags|=2048,al(9,bs(),Rd.bind(null,a,s,n,t),null),ve===null)throw Error(u(349));c||(Hn&124)!==0||Nd(a,t,n)}return n}function Nd(e,t,n){e.flags|=16384,e={getSnapshot:t,value:n},t=P.updateQueue,t===null?(t=wr(),P.updateQueue=t,t.stores=[e]):(n=t.stores,n===null?t.stores=[e]:n.push(e))}function Rd(e,t,n,a){t.value=n,t.getSnapshot=a,kd(t)&&Ld(e)}function Ud(e,t,n){return n(function(){kd(t)&&Ld(e)})}function kd(e){var t=e.getSnapshot;e=e.value;try{var n=t();return!_t(e,n)}catch{return!0}}function Ld(e){var t=Ka(e,2);t!==null&&Ot(t,e,2)}function Ar(e){var t=gt();if(typeof e=="function"){var n=e;if(e=n(),ba){zn(!0);try{n()}finally{zn(!1)}}}return t.memoizedState=t.baseState=e,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:xn,lastRenderedState:e},t}function Hd(e,t,n,a){return e.baseState=n,Tr(e,xe,typeof a=="function"?a:xn)}function Lg(e,t,n,a,s){if(ws(e))throw Error(u(485));if(e=t.action,e!==null){var c={payload:s,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(h){c.listeners.push(h)}};N.T!==null?n(!0):c.isTransition=!1,a(c),n=t.pending,n===null?(c.next=t.pending=c,qd(t,c)):(c.next=n.next,t.pending=n.next=c)}}function qd(e,t){var n=t.action,a=t.payload,s=e.state;if(t.isTransition){var c=N.T,h={};N.T=h;try{var x=n(s,a),v=N.S;v!==null&&v(h,x),$d(e,t,x)}catch(C){Er(e,t,C)}finally{N.T=c}}else try{c=n(s,a),$d(e,t,c)}catch(C){Er(e,t,C)}}function $d(e,t,n){n!==null&&typeof n=="object"&&typeof n.then=="function"?n.then(function(a){Gd(e,t,a)},function(a){return Er(e,t,a)}):Gd(e,t,n)}function Gd(e,t,n){t.status="fulfilled",t.value=n,Yd(t),e.state=n,t=e.pending,t!==null&&(n=t.next,n===t?e.pending=null:(n=n.next,t.next=n,qd(e,n)))}function Er(e,t,n){var a=e.pending;if(e.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=n,Yd(t),t=t.next;while(t!==a)}e.action=null}function Yd(e){e=e.listeners;for(var t=0;t<e.length;t++)(0,e[t])()}function Xd(e,t){return t}function Qd(e,t){if(ce){var n=ve.formState;if(n!==null){e:{var a=P;if(ce){if(Be){t:{for(var s=Be,c=Wt;s.nodeType!==8;){if(!c){s=null;break t}if(s=Vt(s.nextSibling),s===null){s=null;break t}}c=s.data,s=c==="F!"||c==="F"?s:null}if(s){Be=Vt(s.nextSibling),a=s.data==="F!";break e}}pa(a)}a=!1}a&&(t=n[0])}}return n=gt(),n.memoizedState=n.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Xd,lastRenderedState:t},n.queue=a,n=df.bind(null,P,a),a.dispatch=n,a=Ar(!1),c=Br.bind(null,P,!1,a.queue),a=gt(),s={state:t,dispatch:null,action:e,pending:null},a.queue=s,n=Lg.bind(null,P,s,c,n),s.dispatch=n,a.memoizedState=e,[t,n,!1]}function Vd(e){var t=Ye();return Zd(t,xe,e)}function Zd(e,t,n){if(t=Tr(e,t,Xd)[0],e=js(xn)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=Il(t)}catch(h){throw h===Vl?ms:h}else a=t;t=Ye();var s=t.queue,c=s.dispatch;return n!==t.memoizedState&&(P.flags|=2048,al(9,bs(),Hg.bind(null,s,n),null)),[a,c,e]}function Hg(e,t){e.action=t}function Kd(e){var t=Ye(),n=xe;if(n!==null)return Zd(t,n,e);Ye(),t=t.memoizedState,n=Ye();var a=n.queue.dispatch;return n.memoizedState=e,[t,a,!1]}function al(e,t,n,a){return e={tag:e,create:n,deps:a,inst:t,next:null},t=P.updateQueue,t===null&&(t=wr(),P.updateQueue=t),n=t.lastEffect,n===null?t.lastEffect=e.next=e:(a=n.next,n.next=e,e.next=a,t.lastEffect=e),e}function bs(){return{destroy:void 0,resource:void 0}}function Jd(){return Ye().memoizedState}function Ss(e,t,n,a){var s=gt();a=a===void 0?null:a,P.flags|=e,s.memoizedState=al(1|t,bs(),n,a)}function Pl(e,t,n,a){var s=Ye();a=a===void 0?null:a;var c=s.memoizedState.inst;xe!==null&&a!==null&&yr(a,xe.memoizedState.deps)?s.memoizedState=al(t,c,n,a):(P.flags|=e,s.memoizedState=al(1|t,c,n,a))}function Fd(e,t){Ss(8390656,8,e,t)}function Wd(e,t){Pl(2048,8,e,t)}function Id(e,t){return Pl(4,2,e,t)}function Pd(e,t){return Pl(4,4,e,t)}function ef(e,t){if(typeof t=="function"){e=e();var n=t(e);return function(){typeof n=="function"?n():t(null)}}if(t!=null)return e=e(),t.current=e,function(){t.current=null}}function tf(e,t,n){n=n!=null?n.concat([e]):null,Pl(4,4,ef.bind(null,t,e),n)}function Dr(){}function nf(e,t){var n=Ye();t=t===void 0?null:t;var a=n.memoizedState;return t!==null&&yr(t,a[1])?a[0]:(n.memoizedState=[e,t],e)}function af(e,t){var n=Ye();t=t===void 0?null:t;var a=n.memoizedState;if(t!==null&&yr(t,a[1]))return a[0];if(a=e(),ba){zn(!0);try{e()}finally{zn(!1)}}return n.memoizedState=[a,t],a}function Or(e,t,n){return n===void 0||(Hn&1073741824)!==0?e.memoizedState=t:(e.memoizedState=n,e=ch(),P.lanes|=e,Vn|=e,n)}function lf(e,t,n,a){return _t(n,t)?n:el.current!==null?(e=Or(e,n,a),_t(e,t)||(et=!0),e):(Hn&42)===0?(et=!0,e.memoizedState=n):(e=ch(),P.lanes|=e,Vn|=e,t)}function sf(e,t,n,a,s){var c=H.p;H.p=c!==0&&8>c?c:8;var h=N.T,x={};N.T=x,Br(e,!1,t,n);try{var v=s(),C=N.S;if(C!==null&&C(x,v),v!==null&&typeof v=="object"&&typeof v.then=="function"){var z=Rg(v,a);ei(e,t,z,Dt(e))}else ei(e,t,a,Dt(e))}catch(R){ei(e,t,{then:function(){},status:"rejected",reason:R},Dt())}finally{H.p=c,N.T=h}}function qg(){}function Mr(e,t,n,a){if(e.tag!==5)throw Error(u(476));var s=cf(e).queue;sf(e,s,t,F,n===null?qg:function(){return rf(e),n(a)})}function cf(e){var t=e.memoizedState;if(t!==null)return t;t={memoizedState:F,baseState:F,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xn,lastRenderedState:F},next:null};var n={};return t.next={memoizedState:n,baseState:n,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xn,lastRenderedState:n},next:null},e.memoizedState=t,e=e.alternate,e!==null&&(e.memoizedState=t),t}function rf(e){var t=cf(e).next.queue;ei(e,t,{},Dt())}function zr(){return ut(yi)}function uf(){return Ye().memoizedState}function of(){return Ye().memoizedState}function $g(e){for(var t=e.return;t!==null;){switch(t.tag){case 24:case 3:var n=Dt();e=kn(n);var a=Ln(t,e,n);a!==null&&(Ot(a,t,n),Kl(a,t,n)),t={cache:rr()},e.payload=t;return}t=t.return}}function Gg(e,t,n){var a=Dt();n={lane:a,revertLane:0,action:n,hasEagerState:!1,eagerState:null,next:null},ws(e)?ff(t,n):(n=Ic(e,t,n,a),n!==null&&(Ot(n,e,a),hf(n,t,a)))}function df(e,t,n){var a=Dt();ei(e,t,n,a)}function ei(e,t,n,a){var s={lane:a,revertLane:0,action:n,hasEagerState:!1,eagerState:null,next:null};if(ws(e))ff(t,s);else{var c=e.alternate;if(e.lanes===0&&(c===null||c.lanes===0)&&(c=t.lastRenderedReducer,c!==null))try{var h=t.lastRenderedState,x=c(h,n);if(s.hasEagerState=!0,s.eagerState=x,_t(x,h))return ss(e,t,s,0),ve===null&&is(),!1}catch{}finally{}if(n=Ic(e,t,s,a),n!==null)return Ot(n,e,a),hf(n,t,a),!0}return!1}function Br(e,t,n,a){if(a={lane:2,revertLane:du(),action:a,hasEagerState:!1,eagerState:null,next:null},ws(e)){if(t)throw Error(u(479))}else t=Ic(e,n,a,2),t!==null&&Ot(t,e,2)}function ws(e){var t=e.alternate;return e===P||t!==null&&t===P}function ff(e,t){tl=ps=!0;var n=e.pending;n===null?t.next=t:(t.next=n.next,n.next=t),e.pending=t}function hf(e,t,n){if((n&4194048)!==0){var a=t.lanes;a&=e.pendingLanes,n|=a,t.lanes=n,jo(e,n)}}var _s={readContext:ut,use:vs,useCallback:Ue,useContext:Ue,useEffect:Ue,useImperativeHandle:Ue,useLayoutEffect:Ue,useInsertionEffect:Ue,useMemo:Ue,useReducer:Ue,useRef:Ue,useState:Ue,useDebugValue:Ue,useDeferredValue:Ue,useTransition:Ue,useSyncExternalStore:Ue,useId:Ue,useHostTransitionStatus:Ue,useFormState:Ue,useActionState:Ue,useOptimistic:Ue,useMemoCache:Ue,useCacheRefresh:Ue},mf={readContext:ut,use:vs,useCallback:function(e,t){return gt().memoizedState=[e,t===void 0?null:t],e},useContext:ut,useEffect:Fd,useImperativeHandle:function(e,t,n){n=n!=null?n.concat([e]):null,Ss(4194308,4,ef.bind(null,t,e),n)},useLayoutEffect:function(e,t){return Ss(4194308,4,e,t)},useInsertionEffect:function(e,t){Ss(4,2,e,t)},useMemo:function(e,t){var n=gt();t=t===void 0?null:t;var a=e();if(ba){zn(!0);try{e()}finally{zn(!1)}}return n.memoizedState=[a,t],a},useReducer:function(e,t,n){var a=gt();if(n!==void 0){var s=n(t);if(ba){zn(!0);try{n(t)}finally{zn(!1)}}}else s=t;return a.memoizedState=a.baseState=s,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:s},a.queue=e,e=e.dispatch=Gg.bind(null,P,e),[a.memoizedState,e]},useRef:function(e){var t=gt();return e={current:e},t.memoizedState=e},useState:function(e){e=Ar(e);var t=e.queue,n=df.bind(null,P,t);return t.dispatch=n,[e.memoizedState,n]},useDebugValue:Dr,useDeferredValue:function(e,t){var n=gt();return Or(n,e,t)},useTransition:function(){var e=Ar(!1);return e=sf.bind(null,P,e.queue,!0,!1),gt().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,t,n){var a=P,s=gt();if(ce){if(n===void 0)throw Error(u(407));n=n()}else{if(n=t(),ve===null)throw Error(u(349));(le&124)!==0||Nd(a,t,n)}s.memoizedState=n;var c={value:n,getSnapshot:t};return s.queue=c,Fd(Ud.bind(null,a,c,e),[e]),a.flags|=2048,al(9,bs(),Rd.bind(null,a,c,n,t),null),n},useId:function(){var e=gt(),t=ve.identifierPrefix;if(ce){var n=fn,a=dn;n=(a&~(1<<32-wt(a)-1)).toString(32)+n,t="«"+t+"R"+n,n=ys++,0<n&&(t+="H"+n.toString(32)),t+="»"}else n=Ug++,t="«"+t+"r"+n.toString(32)+"»";return e.memoizedState=t},useHostTransitionStatus:zr,useFormState:Qd,useActionState:Qd,useOptimistic:function(e){var t=gt();t.memoizedState=t.baseState=e;var n={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=n,t=Br.bind(null,P,!0,n),n.dispatch=t,[e,t]},useMemoCache:_r,useCacheRefresh:function(){return gt().memoizedState=$g.bind(null,P)}},xf={readContext:ut,use:vs,useCallback:nf,useContext:ut,useEffect:Wd,useImperativeHandle:tf,useInsertionEffect:Id,useLayoutEffect:Pd,useMemo:af,useReducer:js,useRef:Jd,useState:function(){return js(xn)},useDebugValue:Dr,useDeferredValue:function(e,t){var n=Ye();return lf(n,xe.memoizedState,e,t)},useTransition:function(){var e=js(xn)[0],t=Ye().memoizedState;return[typeof e=="boolean"?e:Il(e),t]},useSyncExternalStore:Bd,useId:uf,useHostTransitionStatus:zr,useFormState:Vd,useActionState:Vd,useOptimistic:function(e,t){var n=Ye();return Hd(n,xe,e,t)},useMemoCache:_r,useCacheRefresh:of},Yg={readContext:ut,use:vs,useCallback:nf,useContext:ut,useEffect:Wd,useImperativeHandle:tf,useInsertionEffect:Id,useLayoutEffect:Pd,useMemo:af,useReducer:Cr,useRef:Jd,useState:function(){return Cr(xn)},useDebugValue:Dr,useDeferredValue:function(e,t){var n=Ye();return xe===null?Or(n,e,t):lf(n,xe.memoizedState,e,t)},useTransition:function(){var e=Cr(xn)[0],t=Ye().memoizedState;return[typeof e=="boolean"?e:Il(e),t]},useSyncExternalStore:Bd,useId:uf,useHostTransitionStatus:zr,useFormState:Kd,useActionState:Kd,useOptimistic:function(e,t){var n=Ye();return xe!==null?Hd(n,xe,e,t):(n.baseState=e,[e,n.queue.dispatch])},useMemoCache:_r,useCacheRefresh:of},ll=null,ti=0;function Ts(e){var t=ti;return ti+=1,ll===null&&(ll=[]),Td(ll,e,t)}function ni(e,t){t=t.props.ref,e.ref=t!==void 0?t:null}function Cs(e,t){throw t.$$typeof===E?Error(u(525)):(e=Object.prototype.toString.call(t),Error(u(31,e==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":e)))}function gf(e){var t=e._init;return t(e._payload)}function pf(e){function t(S,b){if(e){var _=S.deletions;_===null?(S.deletions=[b],S.flags|=16):_.push(b)}}function n(S,b){if(!e)return null;for(;b!==null;)t(S,b),b=b.sibling;return null}function a(S){for(var b=new Map;S!==null;)S.key!==null?b.set(S.key,S):b.set(S.index,S),S=S.sibling;return b}function s(S,b){return S=on(S,b),S.index=0,S.sibling=null,S}function c(S,b,_){return S.index=_,e?(_=S.alternate,_!==null?(_=_.index,_<b?(S.flags|=67108866,b):_):(S.flags|=67108866,b)):(S.flags|=1048576,b)}function h(S){return e&&S.alternate===null&&(S.flags|=67108866),S}function x(S,b,_,B){return b===null||b.tag!==6?(b=er(_,S.mode,B),b.return=S,b):(b=s(b,_),b.return=S,b)}function v(S,b,_,B){var $=_.type;return $===L?z(S,b,_.props.children,B,_.key):b!==null&&(b.elementType===$||typeof $=="object"&&$!==null&&$.$$typeof===bt&&gf($)===b.type)?(b=s(b,_.props),ni(b,_),b.return=S,b):(b=rs(_.type,_.key,_.props,null,S.mode,B),ni(b,_),b.return=S,b)}function C(S,b,_,B){return b===null||b.tag!==4||b.stateNode.containerInfo!==_.containerInfo||b.stateNode.implementation!==_.implementation?(b=tr(_,S.mode,B),b.return=S,b):(b=s(b,_.children||[]),b.return=S,b)}function z(S,b,_,B,$){return b===null||b.tag!==7?(b=ha(_,S.mode,B,$),b.return=S,b):(b=s(b,_),b.return=S,b)}function R(S,b,_){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return b=er(""+b,S.mode,_),b.return=S,b;if(typeof b=="object"&&b!==null){switch(b.$$typeof){case O:return _=rs(b.type,b.key,b.props,null,S.mode,_),ni(_,b),_.return=S,_;case M:return b=tr(b,S.mode,_),b.return=S,b;case bt:var B=b._init;return b=B(b._payload),R(S,b,_)}if(cn(b)||zt(b))return b=ha(b,S.mode,_,null),b.return=S,b;if(typeof b.then=="function")return R(S,Ts(b),_);if(b.$$typeof===be)return R(S,fs(S,b),_);Cs(S,b)}return null}function A(S,b,_,B){var $=b!==null?b.key:null;if(typeof _=="string"&&_!==""||typeof _=="number"||typeof _=="bigint")return $!==null?null:x(S,b,""+_,B);if(typeof _=="object"&&_!==null){switch(_.$$typeof){case O:return _.key===$?v(S,b,_,B):null;case M:return _.key===$?C(S,b,_,B):null;case bt:return $=_._init,_=$(_._payload),A(S,b,_,B)}if(cn(_)||zt(_))return $!==null?null:z(S,b,_,B,null);if(typeof _.then=="function")return A(S,b,Ts(_),B);if(_.$$typeof===be)return A(S,b,fs(S,_),B);Cs(S,_)}return null}function D(S,b,_,B,$){if(typeof B=="string"&&B!==""||typeof B=="number"||typeof B=="bigint")return S=S.get(_)||null,x(b,S,""+B,$);if(typeof B=="object"&&B!==null){switch(B.$$typeof){case O:return S=S.get(B.key===null?_:B.key)||null,v(b,S,B,$);case M:return S=S.get(B.key===null?_:B.key)||null,C(b,S,B,$);case bt:var ee=B._init;return B=ee(B._payload),D(S,b,_,B,$)}if(cn(B)||zt(B))return S=S.get(_)||null,z(b,S,B,$,null);if(typeof B.then=="function")return D(S,b,_,Ts(B),$);if(B.$$typeof===be)return D(S,b,_,fs(b,B),$);Cs(b,B)}return null}function J(S,b,_,B){for(var $=null,ee=null,X=b,Z=b=0,nt=null;X!==null&&Z<_.length;Z++){X.index>Z?(nt=X,X=null):nt=X.sibling;var se=A(S,X,_[Z],B);if(se===null){X===null&&(X=nt);break}e&&X&&se.alternate===null&&t(S,X),b=c(se,b,Z),ee===null?$=se:ee.sibling=se,ee=se,X=nt}if(Z===_.length)return n(S,X),ce&&xa(S,Z),$;if(X===null){for(;Z<_.length;Z++)X=R(S,_[Z],B),X!==null&&(b=c(X,b,Z),ee===null?$=X:ee.sibling=X,ee=X);return ce&&xa(S,Z),$}for(X=a(X);Z<_.length;Z++)nt=D(X,S,Z,_[Z],B),nt!==null&&(e&&nt.alternate!==null&&X.delete(nt.key===null?Z:nt.key),b=c(nt,b,Z),ee===null?$=nt:ee.sibling=nt,ee=nt);return e&&X.forEach(function(ta){return t(S,ta)}),ce&&xa(S,Z),$}function V(S,b,_,B){if(_==null)throw Error(u(151));for(var $=null,ee=null,X=b,Z=b=0,nt=null,se=_.next();X!==null&&!se.done;Z++,se=_.next()){X.index>Z?(nt=X,X=null):nt=X.sibling;var ta=A(S,X,se.value,B);if(ta===null){X===null&&(X=nt);break}e&&X&&ta.alternate===null&&t(S,X),b=c(ta,b,Z),ee===null?$=ta:ee.sibling=ta,ee=ta,X=nt}if(se.done)return n(S,X),ce&&xa(S,Z),$;if(X===null){for(;!se.done;Z++,se=_.next())se=R(S,se.value,B),se!==null&&(b=c(se,b,Z),ee===null?$=se:ee.sibling=se,ee=se);return ce&&xa(S,Z),$}for(X=a(X);!se.done;Z++,se=_.next())se=D(X,S,Z,se.value,B),se!==null&&(e&&se.alternate!==null&&X.delete(se.key===null?Z:se.key),b=c(se,b,Z),ee===null?$=se:ee.sibling=se,ee=se);return e&&X.forEach(function(Xp){return t(S,Xp)}),ce&&xa(S,Z),$}function pe(S,b,_,B){if(typeof _=="object"&&_!==null&&_.type===L&&_.key===null&&(_=_.props.children),typeof _=="object"&&_!==null){switch(_.$$typeof){case O:e:{for(var $=_.key;b!==null;){if(b.key===$){if($=_.type,$===L){if(b.tag===7){n(S,b.sibling),B=s(b,_.props.children),B.return=S,S=B;break e}}else if(b.elementType===$||typeof $=="object"&&$!==null&&$.$$typeof===bt&&gf($)===b.type){n(S,b.sibling),B=s(b,_.props),ni(B,_),B.return=S,S=B;break e}n(S,b);break}else t(S,b);b=b.sibling}_.type===L?(B=ha(_.props.children,S.mode,B,_.key),B.return=S,S=B):(B=rs(_.type,_.key,_.props,null,S.mode,B),ni(B,_),B.return=S,S=B)}return h(S);case M:e:{for($=_.key;b!==null;){if(b.key===$)if(b.tag===4&&b.stateNode.containerInfo===_.containerInfo&&b.stateNode.implementation===_.implementation){n(S,b.sibling),B=s(b,_.children||[]),B.return=S,S=B;break e}else{n(S,b);break}else t(S,b);b=b.sibling}B=tr(_,S.mode,B),B.return=S,S=B}return h(S);case bt:return $=_._init,_=$(_._payload),pe(S,b,_,B)}if(cn(_))return J(S,b,_,B);if(zt(_)){if($=zt(_),typeof $!="function")throw Error(u(150));return _=$.call(_),V(S,b,_,B)}if(typeof _.then=="function")return pe(S,b,Ts(_),B);if(_.$$typeof===be)return pe(S,b,fs(S,_),B);Cs(S,_)}return typeof _=="string"&&_!==""||typeof _=="number"||typeof _=="bigint"?(_=""+_,b!==null&&b.tag===6?(n(S,b.sibling),B=s(b,_),B.return=S,S=B):(n(S,b),B=er(_,S.mode,B),B.return=S,S=B),h(S)):n(S,b)}return function(S,b,_,B){try{ti=0;var $=pe(S,b,_,B);return ll=null,$}catch(X){if(X===Vl||X===ms)throw X;var ee=Tt(29,X,null,S.mode);return ee.lanes=B,ee.return=S,ee}finally{}}}var il=pf(!0),yf=pf(!1),Ht=ft(null),It=null;function qn(e){var t=e.alternate;me(Ze,Ze.current&1),me(Ht,e),It===null&&(t===null||el.current!==null||t.memoizedState!==null)&&(It=e)}function vf(e){if(e.tag===22){if(me(Ze,Ze.current),me(Ht,e),It===null){var t=e.alternate;t!==null&&t.memoizedState!==null&&(It=e)}}else $n()}function $n(){me(Ze,Ze.current),me(Ht,Ht.current)}function gn(e){Ae(Ht),It===e&&(It=null),Ae(Ze)}var Ze=ft(0);function As(e){for(var t=e;t!==null;){if(t.tag===13){var n=t.memoizedState;if(n!==null&&(n=n.dehydrated,n===null||n.data==="$?"||wu(n)))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function Nr(e,t,n,a){t=e.memoizedState,n=n(a,t),n=n==null?t:j({},t,n),e.memoizedState=n,e.lanes===0&&(e.updateQueue.baseState=n)}var Rr={enqueueSetState:function(e,t,n){e=e._reactInternals;var a=Dt(),s=kn(a);s.payload=t,n!=null&&(s.callback=n),t=Ln(e,s,a),t!==null&&(Ot(t,e,a),Kl(t,e,a))},enqueueReplaceState:function(e,t,n){e=e._reactInternals;var a=Dt(),s=kn(a);s.tag=1,s.payload=t,n!=null&&(s.callback=n),t=Ln(e,s,a),t!==null&&(Ot(t,e,a),Kl(t,e,a))},enqueueForceUpdate:function(e,t){e=e._reactInternals;var n=Dt(),a=kn(n);a.tag=2,t!=null&&(a.callback=t),t=Ln(e,a,n),t!==null&&(Ot(t,e,n),Kl(t,e,n))}};function jf(e,t,n,a,s,c,h){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(a,c,h):t.prototype&&t.prototype.isPureReactComponent?!Ll(n,a)||!Ll(s,c):!0}function bf(e,t,n,a){e=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(n,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(n,a),t.state!==e&&Rr.enqueueReplaceState(t,t.state,null)}function Sa(e,t){var n=t;if("ref"in t){n={};for(var a in t)a!=="ref"&&(n[a]=t[a])}if(e=e.defaultProps){n===t&&(n=j({},n));for(var s in e)n[s]===void 0&&(n[s]=e[s])}return n}var Es=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}console.error(e)};function Sf(e){Es(e)}function wf(e){console.error(e)}function _f(e){Es(e)}function Ds(e,t){try{var n=e.onUncaughtError;n(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function Tf(e,t,n){try{var a=e.onCaughtError;a(n.value,{componentStack:n.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(s){setTimeout(function(){throw s})}}function Ur(e,t,n){return n=kn(n),n.tag=3,n.payload={element:null},n.callback=function(){Ds(e,t)},n}function Cf(e){return e=kn(e),e.tag=3,e}function Af(e,t,n,a){var s=n.type.getDerivedStateFromError;if(typeof s=="function"){var c=a.value;e.payload=function(){return s(c)},e.callback=function(){Tf(t,n,a)}}var h=n.stateNode;h!==null&&typeof h.componentDidCatch=="function"&&(e.callback=function(){Tf(t,n,a),typeof s!="function"&&(Zn===null?Zn=new Set([this]):Zn.add(this));var x=a.stack;this.componentDidCatch(a.value,{componentStack:x!==null?x:""})})}function Xg(e,t,n,a,s){if(n.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=n.alternate,t!==null&&Yl(t,n,s,!0),n=Ht.current,n!==null){switch(n.tag){case 13:return It===null?su():n.alternate===null&&Ne===0&&(Ne=3),n.flags&=-257,n.flags|=65536,n.lanes=s,a===dr?n.flags|=16384:(t=n.updateQueue,t===null?n.updateQueue=new Set([a]):t.add(a),ru(e,a,s)),!1;case 22:return n.flags|=65536,a===dr?n.flags|=16384:(t=n.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},n.updateQueue=t):(n=t.retryQueue,n===null?t.retryQueue=new Set([a]):n.add(a)),ru(e,a,s)),!1}throw Error(u(435,n.tag))}return ru(e,a,s),su(),!1}if(ce)return t=Ht.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=s,a!==lr&&(e=Error(u(422),{cause:a}),Gl(Rt(e,n)))):(a!==lr&&(t=Error(u(423),{cause:a}),Gl(Rt(t,n))),e=e.current.alternate,e.flags|=65536,s&=-s,e.lanes|=s,a=Rt(a,n),s=Ur(e.stateNode,a,s),mr(e,s),Ne!==4&&(Ne=2)),!1;var c=Error(u(520),{cause:a});if(c=Rt(c,n),ui===null?ui=[c]:ui.push(c),Ne!==4&&(Ne=2),t===null)return!0;a=Rt(a,n),n=t;do{switch(n.tag){case 3:return n.flags|=65536,e=s&-s,n.lanes|=e,e=Ur(n.stateNode,a,e),mr(n,e),!1;case 1:if(t=n.type,c=n.stateNode,(n.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||c!==null&&typeof c.componentDidCatch=="function"&&(Zn===null||!Zn.has(c))))return n.flags|=65536,s&=-s,n.lanes|=s,s=Cf(s),Af(s,e,n,a),mr(n,s),!1}n=n.return}while(n!==null);return!1}var Ef=Error(u(461)),et=!1;function at(e,t,n,a){t.child=e===null?yf(t,null,n,a):il(t,e.child,n,a)}function Df(e,t,n,a,s){n=n.render;var c=t.ref;if("ref"in a){var h={};for(var x in a)x!=="ref"&&(h[x]=a[x])}else h=a;return va(t),a=vr(e,t,n,h,c,s),x=jr(),e!==null&&!et?(br(e,t,s),pn(e,t,s)):(ce&&x&&nr(t),t.flags|=1,at(e,t,a,s),t.child)}function Of(e,t,n,a,s){if(e===null){var c=n.type;return typeof c=="function"&&!Pc(c)&&c.defaultProps===void 0&&n.compare===null?(t.tag=15,t.type=c,Mf(e,t,c,a,s)):(e=rs(n.type,null,a,t,t.mode,s),e.ref=t.ref,e.return=t,t.child=e)}if(c=e.child,!Xr(e,s)){var h=c.memoizedProps;if(n=n.compare,n=n!==null?n:Ll,n(h,a)&&e.ref===t.ref)return pn(e,t,s)}return t.flags|=1,e=on(c,a),e.ref=t.ref,e.return=t,t.child=e}function Mf(e,t,n,a,s){if(e!==null){var c=e.memoizedProps;if(Ll(c,a)&&e.ref===t.ref)if(et=!1,t.pendingProps=a=c,Xr(e,s))(e.flags&131072)!==0&&(et=!0);else return t.lanes=e.lanes,pn(e,t,s)}return kr(e,t,n,a,s)}function zf(e,t,n){var a=t.pendingProps,s=a.children,c=e!==null?e.memoizedState:null;if(a.mode==="hidden"){if((t.flags&128)!==0){if(a=c!==null?c.baseLanes|n:n,e!==null){for(s=t.child=e.child,c=0;s!==null;)c=c|s.lanes|s.childLanes,s=s.sibling;t.childLanes=c&~a}else t.childLanes=0,t.child=null;return Bf(e,t,a,n)}if((n&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},e!==null&&hs(t,c!==null?c.cachePool:null),c!==null?Od(t,c):gr(),vf(t);else return t.lanes=t.childLanes=536870912,Bf(e,t,c!==null?c.baseLanes|n:n,n)}else c!==null?(hs(t,c.cachePool),Od(t,c),$n(),t.memoizedState=null):(e!==null&&hs(t,null),gr(),$n());return at(e,t,s,n),t.child}function Bf(e,t,n,a){var s=or();return s=s===null?null:{parent:Ve._currentValue,pool:s},t.memoizedState={baseLanes:n,cachePool:s},e!==null&&hs(t,null),gr(),vf(t),e!==null&&Yl(e,t,a,!0),null}function Os(e,t){var n=t.ref;if(n===null)e!==null&&e.ref!==null&&(t.flags|=4194816);else{if(typeof n!="function"&&typeof n!="object")throw Error(u(284));(e===null||e.ref!==n)&&(t.flags|=4194816)}}function kr(e,t,n,a,s){return va(t),n=vr(e,t,n,a,void 0,s),a=jr(),e!==null&&!et?(br(e,t,s),pn(e,t,s)):(ce&&a&&nr(t),t.flags|=1,at(e,t,n,s),t.child)}function Nf(e,t,n,a,s,c){return va(t),t.updateQueue=null,n=zd(t,a,n,s),Md(e),a=jr(),e!==null&&!et?(br(e,t,c),pn(e,t,c)):(ce&&a&&nr(t),t.flags|=1,at(e,t,n,c),t.child)}function Rf(e,t,n,a,s){if(va(t),t.stateNode===null){var c=Ja,h=n.contextType;typeof h=="object"&&h!==null&&(c=ut(h)),c=new n(a,c),t.memoizedState=c.state!==null&&c.state!==void 0?c.state:null,c.updater=Rr,t.stateNode=c,c._reactInternals=t,c=t.stateNode,c.props=a,c.state=t.memoizedState,c.refs={},fr(t),h=n.contextType,c.context=typeof h=="object"&&h!==null?ut(h):Ja,c.state=t.memoizedState,h=n.getDerivedStateFromProps,typeof h=="function"&&(Nr(t,n,h,a),c.state=t.memoizedState),typeof n.getDerivedStateFromProps=="function"||typeof c.getSnapshotBeforeUpdate=="function"||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(h=c.state,typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount(),h!==c.state&&Rr.enqueueReplaceState(c,c.state,null),Fl(t,a,c,s),Jl(),c.state=t.memoizedState),typeof c.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(e===null){c=t.stateNode;var x=t.memoizedProps,v=Sa(n,x);c.props=v;var C=c.context,z=n.contextType;h=Ja,typeof z=="object"&&z!==null&&(h=ut(z));var R=n.getDerivedStateFromProps;z=typeof R=="function"||typeof c.getSnapshotBeforeUpdate=="function",x=t.pendingProps!==x,z||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(x||C!==h)&&bf(t,c,a,h),Un=!1;var A=t.memoizedState;c.state=A,Fl(t,a,c,s),Jl(),C=t.memoizedState,x||A!==C||Un?(typeof R=="function"&&(Nr(t,n,R,a),C=t.memoizedState),(v=Un||jf(t,n,v,a,A,C,h))?(z||typeof c.UNSAFE_componentWillMount!="function"&&typeof c.componentWillMount!="function"||(typeof c.componentWillMount=="function"&&c.componentWillMount(),typeof c.UNSAFE_componentWillMount=="function"&&c.UNSAFE_componentWillMount()),typeof c.componentDidMount=="function"&&(t.flags|=4194308)):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=C),c.props=a,c.state=C,c.context=h,a=v):(typeof c.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{c=t.stateNode,hr(e,t),h=t.memoizedProps,z=Sa(n,h),c.props=z,R=t.pendingProps,A=c.context,C=n.contextType,v=Ja,typeof C=="object"&&C!==null&&(v=ut(C)),x=n.getDerivedStateFromProps,(C=typeof x=="function"||typeof c.getSnapshotBeforeUpdate=="function")||typeof c.UNSAFE_componentWillReceiveProps!="function"&&typeof c.componentWillReceiveProps!="function"||(h!==R||A!==v)&&bf(t,c,a,v),Un=!1,A=t.memoizedState,c.state=A,Fl(t,a,c,s),Jl();var D=t.memoizedState;h!==R||A!==D||Un||e!==null&&e.dependencies!==null&&ds(e.dependencies)?(typeof x=="function"&&(Nr(t,n,x,a),D=t.memoizedState),(z=Un||jf(t,n,z,a,A,D,v)||e!==null&&e.dependencies!==null&&ds(e.dependencies))?(C||typeof c.UNSAFE_componentWillUpdate!="function"&&typeof c.componentWillUpdate!="function"||(typeof c.componentWillUpdate=="function"&&c.componentWillUpdate(a,D,v),typeof c.UNSAFE_componentWillUpdate=="function"&&c.UNSAFE_componentWillUpdate(a,D,v)),typeof c.componentDidUpdate=="function"&&(t.flags|=4),typeof c.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof c.componentDidUpdate!="function"||h===e.memoizedProps&&A===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||h===e.memoizedProps&&A===e.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=D),c.props=a,c.state=D,c.context=v,a=z):(typeof c.componentDidUpdate!="function"||h===e.memoizedProps&&A===e.memoizedState||(t.flags|=4),typeof c.getSnapshotBeforeUpdate!="function"||h===e.memoizedProps&&A===e.memoizedState||(t.flags|=1024),a=!1)}return c=a,Os(e,t),a=(t.flags&128)!==0,c||a?(c=t.stateNode,n=a&&typeof n.getDerivedStateFromError!="function"?null:c.render(),t.flags|=1,e!==null&&a?(t.child=il(t,e.child,null,s),t.child=il(t,null,n,s)):at(e,t,n,s),t.memoizedState=c.state,e=t.child):e=pn(e,t,s),e}function Uf(e,t,n,a){return $l(),t.flags|=256,at(e,t,n,a),t.child}var Lr={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Hr(e){return{baseLanes:e,cachePool:Sd()}}function qr(e,t,n){return e=e!==null?e.childLanes&~n:0,t&&(e|=qt),e}function kf(e,t,n){var a=t.pendingProps,s=!1,c=(t.flags&128)!==0,h;if((h=c)||(h=e!==null&&e.memoizedState===null?!1:(Ze.current&2)!==0),h&&(s=!0,t.flags&=-129),h=(t.flags&32)!==0,t.flags&=-33,e===null){if(ce){if(s?qn(t):$n(),ce){var x=Be,v;if(v=x){e:{for(v=x,x=Wt;v.nodeType!==8;){if(!x){x=null;break e}if(v=Vt(v.nextSibling),v===null){x=null;break e}}x=v}x!==null?(t.memoizedState={dehydrated:x,treeContext:ma!==null?{id:dn,overflow:fn}:null,retryLane:536870912,hydrationErrors:null},v=Tt(18,null,null,0),v.stateNode=x,v.return=t,t.child=v,ht=t,Be=null,v=!0):v=!1}v||pa(t)}if(x=t.memoizedState,x!==null&&(x=x.dehydrated,x!==null))return wu(x)?t.lanes=32:t.lanes=536870912,null;gn(t)}return x=a.children,a=a.fallback,s?($n(),s=t.mode,x=Ms({mode:"hidden",children:x},s),a=ha(a,s,n,null),x.return=t,a.return=t,x.sibling=a,t.child=x,s=t.child,s.memoizedState=Hr(n),s.childLanes=qr(e,h,n),t.memoizedState=Lr,a):(qn(t),$r(t,x))}if(v=e.memoizedState,v!==null&&(x=v.dehydrated,x!==null)){if(c)t.flags&256?(qn(t),t.flags&=-257,t=Gr(e,t,n)):t.memoizedState!==null?($n(),t.child=e.child,t.flags|=128,t=null):($n(),s=a.fallback,x=t.mode,a=Ms({mode:"visible",children:a.children},x),s=ha(s,x,n,null),s.flags|=2,a.return=t,s.return=t,a.sibling=s,t.child=a,il(t,e.child,null,n),a=t.child,a.memoizedState=Hr(n),a.childLanes=qr(e,h,n),t.memoizedState=Lr,t=s);else if(qn(t),wu(x)){if(h=x.nextSibling&&x.nextSibling.dataset,h)var C=h.dgst;h=C,a=Error(u(419)),a.stack="",a.digest=h,Gl({value:a,source:null,stack:null}),t=Gr(e,t,n)}else if(et||Yl(e,t,n,!1),h=(n&e.childLanes)!==0,et||h){if(h=ve,h!==null&&(a=n&-n,a=(a&42)!==0?1:_c(a),a=(a&(h.suspendedLanes|n))!==0?0:a,a!==0&&a!==v.retryLane))throw v.retryLane=a,Ka(e,a),Ot(h,e,a),Ef;x.data==="$?"||su(),t=Gr(e,t,n)}else x.data==="$?"?(t.flags|=192,t.child=e.child,t=null):(e=v.treeContext,Be=Vt(x.nextSibling),ht=t,ce=!0,ga=null,Wt=!1,e!==null&&(kt[Lt++]=dn,kt[Lt++]=fn,kt[Lt++]=ma,dn=e.id,fn=e.overflow,ma=t),t=$r(t,a.children),t.flags|=4096);return t}return s?($n(),s=a.fallback,x=t.mode,v=e.child,C=v.sibling,a=on(v,{mode:"hidden",children:a.children}),a.subtreeFlags=v.subtreeFlags&65011712,C!==null?s=on(C,s):(s=ha(s,x,n,null),s.flags|=2),s.return=t,a.return=t,a.sibling=s,t.child=a,a=s,s=t.child,x=e.child.memoizedState,x===null?x=Hr(n):(v=x.cachePool,v!==null?(C=Ve._currentValue,v=v.parent!==C?{parent:C,pool:C}:v):v=Sd(),x={baseLanes:x.baseLanes|n,cachePool:v}),s.memoizedState=x,s.childLanes=qr(e,h,n),t.memoizedState=Lr,a):(qn(t),n=e.child,e=n.sibling,n=on(n,{mode:"visible",children:a.children}),n.return=t,n.sibling=null,e!==null&&(h=t.deletions,h===null?(t.deletions=[e],t.flags|=16):h.push(e)),t.child=n,t.memoizedState=null,n)}function $r(e,t){return t=Ms({mode:"visible",children:t},e.mode),t.return=e,e.child=t}function Ms(e,t){return e=Tt(22,e,null,t),e.lanes=0,e.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},e}function Gr(e,t,n){return il(t,e.child,null,n),e=$r(t,t.pendingProps.children),e.flags|=2,t.memoizedState=null,e}function Lf(e,t,n){e.lanes|=t;var a=e.alternate;a!==null&&(a.lanes|=t),sr(e.return,t,n)}function Yr(e,t,n,a,s){var c=e.memoizedState;c===null?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:n,tailMode:s}:(c.isBackwards=t,c.rendering=null,c.renderingStartTime=0,c.last=a,c.tail=n,c.tailMode=s)}function Hf(e,t,n){var a=t.pendingProps,s=a.revealOrder,c=a.tail;if(at(e,t,a.children,n),a=Ze.current,(a&2)!==0)a=a&1|2,t.flags|=128;else{if(e!==null&&(e.flags&128)!==0)e:for(e=t.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&Lf(e,n,t);else if(e.tag===19)Lf(e,n,t);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;e.sibling===null;){if(e.return===null||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}a&=1}switch(me(Ze,a),s){case"forwards":for(n=t.child,s=null;n!==null;)e=n.alternate,e!==null&&As(e)===null&&(s=n),n=n.sibling;n=s,n===null?(s=t.child,t.child=null):(s=n.sibling,n.sibling=null),Yr(t,!1,s,n,c);break;case"backwards":for(n=null,s=t.child,t.child=null;s!==null;){if(e=s.alternate,e!==null&&As(e)===null){t.child=s;break}e=s.sibling,s.sibling=n,n=s,s=e}Yr(t,!0,n,null,c);break;case"together":Yr(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function pn(e,t,n){if(e!==null&&(t.dependencies=e.dependencies),Vn|=t.lanes,(n&t.childLanes)===0)if(e!==null){if(Yl(e,t,n,!1),(n&t.childLanes)===0)return null}else return null;if(e!==null&&t.child!==e.child)throw Error(u(153));if(t.child!==null){for(e=t.child,n=on(e,e.pendingProps),t.child=n,n.return=t;e.sibling!==null;)e=e.sibling,n=n.sibling=on(e,e.pendingProps),n.return=t;n.sibling=null}return t.child}function Xr(e,t){return(e.lanes&t)!==0?!0:(e=e.dependencies,!!(e!==null&&ds(e)))}function Qg(e,t,n){switch(t.tag){case 3:Gi(t,t.stateNode.containerInfo),Rn(t,Ve,e.memoizedState.cache),$l();break;case 27:case 5:vc(t);break;case 4:Gi(t,t.stateNode.containerInfo);break;case 10:Rn(t,t.type,t.memoizedProps.value);break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(qn(t),t.flags|=128,null):(n&t.child.childLanes)!==0?kf(e,t,n):(qn(t),e=pn(e,t,n),e!==null?e.sibling:null);qn(t);break;case 19:var s=(e.flags&128)!==0;if(a=(n&t.childLanes)!==0,a||(Yl(e,t,n,!1),a=(n&t.childLanes)!==0),s){if(a)return Hf(e,t,n);t.flags|=128}if(s=t.memoizedState,s!==null&&(s.rendering=null,s.tail=null,s.lastEffect=null),me(Ze,Ze.current),a)break;return null;case 22:case 23:return t.lanes=0,zf(e,t,n);case 24:Rn(t,Ve,e.memoizedState.cache)}return pn(e,t,n)}function qf(e,t,n){if(e!==null)if(e.memoizedProps!==t.pendingProps)et=!0;else{if(!Xr(e,n)&&(t.flags&128)===0)return et=!1,Qg(e,t,n);et=(e.flags&131072)!==0}else et=!1,ce&&(t.flags&1048576)!==0&&xd(t,os,t.index);switch(t.lanes=0,t.tag){case 16:e:{e=t.pendingProps;var a=t.elementType,s=a._init;if(a=s(a._payload),t.type=a,typeof a=="function")Pc(a)?(e=Sa(a,e),t.tag=1,t=Rf(null,t,a,e,n)):(t.tag=0,t=kr(null,t,a,e,n));else{if(a!=null){if(s=a.$$typeof,s===te){t.tag=11,t=Df(null,t,a,e,n);break e}else if(s===We){t.tag=14,t=Of(null,t,a,e,n);break e}}throw t=Tl(a)||a,Error(u(306,t,""))}}return t;case 0:return kr(e,t,t.type,t.pendingProps,n);case 1:return a=t.type,s=Sa(a,t.pendingProps),Rf(e,t,a,s,n);case 3:e:{if(Gi(t,t.stateNode.containerInfo),e===null)throw Error(u(387));a=t.pendingProps;var c=t.memoizedState;s=c.element,hr(e,t),Fl(t,a,null,n);var h=t.memoizedState;if(a=h.cache,Rn(t,Ve,a),a!==c.cache&&cr(t,[Ve],n,!0),Jl(),a=h.element,c.isDehydrated)if(c={element:a,isDehydrated:!1,cache:h.cache},t.updateQueue.baseState=c,t.memoizedState=c,t.flags&256){t=Uf(e,t,a,n);break e}else if(a!==s){s=Rt(Error(u(424)),t),Gl(s),t=Uf(e,t,a,n);break e}else{switch(e=t.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(Be=Vt(e.firstChild),ht=t,ce=!0,ga=null,Wt=!0,n=yf(t,null,a,n),t.child=n;n;)n.flags=n.flags&-3|4096,n=n.sibling}else{if($l(),a===s){t=pn(e,t,n);break e}at(e,t,a,n)}t=t.child}return t;case 26:return Os(e,t),e===null?(n=Xh(t.type,null,t.pendingProps,null))?t.memoizedState=n:ce||(n=t.type,e=t.pendingProps,a=Qs(Mn.current).createElement(n),a[rt]=t,a[mt]=e,it(a,n,e),Pe(a),t.stateNode=a):t.memoizedState=Xh(t.type,e.memoizedProps,t.pendingProps,e.memoizedState),null;case 27:return vc(t),e===null&&ce&&(a=t.stateNode=$h(t.type,t.pendingProps,Mn.current),ht=t,Wt=!0,s=Be,Fn(t.type)?(_u=s,Be=Vt(a.firstChild)):Be=s),at(e,t,t.pendingProps.children,n),Os(e,t),e===null&&(t.flags|=4194304),t.child;case 5:return e===null&&ce&&((s=a=Be)&&(a=vp(a,t.type,t.pendingProps,Wt),a!==null?(t.stateNode=a,ht=t,Be=Vt(a.firstChild),Wt=!1,s=!0):s=!1),s||pa(t)),vc(t),s=t.type,c=t.pendingProps,h=e!==null?e.memoizedProps:null,a=c.children,ju(s,c)?a=null:h!==null&&ju(s,h)&&(t.flags|=32),t.memoizedState!==null&&(s=vr(e,t,kg,null,null,n),yi._currentValue=s),Os(e,t),at(e,t,a,n),t.child;case 6:return e===null&&ce&&((e=n=Be)&&(n=jp(n,t.pendingProps,Wt),n!==null?(t.stateNode=n,ht=t,Be=null,e=!0):e=!1),e||pa(t)),null;case 13:return kf(e,t,n);case 4:return Gi(t,t.stateNode.containerInfo),a=t.pendingProps,e===null?t.child=il(t,null,a,n):at(e,t,a,n),t.child;case 11:return Df(e,t,t.type,t.pendingProps,n);case 7:return at(e,t,t.pendingProps,n),t.child;case 8:return at(e,t,t.pendingProps.children,n),t.child;case 12:return at(e,t,t.pendingProps.children,n),t.child;case 10:return a=t.pendingProps,Rn(t,t.type,a.value),at(e,t,a.children,n),t.child;case 9:return s=t.type._context,a=t.pendingProps.children,va(t),s=ut(s),a=a(s),t.flags|=1,at(e,t,a,n),t.child;case 14:return Of(e,t,t.type,t.pendingProps,n);case 15:return Mf(e,t,t.type,t.pendingProps,n);case 19:return Hf(e,t,n);case 31:return a=t.pendingProps,n=t.mode,a={mode:a.mode,children:a.children},e===null?(n=Ms(a,n),n.ref=t.ref,t.child=n,n.return=t,t=n):(n=on(e.child,a),n.ref=t.ref,t.child=n,n.return=t,t=n),t;case 22:return zf(e,t,n);case 24:return va(t),a=ut(Ve),e===null?(s=or(),s===null&&(s=ve,c=rr(),s.pooledCache=c,c.refCount++,c!==null&&(s.pooledCacheLanes|=n),s=c),t.memoizedState={parent:a,cache:s},fr(t),Rn(t,Ve,s)):((e.lanes&n)!==0&&(hr(e,t),Fl(t,null,null,n),Jl()),s=e.memoizedState,c=t.memoizedState,s.parent!==a?(s={parent:a,cache:a},t.memoizedState=s,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=s),Rn(t,Ve,a)):(a=c.cache,Rn(t,Ve,a),a!==s.cache&&cr(t,[Ve],n,!0))),at(e,t,t.pendingProps.children,n),t.child;case 29:throw t.pendingProps}throw Error(u(156,t.tag))}function yn(e){e.flags|=4}function $f(e,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!Jh(t)){if(t=Ht.current,t!==null&&((le&4194048)===le?It!==null:(le&62914560)!==le&&(le&536870912)===0||t!==It))throw Zl=dr,wd;e.flags|=8192}}function zs(e,t){t!==null&&(e.flags|=4),e.flags&16384&&(t=e.tag!==22?yo():536870912,e.lanes|=t,ul|=t)}function ai(e,t){if(!ce)switch(e.tailMode){case"hidden":t=e.tail;for(var n=null;t!==null;)t.alternate!==null&&(n=t),t=t.sibling;n===null?e.tail=null:n.sibling=null;break;case"collapsed":n=e.tail;for(var a=null;n!==null;)n.alternate!==null&&(a=n),n=n.sibling;a===null?t||e.tail===null?e.tail=null:e.tail.sibling=null:a.sibling=null}}function Ee(e){var t=e.alternate!==null&&e.alternate.child===e.child,n=0,a=0;if(t)for(var s=e.child;s!==null;)n|=s.lanes|s.childLanes,a|=s.subtreeFlags&65011712,a|=s.flags&65011712,s.return=e,s=s.sibling;else for(s=e.child;s!==null;)n|=s.lanes|s.childLanes,a|=s.subtreeFlags,a|=s.flags,s.return=e,s=s.sibling;return e.subtreeFlags|=a,e.childLanes=n,t}function Vg(e,t,n){var a=t.pendingProps;switch(ar(t),t.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Ee(t),null;case 1:return Ee(t),null;case 3:return n=t.stateNode,a=null,e!==null&&(a=e.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),mn(Ve),Ba(),n.pendingContext&&(n.context=n.pendingContext,n.pendingContext=null),(e===null||e.child===null)&&(ql(t)?yn(t):e===null||e.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,yd())),Ee(t),null;case 26:return n=t.memoizedState,e===null?(yn(t),n!==null?(Ee(t),$f(t,n)):(Ee(t),t.flags&=-16777217)):n?n!==e.memoizedState?(yn(t),Ee(t),$f(t,n)):(Ee(t),t.flags&=-16777217):(e.memoizedProps!==a&&yn(t),Ee(t),t.flags&=-16777217),null;case 27:Yi(t),n=Mn.current;var s=t.type;if(e!==null&&t.stateNode!=null)e.memoizedProps!==a&&yn(t);else{if(!a){if(t.stateNode===null)throw Error(u(166));return Ee(t),null}e=Ie.current,ql(t)?gd(t):(e=$h(s,a,n),t.stateNode=e,yn(t))}return Ee(t),null;case 5:if(Yi(t),n=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==a&&yn(t);else{if(!a){if(t.stateNode===null)throw Error(u(166));return Ee(t),null}if(e=Ie.current,ql(t))gd(t);else{switch(s=Qs(Mn.current),e){case 1:e=s.createElementNS("http://www.w3.org/2000/svg",n);break;case 2:e=s.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;default:switch(n){case"svg":e=s.createElementNS("http://www.w3.org/2000/svg",n);break;case"math":e=s.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;case"script":e=s.createElement("div"),e.innerHTML="<script><\/script>",e=e.removeChild(e.firstChild);break;case"select":e=typeof a.is=="string"?s.createElement("select",{is:a.is}):s.createElement("select"),a.multiple?e.multiple=!0:a.size&&(e.size=a.size);break;default:e=typeof a.is=="string"?s.createElement(n,{is:a.is}):s.createElement(n)}}e[rt]=t,e[mt]=a;e:for(s=t.child;s!==null;){if(s.tag===5||s.tag===6)e.appendChild(s.stateNode);else if(s.tag!==4&&s.tag!==27&&s.child!==null){s.child.return=s,s=s.child;continue}if(s===t)break e;for(;s.sibling===null;){if(s.return===null||s.return===t)break e;s=s.return}s.sibling.return=s.return,s=s.sibling}t.stateNode=e;e:switch(it(e,n,a),n){case"button":case"input":case"select":case"textarea":e=!!a.autoFocus;break e;case"img":e=!0;break e;default:e=!1}e&&yn(t)}}return Ee(t),t.flags&=-16777217,null;case 6:if(e&&t.stateNode!=null)e.memoizedProps!==a&&yn(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(u(166));if(e=Mn.current,ql(t)){if(e=t.stateNode,n=t.memoizedProps,a=null,s=ht,s!==null)switch(s.tag){case 27:case 5:a=s.memoizedProps}e[rt]=t,e=!!(e.nodeValue===n||a!==null&&a.suppressHydrationWarning===!0||Nh(e.nodeValue,n)),e||pa(t)}else e=Qs(e).createTextNode(a),e[rt]=t,t.stateNode=e}return Ee(t),null;case 13:if(a=t.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(s=ql(t),a!==null&&a.dehydrated!==null){if(e===null){if(!s)throw Error(u(318));if(s=t.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(u(317));s[rt]=t}else $l(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Ee(t),s=!1}else s=yd(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=s),s=!0;if(!s)return t.flags&256?(gn(t),t):(gn(t),null)}if(gn(t),(t.flags&128)!==0)return t.lanes=n,t;if(n=a!==null,e=e!==null&&e.memoizedState!==null,n){a=t.child,s=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(s=a.alternate.memoizedState.cachePool.pool);var c=null;a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(c=a.memoizedState.cachePool.pool),c!==s&&(a.flags|=2048)}return n!==e&&n&&(t.child.flags|=8192),zs(t,t.updateQueue),Ee(t),null;case 4:return Ba(),e===null&&xu(t.stateNode.containerInfo),Ee(t),null;case 10:return mn(t.type),Ee(t),null;case 19:if(Ae(Ze),s=t.memoizedState,s===null)return Ee(t),null;if(a=(t.flags&128)!==0,c=s.rendering,c===null)if(a)ai(s,!1);else{if(Ne!==0||e!==null&&(e.flags&128)!==0)for(e=t.child;e!==null;){if(c=As(e),c!==null){for(t.flags|=128,ai(s,!1),e=c.updateQueue,t.updateQueue=e,zs(t,e),t.subtreeFlags=0,e=n,n=t.child;n!==null;)md(n,e),n=n.sibling;return me(Ze,Ze.current&1|2),t.child}e=e.sibling}s.tail!==null&&Ft()>Rs&&(t.flags|=128,a=!0,ai(s,!1),t.lanes=4194304)}else{if(!a)if(e=As(c),e!==null){if(t.flags|=128,a=!0,e=e.updateQueue,t.updateQueue=e,zs(t,e),ai(s,!0),s.tail===null&&s.tailMode==="hidden"&&!c.alternate&&!ce)return Ee(t),null}else 2*Ft()-s.renderingStartTime>Rs&&n!==536870912&&(t.flags|=128,a=!0,ai(s,!1),t.lanes=4194304);s.isBackwards?(c.sibling=t.child,t.child=c):(e=s.last,e!==null?e.sibling=c:t.child=c,s.last=c)}return s.tail!==null?(t=s.tail,s.rendering=t,s.tail=t.sibling,s.renderingStartTime=Ft(),t.sibling=null,e=Ze.current,me(Ze,a?e&1|2:e&1),t):(Ee(t),null);case 22:case 23:return gn(t),pr(),a=t.memoizedState!==null,e!==null?e.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(n&536870912)!==0&&(t.flags&128)===0&&(Ee(t),t.subtreeFlags&6&&(t.flags|=8192)):Ee(t),n=t.updateQueue,n!==null&&zs(t,n.retryQueue),n=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==n&&(t.flags|=2048),e!==null&&Ae(ja),null;case 24:return n=null,e!==null&&(n=e.memoizedState.cache),t.memoizedState.cache!==n&&(t.flags|=2048),mn(Ve),Ee(t),null;case 25:return null;case 30:return null}throw Error(u(156,t.tag))}function Zg(e,t){switch(ar(t),t.tag){case 1:return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 3:return mn(Ve),Ba(),e=t.flags,(e&65536)!==0&&(e&128)===0?(t.flags=e&-65537|128,t):null;case 26:case 27:case 5:return Yi(t),null;case 13:if(gn(t),e=t.memoizedState,e!==null&&e.dehydrated!==null){if(t.alternate===null)throw Error(u(340));$l()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 19:return Ae(Ze),null;case 4:return Ba(),null;case 10:return mn(t.type),null;case 22:case 23:return gn(t),pr(),e!==null&&Ae(ja),e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 24:return mn(Ve),null;case 25:return null;default:return null}}function Gf(e,t){switch(ar(t),t.tag){case 3:mn(Ve),Ba();break;case 26:case 27:case 5:Yi(t);break;case 4:Ba();break;case 13:gn(t);break;case 19:Ae(Ze);break;case 10:mn(t.type);break;case 22:case 23:gn(t),pr(),e!==null&&Ae(ja);break;case 24:mn(Ve)}}function li(e,t){try{var n=t.updateQueue,a=n!==null?n.lastEffect:null;if(a!==null){var s=a.next;n=s;do{if((n.tag&e)===e){a=void 0;var c=n.create,h=n.inst;a=c(),h.destroy=a}n=n.next}while(n!==s)}}catch(x){ye(t,t.return,x)}}function Gn(e,t,n){try{var a=t.updateQueue,s=a!==null?a.lastEffect:null;if(s!==null){var c=s.next;a=c;do{if((a.tag&e)===e){var h=a.inst,x=h.destroy;if(x!==void 0){h.destroy=void 0,s=t;var v=n,C=x;try{C()}catch(z){ye(s,v,z)}}}a=a.next}while(a!==c)}}catch(z){ye(t,t.return,z)}}function Yf(e){var t=e.updateQueue;if(t!==null){var n=e.stateNode;try{Dd(t,n)}catch(a){ye(e,e.return,a)}}}function Xf(e,t,n){n.props=Sa(e.type,e.memoizedProps),n.state=e.memoizedState;try{n.componentWillUnmount()}catch(a){ye(e,t,a)}}function ii(e,t){try{var n=e.ref;if(n!==null){switch(e.tag){case 26:case 27:case 5:var a=e.stateNode;break;case 30:a=e.stateNode;break;default:a=e.stateNode}typeof n=="function"?e.refCleanup=n(a):n.current=a}}catch(s){ye(e,t,s)}}function Pt(e,t){var n=e.ref,a=e.refCleanup;if(n!==null)if(typeof a=="function")try{a()}catch(s){ye(e,t,s)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof n=="function")try{n(null)}catch(s){ye(e,t,s)}else n.current=null}function Qf(e){var t=e.type,n=e.memoizedProps,a=e.stateNode;try{e:switch(t){case"button":case"input":case"select":case"textarea":n.autoFocus&&a.focus();break e;case"img":n.src?a.src=n.src:n.srcSet&&(a.srcset=n.srcSet)}}catch(s){ye(e,e.return,s)}}function Qr(e,t,n){try{var a=e.stateNode;mp(a,e.type,n,t),a[mt]=t}catch(s){ye(e,e.return,s)}}function Vf(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&Fn(e.type)||e.tag===4}function Vr(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||Vf(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&Fn(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function Zr(e,t,n){var a=e.tag;if(a===5||a===6)e=e.stateNode,t?(n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n).insertBefore(e,t):(t=n.nodeType===9?n.body:n.nodeName==="HTML"?n.ownerDocument.body:n,t.appendChild(e),n=n._reactRootContainer,n!=null||t.onclick!==null||(t.onclick=Xs));else if(a!==4&&(a===27&&Fn(e.type)&&(n=e.stateNode,t=null),e=e.child,e!==null))for(Zr(e,t,n),e=e.sibling;e!==null;)Zr(e,t,n),e=e.sibling}function Bs(e,t,n){var a=e.tag;if(a===5||a===6)e=e.stateNode,t?n.insertBefore(e,t):n.appendChild(e);else if(a!==4&&(a===27&&Fn(e.type)&&(n=e.stateNode),e=e.child,e!==null))for(Bs(e,t,n),e=e.sibling;e!==null;)Bs(e,t,n),e=e.sibling}function Zf(e){var t=e.stateNode,n=e.memoizedProps;try{for(var a=e.type,s=t.attributes;s.length;)t.removeAttributeNode(s[0]);it(t,a,n),t[rt]=e,t[mt]=n}catch(c){ye(e,e.return,c)}}var vn=!1,ke=!1,Kr=!1,Kf=typeof WeakSet=="function"?WeakSet:Set,tt=null;function Kg(e,t){if(e=e.containerInfo,yu=Ws,e=ld(e),Vc(e)){if("selectionStart"in e)var n={start:e.selectionStart,end:e.selectionEnd};else e:{n=(n=e.ownerDocument)&&n.defaultView||window;var a=n.getSelection&&n.getSelection();if(a&&a.rangeCount!==0){n=a.anchorNode;var s=a.anchorOffset,c=a.focusNode;a=a.focusOffset;try{n.nodeType,c.nodeType}catch{n=null;break e}var h=0,x=-1,v=-1,C=0,z=0,R=e,A=null;t:for(;;){for(var D;R!==n||s!==0&&R.nodeType!==3||(x=h+s),R!==c||a!==0&&R.nodeType!==3||(v=h+a),R.nodeType===3&&(h+=R.nodeValue.length),(D=R.firstChild)!==null;)A=R,R=D;for(;;){if(R===e)break t;if(A===n&&++C===s&&(x=h),A===c&&++z===a&&(v=h),(D=R.nextSibling)!==null)break;R=A,A=R.parentNode}R=D}n=x===-1||v===-1?null:{start:x,end:v}}else n=null}n=n||{start:0,end:0}}else n=null;for(vu={focusedElem:e,selectionRange:n},Ws=!1,tt=t;tt!==null;)if(t=tt,e=t.child,(t.subtreeFlags&1024)!==0&&e!==null)e.return=t,tt=e;else for(;tt!==null;){switch(t=tt,c=t.alternate,e=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if((e&1024)!==0&&c!==null){e=void 0,n=t,s=c.memoizedProps,c=c.memoizedState,a=n.stateNode;try{var J=Sa(n.type,s,n.elementType===n.type);e=a.getSnapshotBeforeUpdate(J,c),a.__reactInternalSnapshotBeforeUpdate=e}catch(V){ye(n,n.return,V)}}break;case 3:if((e&1024)!==0){if(e=t.stateNode.containerInfo,n=e.nodeType,n===9)Su(e);else if(n===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":Su(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(u(163))}if(e=t.sibling,e!==null){e.return=t.return,tt=e;break}tt=t.return}}function Jf(e,t,n){var a=n.flags;switch(n.tag){case 0:case 11:case 15:Yn(e,n),a&4&&li(5,n);break;case 1:if(Yn(e,n),a&4)if(e=n.stateNode,t===null)try{e.componentDidMount()}catch(h){ye(n,n.return,h)}else{var s=Sa(n.type,t.memoizedProps);t=t.memoizedState;try{e.componentDidUpdate(s,t,e.__reactInternalSnapshotBeforeUpdate)}catch(h){ye(n,n.return,h)}}a&64&&Yf(n),a&512&&ii(n,n.return);break;case 3:if(Yn(e,n),a&64&&(e=n.updateQueue,e!==null)){if(t=null,n.child!==null)switch(n.child.tag){case 27:case 5:t=n.child.stateNode;break;case 1:t=n.child.stateNode}try{Dd(e,t)}catch(h){ye(n,n.return,h)}}break;case 27:t===null&&a&4&&Zf(n);case 26:case 5:Yn(e,n),t===null&&a&4&&Qf(n),a&512&&ii(n,n.return);break;case 12:Yn(e,n);break;case 13:Yn(e,n),a&4&&If(e,n),a&64&&(e=n.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(n=ap.bind(null,n),bp(e,n))));break;case 22:if(a=n.memoizedState!==null||vn,!a){t=t!==null&&t.memoizedState!==null||ke,s=vn;var c=ke;vn=a,(ke=t)&&!c?Xn(e,n,(n.subtreeFlags&8772)!==0):Yn(e,n),vn=s,ke=c}break;case 30:break;default:Yn(e,n)}}function Ff(e){var t=e.alternate;t!==null&&(e.alternate=null,Ff(t)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(t=e.stateNode,t!==null&&Ac(t)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var _e=null,pt=!1;function jn(e,t,n){for(n=n.child;n!==null;)Wf(e,t,n),n=n.sibling}function Wf(e,t,n){if(St&&typeof St.onCommitFiberUnmount=="function")try{St.onCommitFiberUnmount(Cl,n)}catch{}switch(n.tag){case 26:ke||Pt(n,t),jn(e,t,n),n.memoizedState?n.memoizedState.count--:n.stateNode&&(n=n.stateNode,n.parentNode.removeChild(n));break;case 27:ke||Pt(n,t);var a=_e,s=pt;Fn(n.type)&&(_e=n.stateNode,pt=!1),jn(e,t,n),mi(n.stateNode),_e=a,pt=s;break;case 5:ke||Pt(n,t);case 6:if(a=_e,s=pt,_e=null,jn(e,t,n),_e=a,pt=s,_e!==null)if(pt)try{(_e.nodeType===9?_e.body:_e.nodeName==="HTML"?_e.ownerDocument.body:_e).removeChild(n.stateNode)}catch(c){ye(n,t,c)}else try{_e.removeChild(n.stateNode)}catch(c){ye(n,t,c)}break;case 18:_e!==null&&(pt?(e=_e,Hh(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,n.stateNode),Si(e)):Hh(_e,n.stateNode));break;case 4:a=_e,s=pt,_e=n.stateNode.containerInfo,pt=!0,jn(e,t,n),_e=a,pt=s;break;case 0:case 11:case 14:case 15:ke||Gn(2,n,t),ke||Gn(4,n,t),jn(e,t,n);break;case 1:ke||(Pt(n,t),a=n.stateNode,typeof a.componentWillUnmount=="function"&&Xf(n,t,a)),jn(e,t,n);break;case 21:jn(e,t,n);break;case 22:ke=(a=ke)||n.memoizedState!==null,jn(e,t,n),ke=a;break;default:jn(e,t,n)}}function If(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{Si(e)}catch(n){ye(t,t.return,n)}}function Jg(e){switch(e.tag){case 13:case 19:var t=e.stateNode;return t===null&&(t=e.stateNode=new Kf),t;case 22:return e=e.stateNode,t=e._retryCache,t===null&&(t=e._retryCache=new Kf),t;default:throw Error(u(435,e.tag))}}function Jr(e,t){var n=Jg(e);t.forEach(function(a){var s=lp.bind(null,e,a);n.has(a)||(n.add(a),a.then(s,s))})}function Ct(e,t){var n=t.deletions;if(n!==null)for(var a=0;a<n.length;a++){var s=n[a],c=e,h=t,x=h;e:for(;x!==null;){switch(x.tag){case 27:if(Fn(x.type)){_e=x.stateNode,pt=!1;break e}break;case 5:_e=x.stateNode,pt=!1;break e;case 3:case 4:_e=x.stateNode.containerInfo,pt=!0;break e}x=x.return}if(_e===null)throw Error(u(160));Wf(c,h,s),_e=null,pt=!1,c=s.alternate,c!==null&&(c.return=null),s.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)Pf(t,e),t=t.sibling}var Qt=null;function Pf(e,t){var n=e.alternate,a=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:Ct(t,e),At(e),a&4&&(Gn(3,e,e.return),li(3,e),Gn(5,e,e.return));break;case 1:Ct(t,e),At(e),a&512&&(ke||n===null||Pt(n,n.return)),a&64&&vn&&(e=e.updateQueue,e!==null&&(a=e.callbacks,a!==null&&(n=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=n===null?a:n.concat(a))));break;case 26:var s=Qt;if(Ct(t,e),At(e),a&512&&(ke||n===null||Pt(n,n.return)),a&4){var c=n!==null?n.memoizedState:null;if(a=e.memoizedState,n===null)if(a===null)if(e.stateNode===null){e:{a=e.type,n=e.memoizedProps,s=s.ownerDocument||s;t:switch(a){case"title":c=s.getElementsByTagName("title")[0],(!c||c[Dl]||c[rt]||c.namespaceURI==="http://www.w3.org/2000/svg"||c.hasAttribute("itemprop"))&&(c=s.createElement(a),s.head.insertBefore(c,s.querySelector("head > title"))),it(c,a,n),c[rt]=e,Pe(c),a=c;break e;case"link":var h=Zh("link","href",s).get(a+(n.href||""));if(h){for(var x=0;x<h.length;x++)if(c=h[x],c.getAttribute("href")===(n.href==null||n.href===""?null:n.href)&&c.getAttribute("rel")===(n.rel==null?null:n.rel)&&c.getAttribute("title")===(n.title==null?null:n.title)&&c.getAttribute("crossorigin")===(n.crossOrigin==null?null:n.crossOrigin)){h.splice(x,1);break t}}c=s.createElement(a),it(c,a,n),s.head.appendChild(c);break;case"meta":if(h=Zh("meta","content",s).get(a+(n.content||""))){for(x=0;x<h.length;x++)if(c=h[x],c.getAttribute("content")===(n.content==null?null:""+n.content)&&c.getAttribute("name")===(n.name==null?null:n.name)&&c.getAttribute("property")===(n.property==null?null:n.property)&&c.getAttribute("http-equiv")===(n.httpEquiv==null?null:n.httpEquiv)&&c.getAttribute("charset")===(n.charSet==null?null:n.charSet)){h.splice(x,1);break t}}c=s.createElement(a),it(c,a,n),s.head.appendChild(c);break;default:throw Error(u(468,a))}c[rt]=e,Pe(c),a=c}e.stateNode=a}else Kh(s,e.type,e.stateNode);else e.stateNode=Vh(s,a,e.memoizedProps);else c!==a?(c===null?n.stateNode!==null&&(n=n.stateNode,n.parentNode.removeChild(n)):c.count--,a===null?Kh(s,e.type,e.stateNode):Vh(s,a,e.memoizedProps)):a===null&&e.stateNode!==null&&Qr(e,e.memoizedProps,n.memoizedProps)}break;case 27:Ct(t,e),At(e),a&512&&(ke||n===null||Pt(n,n.return)),n!==null&&a&4&&Qr(e,e.memoizedProps,n.memoizedProps);break;case 5:if(Ct(t,e),At(e),a&512&&(ke||n===null||Pt(n,n.return)),e.flags&32){s=e.stateNode;try{$a(s,"")}catch(D){ye(e,e.return,D)}}a&4&&e.stateNode!=null&&(s=e.memoizedProps,Qr(e,s,n!==null?n.memoizedProps:s)),a&1024&&(Kr=!0);break;case 6:if(Ct(t,e),At(e),a&4){if(e.stateNode===null)throw Error(u(162));a=e.memoizedProps,n=e.stateNode;try{n.nodeValue=a}catch(D){ye(e,e.return,D)}}break;case 3:if(Ks=null,s=Qt,Qt=Vs(t.containerInfo),Ct(t,e),Qt=s,At(e),a&4&&n!==null&&n.memoizedState.isDehydrated)try{Si(t.containerInfo)}catch(D){ye(e,e.return,D)}Kr&&(Kr=!1,eh(e));break;case 4:a=Qt,Qt=Vs(e.stateNode.containerInfo),Ct(t,e),At(e),Qt=a;break;case 12:Ct(t,e),At(e);break;case 13:Ct(t,e),At(e),e.child.flags&8192&&e.memoizedState!==null!=(n!==null&&n.memoizedState!==null)&&(tu=Ft()),a&4&&(a=e.updateQueue,a!==null&&(e.updateQueue=null,Jr(e,a)));break;case 22:s=e.memoizedState!==null;var v=n!==null&&n.memoizedState!==null,C=vn,z=ke;if(vn=C||s,ke=z||v,Ct(t,e),ke=z,vn=C,At(e),a&8192)e:for(t=e.stateNode,t._visibility=s?t._visibility&-2:t._visibility|1,s&&(n===null||v||vn||ke||wa(e)),n=null,t=e;;){if(t.tag===5||t.tag===26){if(n===null){v=n=t;try{if(c=v.stateNode,s)h=c.style,typeof h.setProperty=="function"?h.setProperty("display","none","important"):h.display="none";else{x=v.stateNode;var R=v.memoizedProps.style,A=R!=null&&R.hasOwnProperty("display")?R.display:null;x.style.display=A==null||typeof A=="boolean"?"":(""+A).trim()}}catch(D){ye(v,v.return,D)}}}else if(t.tag===6){if(n===null){v=t;try{v.stateNode.nodeValue=s?"":v.memoizedProps}catch(D){ye(v,v.return,D)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===e)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break e;for(;t.sibling===null;){if(t.return===null||t.return===e)break e;n===t&&(n=null),t=t.return}n===t&&(n=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=e.updateQueue,a!==null&&(n=a.retryQueue,n!==null&&(a.retryQueue=null,Jr(e,n))));break;case 19:Ct(t,e),At(e),a&4&&(a=e.updateQueue,a!==null&&(e.updateQueue=null,Jr(e,a)));break;case 30:break;case 21:break;default:Ct(t,e),At(e)}}function At(e){var t=e.flags;if(t&2){try{for(var n,a=e.return;a!==null;){if(Vf(a)){n=a;break}a=a.return}if(n==null)throw Error(u(160));switch(n.tag){case 27:var s=n.stateNode,c=Vr(e);Bs(e,c,s);break;case 5:var h=n.stateNode;n.flags&32&&($a(h,""),n.flags&=-33);var x=Vr(e);Bs(e,x,h);break;case 3:case 4:var v=n.stateNode.containerInfo,C=Vr(e);Zr(e,C,v);break;default:throw Error(u(161))}}catch(z){ye(e,e.return,z)}e.flags&=-3}t&4096&&(e.flags&=-4097)}function eh(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var t=e;eh(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),e=e.sibling}}function Yn(e,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)Jf(e,t.alternate,t),t=t.sibling}function wa(e){for(e=e.child;e!==null;){var t=e;switch(t.tag){case 0:case 11:case 14:case 15:Gn(4,t,t.return),wa(t);break;case 1:Pt(t,t.return);var n=t.stateNode;typeof n.componentWillUnmount=="function"&&Xf(t,t.return,n),wa(t);break;case 27:mi(t.stateNode);case 26:case 5:Pt(t,t.return),wa(t);break;case 22:t.memoizedState===null&&wa(t);break;case 30:wa(t);break;default:wa(t)}e=e.sibling}}function Xn(e,t,n){for(n=n&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,s=e,c=t,h=c.flags;switch(c.tag){case 0:case 11:case 15:Xn(s,c,n),li(4,c);break;case 1:if(Xn(s,c,n),a=c,s=a.stateNode,typeof s.componentDidMount=="function")try{s.componentDidMount()}catch(C){ye(a,a.return,C)}if(a=c,s=a.updateQueue,s!==null){var x=a.stateNode;try{var v=s.shared.hiddenCallbacks;if(v!==null)for(s.shared.hiddenCallbacks=null,s=0;s<v.length;s++)Ed(v[s],x)}catch(C){ye(a,a.return,C)}}n&&h&64&&Yf(c),ii(c,c.return);break;case 27:Zf(c);case 26:case 5:Xn(s,c,n),n&&a===null&&h&4&&Qf(c),ii(c,c.return);break;case 12:Xn(s,c,n);break;case 13:Xn(s,c,n),n&&h&4&&If(s,c);break;case 22:c.memoizedState===null&&Xn(s,c,n),ii(c,c.return);break;case 30:break;default:Xn(s,c,n)}t=t.sibling}}function Fr(e,t){var n=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(n=e.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==n&&(e!=null&&e.refCount++,n!=null&&Xl(n))}function Wr(e,t){e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&Xl(e))}function en(e,t,n,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)th(e,t,n,a),t=t.sibling}function th(e,t,n,a){var s=t.flags;switch(t.tag){case 0:case 11:case 15:en(e,t,n,a),s&2048&&li(9,t);break;case 1:en(e,t,n,a);break;case 3:en(e,t,n,a),s&2048&&(e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&Xl(e)));break;case 12:if(s&2048){en(e,t,n,a),e=t.stateNode;try{var c=t.memoizedProps,h=c.id,x=c.onPostCommit;typeof x=="function"&&x(h,t.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(v){ye(t,t.return,v)}}else en(e,t,n,a);break;case 13:en(e,t,n,a);break;case 23:break;case 22:c=t.stateNode,h=t.alternate,t.memoizedState!==null?c._visibility&2?en(e,t,n,a):si(e,t):c._visibility&2?en(e,t,n,a):(c._visibility|=2,sl(e,t,n,a,(t.subtreeFlags&10256)!==0)),s&2048&&Fr(h,t);break;case 24:en(e,t,n,a),s&2048&&Wr(t.alternate,t);break;default:en(e,t,n,a)}}function sl(e,t,n,a,s){for(s=s&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var c=e,h=t,x=n,v=a,C=h.flags;switch(h.tag){case 0:case 11:case 15:sl(c,h,x,v,s),li(8,h);break;case 23:break;case 22:var z=h.stateNode;h.memoizedState!==null?z._visibility&2?sl(c,h,x,v,s):si(c,h):(z._visibility|=2,sl(c,h,x,v,s)),s&&C&2048&&Fr(h.alternate,h);break;case 24:sl(c,h,x,v,s),s&&C&2048&&Wr(h.alternate,h);break;default:sl(c,h,x,v,s)}t=t.sibling}}function si(e,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var n=e,a=t,s=a.flags;switch(a.tag){case 22:si(n,a),s&2048&&Fr(a.alternate,a);break;case 24:si(n,a),s&2048&&Wr(a.alternate,a);break;default:si(n,a)}t=t.sibling}}var ci=8192;function cl(e){if(e.subtreeFlags&ci)for(e=e.child;e!==null;)nh(e),e=e.sibling}function nh(e){switch(e.tag){case 26:cl(e),e.flags&ci&&e.memoizedState!==null&&Np(Qt,e.memoizedState,e.memoizedProps);break;case 5:cl(e);break;case 3:case 4:var t=Qt;Qt=Vs(e.stateNode.containerInfo),cl(e),Qt=t;break;case 22:e.memoizedState===null&&(t=e.alternate,t!==null&&t.memoizedState!==null?(t=ci,ci=16777216,cl(e),ci=t):cl(e));break;default:cl(e)}}function ah(e){var t=e.alternate;if(t!==null&&(e=t.child,e!==null)){t.child=null;do t=e.sibling,e.sibling=null,e=t;while(e!==null)}}function ri(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var n=0;n<t.length;n++){var a=t[n];tt=a,ih(a,e)}ah(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)lh(e),e=e.sibling}function lh(e){switch(e.tag){case 0:case 11:case 15:ri(e),e.flags&2048&&Gn(9,e,e.return);break;case 3:ri(e);break;case 12:ri(e);break;case 22:var t=e.stateNode;e.memoizedState!==null&&t._visibility&2&&(e.return===null||e.return.tag!==13)?(t._visibility&=-3,Ns(e)):ri(e);break;default:ri(e)}}function Ns(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var n=0;n<t.length;n++){var a=t[n];tt=a,ih(a,e)}ah(e)}for(e=e.child;e!==null;){switch(t=e,t.tag){case 0:case 11:case 15:Gn(8,t,t.return),Ns(t);break;case 22:n=t.stateNode,n._visibility&2&&(n._visibility&=-3,Ns(t));break;default:Ns(t)}e=e.sibling}}function ih(e,t){for(;tt!==null;){var n=tt;switch(n.tag){case 0:case 11:case 15:Gn(8,n,t);break;case 23:case 22:if(n.memoizedState!==null&&n.memoizedState.cachePool!==null){var a=n.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Xl(n.memoizedState.cache)}if(a=n.child,a!==null)a.return=n,tt=a;else e:for(n=e;tt!==null;){a=tt;var s=a.sibling,c=a.return;if(Ff(a),a===n){tt=null;break e}if(s!==null){s.return=c,tt=s;break e}tt=c}}}var Fg={getCacheForType:function(e){var t=ut(Ve),n=t.data.get(e);return n===void 0&&(n=e(),t.data.set(e,n)),n}},Wg=typeof WeakMap=="function"?WeakMap:Map,fe=0,ve=null,ne=null,le=0,he=0,Et=null,Qn=!1,rl=!1,Ir=!1,bn=0,Ne=0,Vn=0,_a=0,Pr=0,qt=0,ul=0,ui=null,yt=null,eu=!1,tu=0,Rs=1/0,Us=null,Zn=null,lt=0,Kn=null,ol=null,dl=0,nu=0,au=null,sh=null,oi=0,lu=null;function Dt(){if((fe&2)!==0&&le!==0)return le&-le;if(N.T!==null){var e=Ia;return e!==0?e:du()}return bo()}function ch(){qt===0&&(qt=(le&536870912)===0||ce?po():536870912);var e=Ht.current;return e!==null&&(e.flags|=32),qt}function Ot(e,t,n){(e===ve&&(he===2||he===9)||e.cancelPendingCommit!==null)&&(fl(e,0),Jn(e,le,qt,!1)),El(e,n),((fe&2)===0||e!==ve)&&(e===ve&&((fe&2)===0&&(_a|=n),Ne===4&&Jn(e,le,qt,!1)),tn(e))}function rh(e,t,n){if((fe&6)!==0)throw Error(u(327));var a=!n&&(t&124)===0&&(t&e.expiredLanes)===0||Al(e,t),s=a?ep(e,t):cu(e,t,!0),c=a;do{if(s===0){rl&&!a&&Jn(e,t,0,!1);break}else{if(n=e.current.alternate,c&&!Ig(n)){s=cu(e,t,!1),c=!1;continue}if(s===2){if(c=t,e.errorRecoveryDisabledLanes&c)var h=0;else h=e.pendingLanes&-536870913,h=h!==0?h:h&536870912?536870912:0;if(h!==0){t=h;e:{var x=e;s=ui;var v=x.current.memoizedState.isDehydrated;if(v&&(fl(x,h).flags|=256),h=cu(x,h,!1),h!==2){if(Ir&&!v){x.errorRecoveryDisabledLanes|=c,_a|=c,s=4;break e}c=yt,yt=s,c!==null&&(yt===null?yt=c:yt.push.apply(yt,c))}s=h}if(c=!1,s!==2)continue}}if(s===1){fl(e,0),Jn(e,t,0,!0);break}e:{switch(a=e,c=s,c){case 0:case 1:throw Error(u(345));case 4:if((t&4194048)!==t)break;case 6:Jn(a,t,qt,!Qn);break e;case 2:yt=null;break;case 3:case 5:break;default:throw Error(u(329))}if((t&62914560)===t&&(s=tu+300-Ft(),10<s)){if(Jn(a,t,qt,!Qn),Zi(a,0,!0)!==0)break e;a.timeoutHandle=kh(uh.bind(null,a,n,yt,Us,eu,t,qt,_a,ul,Qn,c,2,-0,0),s);break e}uh(a,n,yt,Us,eu,t,qt,_a,ul,Qn,c,0,-0,0)}}break}while(!0);tn(e)}function uh(e,t,n,a,s,c,h,x,v,C,z,R,A,D){if(e.timeoutHandle=-1,R=t.subtreeFlags,(R&8192||(R&16785408)===16785408)&&(pi={stylesheets:null,count:0,unsuspend:Bp},nh(t),R=Rp(),R!==null)){e.cancelPendingCommit=R(gh.bind(null,e,t,c,n,a,s,h,x,v,z,1,A,D)),Jn(e,c,h,!C);return}gh(e,t,c,n,a,s,h,x,v)}function Ig(e){for(var t=e;;){var n=t.tag;if((n===0||n===11||n===15)&&t.flags&16384&&(n=t.updateQueue,n!==null&&(n=n.stores,n!==null)))for(var a=0;a<n.length;a++){var s=n[a],c=s.getSnapshot;s=s.value;try{if(!_t(c(),s))return!1}catch{return!1}}if(n=t.child,t.subtreeFlags&16384&&n!==null)n.return=t,t=n;else{if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function Jn(e,t,n,a){t&=~Pr,t&=~_a,e.suspendedLanes|=t,e.pingedLanes&=~t,a&&(e.warmLanes|=t),a=e.expirationTimes;for(var s=t;0<s;){var c=31-wt(s),h=1<<c;a[c]=-1,s&=~h}n!==0&&vo(e,n,t)}function ks(){return(fe&6)===0?(di(0),!1):!0}function iu(){if(ne!==null){if(he===0)var e=ne.return;else e=ne,hn=ya=null,Sr(e),ll=null,ti=0,e=ne;for(;e!==null;)Gf(e.alternate,e),e=e.return;ne=null}}function fl(e,t){var n=e.timeoutHandle;n!==-1&&(e.timeoutHandle=-1,gp(n)),n=e.cancelPendingCommit,n!==null&&(e.cancelPendingCommit=null,n()),iu(),ve=e,ne=n=on(e.current,null),le=t,he=0,Et=null,Qn=!1,rl=Al(e,t),Ir=!1,ul=qt=Pr=_a=Vn=Ne=0,yt=ui=null,eu=!1,(t&8)!==0&&(t|=t&32);var a=e.entangledLanes;if(a!==0)for(e=e.entanglements,a&=t;0<a;){var s=31-wt(a),c=1<<s;t|=e[s],a&=~c}return bn=t,is(),n}function oh(e,t){P=null,N.H=_s,t===Vl||t===ms?(t=Cd(),he=3):t===wd?(t=Cd(),he=4):he=t===Ef?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Et=t,ne===null&&(Ne=1,Ds(e,Rt(t,e.current)))}function dh(){var e=N.H;return N.H=_s,e===null?_s:e}function fh(){var e=N.A;return N.A=Fg,e}function su(){Ne=4,Qn||(le&4194048)!==le&&Ht.current!==null||(rl=!0),(Vn&134217727)===0&&(_a&134217727)===0||ve===null||Jn(ve,le,qt,!1)}function cu(e,t,n){var a=fe;fe|=2;var s=dh(),c=fh();(ve!==e||le!==t)&&(Us=null,fl(e,t)),t=!1;var h=Ne;e:do try{if(he!==0&&ne!==null){var x=ne,v=Et;switch(he){case 8:iu(),h=6;break e;case 3:case 2:case 9:case 6:Ht.current===null&&(t=!0);var C=he;if(he=0,Et=null,hl(e,x,v,C),n&&rl){h=0;break e}break;default:C=he,he=0,Et=null,hl(e,x,v,C)}}Pg(),h=Ne;break}catch(z){oh(e,z)}while(!0);return t&&e.shellSuspendCounter++,hn=ya=null,fe=a,N.H=s,N.A=c,ne===null&&(ve=null,le=0,is()),h}function Pg(){for(;ne!==null;)hh(ne)}function ep(e,t){var n=fe;fe|=2;var a=dh(),s=fh();ve!==e||le!==t?(Us=null,Rs=Ft()+500,fl(e,t)):rl=Al(e,t);e:do try{if(he!==0&&ne!==null){t=ne;var c=Et;t:switch(he){case 1:he=0,Et=null,hl(e,t,c,1);break;case 2:case 9:if(_d(c)){he=0,Et=null,mh(t);break}t=function(){he!==2&&he!==9||ve!==e||(he=7),tn(e)},c.then(t,t);break e;case 3:he=7;break e;case 4:he=5;break e;case 7:_d(c)?(he=0,Et=null,mh(t)):(he=0,Et=null,hl(e,t,c,7));break;case 5:var h=null;switch(ne.tag){case 26:h=ne.memoizedState;case 5:case 27:var x=ne;if(!h||Jh(h)){he=0,Et=null;var v=x.sibling;if(v!==null)ne=v;else{var C=x.return;C!==null?(ne=C,Ls(C)):ne=null}break t}}he=0,Et=null,hl(e,t,c,5);break;case 6:he=0,Et=null,hl(e,t,c,6);break;case 8:iu(),Ne=6;break e;default:throw Error(u(462))}}tp();break}catch(z){oh(e,z)}while(!0);return hn=ya=null,N.H=a,N.A=s,fe=n,ne!==null?0:(ve=null,le=0,is(),Ne)}function tp(){for(;ne!==null&&!wx();)hh(ne)}function hh(e){var t=qf(e.alternate,e,bn);e.memoizedProps=e.pendingProps,t===null?Ls(e):ne=t}function mh(e){var t=e,n=t.alternate;switch(t.tag){case 15:case 0:t=Nf(n,t,t.pendingProps,t.type,void 0,le);break;case 11:t=Nf(n,t,t.pendingProps,t.type.render,t.ref,le);break;case 5:Sr(t);default:Gf(n,t),t=ne=md(t,bn),t=qf(n,t,bn)}e.memoizedProps=e.pendingProps,t===null?Ls(e):ne=t}function hl(e,t,n,a){hn=ya=null,Sr(t),ll=null,ti=0;var s=t.return;try{if(Xg(e,s,t,n,le)){Ne=1,Ds(e,Rt(n,e.current)),ne=null;return}}catch(c){if(s!==null)throw ne=s,c;Ne=1,Ds(e,Rt(n,e.current)),ne=null;return}t.flags&32768?(ce||a===1?e=!0:rl||(le&536870912)!==0?e=!1:(Qn=e=!0,(a===2||a===9||a===3||a===6)&&(a=Ht.current,a!==null&&a.tag===13&&(a.flags|=16384))),xh(t,e)):Ls(t)}function Ls(e){var t=e;do{if((t.flags&32768)!==0){xh(t,Qn);return}e=t.return;var n=Vg(t.alternate,t,bn);if(n!==null){ne=n;return}if(t=t.sibling,t!==null){ne=t;return}ne=t=e}while(t!==null);Ne===0&&(Ne=5)}function xh(e,t){do{var n=Zg(e.alternate,e);if(n!==null){n.flags&=32767,ne=n;return}if(n=e.return,n!==null&&(n.flags|=32768,n.subtreeFlags=0,n.deletions=null),!t&&(e=e.sibling,e!==null)){ne=e;return}ne=e=n}while(e!==null);Ne=6,ne=null}function gh(e,t,n,a,s,c,h,x,v){e.cancelPendingCommit=null;do Hs();while(lt!==0);if((fe&6)!==0)throw Error(u(327));if(t!==null){if(t===e.current)throw Error(u(177));if(c=t.lanes|t.childLanes,c|=Wc,Bx(e,n,c,h,x,v),e===ve&&(ne=ve=null,le=0),ol=t,Kn=e,dl=n,nu=c,au=s,sh=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,ip(Xi,function(){return bh(),null})):(e.callbackNode=null,e.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=N.T,N.T=null,s=H.p,H.p=2,h=fe,fe|=4;try{Kg(e,t,n)}finally{fe=h,H.p=s,N.T=a}}lt=1,ph(),yh(),vh()}}function ph(){if(lt===1){lt=0;var e=Kn,t=ol,n=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||n){n=N.T,N.T=null;var a=H.p;H.p=2;var s=fe;fe|=4;try{Pf(t,e);var c=vu,h=ld(e.containerInfo),x=c.focusedElem,v=c.selectionRange;if(h!==x&&x&&x.ownerDocument&&ad(x.ownerDocument.documentElement,x)){if(v!==null&&Vc(x)){var C=v.start,z=v.end;if(z===void 0&&(z=C),"selectionStart"in x)x.selectionStart=C,x.selectionEnd=Math.min(z,x.value.length);else{var R=x.ownerDocument||document,A=R&&R.defaultView||window;if(A.getSelection){var D=A.getSelection(),J=x.textContent.length,V=Math.min(v.start,J),pe=v.end===void 0?V:Math.min(v.end,J);!D.extend&&V>pe&&(h=pe,pe=V,V=h);var S=nd(x,V),b=nd(x,pe);if(S&&b&&(D.rangeCount!==1||D.anchorNode!==S.node||D.anchorOffset!==S.offset||D.focusNode!==b.node||D.focusOffset!==b.offset)){var _=R.createRange();_.setStart(S.node,S.offset),D.removeAllRanges(),V>pe?(D.addRange(_),D.extend(b.node,b.offset)):(_.setEnd(b.node,b.offset),D.addRange(_))}}}}for(R=[],D=x;D=D.parentNode;)D.nodeType===1&&R.push({element:D,left:D.scrollLeft,top:D.scrollTop});for(typeof x.focus=="function"&&x.focus(),x=0;x<R.length;x++){var B=R[x];B.element.scrollLeft=B.left,B.element.scrollTop=B.top}}Ws=!!yu,vu=yu=null}finally{fe=s,H.p=a,N.T=n}}e.current=t,lt=2}}function yh(){if(lt===2){lt=0;var e=Kn,t=ol,n=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||n){n=N.T,N.T=null;var a=H.p;H.p=2;var s=fe;fe|=4;try{Jf(e,t.alternate,t)}finally{fe=s,H.p=a,N.T=n}}lt=3}}function vh(){if(lt===4||lt===3){lt=0,_x();var e=Kn,t=ol,n=dl,a=sh;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?lt=5:(lt=0,ol=Kn=null,jh(e,e.pendingLanes));var s=e.pendingLanes;if(s===0&&(Zn=null),Tc(n),t=t.stateNode,St&&typeof St.onCommitFiberRoot=="function")try{St.onCommitFiberRoot(Cl,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=N.T,s=H.p,H.p=2,N.T=null;try{for(var c=e.onRecoverableError,h=0;h<a.length;h++){var x=a[h];c(x.value,{componentStack:x.stack})}}finally{N.T=t,H.p=s}}(dl&3)!==0&&Hs(),tn(e),s=e.pendingLanes,(n&4194090)!==0&&(s&42)!==0?e===lu?oi++:(oi=0,lu=e):oi=0,di(0)}}function jh(e,t){(e.pooledCacheLanes&=t)===0&&(t=e.pooledCache,t!=null&&(e.pooledCache=null,Xl(t)))}function Hs(e){return ph(),yh(),vh(),bh()}function bh(){if(lt!==5)return!1;var e=Kn,t=nu;nu=0;var n=Tc(dl),a=N.T,s=H.p;try{H.p=32>n?32:n,N.T=null,n=au,au=null;var c=Kn,h=dl;if(lt=0,ol=Kn=null,dl=0,(fe&6)!==0)throw Error(u(331));var x=fe;if(fe|=4,lh(c.current),th(c,c.current,h,n),fe=x,di(0,!1),St&&typeof St.onPostCommitFiberRoot=="function")try{St.onPostCommitFiberRoot(Cl,c)}catch{}return!0}finally{H.p=s,N.T=a,jh(e,t)}}function Sh(e,t,n){t=Rt(n,t),t=Ur(e.stateNode,t,2),e=Ln(e,t,2),e!==null&&(El(e,2),tn(e))}function ye(e,t,n){if(e.tag===3)Sh(e,e,n);else for(;t!==null;){if(t.tag===3){Sh(t,e,n);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(Zn===null||!Zn.has(a))){e=Rt(n,e),n=Cf(2),a=Ln(t,n,2),a!==null&&(Af(n,a,t,e),El(a,2),tn(a));break}}t=t.return}}function ru(e,t,n){var a=e.pingCache;if(a===null){a=e.pingCache=new Wg;var s=new Set;a.set(t,s)}else s=a.get(t),s===void 0&&(s=new Set,a.set(t,s));s.has(n)||(Ir=!0,s.add(n),e=np.bind(null,e,t,n),t.then(e,e))}function np(e,t,n){var a=e.pingCache;a!==null&&a.delete(t),e.pingedLanes|=e.suspendedLanes&n,e.warmLanes&=~n,ve===e&&(le&n)===n&&(Ne===4||Ne===3&&(le&62914560)===le&&300>Ft()-tu?(fe&2)===0&&fl(e,0):Pr|=n,ul===le&&(ul=0)),tn(e)}function wh(e,t){t===0&&(t=yo()),e=Ka(e,t),e!==null&&(El(e,t),tn(e))}function ap(e){var t=e.memoizedState,n=0;t!==null&&(n=t.retryLane),wh(e,n)}function lp(e,t){var n=0;switch(e.tag){case 13:var a=e.stateNode,s=e.memoizedState;s!==null&&(n=s.retryLane);break;case 19:a=e.stateNode;break;case 22:a=e.stateNode._retryCache;break;default:throw Error(u(314))}a!==null&&a.delete(t),wh(e,n)}function ip(e,t){return bc(e,t)}var qs=null,ml=null,uu=!1,$s=!1,ou=!1,Ta=0;function tn(e){e!==ml&&e.next===null&&(ml===null?qs=ml=e:ml=ml.next=e),$s=!0,uu||(uu=!0,cp())}function di(e,t){if(!ou&&$s){ou=!0;do for(var n=!1,a=qs;a!==null;){if(e!==0){var s=a.pendingLanes;if(s===0)var c=0;else{var h=a.suspendedLanes,x=a.pingedLanes;c=(1<<31-wt(42|e)+1)-1,c&=s&~(h&~x),c=c&201326741?c&201326741|1:c?c|2:0}c!==0&&(n=!0,Ah(a,c))}else c=le,c=Zi(a,a===ve?c:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(c&3)===0||Al(a,c)||(n=!0,Ah(a,c));a=a.next}while(n);ou=!1}}function sp(){_h()}function _h(){$s=uu=!1;var e=0;Ta!==0&&(xp()&&(e=Ta),Ta=0);for(var t=Ft(),n=null,a=qs;a!==null;){var s=a.next,c=Th(a,t);c===0?(a.next=null,n===null?qs=s:n.next=s,s===null&&(ml=n)):(n=a,(e!==0||(c&3)!==0)&&($s=!0)),a=s}di(e)}function Th(e,t){for(var n=e.suspendedLanes,a=e.pingedLanes,s=e.expirationTimes,c=e.pendingLanes&-62914561;0<c;){var h=31-wt(c),x=1<<h,v=s[h];v===-1?((x&n)===0||(x&a)!==0)&&(s[h]=zx(x,t)):v<=t&&(e.expiredLanes|=x),c&=~x}if(t=ve,n=le,n=Zi(e,e===t?n:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),a=e.callbackNode,n===0||e===t&&(he===2||he===9)||e.cancelPendingCommit!==null)return a!==null&&a!==null&&Sc(a),e.callbackNode=null,e.callbackPriority=0;if((n&3)===0||Al(e,n)){if(t=n&-n,t===e.callbackPriority)return t;switch(a!==null&&Sc(a),Tc(n)){case 2:case 8:n=xo;break;case 32:n=Xi;break;case 268435456:n=go;break;default:n=Xi}return a=Ch.bind(null,e),n=bc(n,a),e.callbackPriority=t,e.callbackNode=n,t}return a!==null&&a!==null&&Sc(a),e.callbackPriority=2,e.callbackNode=null,2}function Ch(e,t){if(lt!==0&&lt!==5)return e.callbackNode=null,e.callbackPriority=0,null;var n=e.callbackNode;if(Hs()&&e.callbackNode!==n)return null;var a=le;return a=Zi(e,e===ve?a:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),a===0?null:(rh(e,a,t),Th(e,Ft()),e.callbackNode!=null&&e.callbackNode===n?Ch.bind(null,e):null)}function Ah(e,t){if(Hs())return null;rh(e,t,!0)}function cp(){pp(function(){(fe&6)!==0?bc(mo,sp):_h()})}function du(){return Ta===0&&(Ta=po()),Ta}function Eh(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:Ii(""+e)}function Dh(e,t){var n=t.ownerDocument.createElement("input");return n.name=t.name,n.value=t.value,e.id&&n.setAttribute("form",e.id),t.parentNode.insertBefore(n,t),e=new FormData(e),n.parentNode.removeChild(n),e}function rp(e,t,n,a,s){if(t==="submit"&&n&&n.stateNode===s){var c=Eh((s[mt]||null).action),h=a.submitter;h&&(t=(t=h[mt]||null)?Eh(t.formAction):h.getAttribute("formAction"),t!==null&&(c=t,h=null));var x=new ns("action","action",null,a,s);e.push({event:x,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Ta!==0){var v=h?Dh(s,h):new FormData(s);Mr(n,{pending:!0,data:v,method:s.method,action:c},null,v)}}else typeof c=="function"&&(x.preventDefault(),v=h?Dh(s,h):new FormData(s),Mr(n,{pending:!0,data:v,method:s.method,action:c},c,v))},currentTarget:s}]})}}for(var fu=0;fu<Fc.length;fu++){var hu=Fc[fu],up=hu.toLowerCase(),op=hu[0].toUpperCase()+hu.slice(1);Xt(up,"on"+op)}Xt(cd,"onAnimationEnd"),Xt(rd,"onAnimationIteration"),Xt(ud,"onAnimationStart"),Xt("dblclick","onDoubleClick"),Xt("focusin","onFocus"),Xt("focusout","onBlur"),Xt(Ag,"onTransitionRun"),Xt(Eg,"onTransitionStart"),Xt(Dg,"onTransitionCancel"),Xt(od,"onTransitionEnd"),La("onMouseEnter",["mouseout","mouseover"]),La("onMouseLeave",["mouseout","mouseover"]),La("onPointerEnter",["pointerout","pointerover"]),La("onPointerLeave",["pointerout","pointerover"]),ua("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),ua("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),ua("onBeforeInput",["compositionend","keypress","textInput","paste"]),ua("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),ua("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),ua("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var fi="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),dp=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(fi));function Oh(e,t){t=(t&4)!==0;for(var n=0;n<e.length;n++){var a=e[n],s=a.event;a=a.listeners;e:{var c=void 0;if(t)for(var h=a.length-1;0<=h;h--){var x=a[h],v=x.instance,C=x.currentTarget;if(x=x.listener,v!==c&&s.isPropagationStopped())break e;c=x,s.currentTarget=C;try{c(s)}catch(z){Es(z)}s.currentTarget=null,c=v}else for(h=0;h<a.length;h++){if(x=a[h],v=x.instance,C=x.currentTarget,x=x.listener,v!==c&&s.isPropagationStopped())break e;c=x,s.currentTarget=C;try{c(s)}catch(z){Es(z)}s.currentTarget=null,c=v}}}}function ae(e,t){var n=t[Cc];n===void 0&&(n=t[Cc]=new Set);var a=e+"__bubble";n.has(a)||(Mh(t,e,2,!1),n.add(a))}function mu(e,t,n){var a=0;t&&(a|=4),Mh(n,e,a,t)}var Gs="_reactListening"+Math.random().toString(36).slice(2);function xu(e){if(!e[Gs]){e[Gs]=!0,wo.forEach(function(n){n!=="selectionchange"&&(dp.has(n)||mu(n,!1,e),mu(n,!0,e))});var t=e.nodeType===9?e:e.ownerDocument;t===null||t[Gs]||(t[Gs]=!0,mu("selectionchange",!1,t))}}function Mh(e,t,n,a){switch(tm(t)){case 2:var s=Lp;break;case 8:s=Hp;break;default:s=Du}n=s.bind(null,t,n,e),s=void 0,!kc||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(s=!0),a?s!==void 0?e.addEventListener(t,n,{capture:!0,passive:s}):e.addEventListener(t,n,!0):s!==void 0?e.addEventListener(t,n,{passive:s}):e.addEventListener(t,n,!1)}function gu(e,t,n,a,s){var c=a;if((t&1)===0&&(t&2)===0&&a!==null)e:for(;;){if(a===null)return;var h=a.tag;if(h===3||h===4){var x=a.stateNode.containerInfo;if(x===s)break;if(h===4)for(h=a.return;h!==null;){var v=h.tag;if((v===3||v===4)&&h.stateNode.containerInfo===s)return;h=h.return}for(;x!==null;){if(h=Ra(x),h===null)return;if(v=h.tag,v===5||v===6||v===26||v===27){a=c=h;continue e}x=x.parentNode}}a=a.return}ko(function(){var C=c,z=Rc(n),R=[];e:{var A=dd.get(e);if(A!==void 0){var D=ns,J=e;switch(e){case"keypress":if(es(n)===0)break e;case"keydown":case"keyup":D=ig;break;case"focusin":J="focus",D=$c;break;case"focusout":J="blur",D=$c;break;case"beforeblur":case"afterblur":D=$c;break;case"click":if(n.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":D=qo;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":D=Zx;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":D=rg;break;case cd:case rd:case ud:D=Fx;break;case od:D=og;break;case"scroll":case"scrollend":D=Qx;break;case"wheel":D=fg;break;case"copy":case"cut":case"paste":D=Ix;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":D=Go;break;case"toggle":case"beforetoggle":D=mg}var V=(t&4)!==0,pe=!V&&(e==="scroll"||e==="scrollend"),S=V?A!==null?A+"Capture":null:A;V=[];for(var b=C,_;b!==null;){var B=b;if(_=B.stateNode,B=B.tag,B!==5&&B!==26&&B!==27||_===null||S===null||(B=Ml(b,S),B!=null&&V.push(hi(b,B,_))),pe)break;b=b.return}0<V.length&&(A=new D(A,J,null,n,z),R.push({event:A,listeners:V}))}}if((t&7)===0){e:{if(A=e==="mouseover"||e==="pointerover",D=e==="mouseout"||e==="pointerout",A&&n!==Nc&&(J=n.relatedTarget||n.fromElement)&&(Ra(J)||J[Na]))break e;if((D||A)&&(A=z.window===z?z:(A=z.ownerDocument)?A.defaultView||A.parentWindow:window,D?(J=n.relatedTarget||n.toElement,D=C,J=J?Ra(J):null,J!==null&&(pe=f(J),V=J.tag,J!==pe||V!==5&&V!==27&&V!==6)&&(J=null)):(D=null,J=C),D!==J)){if(V=qo,B="onMouseLeave",S="onMouseEnter",b="mouse",(e==="pointerout"||e==="pointerover")&&(V=Go,B="onPointerLeave",S="onPointerEnter",b="pointer"),pe=D==null?A:Ol(D),_=J==null?A:Ol(J),A=new V(B,b+"leave",D,n,z),A.target=pe,A.relatedTarget=_,B=null,Ra(z)===C&&(V=new V(S,b+"enter",J,n,z),V.target=_,V.relatedTarget=pe,B=V),pe=B,D&&J)t:{for(V=D,S=J,b=0,_=V;_;_=xl(_))b++;for(_=0,B=S;B;B=xl(B))_++;for(;0<b-_;)V=xl(V),b--;for(;0<_-b;)S=xl(S),_--;for(;b--;){if(V===S||S!==null&&V===S.alternate)break t;V=xl(V),S=xl(S)}V=null}else V=null;D!==null&&zh(R,A,D,V,!1),J!==null&&pe!==null&&zh(R,pe,J,V,!0)}}e:{if(A=C?Ol(C):window,D=A.nodeName&&A.nodeName.toLowerCase(),D==="select"||D==="input"&&A.type==="file")var $=Fo;else if(Ko(A))if(Wo)$=_g;else{$=Sg;var ee=bg}else D=A.nodeName,!D||D.toLowerCase()!=="input"||A.type!=="checkbox"&&A.type!=="radio"?C&&Bc(C.elementType)&&($=Fo):$=wg;if($&&($=$(e,C))){Jo(R,$,n,z);break e}ee&&ee(e,A,C),e==="focusout"&&C&&A.type==="number"&&C.memoizedProps.value!=null&&zc(A,"number",A.value)}switch(ee=C?Ol(C):window,e){case"focusin":(Ko(ee)||ee.contentEditable==="true")&&(Qa=ee,Zc=C,Hl=null);break;case"focusout":Hl=Zc=Qa=null;break;case"mousedown":Kc=!0;break;case"contextmenu":case"mouseup":case"dragend":Kc=!1,id(R,n,z);break;case"selectionchange":if(Cg)break;case"keydown":case"keyup":id(R,n,z)}var X;if(Yc)e:{switch(e){case"compositionstart":var Z="onCompositionStart";break e;case"compositionend":Z="onCompositionEnd";break e;case"compositionupdate":Z="onCompositionUpdate";break e}Z=void 0}else Xa?Vo(e,n)&&(Z="onCompositionEnd"):e==="keydown"&&n.keyCode===229&&(Z="onCompositionStart");Z&&(Yo&&n.locale!=="ko"&&(Xa||Z!=="onCompositionStart"?Z==="onCompositionEnd"&&Xa&&(X=Lo()):(Nn=z,Lc="value"in Nn?Nn.value:Nn.textContent,Xa=!0)),ee=Ys(C,Z),0<ee.length&&(Z=new $o(Z,e,null,n,z),R.push({event:Z,listeners:ee}),X?Z.data=X:(X=Zo(n),X!==null&&(Z.data=X)))),(X=gg?pg(e,n):yg(e,n))&&(Z=Ys(C,"onBeforeInput"),0<Z.length&&(ee=new $o("onBeforeInput","beforeinput",null,n,z),R.push({event:ee,listeners:Z}),ee.data=X)),rp(R,e,C,n,z)}Oh(R,t)})}function hi(e,t,n){return{instance:e,listener:t,currentTarget:n}}function Ys(e,t){for(var n=t+"Capture",a=[];e!==null;){var s=e,c=s.stateNode;if(s=s.tag,s!==5&&s!==26&&s!==27||c===null||(s=Ml(e,n),s!=null&&a.unshift(hi(e,s,c)),s=Ml(e,t),s!=null&&a.push(hi(e,s,c))),e.tag===3)return a;e=e.return}return[]}function xl(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function zh(e,t,n,a,s){for(var c=t._reactName,h=[];n!==null&&n!==a;){var x=n,v=x.alternate,C=x.stateNode;if(x=x.tag,v!==null&&v===a)break;x!==5&&x!==26&&x!==27||C===null||(v=C,s?(C=Ml(n,c),C!=null&&h.unshift(hi(n,C,v))):s||(C=Ml(n,c),C!=null&&h.push(hi(n,C,v)))),n=n.return}h.length!==0&&e.push({event:t,listeners:h})}var fp=/\r\n?/g,hp=/\u0000|\uFFFD/g;function Bh(e){return(typeof e=="string"?e:""+e).replace(fp,`
`).replace(hp,"")}function Nh(e,t){return t=Bh(t),Bh(e)===t}function Xs(){}function ge(e,t,n,a,s,c){switch(n){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||$a(e,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&$a(e,""+a);break;case"className":Ji(e,"class",a);break;case"tabIndex":Ji(e,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":Ji(e,n,a);break;case"style":Ro(e,a,c);break;case"data":if(t!=="object"){Ji(e,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||n!=="href")){e.removeAttribute(n);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){e.removeAttribute(n);break}a=Ii(""+a),e.setAttribute(n,a);break;case"action":case"formAction":if(typeof a=="function"){e.setAttribute(n,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof c=="function"&&(n==="formAction"?(t!=="input"&&ge(e,t,"name",s.name,s,null),ge(e,t,"formEncType",s.formEncType,s,null),ge(e,t,"formMethod",s.formMethod,s,null),ge(e,t,"formTarget",s.formTarget,s,null)):(ge(e,t,"encType",s.encType,s,null),ge(e,t,"method",s.method,s,null),ge(e,t,"target",s.target,s,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){e.removeAttribute(n);break}a=Ii(""+a),e.setAttribute(n,a);break;case"onClick":a!=null&&(e.onclick=Xs);break;case"onScroll":a!=null&&ae("scroll",e);break;case"onScrollEnd":a!=null&&ae("scrollend",e);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(u(61));if(n=a.__html,n!=null){if(s.children!=null)throw Error(u(60));e.innerHTML=n}}break;case"multiple":e.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":e.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){e.removeAttribute("xlink:href");break}n=Ii(""+a),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",n);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(n,""+a):e.removeAttribute(n);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(n,""):e.removeAttribute(n);break;case"capture":case"download":a===!0?e.setAttribute(n,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(n,a):e.removeAttribute(n);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?e.setAttribute(n,a):e.removeAttribute(n);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?e.removeAttribute(n):e.setAttribute(n,a);break;case"popover":ae("beforetoggle",e),ae("toggle",e),Ki(e,"popover",a);break;case"xlinkActuate":rn(e,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":rn(e,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":rn(e,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":rn(e,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":rn(e,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":rn(e,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":rn(e,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":rn(e,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":rn(e,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":Ki(e,"is",a);break;case"innerText":case"textContent":break;default:(!(2<n.length)||n[0]!=="o"&&n[0]!=="O"||n[1]!=="n"&&n[1]!=="N")&&(n=Yx.get(n)||n,Ki(e,n,a))}}function pu(e,t,n,a,s,c){switch(n){case"style":Ro(e,a,c);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(u(61));if(n=a.__html,n!=null){if(s.children!=null)throw Error(u(60));e.innerHTML=n}}break;case"children":typeof a=="string"?$a(e,a):(typeof a=="number"||typeof a=="bigint")&&$a(e,""+a);break;case"onScroll":a!=null&&ae("scroll",e);break;case"onScrollEnd":a!=null&&ae("scrollend",e);break;case"onClick":a!=null&&(e.onclick=Xs);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!_o.hasOwnProperty(n))e:{if(n[0]==="o"&&n[1]==="n"&&(s=n.endsWith("Capture"),t=n.slice(2,s?n.length-7:void 0),c=e[mt]||null,c=c!=null?c[n]:null,typeof c=="function"&&e.removeEventListener(t,c,s),typeof a=="function")){typeof c!="function"&&c!==null&&(n in e?e[n]=null:e.hasAttribute(n)&&e.removeAttribute(n)),e.addEventListener(t,a,s);break e}n in e?e[n]=a:a===!0?e.setAttribute(n,""):Ki(e,n,a)}}}function it(e,t,n){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":ae("error",e),ae("load",e);var a=!1,s=!1,c;for(c in n)if(n.hasOwnProperty(c)){var h=n[c];if(h!=null)switch(c){case"src":a=!0;break;case"srcSet":s=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(u(137,t));default:ge(e,t,c,h,n,null)}}s&&ge(e,t,"srcSet",n.srcSet,n,null),a&&ge(e,t,"src",n.src,n,null);return;case"input":ae("invalid",e);var x=c=h=s=null,v=null,C=null;for(a in n)if(n.hasOwnProperty(a)){var z=n[a];if(z!=null)switch(a){case"name":s=z;break;case"type":h=z;break;case"checked":v=z;break;case"defaultChecked":C=z;break;case"value":c=z;break;case"defaultValue":x=z;break;case"children":case"dangerouslySetInnerHTML":if(z!=null)throw Error(u(137,t));break;default:ge(e,t,a,z,n,null)}}Mo(e,c,x,v,C,h,s,!1),Fi(e);return;case"select":ae("invalid",e),a=h=c=null;for(s in n)if(n.hasOwnProperty(s)&&(x=n[s],x!=null))switch(s){case"value":c=x;break;case"defaultValue":h=x;break;case"multiple":a=x;default:ge(e,t,s,x,n,null)}t=c,n=h,e.multiple=!!a,t!=null?qa(e,!!a,t,!1):n!=null&&qa(e,!!a,n,!0);return;case"textarea":ae("invalid",e),c=s=a=null;for(h in n)if(n.hasOwnProperty(h)&&(x=n[h],x!=null))switch(h){case"value":a=x;break;case"defaultValue":s=x;break;case"children":c=x;break;case"dangerouslySetInnerHTML":if(x!=null)throw Error(u(91));break;default:ge(e,t,h,x,n,null)}Bo(e,a,s,c),Fi(e);return;case"option":for(v in n)if(n.hasOwnProperty(v)&&(a=n[v],a!=null))switch(v){case"selected":e.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:ge(e,t,v,a,n,null)}return;case"dialog":ae("beforetoggle",e),ae("toggle",e),ae("cancel",e),ae("close",e);break;case"iframe":case"object":ae("load",e);break;case"video":case"audio":for(a=0;a<fi.length;a++)ae(fi[a],e);break;case"image":ae("error",e),ae("load",e);break;case"details":ae("toggle",e);break;case"embed":case"source":case"link":ae("error",e),ae("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(C in n)if(n.hasOwnProperty(C)&&(a=n[C],a!=null))switch(C){case"children":case"dangerouslySetInnerHTML":throw Error(u(137,t));default:ge(e,t,C,a,n,null)}return;default:if(Bc(t)){for(z in n)n.hasOwnProperty(z)&&(a=n[z],a!==void 0&&pu(e,t,z,a,n,void 0));return}}for(x in n)n.hasOwnProperty(x)&&(a=n[x],a!=null&&ge(e,t,x,a,n,null))}function mp(e,t,n,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var s=null,c=null,h=null,x=null,v=null,C=null,z=null;for(D in n){var R=n[D];if(n.hasOwnProperty(D)&&R!=null)switch(D){case"checked":break;case"value":break;case"defaultValue":v=R;default:a.hasOwnProperty(D)||ge(e,t,D,null,a,R)}}for(var A in a){var D=a[A];if(R=n[A],a.hasOwnProperty(A)&&(D!=null||R!=null))switch(A){case"type":c=D;break;case"name":s=D;break;case"checked":C=D;break;case"defaultChecked":z=D;break;case"value":h=D;break;case"defaultValue":x=D;break;case"children":case"dangerouslySetInnerHTML":if(D!=null)throw Error(u(137,t));break;default:D!==R&&ge(e,t,A,D,a,R)}}Mc(e,h,x,v,C,z,c,s);return;case"select":D=h=x=A=null;for(c in n)if(v=n[c],n.hasOwnProperty(c)&&v!=null)switch(c){case"value":break;case"multiple":D=v;default:a.hasOwnProperty(c)||ge(e,t,c,null,a,v)}for(s in a)if(c=a[s],v=n[s],a.hasOwnProperty(s)&&(c!=null||v!=null))switch(s){case"value":A=c;break;case"defaultValue":x=c;break;case"multiple":h=c;default:c!==v&&ge(e,t,s,c,a,v)}t=x,n=h,a=D,A!=null?qa(e,!!n,A,!1):!!a!=!!n&&(t!=null?qa(e,!!n,t,!0):qa(e,!!n,n?[]:"",!1));return;case"textarea":D=A=null;for(x in n)if(s=n[x],n.hasOwnProperty(x)&&s!=null&&!a.hasOwnProperty(x))switch(x){case"value":break;case"children":break;default:ge(e,t,x,null,a,s)}for(h in a)if(s=a[h],c=n[h],a.hasOwnProperty(h)&&(s!=null||c!=null))switch(h){case"value":A=s;break;case"defaultValue":D=s;break;case"children":break;case"dangerouslySetInnerHTML":if(s!=null)throw Error(u(91));break;default:s!==c&&ge(e,t,h,s,a,c)}zo(e,A,D);return;case"option":for(var J in n)if(A=n[J],n.hasOwnProperty(J)&&A!=null&&!a.hasOwnProperty(J))switch(J){case"selected":e.selected=!1;break;default:ge(e,t,J,null,a,A)}for(v in a)if(A=a[v],D=n[v],a.hasOwnProperty(v)&&A!==D&&(A!=null||D!=null))switch(v){case"selected":e.selected=A&&typeof A!="function"&&typeof A!="symbol";break;default:ge(e,t,v,A,a,D)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var V in n)A=n[V],n.hasOwnProperty(V)&&A!=null&&!a.hasOwnProperty(V)&&ge(e,t,V,null,a,A);for(C in a)if(A=a[C],D=n[C],a.hasOwnProperty(C)&&A!==D&&(A!=null||D!=null))switch(C){case"children":case"dangerouslySetInnerHTML":if(A!=null)throw Error(u(137,t));break;default:ge(e,t,C,A,a,D)}return;default:if(Bc(t)){for(var pe in n)A=n[pe],n.hasOwnProperty(pe)&&A!==void 0&&!a.hasOwnProperty(pe)&&pu(e,t,pe,void 0,a,A);for(z in a)A=a[z],D=n[z],!a.hasOwnProperty(z)||A===D||A===void 0&&D===void 0||pu(e,t,z,A,a,D);return}}for(var S in n)A=n[S],n.hasOwnProperty(S)&&A!=null&&!a.hasOwnProperty(S)&&ge(e,t,S,null,a,A);for(R in a)A=a[R],D=n[R],!a.hasOwnProperty(R)||A===D||A==null&&D==null||ge(e,t,R,A,a,D)}var yu=null,vu=null;function Qs(e){return e.nodeType===9?e:e.ownerDocument}function Rh(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Uh(e,t){if(e===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&t==="foreignObject"?0:e}function ju(e,t){return e==="textarea"||e==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var bu=null;function xp(){var e=window.event;return e&&e.type==="popstate"?e===bu?!1:(bu=e,!0):(bu=null,!1)}var kh=typeof setTimeout=="function"?setTimeout:void 0,gp=typeof clearTimeout=="function"?clearTimeout:void 0,Lh=typeof Promise=="function"?Promise:void 0,pp=typeof queueMicrotask=="function"?queueMicrotask:typeof Lh<"u"?function(e){return Lh.resolve(null).then(e).catch(yp)}:kh;function yp(e){setTimeout(function(){throw e})}function Fn(e){return e==="head"}function Hh(e,t){var n=t,a=0,s=0;do{var c=n.nextSibling;if(e.removeChild(n),c&&c.nodeType===8)if(n=c.data,n==="/$"){if(0<a&&8>a){n=a;var h=e.ownerDocument;if(n&1&&mi(h.documentElement),n&2&&mi(h.body),n&4)for(n=h.head,mi(n),h=n.firstChild;h;){var x=h.nextSibling,v=h.nodeName;h[Dl]||v==="SCRIPT"||v==="STYLE"||v==="LINK"&&h.rel.toLowerCase()==="stylesheet"||n.removeChild(h),h=x}}if(s===0){e.removeChild(c),Si(t);return}s--}else n==="$"||n==="$?"||n==="$!"?s++:a=n.charCodeAt(0)-48;else a=0;n=c}while(n);Si(t)}function Su(e){var t=e.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var n=t;switch(t=t.nextSibling,n.nodeName){case"HTML":case"HEAD":case"BODY":Su(n),Ac(n);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(n.rel.toLowerCase()==="stylesheet")continue}e.removeChild(n)}}function vp(e,t,n,a){for(;e.nodeType===1;){var s=n;if(e.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(a){if(!e[Dl])switch(t){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(c=e.getAttribute("rel"),c==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(c!==s.rel||e.getAttribute("href")!==(s.href==null||s.href===""?null:s.href)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin)||e.getAttribute("title")!==(s.title==null?null:s.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(c=e.getAttribute("src"),(c!==(s.src==null?null:s.src)||e.getAttribute("type")!==(s.type==null?null:s.type)||e.getAttribute("crossorigin")!==(s.crossOrigin==null?null:s.crossOrigin))&&c&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(t==="input"&&e.type==="hidden"){var c=s.name==null?null:""+s.name;if(s.type==="hidden"&&e.getAttribute("name")===c)return e}else return e;if(e=Vt(e.nextSibling),e===null)break}return null}function jp(e,t,n){if(t==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!n||(e=Vt(e.nextSibling),e===null))return null;return e}function wu(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState==="complete"}function bp(e,t){var n=e.ownerDocument;if(e.data!=="$?"||n.readyState==="complete")t();else{var a=function(){t(),n.removeEventListener("DOMContentLoaded",a)};n.addEventListener("DOMContentLoaded",a),e._reactRetry=a}}function Vt(e){for(;e!=null;e=e.nextSibling){var t=e.nodeType;if(t===1||t===3)break;if(t===8){if(t=e.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return e}var _u=null;function qh(e){e=e.previousSibling;for(var t=0;e;){if(e.nodeType===8){var n=e.data;if(n==="$"||n==="$!"||n==="$?"){if(t===0)return e;t--}else n==="/$"&&t++}e=e.previousSibling}return null}function $h(e,t,n){switch(t=Qs(n),e){case"html":if(e=t.documentElement,!e)throw Error(u(452));return e;case"head":if(e=t.head,!e)throw Error(u(453));return e;case"body":if(e=t.body,!e)throw Error(u(454));return e;default:throw Error(u(451))}}function mi(e){for(var t=e.attributes;t.length;)e.removeAttributeNode(t[0]);Ac(e)}var $t=new Map,Gh=new Set;function Vs(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var Sn=H.d;H.d={f:Sp,r:wp,D:_p,C:Tp,L:Cp,m:Ap,X:Dp,S:Ep,M:Op};function Sp(){var e=Sn.f(),t=ks();return e||t}function wp(e){var t=Ua(e);t!==null&&t.tag===5&&t.type==="form"?rf(t):Sn.r(e)}var gl=typeof document>"u"?null:document;function Yh(e,t,n){var a=gl;if(a&&typeof t=="string"&&t){var s=Nt(t);s='link[rel="'+e+'"][href="'+s+'"]',typeof n=="string"&&(s+='[crossorigin="'+n+'"]'),Gh.has(s)||(Gh.add(s),e={rel:e,crossOrigin:n,href:t},a.querySelector(s)===null&&(t=a.createElement("link"),it(t,"link",e),Pe(t),a.head.appendChild(t)))}}function _p(e){Sn.D(e),Yh("dns-prefetch",e,null)}function Tp(e,t){Sn.C(e,t),Yh("preconnect",e,t)}function Cp(e,t,n){Sn.L(e,t,n);var a=gl;if(a&&e&&t){var s='link[rel="preload"][as="'+Nt(t)+'"]';t==="image"&&n&&n.imageSrcSet?(s+='[imagesrcset="'+Nt(n.imageSrcSet)+'"]',typeof n.imageSizes=="string"&&(s+='[imagesizes="'+Nt(n.imageSizes)+'"]')):s+='[href="'+Nt(e)+'"]';var c=s;switch(t){case"style":c=pl(e);break;case"script":c=yl(e)}$t.has(c)||(e=j({rel:"preload",href:t==="image"&&n&&n.imageSrcSet?void 0:e,as:t},n),$t.set(c,e),a.querySelector(s)!==null||t==="style"&&a.querySelector(xi(c))||t==="script"&&a.querySelector(gi(c))||(t=a.createElement("link"),it(t,"link",e),Pe(t),a.head.appendChild(t)))}}function Ap(e,t){Sn.m(e,t);var n=gl;if(n&&e){var a=t&&typeof t.as=="string"?t.as:"script",s='link[rel="modulepreload"][as="'+Nt(a)+'"][href="'+Nt(e)+'"]',c=s;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":c=yl(e)}if(!$t.has(c)&&(e=j({rel:"modulepreload",href:e},t),$t.set(c,e),n.querySelector(s)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(n.querySelector(gi(c)))return}a=n.createElement("link"),it(a,"link",e),Pe(a),n.head.appendChild(a)}}}function Ep(e,t,n){Sn.S(e,t,n);var a=gl;if(a&&e){var s=ka(a).hoistableStyles,c=pl(e);t=t||"default";var h=s.get(c);if(!h){var x={loading:0,preload:null};if(h=a.querySelector(xi(c)))x.loading=5;else{e=j({rel:"stylesheet",href:e,"data-precedence":t},n),(n=$t.get(c))&&Tu(e,n);var v=h=a.createElement("link");Pe(v),it(v,"link",e),v._p=new Promise(function(C,z){v.onload=C,v.onerror=z}),v.addEventListener("load",function(){x.loading|=1}),v.addEventListener("error",function(){x.loading|=2}),x.loading|=4,Zs(h,t,a)}h={type:"stylesheet",instance:h,count:1,state:x},s.set(c,h)}}}function Dp(e,t){Sn.X(e,t);var n=gl;if(n&&e){var a=ka(n).hoistableScripts,s=yl(e),c=a.get(s);c||(c=n.querySelector(gi(s)),c||(e=j({src:e,async:!0},t),(t=$t.get(s))&&Cu(e,t),c=n.createElement("script"),Pe(c),it(c,"link",e),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},a.set(s,c))}}function Op(e,t){Sn.M(e,t);var n=gl;if(n&&e){var a=ka(n).hoistableScripts,s=yl(e),c=a.get(s);c||(c=n.querySelector(gi(s)),c||(e=j({src:e,async:!0,type:"module"},t),(t=$t.get(s))&&Cu(e,t),c=n.createElement("script"),Pe(c),it(c,"link",e),n.head.appendChild(c)),c={type:"script",instance:c,count:1,state:null},a.set(s,c))}}function Xh(e,t,n,a){var s=(s=Mn.current)?Vs(s):null;if(!s)throw Error(u(446));switch(e){case"meta":case"title":return null;case"style":return typeof n.precedence=="string"&&typeof n.href=="string"?(t=pl(n.href),n=ka(s).hoistableStyles,a=n.get(t),a||(a={type:"style",instance:null,count:0,state:null},n.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(n.rel==="stylesheet"&&typeof n.href=="string"&&typeof n.precedence=="string"){e=pl(n.href);var c=ka(s).hoistableStyles,h=c.get(e);if(h||(s=s.ownerDocument||s,h={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},c.set(e,h),(c=s.querySelector(xi(e)))&&!c._p&&(h.instance=c,h.state.loading=5),$t.has(e)||(n={rel:"preload",as:"style",href:n.href,crossOrigin:n.crossOrigin,integrity:n.integrity,media:n.media,hrefLang:n.hrefLang,referrerPolicy:n.referrerPolicy},$t.set(e,n),c||Mp(s,e,n,h.state))),t&&a===null)throw Error(u(528,""));return h}if(t&&a!==null)throw Error(u(529,""));return null;case"script":return t=n.async,n=n.src,typeof n=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=yl(n),n=ka(s).hoistableScripts,a=n.get(t),a||(a={type:"script",instance:null,count:0,state:null},n.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(u(444,e))}}function pl(e){return'href="'+Nt(e)+'"'}function xi(e){return'link[rel="stylesheet"]['+e+"]"}function Qh(e){return j({},e,{"data-precedence":e.precedence,precedence:null})}function Mp(e,t,n,a){e.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=e.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),it(t,"link",n),Pe(t),e.head.appendChild(t))}function yl(e){return'[src="'+Nt(e)+'"]'}function gi(e){return"script[async]"+e}function Vh(e,t,n){if(t.count++,t.instance===null)switch(t.type){case"style":var a=e.querySelector('style[data-href~="'+Nt(n.href)+'"]');if(a)return t.instance=a,Pe(a),a;var s=j({},n,{"data-href":n.href,"data-precedence":n.precedence,href:null,precedence:null});return a=(e.ownerDocument||e).createElement("style"),Pe(a),it(a,"style",s),Zs(a,n.precedence,e),t.instance=a;case"stylesheet":s=pl(n.href);var c=e.querySelector(xi(s));if(c)return t.state.loading|=4,t.instance=c,Pe(c),c;a=Qh(n),(s=$t.get(s))&&Tu(a,s),c=(e.ownerDocument||e).createElement("link"),Pe(c);var h=c;return h._p=new Promise(function(x,v){h.onload=x,h.onerror=v}),it(c,"link",a),t.state.loading|=4,Zs(c,n.precedence,e),t.instance=c;case"script":return c=yl(n.src),(s=e.querySelector(gi(c)))?(t.instance=s,Pe(s),s):(a=n,(s=$t.get(c))&&(a=j({},n),Cu(a,s)),e=e.ownerDocument||e,s=e.createElement("script"),Pe(s),it(s,"link",a),e.head.appendChild(s),t.instance=s);case"void":return null;default:throw Error(u(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,Zs(a,n.precedence,e));return t.instance}function Zs(e,t,n){for(var a=n.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),s=a.length?a[a.length-1]:null,c=s,h=0;h<a.length;h++){var x=a[h];if(x.dataset.precedence===t)c=x;else if(c!==s)break}c?c.parentNode.insertBefore(e,c.nextSibling):(t=n.nodeType===9?n.head:n,t.insertBefore(e,t.firstChild))}function Tu(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.title==null&&(e.title=t.title)}function Cu(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.integrity==null&&(e.integrity=t.integrity)}var Ks=null;function Zh(e,t,n){if(Ks===null){var a=new Map,s=Ks=new Map;s.set(n,a)}else s=Ks,a=s.get(n),a||(a=new Map,s.set(n,a));if(a.has(e))return a;for(a.set(e,null),n=n.getElementsByTagName(e),s=0;s<n.length;s++){var c=n[s];if(!(c[Dl]||c[rt]||e==="link"&&c.getAttribute("rel")==="stylesheet")&&c.namespaceURI!=="http://www.w3.org/2000/svg"){var h=c.getAttribute(t)||"";h=e+h;var x=a.get(h);x?x.push(c):a.set(h,[c])}}return a}function Kh(e,t,n){e=e.ownerDocument||e,e.head.insertBefore(n,t==="title"?e.querySelector("head > title"):null)}function zp(e,t,n){if(n===1||t.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return e=t.disabled,typeof t.precedence=="string"&&e==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Jh(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}var pi=null;function Bp(){}function Np(e,t,n){if(pi===null)throw Error(u(475));var a=pi;if(t.type==="stylesheet"&&(typeof n.media!="string"||matchMedia(n.media).matches!==!1)&&(t.state.loading&4)===0){if(t.instance===null){var s=pl(n.href),c=e.querySelector(xi(s));if(c){e=c._p,e!==null&&typeof e=="object"&&typeof e.then=="function"&&(a.count++,a=Js.bind(a),e.then(a,a)),t.state.loading|=4,t.instance=c,Pe(c);return}c=e.ownerDocument||e,n=Qh(n),(s=$t.get(s))&&Tu(n,s),c=c.createElement("link"),Pe(c);var h=c;h._p=new Promise(function(x,v){h.onload=x,h.onerror=v}),it(c,"link",n),t.instance=c}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(t,e),(e=t.state.preload)&&(t.state.loading&3)===0&&(a.count++,t=Js.bind(a),e.addEventListener("load",t),e.addEventListener("error",t))}}function Rp(){if(pi===null)throw Error(u(475));var e=pi;return e.stylesheets&&e.count===0&&Au(e,e.stylesheets),0<e.count?function(t){var n=setTimeout(function(){if(e.stylesheets&&Au(e,e.stylesheets),e.unsuspend){var a=e.unsuspend;e.unsuspend=null,a()}},6e4);return e.unsuspend=t,function(){e.unsuspend=null,clearTimeout(n)}}:null}function Js(){if(this.count--,this.count===0){if(this.stylesheets)Au(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var Fs=null;function Au(e,t){e.stylesheets=null,e.unsuspend!==null&&(e.count++,Fs=new Map,t.forEach(Up,e),Fs=null,Js.call(e))}function Up(e,t){if(!(t.state.loading&4)){var n=Fs.get(e);if(n)var a=n.get(null);else{n=new Map,Fs.set(e,n);for(var s=e.querySelectorAll("link[data-precedence],style[data-precedence]"),c=0;c<s.length;c++){var h=s[c];(h.nodeName==="LINK"||h.getAttribute("media")!=="not all")&&(n.set(h.dataset.precedence,h),a=h)}a&&n.set(null,a)}s=t.instance,h=s.getAttribute("data-precedence"),c=n.get(h)||a,c===a&&n.set(null,s),n.set(h,s),this.count++,a=Js.bind(this),s.addEventListener("load",a),s.addEventListener("error",a),c?c.parentNode.insertBefore(s,c.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(s,e.firstChild)),t.state.loading|=4}}var yi={$$typeof:be,Provider:null,Consumer:null,_currentValue:F,_currentValue2:F,_threadCount:0};function kp(e,t,n,a,s,c,h,x){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=wc(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=wc(0),this.hiddenUpdates=wc(null),this.identifierPrefix=a,this.onUncaughtError=s,this.onCaughtError=c,this.onRecoverableError=h,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=x,this.incompleteTransitions=new Map}function Fh(e,t,n,a,s,c,h,x,v,C,z,R){return e=new kp(e,t,n,h,x,v,C,R),t=1,c===!0&&(t|=24),c=Tt(3,null,null,t),e.current=c,c.stateNode=e,t=rr(),t.refCount++,e.pooledCache=t,t.refCount++,c.memoizedState={element:a,isDehydrated:n,cache:t},fr(c),e}function Wh(e){return e?(e=Ja,e):Ja}function Ih(e,t,n,a,s,c){s=Wh(s),a.context===null?a.context=s:a.pendingContext=s,a=kn(t),a.payload={element:n},c=c===void 0?null:c,c!==null&&(a.callback=c),n=Ln(e,a,t),n!==null&&(Ot(n,e,t),Kl(n,e,t))}function Ph(e,t){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var n=e.retryLane;e.retryLane=n!==0&&n<t?n:t}}function Eu(e,t){Ph(e,t),(e=e.alternate)&&Ph(e,t)}function em(e){if(e.tag===13){var t=Ka(e,67108864);t!==null&&Ot(t,e,67108864),Eu(e,67108864)}}var Ws=!0;function Lp(e,t,n,a){var s=N.T;N.T=null;var c=H.p;try{H.p=2,Du(e,t,n,a)}finally{H.p=c,N.T=s}}function Hp(e,t,n,a){var s=N.T;N.T=null;var c=H.p;try{H.p=8,Du(e,t,n,a)}finally{H.p=c,N.T=s}}function Du(e,t,n,a){if(Ws){var s=Ou(a);if(s===null)gu(e,t,a,Is,n),nm(e,a);else if($p(s,e,t,n,a))a.stopPropagation();else if(nm(e,a),t&4&&-1<qp.indexOf(e)){for(;s!==null;){var c=Ua(s);if(c!==null)switch(c.tag){case 3:if(c=c.stateNode,c.current.memoizedState.isDehydrated){var h=ra(c.pendingLanes);if(h!==0){var x=c;for(x.pendingLanes|=2,x.entangledLanes|=2;h;){var v=1<<31-wt(h);x.entanglements[1]|=v,h&=~v}tn(c),(fe&6)===0&&(Rs=Ft()+500,di(0))}}break;case 13:x=Ka(c,2),x!==null&&Ot(x,c,2),ks(),Eu(c,2)}if(c=Ou(a),c===null&&gu(e,t,a,Is,n),c===s)break;s=c}s!==null&&a.stopPropagation()}else gu(e,t,a,null,n)}}function Ou(e){return e=Rc(e),Mu(e)}var Is=null;function Mu(e){if(Is=null,e=Ra(e),e!==null){var t=f(e);if(t===null)e=null;else{var n=t.tag;if(n===13){if(e=m(t),e!==null)return e;e=null}else if(n===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;e=null}else t!==e&&(e=null)}}return Is=e,null}function tm(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Tx()){case mo:return 2;case xo:return 8;case Xi:case Cx:return 32;case go:return 268435456;default:return 32}default:return 32}}var zu=!1,Wn=null,In=null,Pn=null,vi=new Map,ji=new Map,ea=[],qp="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function nm(e,t){switch(e){case"focusin":case"focusout":Wn=null;break;case"dragenter":case"dragleave":In=null;break;case"mouseover":case"mouseout":Pn=null;break;case"pointerover":case"pointerout":vi.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":ji.delete(t.pointerId)}}function bi(e,t,n,a,s,c){return e===null||e.nativeEvent!==c?(e={blockedOn:t,domEventName:n,eventSystemFlags:a,nativeEvent:c,targetContainers:[s]},t!==null&&(t=Ua(t),t!==null&&em(t)),e):(e.eventSystemFlags|=a,t=e.targetContainers,s!==null&&t.indexOf(s)===-1&&t.push(s),e)}function $p(e,t,n,a,s){switch(t){case"focusin":return Wn=bi(Wn,e,t,n,a,s),!0;case"dragenter":return In=bi(In,e,t,n,a,s),!0;case"mouseover":return Pn=bi(Pn,e,t,n,a,s),!0;case"pointerover":var c=s.pointerId;return vi.set(c,bi(vi.get(c)||null,e,t,n,a,s)),!0;case"gotpointercapture":return c=s.pointerId,ji.set(c,bi(ji.get(c)||null,e,t,n,a,s)),!0}return!1}function am(e){var t=Ra(e.target);if(t!==null){var n=f(t);if(n!==null){if(t=n.tag,t===13){if(t=m(n),t!==null){e.blockedOn=t,Nx(e.priority,function(){if(n.tag===13){var a=Dt();a=_c(a);var s=Ka(n,a);s!==null&&Ot(s,n,a),Eu(n,a)}});return}}else if(t===3&&n.stateNode.current.memoizedState.isDehydrated){e.blockedOn=n.tag===3?n.stateNode.containerInfo:null;return}}}e.blockedOn=null}function Ps(e){if(e.blockedOn!==null)return!1;for(var t=e.targetContainers;0<t.length;){var n=Ou(e.nativeEvent);if(n===null){n=e.nativeEvent;var a=new n.constructor(n.type,n);Nc=a,n.target.dispatchEvent(a),Nc=null}else return t=Ua(n),t!==null&&em(t),e.blockedOn=n,!1;t.shift()}return!0}function lm(e,t,n){Ps(e)&&n.delete(t)}function Gp(){zu=!1,Wn!==null&&Ps(Wn)&&(Wn=null),In!==null&&Ps(In)&&(In=null),Pn!==null&&Ps(Pn)&&(Pn=null),vi.forEach(lm),ji.forEach(lm)}function ec(e,t){e.blockedOn===t&&(e.blockedOn=null,zu||(zu=!0,i.unstable_scheduleCallback(i.unstable_NormalPriority,Gp)))}var tc=null;function im(e){tc!==e&&(tc=e,i.unstable_scheduleCallback(i.unstable_NormalPriority,function(){tc===e&&(tc=null);for(var t=0;t<e.length;t+=3){var n=e[t],a=e[t+1],s=e[t+2];if(typeof a!="function"){if(Mu(a||n)===null)continue;break}var c=Ua(n);c!==null&&(e.splice(t,3),t-=3,Mr(c,{pending:!0,data:s,method:n.method,action:a},a,s))}}))}function Si(e){function t(v){return ec(v,e)}Wn!==null&&ec(Wn,e),In!==null&&ec(In,e),Pn!==null&&ec(Pn,e),vi.forEach(t),ji.forEach(t);for(var n=0;n<ea.length;n++){var a=ea[n];a.blockedOn===e&&(a.blockedOn=null)}for(;0<ea.length&&(n=ea[0],n.blockedOn===null);)am(n),n.blockedOn===null&&ea.shift();if(n=(e.ownerDocument||e).$$reactFormReplay,n!=null)for(a=0;a<n.length;a+=3){var s=n[a],c=n[a+1],h=s[mt]||null;if(typeof c=="function")h||im(n);else if(h){var x=null;if(c&&c.hasAttribute("formAction")){if(s=c,h=c[mt]||null)x=h.formAction;else if(Mu(s)!==null)continue}else x=h.action;typeof x=="function"?n[a+1]=x:(n.splice(a,3),a-=3),im(n)}}}function Bu(e){this._internalRoot=e}nc.prototype.render=Bu.prototype.render=function(e){var t=this._internalRoot;if(t===null)throw Error(u(409));var n=t.current,a=Dt();Ih(n,a,e,t,null,null)},nc.prototype.unmount=Bu.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var t=e.containerInfo;Ih(e.current,2,null,e,null,null),ks(),t[Na]=null}};function nc(e){this._internalRoot=e}nc.prototype.unstable_scheduleHydration=function(e){if(e){var t=bo();e={blockedOn:null,target:e,priority:t};for(var n=0;n<ea.length&&t!==0&&t<ea[n].priority;n++);ea.splice(n,0,e),n===0&&am(e)}};var sm=r.version;if(sm!=="19.1.0")throw Error(u(527,sm,"19.1.0"));H.findDOMNode=function(e){var t=e._reactInternals;if(t===void 0)throw typeof e.render=="function"?Error(u(188)):(e=Object.keys(e).join(","),Error(u(268,e)));return e=p(t),e=e!==null?y(e):null,e=e===null?null:e.stateNode,e};var Yp={bundleType:0,version:"19.1.0",rendererPackageName:"react-dom",currentDispatcherRef:N,reconcilerVersion:"19.1.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var ac=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!ac.isDisabled&&ac.supportsFiber)try{Cl=ac.inject(Yp),St=ac}catch{}}return wi.createRoot=function(e,t){if(!o(e))throw Error(u(299));var n=!1,a="",s=Sf,c=wf,h=_f,x=null;return t!=null&&(t.unstable_strictMode===!0&&(n=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(s=t.onUncaughtError),t.onCaughtError!==void 0&&(c=t.onCaughtError),t.onRecoverableError!==void 0&&(h=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(x=t.unstable_transitionCallbacks)),t=Fh(e,1,!1,null,null,n,a,s,c,h,x,null),e[Na]=t.current,xu(e),new Bu(t)},wi.hydrateRoot=function(e,t,n){if(!o(e))throw Error(u(299));var a=!1,s="",c=Sf,h=wf,x=_f,v=null,C=null;return n!=null&&(n.unstable_strictMode===!0&&(a=!0),n.identifierPrefix!==void 0&&(s=n.identifierPrefix),n.onUncaughtError!==void 0&&(c=n.onUncaughtError),n.onCaughtError!==void 0&&(h=n.onCaughtError),n.onRecoverableError!==void 0&&(x=n.onRecoverableError),n.unstable_transitionCallbacks!==void 0&&(v=n.unstable_transitionCallbacks),n.formState!==void 0&&(C=n.formState)),t=Fh(e,1,!0,t,n??null,a,s,c,h,x,v,C),t.context=Wh(null),n=t.current,a=Dt(),a=_c(a),s=kn(a),s.callback=null,Ln(n,s,a),n=a,t.current.lanes=n,El(t,n),tn(t),e[Na]=t.current,xu(e),new nc(t)},wi.version="19.1.0",wi}var fm;function X0(){if(fm)return Ru.exports;fm=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(r){console.error(r)}}return i(),Ru.exports=Y0(),Ru.exports}var Q0=X0();function la(i){var r=[],d=Math.floor(i/3600);d>0&&r.push(`${d}h`);var u=Math.floor(i%3600/60);u>0&&r.push(`${u}min`);var o=i%60;return o>0&&r.push(`${o}s`),r?r.length>1?`${r[0]} ${r[1]}`:r[0]:"-"}function wl(i){return i.toLocaleString("en-GB",{timeZone:"UTC"})}function gc(i){const r=(f,m,g=!1)=>{f=Math.trunc(f),f>1&&(m+="s");let p="";return g||(p+="in "),p+=`${f.toLocaleString()} ${m}`,g&&(p+=" ago"),p};if(!(i instanceof Date))return`expected date saw ${typeof i}`;const d=new Date,u=i<d;var o=Math.abs(d-i)/1e3;return o<60?u?"just now":"less than one minute":(o=o/60,o<60?r(o,"minute",u):(o=o/60,o<24?r(o,"hour",u):(o=o/24,o<365?r(o,"day",u):i.toLocaleDateString("en-GB",{timeZone:"UTC"}))))}function zi(i){return i.toLocaleString("en-GB",{timeZone:"UTC",dateStyle:"short"})}/*! js-cookie v3.0.5 | MIT */function lc(i){for(var r=1;r<arguments.length;r++){var d=arguments[r];for(var u in d)i[u]=d[u]}return i}var V0={read:function(i){return i[0]==='"'&&(i=i.slice(1,-1)),i.replace(/(%[\dA-F]{2})+/gi,decodeURIComponent)},write:function(i){return encodeURIComponent(i).replace(/%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,decodeURIComponent)}};function Gu(i,r){function d(o,f,m){if(!(typeof document>"u")){m=lc({},r,m),typeof m.expires=="number"&&(m.expires=new Date(Date.now()+m.expires*864e5)),m.expires&&(m.expires=m.expires.toUTCString()),o=encodeURIComponent(o).replace(/%(2[346B]|5E|60|7C)/g,decodeURIComponent).replace(/[()]/g,escape);var g="";for(var p in m)m[p]&&(g+="; "+p,m[p]!==!0&&(g+="="+m[p].split(";")[0]));return document.cookie=o+"="+i.write(f,o)+g}}function u(o){if(!(typeof document>"u"||arguments.length&&!o)){for(var f=document.cookie?document.cookie.split("; "):[],m={},g=0;g<f.length;g++){var p=f[g].split("="),y=p.slice(1).join("=");try{var j=decodeURIComponent(p[0]);if(m[j]=i.read(y,j),o===j)break}catch{}}return o?m[o]:m}}return Object.create({set:d,get:u,remove:function(o,f){d(o,"",lc({},f,{expires:-1}))},withAttributes:function(o){return Gu(this.converter,lc({},this.attributes,o))},withConverter:function(o){return Gu(lc({},this.converter,o),this.attributes)}},{attributes:{value:Object.freeze(r)},converter:{value:Object.freeze(i)}})}var Km=Gu(V0,{path:"/"}),Z0=Zm();const Jm=e0(Z0),_n=T.div`
  position: fixed;
  background-color: ${({theme:i,$variant:r})=>i.colors[r].color};
  color: ${({theme:i,$variant:r})=>i.colors[r].text};
  border-radius: 15px;
  padding: 20px;
  max-width: 400px;
  transition:
    bottom 0.3s ease-in-out,
    right 0.3s ease-in-out,
    opacity 0.3s ease-in-out,
    padding 0.3s ease-in-out;
  box-sizing: content-box;
  z-index: 101;
`;_n.Container=T.div`
  > ${_n} {
    display: none;
  }

  > ${_n}:nth-last-child(1) {
    display: block;
    padding: 20px;
    bottom: 50px;
    right: 50px;
    opacity: 1;
  }

  > ${_n}:nth-last-child(2) {
    display: block;
    padding: 15px;
    bottom: 90px;
    right: 55px;
    opacity: 0.8;
  }

  > ${_n}:nth-last-child(3) {
    display: block;
    padding: 10px;
    bottom: 130px;
    right: 60px;
    opacity: 0.6;
  }
`;_n.Title=T.strong`
  font-weight: bold;
`;function K0({title:i,message:r,variant:d}){return l.jsxs(_n,{$variant:d,children:[i&&l.jsxs(_n.Title,{children:[i," "]}),r]})}function J0({toasts:i,setToasts:r}){return w.useEffect(()=>{const d=setInterval(()=>{const u=new Date,o=i.filter(f=>f.expire>u);o.length!==i.length&&r(o)},1e3);return()=>clearInterval(d)},[i,r]),Jm.createPortal(l.jsx(_n.Container,{children:i.map(({id:d,...u})=>l.jsx(K0,{...u},d))}),document.body)}function ln(i,{title:r="",message:d,variant:u,time:o=1e4}){const f=Math.random().toString(36),m=new Date(Date.now()+o);i({id:f,title:r,message:d,variant:u,expire:m})}async function Cn(i,r){var d,u;try{const o=await r;let f="Action completed successfully";if(typeof o=="string")f=o;else if(typeof(o==null?void 0:o.status)=="string")f=o.status;else try{f=JSON.stringify(o)}catch{f=((d=o==null?void 0:o.toString)==null?void 0:d.call(o))??"Success"}return ln(i,{message:f,variant:"success"}),o}catch(o){throw console.error(o),ln(i,{message:((u=o==null?void 0:o.toString)==null?void 0:u.call(o))??"Unknown error",variant:"danger"}),o}}async function re(i,r){var d,u,o;try{return await r}catch(f){console.error(f);let m="An unknown error occurred";if((u=(d=f==null?void 0:f.response)==null?void 0:d.data)!=null&&u.detail)m=f.response.data.detail;else if(f!=null&&f.detail)m=f.detail;else if(f!=null&&f.message)m=f.message;else if(typeof f=="string")m=f;else try{m=JSON.stringify(f)}catch{m=(o=f.toString)==null?void 0:o.call(f)}ln(i,{title:"Error",message:m,variant:"danger"})}}const ze=K.createContext(null),oe=K.createContext(()=>{}),_l=K.createContext(null);async function Qe(i,{json:r,...d}){var u={...d};u.headers||(u.headers={});const o=Km.get("csrftoken");o&&(u.headers["x-csrftoken"]=o),r&&(u.method||(u.method="POST"),u.headers["Content-Type"]="application/json",u.body=JSON.stringify(r));const f=await fetch(i,u);var m;if((f.headers.get("Content-Type")||"").match(/json/)?m=await f.json():m=await f.text(),f.status>=400)throw m;return m}async function F0(i,r){var d;try{const u=await r;let o="Action completed successfully";if(typeof u=="string")o=u;else if(typeof(u==null?void 0:u.status)=="string")o=u.status;else try{o=JSON.stringify(u)}catch{o=((d=u==null?void 0:u.toString)==null?void 0:d.call(u))??"Success"}return ln(i,{message:o,variant:"success"}),u}catch(u){throw console.error(u),ln(i,{message:u.toString(),variant:"danger"}),u}}async function W0(i,r){var d,u;try{await r}catch(o){console.error(o);let f="An unknown error occurred";if((u=(d=o==null?void 0:o.response)==null?void 0:d.data)!=null&&u.detail)f=o.response.data.detail;else if(o!=null&&o.detail)f=o.detail;else if(o!=null&&o.message)f=o.message;else if(typeof o=="string")f=o;else try{f=JSON.stringify(o)}catch{f=o.toString()}ln(i,{title:"Error",message:f,variant:"danger"})}}function Le(i){const r=K.useContext(oe),[d,u]=K.useState(null),o=K.useCallback(()=>{i&&W0(r,Qe(i,{}).then(u,f=>{throw u(null),f}))},[r,i]);return K.useEffect(()=>{u(null),o()},[o]),[d,o]}async function He(i,r,d={}){let u=i;if(d.params){for(const[E,O]of Object.entries(d.params)){const M=`{${E}}`;u.includes(M)&&(u=u.replace(M,encodeURIComponent(String(O))))}if(r==="get"){const E=new Set;for(const[O,M]of Object.entries(d.params)){const L=`{${O}}`;u.includes(L)&&(u=u.replace(L,encodeURIComponent(String(M))),E.add(O))}if(r==="get"){const O=new URLSearchParams;for(const[M,L]of Object.entries(d.params))E.has(M)||O.append(M,String(L));O.toString()&&(u+=u.includes("?")?"&"+O.toString():"?"+O.toString())}}}const f={"x-csrftoken":Km.get("csrftoken")??"",Accept:"application/json",...d.headers||{}},m={method:r.toUpperCase(),headers:f};d.body&&(f["Content-Type"]="application/json",m.body=JSON.stringify(d.body));const g=await fetch(u,m),j=(g.headers.get("Content-Type")||"").includes("json")?await g.json():await g.text();if(!g.ok)throw j;return j}function Ju(i){const r=w.useContext(oe),[d,u]=w.useState(null),o=w.useCallback(()=>{i&&re(r,fetch(i).then(async f=>{if(!f.ok)throw await f.json();return await f.json()}).then(u).catch(f=>{throw u(null),f}))},[r,i]);return w.useEffect(()=>{u(null),o()},[o]),[d,o]}function Fm(i){return He("/incursions/api/open_window","post",{body:i})}function I0(i){return He("/incursions/api/pilot/info","get",{params:{character_id:i}})}async function P0(i,r){await He("/incursions/api/notes/add","post",{body:{character_id:i,note:r}})}const Fu=T.img`
  border-radius: 25%;
  margin-right: 10px;
  vertical-align: middle;

  @media (max-width: 450px) {
    display: none;
  }
`;function dt({avatar:i=!0,avatarSize:r=32,character_id:d=1,character_name:u,noLink:o=!1}){return l.jsxs(l.Fragment,{children:[i&&l.jsx(Fu,{src:`https://images.evetech.net/characters/${d}/portrait?size=${r}`,loading:"lazy"}),o?u:l.jsx(fc,{to:`/fc/search?query=${u}`,children:u})]})}function Wu({avatar:i=!0,avatarSize:r=32,corporation_id:d=1,corporation_name:u,noLink:o=!1}){const f=w.useContext(oe),m=w.useContext(ze),g=()=>{re(f,Fm({character_id:m.current.character_id,target_id:d}))};return l.jsxs(l.Fragment,{children:[i&&l.jsx(Fu,{src:`https://images.evetech.net/corporations/${d}/logo?size=${r}`,loading:"lazy"}),o?u:l.jsxs(l.Fragment,{children:[l.jsx(fc,{to:"#",onClick:g,children:u}),l.jsx(ie,{fixedWidth:!0,icon:Ri})]})]})}function Iu({avatar:i=!0,avatarSize:r=32,alliance_id:d=1,alliance_name:u,noLink:o=!1}){const f=w.useContext(oe),m=w.useContext(ze),g=()=>{re(f,Fm({character_id:m.current.character_id,target_id:d}))};return l.jsxs(l.Fragment,{children:[i&&l.jsx(Fu,{src:`https://images.evetech.net/alliances/${d}/logo?size=${r}`,loading:"lazy"}),o?u:l.jsxs(l.Fragment,{children:[l.jsx(fc,{to:"#",onClick:g,children:u}),l.jsx(ie,{fixedWidth:!0,icon:Ri})]})]})}const Dn=T.table.withConfig({shouldForwardProp:i=>!["fullWidth","edgeLine"].includes(i)})`
  table-layout: fixed;
  ${({fullWidth:i})=>i&&"width: 100%;"}
  ${({edgeLine:i,theme:r})=>i&&`
    border-top: solid 1px ${r.colors.accent2};
    border-bottom: solid 1px ${r.colors.accent2};
  `}

  @media (max-width: 480px) {
    width: 100%;
    font-size: 3.4vw;
  }
`,Ma=T.thead`
  border-bottom: solid 2px ${({theme:i})=>i.colors.accent2};
`,On=T.tbody``,Oe=T.tr`
  background-color: ${({theme:i})=>i.colors.background};

  ${({background:i,theme:r})=>i&&`
      background-color: ${r.colors.accent1};
      box-shadow: 2px 2px 5px ${r.colors.shadow};
    `}

  &:last-child {
    border-bottom: none;
  }

  ${({noAlternating:i,theme:r})=>!i&&`
      border-bottom: solid 1px ${r.colors.accent2};
      &:nth-child(odd) {
        background-color: ${r.colors.accent1};
      }
    `}
`,Fe=T.th`
  text-align: left;
  padding: 0.5em;
  font-weight: 600;
`,ey=T.th`
  text-align: left;
  padding: 0.5em;
  font-weight: 600;
  width: 75px;

  @media (max-width: 480px) {
    width: 60px;
  }
`,I=T.td`
  padding: 0.5em;
  color: ${({theme:i})=>i.colors.text};

  a {
    color: ${({theme:i})=>i.colors.text};
  }

  @media (max-width: 480px) {
    padding: 0.3em;
  }
`,Tn=T.td`
  color: ${({theme:i})=>i.colors.text};

  a {
    color: ${({theme:i})=>i.colors.text};
  }

  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  padding-right: 0.3em;

  @media (max-width: 480px) {
    padding: 0.3em;
  }
`,ty=T.td`
  position: relative;
  text-align: end;
  padding: 0 0.5em;

  &::before {
    content: '';
    position: absolute;
    left: 50%;
    top: 0;
    bottom: 0;
    width: 2px;
    background-color: ${({theme:i})=>i.colors.accent2};
  }

  ${({warn:i})=>i&&`
      &::after {
        content: '';
        position: absolute;
        left: 40%;
        top: 0;
        bottom: 0;
        width: 10%;
        background: ${i};
      }
    `}
`,ny=T.span`
  a {
    color: ${i=>i.theme.colors.highlight.text};
    text-decoration: none;
    font-weight: bold;

    &:hover:not(:disabled):not(.static) {
      cursor: pointer;
      color: ${i=>i.theme.colors.highlight.active};
    }
  }
`,ay=T.div`
  h2,
  h3,
  h4,
  h5,
  h6 {
    display: inline;
    &:hover a {
      visibility: visible;
      opacity: 1;
    }

    a {
      margin-left: 10px;
      font-size: smaller;
      text-decoration: none;
      visibility: hidden;
      opacity: 0;
      transition:
        visibility 0.05s,
        opacity 0.05s linear;

      &:after {
        content: '#';
      }

      &:hover {
        color: ${i=>i.theme.colors.highlight.active};
      }
    }
  }
`,ly=T.ul`
  padding-left: 1.2em;
  list-style-type: none;
  font-size: 0.9em;
  margin-bottom: 1em;

  li {
    margin: 0.3em 0;
  }

  a {
    text-decoration: none;
    color: ${i=>i.theme.colors.text};
    &:hover {
      color: ${i=>i.theme.colors.highlight.text};
    }
  }
`;function iy({href:i,children:r,...d}){return l.jsx(ny,{children:i.startsWith("/")?l.jsx(jt,{to:i,end:!0,...d,children:r}):l.jsx("a",{href:i,target:"_blank",rel:"noopener noreferrer",...d,children:r})})}function sy({headings:i}){return i.length?l.jsx(ly,{children:i.map(({text:r,slug:d},u)=>l.jsx("li",{children:l.jsx("a",{href:`#${d}-${u}`,children:r})},u))}):null}function Ui({...i}){const[r,d]=w.useState([]),u=({level:f,children:m})=>{const g=m.map(j=>{var E;return typeof j=="string"?j:((E=j==null?void 0:j.props)==null?void 0:E.children)??""}).flat().join(" "),p=encodeURIComponent(g.replace(/[^a-zA-Z0-9 ]/g,"").replace(/\s+/g,"-").toLowerCase()),y=`${p}-${r.length}`;return d(j=>j.some(E=>E.slug===p)?j:[...j,{text:g,slug:p}]),l.jsx(ay,{children:K.createElement(`h${f}`,{id:y},l.jsxs(l.Fragment,{children:[m,l.jsx("a",{href:`#${y}`,"aria-label":`Link to heading ${g}`})]}))})};w.useEffect(()=>{var m;const{hash:f}=window.location;f&&((m=document.getElementById(f.substring(1)))==null||m.scrollIntoView())},[]);const o={h2:u,h3:u,h4:u,h5:u,h6:u,a:iy,table:Dn,thead:Ma,tbody:On,th:Fe,td:I,tr:Oe};return l.jsxs(l.Fragment,{children:[l.jsx(sy,{headings:r}),l.jsx(Rm,{components:o,remarkPlugins:[t0],...i})]})}const ct=T.div`
  color: ${({theme:i})=>i.colors.text};

  p,
  ul,
  ol {
    margin-bottom: 1em;
    line-height: 1.5em;
  }

  a {
    font-weight: bold;
    text-decoration: none;
    color: ${({theme:i})=>i.colors.highlight.text};

    &:hover:not(:disabled):not(.static) {
      cursor: pointer;
      color: ${({theme:i})=>i.colors.highlight.active};
    }
  }

  i,
  em {
    font-style: italic;
  }

  b,
  strong {
    font-weight: bold;
  }

  h1,
  h2,
  h3,
  h4,
  h5,
  h6 {
    margin-top: 1em;
  }

  h1 + h2,
  h2 + h3,
  h3 + h4,
  h4 + h5,
  h5 + h6 {
    margin-top: 0;
  }

  h1 {
    margin-top: 0;
    font-size: 3em;
  }

  h2 {
    font-size: 2em;
  }

  h3 {
    font-size: 1.5em;
    font-weight: 600;
  }

  h4 {
    font-size: 1.2em;
    font-weight: 500;
  }

  ul {
    list-style-type: disc;
    padding-left: 2em;
  }

  ol {
    list-style-type: number;
    padding-left: 2em;
  }

  pre {
    font-family: ${({theme:i})=>i.font.monospaceFamily};
    font-size: 0.8em;
    padding: 1em;
    margin-bottom: 1em;
    border-radius: 5px;
    background-color: ${({theme:i})=>i.colors.accent1};
  }

  img {
    max-width: 100%;
  }
`,sa=T.h1`
  font-size: 3em;
  margin-bottom: 0.5em;

  @media (max-width: 480px) {
    font-size: 2em;
  }
`,Me=T.h2`
  font-size: 1.5em;
`,Wm=[{name:"Fits",value:"/fits"},{name:"Guides",value:"/guide"},{name:"Skills",value:"/skills"},{name:"Profile",value:"/pilot"},{name:"Waitlist",value:"/waitlist"}],cy=T.div`
  background: ${i=>i.theme.colors.secondary.color};
  box-shadow: 0px 3px ${i=>i.theme.colors.shadow};
  color: ${i=>i.theme.colors.text};
  margin-bottom: 3.5px;
  padding: 12px;
  position: relative;

  &[data-alert='true'] {
    background: ${i=>i.theme.colors.danger.color};
    color: ${i=>i.theme.colors.danger.text};
  }

  small {
    font-style: italic;
    font-size: small;
  }

  .close {
    position: absolute;
    right: 15px;
    top: 15px;
    width: 32px;
    height: 32px;
    opacity: 0.6;
  }

  .close:hover {
    opacity: 1;
    transition: ease-in-out 0.2s;
    cursor: pointer;
  }

  .close:before,
  .close:after {
    position: absolute;
    left: 15px;
    content: ' ';
    height: 15px;
    width: 2px;
    background-color: ${i=>i.theme.colors.secondary.text};
  }

  .close:before {
    transform: rotate(45deg);
  }

  .close:after {
    transform: rotate(-45deg);
  }
`,ry=T(ct)`
  padding-left: 42px;

  p {
    margin-bottom: 0em;
  }

  h1,
  h2,
  h3,
  h4 {
    margin-top: 0em;
  }
`,uy=(i,r)=>{const d=w.useRef();w.useEffect(()=>{d.current=i},[i]),w.useEffect(()=>{function u(){var o;(o=d.current)==null||o.call(d)}{const o=setInterval(u,r);return()=>clearInterval(o)}},[r])},oy=()=>{const i=w.useContext(ze),r=w.useContext(_l),[,d]=w.useReducer(M=>M+1,0),{t:u}=k(),o=sn(),[f,m]=w.useState([]),[g,p]=w.useState({}),[y,j]=w.useState(window.location.pathname);w.useEffect(()=>{j(o.pathname)},[o]);const E=M=>{try{const L=JSON.parse(M.data);Array.isArray(L)&&m(L)}catch{}};w.useEffect(()=>{if(r)return r.addEventListener("announcement;new",E),r.addEventListener("announcement;updated",E),()=>{r.removeEventListener("announcement;new",E),r.removeEventListener("announcement;updated",E)}},[r]);const O=M=>{const L=JSON.parse(localStorage.getItem("ignore-announcements")||"{}"),q=new Date;Object.keys(L).forEach(U=>{L[U]<q.getTime()&&delete L[U]}),L[M]=new Date().setDate(q.getDate()+30),localStorage.setItem("ignore-announcements",JSON.stringify(L)),p(L)};return w.useEffect(()=>{(async()=>{const L=JSON.parse(localStorage.getItem("ignore-announcements")||"{}");p(L);const q=await Qe("/incursions/api/announcements",{});m(Array.isArray(q)?q:[])})()},[]),uy(()=>d(),6e4),f.length===0?null:l.jsx("div",{style:{marginBottom:"10px"},children:f.map(M=>{var U,G;if(M.id in g)return null;const L=M.pages?JSON.parse(M.pages):[];if(L.length>0&&!Wm.filter(te=>L.includes(te.name.toLowerCase())).some(te=>y.startsWith(te.value.toLowerCase())))return null;const q=new Date(M.created_at);return l.jsxs(cy,{"data-alert":M.is_alert,children:[l.jsx(dt,{...M.created_by,noLink:!((U=i==null?void 0:i.access)!=null&&U["incursions.waitlist_announcements_manage"])}),", ",u("{{time}} ago",{time:gc(q)}),l.jsx("span",{className:"close",onClick:()=>O(M.id)}),l.jsx(ry,{children:l.jsx(Ui,{children:M.message})}),((G=i==null?void 0:i.access)==null?void 0:G["incursions.waitlist_announcements_manage"])&&l.jsxs("small",{style:{paddingLeft:"42px"},children:[u("Displayed on"),": ",L.length>0?L.join(", "):u("all pages"),"."]})]},M.id)})})};async function dy(i){try{const r=await He("/incursions/api/auth/whoami","get"),d={};r.access.forEach(f=>{d[f]=!0});const u=window.localStorage?parseInt(window.localStorage.getItem("selectedCharacter")||"",10):null;let o=0;if(u){const f=r.characters.findIndex(m=>m.character_id===u);o=f!==-1?f:0}i({...r,current:r.characters[o],access:d})}catch(r){console.error("Error fetching whoami:",r),i(null)}}class fy extends w.Component{constructor(r){super(r),this.state={hasError:!1,message:"",trace:""}}static getDerivedStateFromError(){return{hasError:!0}}componentDidCatch(r,d){console.error("ErrorBoundary caught an error:",r,d),this.setState({message:r.message,trace:String(d.componentStack)})}render(){const{t:r}=this.props;return this.state.hasError?l.jsxs(l.Fragment,{children:[l.jsx("p",{className:"text-center",children:r("errorBoundary.fallbackMessage","You should not be seeing this message, please report this error to your Administrators.")}),l.jsx("div",{style:{justifyContent:"center"},className:"d-flex",children:l.jsx("pre",{style:{maxWidth:"1000px"},className:"border",children:this.state.trace})})]}):this.props.children}}const Ca=R0()(fy),Ce=T.div`
  background-color: ${({theme:i})=>i.colors.background};
  padding: 1.5em;
  border-radius: 5px;

  @media (max-width: 480px) {
    padding: ${({mpadding:i})=>i??"0.6em"};
    width: 100%;
  }
`,Kt=n0`
  position: relative;
  padding: 0 1em;
  font-size: 1em;
  border: solid ${({$variant:i})=>i?"0px":"1px"};
  border-color: ${({theme:i})=>i.colors.accent2};
  border-radius: 20px;
  background-color: ${({theme:i,$variant:r})=>i.colors[r||"input"].color};
  color: ${({theme:i,$variant:r})=>i.colors[r||"input"].text} !important;
  display: inline-block;
  font: inherit;

  &.active {
    border-color: ${({theme:i})=>i.colors.accent2};
  }

  &:hover:not(:disabled):not(.static) {
    color: ${({theme:i,$variant:r})=>i.colors[r||"input"].text};
    border-color: ${({theme:i})=>i.colors.accent3};
    background-color: ${({theme:i,$variant:r})=>i.colors[r||"input"].accent};

    &.active {
      border-color: ${({theme:i})=>i.colors.active};
    }
  }

  &:focus:not(:disabled):not(.static) {
    outline: none;
  }

  &:disabled {
    cursor: not-allowed;
  }

  &.static {
    cursor: default;
  }

  &:disabled,
  &.static {
    color: ${({theme:i,$variant:r})=>i.colors[r||"input"].disabled};
  }

  @media (max-width: 480px) {
    padding: 0 0.8em;
  }
`,Y=T.button.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  min-height: 2.5em;
  height: 2.5em;
  cursor: pointer;

  &:disabled {
    opacity: 0.6;
  }

  border-color: ${({theme:i,$variant:r})=>i.colors[r||"input"].color};

  @media (max-width: 700px) {
    height: max-content;
  }
`,hy=T.button.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  height: 2.5em;
  width: 3.35em;
  background-color: #00000063;
  align-self: center;
  cursor: pointer;
  border: unset;

  @media (min-width: 481px) {
    display: none;
  }

  &:hover:not(:disabled):not(.static) {
    background-color: #000000a3;
  }

  color: #cccccc !important;
`,Im=T.a.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;

  &:hover:not(:disabled):not(.static) {
    cursor: pointer;
  }

  border-color: ${({theme:i,$variant:r})=>i.colors[r||"input"].color};
`,Pm=T.a.attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  border: unset;
  background-color: #ffffff0a;
  color: #cccccc !important;

  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }
`,Je=T.label`
  display: block;
  margin-bottom: 10px;

  &[required]::after {
    content: '  *';
    color: red;
    font-size: 15px;
    font-weight: bolder;
  }
`,an=T(jt).attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;

  border-color: ${({theme:i,$variant:r})=>i.colors[r||"input"].color};
`,my=T(jt).attrs(i=>({className:`${i.$active?"active":""} ${i.static?"static":""}`}))`
  ${Kt}
  height: 2.5em;
  text-decoration: none;
  line-height: 2.5em;
  border: unset;
  background-color: #ffffff0a;
  color: #cccccc !important;

  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }
`,En=T.input`
  ${Kt}
  height: 2.5em;
`,xy=T.input.attrs({type:"radio"})`
  ${Kt}
`,Da=T.select`
  ${Kt}
  height: 2.5em;
  appearance: none;

  > option {
    background-color: ${({theme:i})=>i.colors.background};
    color: ${({theme:i})=>i.colors.text};
  }
`,gy=T.select`
  ${Kt}
  height: 2.5em;
  appearance: listbox;
  background-color: #ffffff0a;
  color: #cccccc !important;

  &:hover:not(:disabled):not(.static) {
    background-color: #f9f9f921;
  }

  > option {
    color: black;
  }
`,Zt=T.textarea`
  ${Kt}
  padding: 1em;

  &:focus::placeholder {
    color: transparent;
  }
`,Te=T.div`
  display: flex;
  flex-wrap: nowrap;

  > * {
    z-index: 1;
    margin: 0;
  }

  > :not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
  }

  > :not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-left: -1px;
  }

  > .active:hover {
    z-index: 4;
  }

  > .active {
    z-index: 3;
  }

  > :hover {
    z-index: 2;
  }

  @media (max-width: 480px) {
    ${({$fixed:i})=>!i&&`
        * {
          padding-right: 0.4em;
          padding-left: 0.4em;
          font-size: 0.85em;
          svg {
            padding: 0;
            margin: 0 0.3em;
          }
        }
      `}
  }

  box-shadow: 3px 3px 1px ${({theme:i})=>i.colors.shadow};
  border-radius: 20px;
  width: fit-content;
  height: fit-content;
`,hm=T(Te)`
  box-shadow: none;
`,Mt=T.div`
  display: flex;
  flex-wrap: wrap;

  > * {
    margin-bottom: ${({marginb:i})=>i??"0.5em"};
    margin-right: 0.5em;
  }

  > :not(:last-child) {
    @media (max-width: 480px) {
      margin-bottom: 0.4em;
      margin-right: 0.3em;
    }
  }
`,pc=T.div`
  display: flex;
  justify-content: center;

  > * {
    width: ${({size:i})=>i??"inherit"};
    margin: 0.2em;
  }
`,py=T.b`
  color: ${({theme:i})=>i.colors.highlight.text};

  &:hover:not(:disabled):not(.static) {
    cursor: pointer;
    color: ${({theme:i})=>i.colors.highlight.active};
  }
`,nn=T.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  text-align: center;
  width: 100%;
`;nn.Head=T.h3`
  font-weight: bold;
  font-size: 1.5em;
  text-decoration: underline;
`;nn.Paragraph=T.div`
  margin: 0;
  border-top: 2px solid;
  padding: 2em 5em;

  @media (max-width: 720px) {
    padding: 1em;
  }

  border-color: ${({theme:i})=>i.colors.accent2};
`;nn.ParagraphALT=T.div`
  margin: 0;
  padding: 2em 5em;

  @media (max-width: 720px) {
    padding: 1em;
  }

  b {
    display: block;
  }

  border-color: ${({theme:i})=>i.colors.accent2};
`;const Ei=T.div`
  display: ${({open:i})=>i?"flex":"none"};
  position: fixed;
  top: 0;
  left: 0;
  bottom: 0;
  right: 0;
  padding: 20px;
  z-index: 50;
  min-width: 100%;
`;Ei.Background=T.div`
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: ${({theme:i})=>i.colors.modal};
`;Ei.Content=T.div`
  position: relative;
  margin: auto;
  max-height: 100%;
  overflow-y: auto;
  width: ${({fill:i})=>i?"70%":"auto"};

  > ${Ce} {
    min-width: 200px;
    min-height: 200px;
    max-width: 1300px;
  }

  ${({fill:i})=>i&&`
    @media (max-width: 900px) {
      width: 100%;
    }
  `}
`;function qe({children:i,open:r=!1,setOpen:d,fill:u}){return w.useEffect(()=>{const o=f=>{f.key==="Escape"&&d(!1)};return window.addEventListener("keydown",o),()=>window.removeEventListener("keydown",o)},[d]),Jm.createPortal(l.jsxs(Ei,{open:r,children:[l.jsx(Ei.Background,{onClick:()=>d(!1)}),l.jsx(Ei.Content,{fill:u,children:i})]}),document.body)}function mm({children:i,onConfirm:r,title:d,setOpen:u,...o}){const{t:f}=k();return l.jsx(qe,{setOpen:u,...o,children:l.jsxs(Ce,{children:[l.jsx("h2",{style:{fontWeight:"bolder"},children:d||f("Please confirm!")}),i,l.jsxs(Te,{children:[l.jsx(Y,{$variant:"danger",onClick:r,children:f("Yes")}),l.jsx(Y,{$variant:"secondary",onClick:()=>u(!1),children:f("No")})]})]})})}const yy="/static/incursions/waitlist/bell-ringing-04.mp3",vy="/static/incursions/waitlist/notification-icon.png",xm="EventNotifierSettings";function jy(){const{t:i}=k(),r=w.useContext(_l),[d,u]=w.useState(!1),[o,f]=w.useState(!1),m=w.useRef(null),[g,p]=w.useState(()=>{try{const E=localStorage.getItem(xm);return E?JSON.parse(E):{enableSound:!1}}catch{return{enableSound:!1}}});w.useEffect(()=>{localStorage.setItem(xm,JSON.stringify(g))},[g]),w.useEffect(()=>{m.current&&(o?m.current.play().catch(console.warn):m.current.pause())},[o]);const y=w.useCallback(E=>{const O=E.data;Notification.permission==="granted"?new Notification("TLA",{body:O,icon:vy,tag:O,renotify:!0,timestamp:Date.now()}):Notification.permission==="default"&&Notification.requestPermission().catch(console.warn),g.enableSound&&m.current&&f(O)},[g]),j=w.useCallback(E=>{const O=JSON.parse(E.data);Notification.permission==="granted"?new Notification(O.message,{silent:!0}):Notification.permission==="default"&&Notification.requestPermission().catch(console.warn)},[]);return w.useEffect(()=>{if(r)return r.addEventListener("wakeup",y),r.addEventListener("message",j),()=>{r.removeEventListener("wakeup",y),r.removeEventListener("message",j)}},[r,y,j]),l.jsxs(l.Fragment,{children:[l.jsx(qe,{open:d,setOpen:u,children:l.jsxs(Ce,{children:[l.jsx("p",{children:l.jsxs("label",{children:[l.jsx("input",{type:"checkbox",checked:g.enableSound,onChange:E=>p(O=>({...O,enableSound:!!E.target.checked}))})," ",i("Enable sound notifications")]})}),l.jsx(Y,{onClick:()=>y({data:i("This is a test alert")}),children:i("Send test notification")})]})}),l.jsx(qe,{open:!!o,setOpen:()=>f(!1),children:l.jsxs(Ce,{style:{minHeight:"50px"},children:[l.jsx("p",{style:{marginBottom:"20px"},children:o}),l.jsx(Y,{onClick:()=>f(!1),$variant:"success",children:i("OK")}),l.jsx("audio",{ref:m,loop:!0,children:l.jsx("source",{src:yy,type:"audio/mp3"})})]})}),l.jsx(Pm,{onClick:()=>u(!0),title:g.enableSound?i("Sound alerts are currently enabled"):i("Sound alerts are currently disabled"),children:l.jsx(ie,{fixedWidth:!0,icon:g.enableSound?v0:j0})})]})}const gm={font:{family:'-apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',monospaceFamily:'SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace'},logo:{}},st={Light:ue.merge({},gm,{base:"light",colors:{background:"#ffffff",text:"#4a4a4a",active:"#000000",lumFactor:1,outline:"hsla(213, 100%, 40%, 0.2)",modal:"hsla(0, 0%, 0%, 0.80)",shadow:"hsla(0, 0%, 0%, 0.2)",input:{color:"#2020200d",text:"#4a4a4a",accent:"2020200d",disabled:"#cccccc"},success:{color:"#48c774",text:"white",accent:"#3ec46d",disabled:"#92ddac"},warning:{color:"#ffdd57",text:"#4a4a4a",accent:"#ffda47",disabled:"#cccccc"},danger:{color:"#f14668",text:"white",accent:"#f03a5f",disabled:"#f8a5b6"},primary:{color:"#47afff",text:"white",accent:"#38a9ff",disabled:"#addcff"},secondary:{color:"#e6e6e6",text:"#4a4a4a",accent:"#dbdbdb",disabled:"#cccccc"},highlight:{text:"#fc9936",active:"#ffad5c"},accent1:"#fafafa",accent2:"#dbdbdb",accent3:"#999999",accent4:"#666666",tdfShields:{red:"#d60015",green:"#19b915",blue:"#0076c2",yellow:"#d2bd00",purple:"#820082",neutral:"#4b4b4b",cyan:"#1eabaa",text:"#ffffff"}}}),Dark:ue.merge({},gm,{base:"dark",logo:{filter:"invert(1)"},colors:{background:"#1f1f1f",text:"#cccccc",active:"#eeeeee",lumFactor:.6,outline:"hsla(213, 100%, 40%, 0.2)",modal:"hsla(0, 0%, 0%, 0.80)",shadow:"hsla(0, 0%, 0%, 0.5)",input:{color:"#ffffff0a",text:"#cccccc",accent:"#ffffff0a",disabled:"#999999"},success:{color:"#1f6538",text:"white",accent:"#226d3c",disabled:"#133e22"},warning:{color:"#977c0b",text:"white",accent:"#b89300",disabled:"#574500"},danger:{color:"#661425",text:"white",accent:"#6f1628",disabled:"#330a12"},primary:{color:"#005ca3",text:"white",disabled:"#cccccc",accent:"#002e52"},secondary:{color:"#404040",text:"white",accent:"#454545",disabled:"#202020"},highlight:{text:"#fc9936",active:"#ffad5c"},accent1:"#2e2e2e",accent2:"#454545",accent3:"#757575",accent4:"#ababab",tdfShields:{red:"#9a121f",green:"#21861e",blue:"#105b8b",yellow:"#968912",purple:"#820082",neutral:"#777777",cyan:"#1c9493",text:"#cccccc"}}})};st.AMOLED=ue.merge({},st.Dark,{colors:{text:"#f0f0f0",background:"#000000",modal:"hsla(55, 0%, 13%, 0.83)"}});st["Midnight Blue"]=ue.merge({},st.Dark,{colors:{background:"#0a0a2c",accent1:"#1e1e40"}});st.Specialist=ue.merge({},st.Light,{colors:{text:"#666666",background:"#fdf3f9",accent1:"#ffcbe9",accent2:"#ffbcdf",accent3:"#d55f9d",active:"#e11891",outline:"hsla(306, 100%, 75%, 0.2)",modal:"hsla(0, 0%, 0%, 0.50)",shadow:"hsla(315, 100%, 90%, 0.4)",input:{color:"#ffc3e536",text:"#4a4a4a",accent:"#ffc3e536",disabled:"#757575"},primary:{color:"#d36ab9",text:"white",accent:"#b64a9b",disabled:"#e8e8e8"},secondary:{color:"#f1abd6",text:"white",accent:"#e58ac2",disabled:"#e8e8e8"},warning:{color:"#ffeb9f",text:"#363636",accent:"#ffda47",disabled:"#e8e8e8"},danger:{color:"#ff889f",text:"white",accent:"#f35e7b",disabled:"#f35e7b"},success:{color:"#d673af",text:"white",accent:"#c15496",disabled:"#e8e8e8"},tdfShields:{red:"#ff5676",yellow:"#f2d56d",green:"#50df4d",blue:"#2e91d1"}},logo:{filter:"hue-rotate(-55deg) drop-shadow(1px 2px 0.5px #ff8fc9) contrast(90%)"}});st.Chocola=ue.merge({},st.Dark,{colors:{background:"#30292c",active:"#FF357C",shadow:"hsla(0, 0%, 0%, 0.2)",outline:"hsla(339, 100%, 60%, 0.2)",secondary:{color:"#AE3F69",text:"white",accent:"#bc577d",disabled:"#e8e8e8"},input:{color:"#4f3d44",text:"#cccccc",accent:"#4f3d44",disabled:"#999999"},success:{color:"#1f6538",text:"white",accent:"#226d3c",disabled:"#133e22"},danger:{color:"#711818",text:"white",accent:"#6f1628",disabled:"#330a12"},accent1:"#4f3d44",accent2:"#5b4453",accent3:"#d15886"},logo:{filter:"invert(1) drop-shadow(1px 2px 0.5px #80173E)"},sticker:"https://i.imgur.com/ohDedR4.png"});st.Vanilla=ue.merge({},st.Dark,{colors:{background:"#2d2f43",active:"#9bf8ff",shadow:"rgba(0, 0, 0, .2)",outline:"hsla(203, 69%, 25%, 0.2)",text:"#6a96e9",secondary:{color:"#4b598a",text:"#e6e6e6",accent:"#5e6faa",disabled:"#b0a17f"},success:{color:"#1f6538",text:"#e4eff9 ",accent:"#226d3c",disabled:"#cccccc"},input:{color:"#3a425e",text:"#b0a17f",accent:"#3a425e",disabled:"#999999"},warning:{color:"#b79718",text:"white",accent:"#c8a51c",disabled:"#cccccc"},danger:{color:"#752626",text:"#cdcdcd ",accent:"#842c2c",disabled:"#330a12"},accent1:"#333557",accent2:"#3d5d86",accent3:"#9bf8ff",accent4:"#b0a17f",highlight:{text:"#fc9936",active:"#ffad5c"}},logo:{filter:"invert(62%) sepia(28%) saturate(325%) hue-rotate(4deg) brightness(100%) contrast(84%) drop-shadow(1px 1px 0.3px #000000)"},sticker:"https://i.imgur.com/8JN6udB.png"});Object.keys(st).forEach(i=>{st[i].name=i});const by=Object.keys(st);function Sy({theme:i,setTheme:r,sticker:d,setSticker:u}){var y;const{t:o}=k(),[f,m]=w.useState(!1),g=()=>{u(!d)},p=()=>["dark","AMOLED"].includes(i)?b0:i==="Specialist"?S0:w0;return l.jsxs(l.Fragment,{children:[l.jsx(qe,{open:f,setOpen:m,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:o("Theme select")}),by.map(j=>l.jsx("div",{children:l.jsxs("label",{children:[l.jsx(xy,{value:j,checked:i===j,onChange:E=>r(E.target.value)})," ",o(j)]})},j)),((y=st[i])==null?void 0:y.sticker)&&l.jsx(Y,{style:{marginTop:"0.5em"},onClick:g,children:o(d?"Disable Sticker":"Enable Sticker")})]})}),l.jsx(Pm,{onClick:()=>m(!0),children:l.jsx(ie,{fixedWidth:!0,icon:p()})})]})}const wn=T(jt)`
  padding: 0 1em;
  color: #bbb;
  text-decoration: none;
  text-shadow: 2px 2px 5px rgba(0, 0, 0, 0.5);
  &:hover {
    color: #cccccc;
    border-radius: 2px;
  }
  &.active {
    color: #eeeeee;
    text-shadow: 0px 0px 5px rgba(255, 255, 255, 0.5);
  }

  @media (max-width: 480px) {
    padding: 1em;
    &.active {
      background-color: #454545;
      border-radius: 4px;
    }
  }
`,wy=T.div`
  display: ${({$open:i})=>i?"flex":"none"};
  flex-wrap: wrap;
  flex-direction: column;
`,_y=T.div`
  padding: 0.3em;
  width: 100%;
  transition: all 0.3s;
  opacity: ${({$open:i})=>i?"1":"0"};
  height: ${({$open:i})=>i?"100%":"0"};
  background-color: #2e2e2e;
  border-radius: 0 0 5px 5px;
`,Ty=({isOpen:i,whoami:r})=>l.jsx(_y,{$open:i,children:l.jsx(wy,{$open:i,children:l.jsx(ex,{whoami:r})})}),Cy=({isOpen:i,setIsOpen:r})=>{const d=sn();return w.useEffect(()=>{r(!1)},[d,r]),l.jsx(hy,{onClick:()=>r(!i),children:l.jsx(ie,{icon:i?Zu:_0})})},ex=({whoami:i})=>{var d,u;const{t:r}=k();return l.jsxs(l.Fragment,{children:[l.jsx(wn,{to:"/",end:!0,className:({isActive:o})=>o?"active":"",children:r("Home")}),i&&l.jsx(wn,{to:"/waitlist",end:!0,className:({isActive:o})=>o?"active":"",children:r("Waitlist")}),l.jsx(wn,{to:"/guide",end:!0,className:({isActive:o})=>o?"active":"",children:r("Guides")}),l.jsx(wn,{to:"/fits?Tier=Mainline",end:!0,className:({isActive:o})=>o?"active":"",children:r("Fits")}),l.jsx(wn,{to:"/skills?ship=Paladin",end:!0,className:({isActive:o})=>o?"active":"",children:r("Skills")}),l.jsx(wn,{to:"/isk-h/calc",end:!0,className:({isActive:o})=>o?"active":"",children:r("ISK/h")}),((d=i==null?void 0:i.access)==null?void 0:d["incursions.waitlist_manage_waitlist"])&&l.jsxs(l.Fragment,{children:[l.jsx(wn,{to:"/fc/fleet",end:!0,className:({isActive:o})=>o?"active":"",children:r("Fleet")}),l.jsx(wn,{to:"/fc",end:!0,className:({isActive:o})=>o?"active":"",children:r("FC")})]}),((u=i==null?void 0:i.access)==null?void 0:u["incursions.waitlist_search"])&&l.jsx(wn,{to:"/fc/search",end:!0,className:({isActive:o})=>o?"active":"",children:r("Search")})]})},Ay="/static/incursions/waitlist/banner.png",Ey=T.div`
  background-image: url(${Ay});
  background-size: 100% auto;
  background-repeat: no-repeat;
  padding: 0.5em;
  border-radius: 0 0 20px 20px;
  box-shadow: 2px 2px 10px rgba(0, 0, 0, 0.3);
  transition: border-radius 0.1s ease-in-out;
  padding-top: 6.5em;

  @media (max-width: 700px) {
    background-size: auto 100%;
    border-radius: ${({$mobileopen:i})=>i?"unset":"0 0 20px 20px"};
  }
`,Dy=T(jt)`
  height: 2.5em;

  img {
    &:hover {
      opacity: 0.7;
    }
  }

  &.active {
    font-weight: bold;
  }
`,Gt=T.div`
  margin-bottom: 2em;
`;Gt.LogoLink=T(jt)`
  margin-right: 2em;
  flex-grow: 0;
  line-height: 0;

  @media (max-width: 480px) {
    margin-right: unset;
    margin-left: auto;
  }

  &.active {
    font-weight: bold;
  }
`;Gt.Logo=T.img`
  width: 150px;
  filter: ${i=>i.theme.logo.filter};
`;Gt.Menu=T.div`
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  flex-grow: 1;
`;Gt.Link=T(jt)`
  padding: 1em;
  color: ${i=>i.theme.colors.accent4};
  text-decoration: none;

  &.active {
    color: ${i=>i.theme.colors.active};
    font-weight: bold;
  }
`;Gt.End=T.div`
  margin-left: auto;
  display: flex;
  flex-wrap: wrap;
  align-items: center;

  > :not(:last-child) {
    @media (max-width: 480px) {
      margin-bottom: 0.4em;
    }
  }
`;Gt.Main=T.div`
  display: flex;
  flex-wrap: wrap;

  @media (max-width: 480px) {
    display: none;
  }
`;Gt.Name=T.div`
  margin-right: 2em;

  @media (max-width: 480px) {
    margin-right: 0;
    width: 100%;
  }
`;function Oy({onChangeCharacter:i,theme:r,setTheme:d,sticker:u,setSticker:o}){const[f,m]=w.useState(!1),[g,p]=w.useState(window.innerWidth),{t:y}=k(),j=w.useContext(ze);return w.useEffect(()=>{const E=()=>p(window.innerWidth);return window.addEventListener("resize",E),()=>window.removeEventListener("resize",E)},[]),l.jsxs(Gt,{children:[l.jsx(Ey,{$mobileopen:f,children:l.jsxs(Gt.Menu,{children:[l.jsx(Gt.Main,{children:l.jsx(ex,{whoami:j})}),l.jsxs(Gt.End,{children:[j&&l.jsx(Gt.Name,{children:l.jsxs(hm,{$fixed:!0,children:[l.jsx(Dy,{to:"/pilot",end:!0,className:({isActive:E})=>E?"active":"",children:l.jsx("img",{style:{maxHeight:"100%",borderRadius:"20px 0 0 20px"},src:`https://images.evetech.net/characters/${j.current.character_id}/portrait?size=128`,alt:"Character Portrait"})}),l.jsx(gy,{value:j.current.character_id,onChange:E=>i==null?void 0:i(parseInt(E.target.value)),style:{flexGrow:1,border:"unset"},children:j.characters.map(E=>l.jsx("option",{value:E.character_id,children:E.character_name},E.character_id))}),l.jsx(an,{as:"a",href:"/incursions/char/add",children:"+"})]})}),l.jsxs(hm,{children:[g<481&&l.jsx(Cy,{isOpen:f,setIsOpen:m}),l.jsx(jy,{}),l.jsx(Sy,{theme:r,setTheme:d,sticker:u,setSticker:o}),j?l.jsx(my,{as:"button",onClick:()=>window.location.href="/incursions/waitlist/auth/logout",children:y("Logout")}):l.jsx(an,{as:"a",href:"/incursions/char/add",$variant:"primary",children:y("Login")})]})]})]})}),l.jsx(Ty,{isOpen:f,whoami:j})]})}U0.use(k0).use(L0).use(H0).init({detection:{order:["htmlTag","querystring","cookie","localStorage","sessionStorage","navigator","path","subdomain"],htmlTag:document.documentElement},fallbackLng:"en",interpolation:{escapeValue:!1},react:{useSuspense:!1},backend:{loadPath:"/static/incursions/waitlist/i18n/{{lng}}/{{ns}}.json"}});const My=T.a`
  color: ${({theme:i})=>i.colors.highlight.text};
  text-decoration: none;

  &:hover {
    cursor: pointer;
    color: ${({theme:i})=>i.colors.highlight.active};
    transition: color 0.15s ease-in-out;
  }

  & + svg {
    margin-left: 5px;
    font-size: small;
  }
`;function $e(i){w.useEffect(()=>{let r=document.title;return Pu(i),()=>document.title=r})}function Pu(i){document.title=`AA: ${i}`}function tx(i){const r=i.split(`
`)[0];return r.substring(r.indexOf(" "))}function zy(i){return i.split(" ").map(r=>r[0].toUpperCase()+r.substr(1).toLowerCase()).join(" ")}const By=T.div`
  padding: 10px 20px;
  font-weight: 600;

  h1 {
    font-size: 30px;
  }
`,eo=({title:i,children:r})=>($e(i),l.jsx(By,{children:r})),Ny=()=>{const{t:i}=k();return l.jsx(eo,{title:i("Login Required"),children:l.jsxs("p",{children:[i("You must")," ",l.jsx(My,{href:"/incursions/char/add",children:i("Login")})," ",i("to view this page.")]})})},Ry=()=>{const{t:i}=k();return l.jsxs(eo,{title:i("Forbidden"),children:[l.jsx("h1",{children:i("403 Error")}),l.jsx("p",{children:i("You are not allowed to view this page. Contact leadership to request access.")})]})},Uy=()=>{const{t:i}=k();return l.jsxs(eo,{title:i("Page Not Found"),children:[l.jsx("h1",{children:i("404 Error")}),l.jsx("p",{children:i("I warped to the FC twice, and all I got was this '404: page not found' error.")})]})};function to(i){const d=w.useContext(Oa).name;return Object.entries(st).forEach(([u,o])=>{Zp(`TDF-${u}`,{text:{primary:o.colors.primary,secondary:o.colors.secondary},background:{default:o.colors.background}},o.base??"dark")}),l.jsx(Kp,{...i,theme:`TDF-${d}`})}const ky=(i,r)=>i.localeCompare(r,{sensitivity:"base"}),pm=new Date(864e13),Ly=(i,r)=>{const d=i?i instanceof Date?i:new Date(i):pm,u=r?r instanceof Date?r:new Date(r):pm;return d.getTime()-u.getTime()},ym=["Character","Corporation","Alliance"],Hy=(i,r)=>ym.indexOf(i.category)-ym.indexOf(r.category),bl=T.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,nx=T.div`
  font-style: italic;
`,qy={marginRight:"20px",marginBottom:"15px",display:"inline-block"},vm={"Use in game channel":{content:"Join the TLA Incursions channel to x-up for the fleet.",alert:!1},"Gankers in Focus":{content:"GANKERS ARE IN FOCUS! Stay docked and read the fleet MOTD for instructions.",alert:!0}},ax=({idPrefix:i="",selectedFilters:r=[],onChange:d})=>{const{t:u}=k(),o=f=>{const{dataset:m,checked:g}=f.target,p=m.value;if(!p)return;const y=g?[...r,p]:r.filter(j=>j!==p);d(y)};return l.jsxs(bl,{children:[l.jsxs(Je,{children:[u("Display on:")," (",u("leave blank for site-wide"),")"]}),Wm.map((f,m)=>{const g=f.name.toLowerCase(),p=r.includes(g),y=`${i}-${g}`;return l.jsxs("label",{htmlFor:y,style:qy,children:[l.jsx("input",{id:y,"data-value":g,type:"checkbox",checked:p,onChange:o})," ",u(f.name)]},m)})]})},$y=({isOpen:i,setOpen:r,refreshFunction:d})=>{const{t:u}=k(),o=w.useContext(oe),[f,m]=w.useState(!1),[g,p]=w.useState(void 0),[y,j]=w.useState([]),[E,O]=w.useState(!1),M=()=>{m(!1),p(void 0),j([])},L=U=>{if(U.preventDefault(),E)return;O(!0);const G=y.length>0?JSON.stringify(y):null;re(o,Qe("/incursions/api/announcements",{method:"POST",json:{message:g,is_alert:f,pages:G}}).then(()=>{r(!1),d(),M()}).finally(()=>O(!1)))},q=U=>{const G=vm[U.target.value];m((G==null?void 0:G.alert)??!1),p((G==null?void 0:G.content)??"")};return l.jsx(qe,{open:i,setOpen:r,fill:void 0,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:u("New Announcement")}),l.jsxs("form",{onSubmit:L,children:[l.jsxs(bl,{children:[l.jsxs(Je,{htmlFor:"content",children:[u("Content"),":"]}),l.jsx(Zt,{id:"content",value:g??"",style:{maxWidth:"450px",width:"80vw",height:"250px",resize:"vertical"},onChange:U=>p(U.target.value),required:!0,minLength:0,maxLength:512}),l.jsx(nx,{children:u("Maximum 512 characters.")})]}),l.jsxs(bl,{children:[l.jsx("input",{id:"important",type:"checkbox",checked:f,onChange:()=>m(!f)}),l.jsxs("label",{htmlFor:"important",title:u("Banner has a red background."),children:[u("This is a")," ",l.jsx("b",{children:l.jsx("u",{children:u("REALLY")})})," ",u("important announcement!")]})]}),l.jsx(ax,{selectedFilters:y,onChange:j}),l.jsxs(bl,{children:[l.jsx(Je,{children:u("or select a template")}),l.jsxs(Da,{style:{width:"100%",appearance:"auto"},onChange:q,children:[l.jsx("option",{children:u("Select...")}),Object.entries(vm).map(([U],G)=>l.jsx("option",{value:U,children:u(U)},G))]})]}),l.jsxs(Mt,{style:{paddingLeft:"8px"},children:[l.jsx(Y,{$variant:"danger",type:"submit",disabled:E,children:u("Confirm")}),l.jsx(Y,{$variant:"secondary",type:"button",onClick:()=>r(!1),children:u("Cancel")})]})]})]})})},Gy=({data:i,refreshFunction:r})=>{const{t:d}=k(),[u,o]=w.useState(!1),f=({data:m,refreshFunction:g,isOpen:p,setOpen:y})=>{const j=w.useContext(oe),[E,O]=w.useState(),[M,L]=w.useState(!1),[q,U]=w.useState([]),[G,Q]=w.useState(!1),be=W=>{try{return W?JSON.parse(W):[]}catch{return[]}};w.useEffect(()=>{O(m.message),L(m.is_alert),U(be(m.pages))},[m.id,m.message,m.is_alert,m.pages]);const te=W=>{if(W.preventDefault(),G)return;Q(!0);const de=q.length>0?JSON.stringify(q):null;re(j,Qe(`/incursions/api/announcements/${m.id}`,{method:"PUT",json:{message:E,is_alert:M,pages:de}}).then(()=>{y(!1),g()}).finally(()=>Q(!1)))};return l.jsx(qe,{open:p,setOpen:y,fill:void 0,children:l.jsxs(Ce,{children:[l.jsxs(Me,{children:[d("Update Announcement")," #",m.id]}),l.jsxs("form",{onSubmit:te,children:[l.jsxs(bl,{children:[l.jsxs(Je,{htmlFor:`content-${m.id}`,children:[d("Content"),":"]}),l.jsx(Zt,{id:`content-${m.id}`,value:E??"",style:{maxWidth:"450px",width:"80vw",height:"250px",resize:"vertical"},onChange:W=>O(W.target.value),required:!0,minLength:0,maxLength:512}),l.jsx(nx,{children:d("Maximum 512 characters.")})]}),l.jsxs(bl,{children:[l.jsx("input",{id:`important-${m.id}`,type:"checkbox",checked:M,onChange:()=>L(!M)}),l.jsxs("label",{htmlFor:`important-${m.id}`,title:d("Banner has a red background."),children:[d("This is a")," ",l.jsx("b",{children:l.jsx("u",{children:d("REALLY")})})," ",d("important announcement!")]})]}),l.jsx(ax,{idPrefix:m.id.toString(),selectedFilters:m!=null&&m.pages?JSON.parse(m.pages):[],onChange:U}),l.jsxs(Mt,{style:{paddingLeft:"8px"},children:[l.jsx(Y,{$variant:"danger",type:"submit",disabled:G,children:d("Confirm")}),l.jsx(Y,{$variant:"secondary",type:"button",onClick:()=>y(!1),children:d("Cancel")})]})]})]})})};return l.jsxs(l.Fragment,{children:[l.jsx(Y,{onClick:()=>o(!0),children:d("Update")}),l.jsx(f,{isOpen:u,setOpen:o,data:i,refreshFunction:r})]})},Yy=T.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`;async function Xy(i){await Qe(`/incursions/api/announcements/${i}`,{method:"DELETE",json:null})}const Qy=()=>{const[i,r]=Le("/incursions/api/announcements"),[d,u]=w.useState(!1),o=w.useContext(oe),{t:f}=k(),m=[{name:f("Content"),grow:5,selector:g=>g.message,wrap:!0},{name:f("Pages"),selector:g=>{if(!g.pages)return f("table.pages.all","All");try{return JSON.parse(g.pages).map(p=>f(`pages.${p}`,p)).join(", ")}catch{return g.pages}},wrap:!0},{name:f("Created By"),selector:g=>l.jsx(dt,{...g.created_by})},{name:"",maxWidth:"115px",selector:g=>l.jsx(Gy,{data:g,refreshFunction:r??(()=>{})})},{name:"",maxWidth:"110px",selector:g=>l.jsx(Y,{$variant:"danger",onClick:()=>re(o,Xy(g.id).then(r)),children:f("Delete")})}];return $e(f("Announcements")),l.jsxs(l.Fragment,{children:[l.jsxs(Yy,{children:[l.jsx("h1",{children:f("Announcements")}),l.jsxs(Y,{variant:"primary",onClick:()=>u(!0),style:{marginTop:"15px"},children:[l.jsx(ie,{fixedWidth:!0,icon:Hm,style:{marginRight:"10px"}}),f("New")]})]}),l.jsx(to,{columns:m,data:i??[],pagination:!1,progressPending:!i}),l.jsx($y,{isOpen:d,setOpen:u,refreshFunction:r??(()=>{})})]})},jm={width:"100%",resize:"vertical",minWidth:"250px"},_i=T.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,Vy=T.form`
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;

  & label::selection,
  div::selection,
  button::selection {
    background: none;
  }
`,bm=T.div`
  font-style: italic;
`,Zy=({entity_type:i,entity_character:r,entity_corporation:d,entity_alliance:u,entity_name:o})=>{switch(i){case"Character":return l.jsx(dt,{...r,noLink:!0});case"Corporation":return l.jsx(Wu,{...d,noLink:!0});case"Alliance":return l.jsx(Iu,{...u,noLink:!0});default:return o}},Ky=({isOpen:i,setOpen:r,refreshFunction:d})=>{const{t:u}=k(),o=w.useContext(oe),[f,m]=w.useState(!1),[g,p]=w.useState(!1),[y,j]=w.useState(void 0),[E,O]=w.useState("Character"),[M,L]=w.useState({id:null,name:""}),[q,U]=w.useState(""),[G,Q]=w.useState(!1),[be,te]=w.useState(void 0),[W,de]=w.useState(void 0),We=Re=>{if(Re.preventDefault(),!f){if(!M.id){ln(o,{variant:"danger",message:u("You need to provide a {{category}} name.",{category:E.toLowerCase()})});return}m(!0),re(o,Qe("/incursions/api/bans",{method:"POST",json:{entity:{...M,category:E},reason:be,public_reason:W,revoked_at:g?null:y}}).then(()=>{r(!1),d(),bt()}).finally(()=>m(!1)))}},bt=()=>{p(!1),j(void 0),O("Character"),L({id:null,name:""}),U(""),Q(!1),te(void 0),de(void 0)};return w.useEffect(()=>{const Re=()=>L({id:null,name:""});if(q.length<3)return Re();Q(!0),re(o,Qe("/incursions/api/search",{method:"POST",json:{search:q,category:E.toLowerCase(),strict:!0}}).then(ca=>{Q(!1),ca.length>0?L({id:ca[0],name:q}):Re()}))},[q,E,o]),l.jsx(qe,{open:i,setOpen:r,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:u("Issue a Ban","Issue a Ban")}),l.jsxs(Vy,{onSubmit:We,children:[l.jsxs("div",{children:[l.jsxs(_i,{style:{paddingBottom:"40px"},children:[l.jsx(Je,{htmlFor:"select-type",required:!0,children:u("Type:","Type:")}),l.jsxs(Da,{id:"select-type",value:E,onChange:Re=>{U(""),O(Re.target.value)},style:{width:"100%",appearance:"auto"},children:[l.jsx("option",{disabled:!0,children:u("Account","Account")}),l.jsx("option",{children:u("Character","Character")}),l.jsx("option",{children:u("Corporation","Corporation")}),l.jsx("option",{children:u("Alliance","Alliance")})]})]}),l.jsxs(_i,{children:[l.jsx(Je,{htmlFor:"entity-name",required:!0,children:u("{{category}} Name:","{{category}} Name:",{category:E})}),l.jsx(En,{id:"entity-name",type:"text",value:q,required:!0,tabIndex:2,onChange:Re=>U(Re.target.value)}),l.jsx("div",{style:{paddingTop:"10px"},children:G?u("Searching...","Searching..."):(M==null?void 0:M.id)&&l.jsx(Zy,{category:E,...M})})]})]}),l.jsxs("div",{children:[l.jsxs(_i,{children:[l.jsx(Je,{htmlFor:"expires_at",required:!0,children:u("Expires:","Expires:")}),l.jsx(En,{id:"expires_at",type:"date",value:y?new Date(y*1e3).toISOString().substring(0,10):"",onChange:Re=>j(new Date(Re.target.value).getTime()/1e3),min:new Date(Date.now()+3600*1e3*24).toISOString().substring(0,10),required:!0,disabled:g}),l.jsx("span",{style:{margin:"0 5px"},children:u("or","or")}),l.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},children:[l.jsx("input",{type:"checkbox",checked:g,onChange:()=>p(!g)}),u("Permanent","Permanent")]}),l.jsx(bm,{children:u("Bans expire at downtime","Bans expire at downtime")})]}),l.jsxs(_i,{children:[l.jsx(Je,{htmlFor:"reason",required:!0,children:u("Reason:","Reason:")}),l.jsx(Zt,{id:"reason",value:be??"",style:jm,required:!0,onChange:Re=>te(Re.target.value)})]}),l.jsxs(_i,{children:[l.jsx(Je,{htmlFor:"public_reason",children:u("Public Reason:","Public Reason:")}),l.jsx(Zt,{id:"public_reason",value:W??"",style:jm,onChange:Re=>de(Re.target.value)}),l.jsx(bm,{children:u("This reason will be shown to the pilot on the ban page.","This reason will be shown to the pilot on the ban page.")})]}),l.jsxs(Mt,{style:{paddingLeft:"8px"},children:[l.jsx(Y,{$variant:"secondary",onClick:()=>r(!1),children:u("Cancel","Cancel")}),l.jsx(Y,{$variant:"danger",type:"submit",disabled:f,children:u("Confirm","Confirm")})]})]})]})]})})},Sm={width:"100%",resize:"vertical",minWidth:"250px"},aa=T.div`
  margin: 15px 0px;
  padding: 5px 10px;
  flex-grow: 2;
`,Jy=T.div`
  font-style: italic;
`,lx=i=>{switch(i.entity_type){case"Character":return i.entity_character?l.jsx(dt,{...i.entity_character}):i.entity_name;case"Corporation":return i.entity_corporation?l.jsx(Wu,{...i.entity_corporation}):i.entity_name;case"Alliance":return i.entity_alliance?l.jsx(Iu,{...i.entity_alliance}):i.entity_name;default:return i.entity_name}},Fy=({ban:i,isOpen:r,setOpen:d,refreshFunction:u})=>{const{t:o}=k(),[f,m]=w.useState(!1),g=w.useContext(oe),p=()=>{f||(m(!0),re(g,Qe(`/incursions/api/bans/${i.id}`,{method:"DELETE"}).then(()=>{d(!1),u()}).finally(()=>m(!1))))};return l.jsx(qe,{open:r,setOpen:d,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:o("Revoke {{type}} Ban?","Revoke {{type}} Ban?",{type:i.entity_type})}),l.jsxs("div",{style:{maxWidth:"500px",display:"flex"},children:[l.jsxs(aa,{children:[l.jsx(Je,{children:o("{{type}}:","{{type}}:",{type:i.entity_type})}),l.jsx(lx,{...i})]}),l.jsxs(aa,{children:[l.jsx(Je,{children:o("Issued By:","Issued By:")}),i.issued_by&&l.jsx(dt,{...i.issued_by})]})]}),l.jsxs(aa,{children:[l.jsx(Je,{children:o("Reason:","Reason:")}),l.jsx("p",{style:{maxWidth:"500px"},children:i.reason})]}),l.jsxs(pc,{size:"90px",children:[l.jsx(Y,{$variant:"secondary",onClick:()=>d(!1),children:o("Cancel","Cancel")}),l.jsx(Y,{$variant:"danger",onClick:p,disabled:f,children:o("Confirm","Confirm")})]})]})})},Wy=({ban:i,isOpen:r,setOpen:d,refreshFunction:u})=>{const{t:o}=k(),[f,m]=w.useState(),[g,p]=w.useState(""),[y,j]=w.useState(""),[E,O]=w.useState(!1),[M,L]=w.useState(!1),q=w.useContext(oe),U=G=>{G.preventDefault(),!M&&(L(!0),re(q,Qe(`/incursions/api/bans/${i.id}`,{method:"PATCH",json:{reason:g,public_reason:y,revoked_at:E?null:f}}).then(()=>{d(!1),u()}).finally(()=>L(!1))))};return w.useEffect(()=>{m(i.revoked_at??void 0),O(i.revoked_at==null),p(i.reason??""),j(i.public_reason??"")},[i]),l.jsx(qe,{open:r,setOpen:d,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:o("Update {{type}} Ban:","Update {{type}} Ban:",{type:i.entity_type})}),l.jsxs("div",{style:{maxWidth:"500px",display:"flex"},children:[l.jsxs(aa,{children:[l.jsx(Je,{children:o("{{type}}:","{{type}}:",{type:i.entity_type})}),l.jsx(lx,{...i})]}),l.jsxs(aa,{children:[l.jsx(Je,{children:o("Issued By:","Issued By:")}),i.issued_by&&l.jsx(dt,{...i.issued_by})]})]}),l.jsxs("form",{onSubmit:U,children:[l.jsxs(aa,{children:[l.jsx(Je,{required:!0,children:o("Expires:","Expires:")}),l.jsx(En,{type:"date",value:f?new Date(f*1e3).toISOString().substring(0,10):"",onChange:G=>m(new Date(G.target.value).getTime()/1e3),min:new Date(Date.now()+3600*1e3*24).toISOString().substring(0,10),disabled:E,required:!0}),l.jsx("span",{style:{margin:"0 5px"},children:o("or","or")}),l.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},children:[l.jsx("input",{type:"checkbox",checked:E,onChange:()=>O(!E)}),o("Permanent","Permanent")]})]}),l.jsxs(aa,{children:[l.jsx(Je,{htmlFor:`reason-${i.id}`,required:!0,children:o("Reason:","Reason:")}),l.jsx(Zt,{id:`reason-${i.id}`,value:g,onChange:G=>p(G.target.value),style:Sm,required:!0})]}),l.jsxs(aa,{children:[l.jsx(Je,{htmlFor:`public_reason-${i.id}`,children:o("Public Reason:","Public Reason:")}),l.jsx(Zt,{id:`public_reason-${i.id}`,value:y,onChange:G=>j(G.target.value),style:Sm}),l.jsx(Jy,{children:o("This reason will be shown to the pilot on the ban page.","This reason will be shown to the pilot on the ban page.")})]}),l.jsxs(pc,{size:"90px",children:[l.jsx(Y,{$variant:"secondary",type:"button",onClick:()=>d(!1),children:o("Cancel","Cancel")}),l.jsx(Y,{$variant:"danger",type:"submit",disabled:M,children:o("Confirm","Confirm")})]})]})]})})},wm={marginRight:"10px",marginBottom:"10px",appearance:"auto"},Iy=({filters:i,onChange:r,onClear:d})=>{const{t:u}=k(),o={type:[{text:u("any duration","any duration"),value:"-1"},{text:u("permanent","permanent")},{text:u("temporary","temporary")}],entity_type:[{text:u("any type","any type"),value:"-1"},{text:u("account","account")},{text:u("alliance","alliance")},{text:u("character","character")},{text:u("corporation","corporation")}]},f=(g,p)=>{const y=g.target.value==="-1"?null:g.target.value;r({...i,[p]:y})},m=g=>{r({...i,name:g.target.value})};return l.jsxs("div",{id:"filters",children:[l.jsx("span",{children:u("Filter results by...","Filter results by...")}),l.jsx(Da,{value:i.entity_type??"",onChange:g=>f(g,"entity_type"),style:wm,children:o.entity_type.map((g,p)=>l.jsx("option",{value:g.value??g.text,disabled:g.text===u("account"),children:g.text},p))}),l.jsx(Da,{value:i.type??"",onChange:g=>f(g,"type"),style:wm,children:o.type.map((g,p)=>l.jsx("option",{value:g.value??g.text,children:g.text},p))}),l.jsx(En,{value:i.name??"",onChange:m,placeholder:u("name","name"),style:{marginRight:"10px",marginBottom:"10px"}}),l.jsx(Y,{$variant:"primary",onClick:d,style:{marginBottom:"10px"},children:u("Clear","Clear")})]})},Py=i=>{const{t:r}=k(),[d,u]=w.useState(!1);return l.jsxs(l.Fragment,{children:[l.jsxs(Y,{$variant:"primary",onClick:()=>u(!0),children:[l.jsx(ie,{fixedWidth:!0,icon:T0,style:{marginRight:"10px"}}),r("Issue Ban","Issue Ban")]}),l.jsx(Ky,{isOpen:d,setOpen:u,...i})]})},ev=i=>{const{t:r}=k(),[d,u]=w.useState(!1);return l.jsxs(l.Fragment,{children:[l.jsx(Y,{$variant:"danger",onClick:()=>u(!0),children:r("Revoke","Revoke")}),l.jsx(Fy,{isOpen:d,setOpen:u,...i})]})},tv=i=>{const{t:r}=k(),[d,u]=w.useState(!1);return l.jsxs(l.Fragment,{children:[l.jsx(Y,{onClick:()=>u(!0),children:r("Update","Update")}),l.jsx(Wy,{isOpen:d,setOpen:u,...i})]})},nv=T.div`
  display: flex;
  flex-flow: column wrap;
  justify-content: space-around;
  padding-top: 10px;
  padding-bottom: 15px;

  p {
    padding-bottom: 5px;
    font-weight: bold;

    span {
      font-weight: normal;
      font-style: italic;
      font-size: small;
      color: ${i=>i.theme.colors.active};
    }
  }

  div {
    padding-bottom: 20px;

    &[mode='wide'] {
      display: flex;
      flex-flow: row wrap;

      div {
        min-width: 120px;
        width: 20vw;
      }
    }
  }
`,av=({data:i,refreshFunction:r})=>{const{t:d}=k(),u=new Date,o=new Date(i.issued_at),f=i.revoked_at?new Date(i.revoked_at):null;return l.jsxs(nv,{children:[l.jsxs("div",{style:{paddingBottom:"0"},children:[l.jsxs("div",{children:[l.jsx("p",{children:d("Issued by:","Issued by:")}),l.jsx(dt,{...i.issued_by})]}),i.revoked_by&&l.jsxs("div",{children:[l.jsx("p",{children:d("Revoked by:","Revoked by:")}),l.jsx(dt,{...i.revoked_by})]})]}),l.jsxs("div",{style:{paddingBottom:"0"},children:[l.jsxs("div",{children:[l.jsx("p",{children:d("Issued at:","Issued at:")}),wl(o)]}),f&&f<u&&l.jsxs("div",{children:[l.jsx("p",{children:d("Revoked at:","Revoked at:")}),zi(f)]})]}),f&&f>u&&l.jsxs("div",{children:[l.jsx("p",{children:d("Expires In:","Expires In:")}),l.jsx("span",{title:zi(f),children:gc(f)})]}),l.jsxs("div",{style:{wordWrap:"break-word",maxWidth:"70vw"},children:[l.jsxs("p",{children:[d("Reason:","Reason:")," ",l.jsx("span",{children:d("(this reason can ONLY be seen by the FC team)","(this reason can ONLY be seen by the FC team)")})]}),i.reason]}),i.public_reason&&l.jsxs("div",{style:{wordWrap:"break-word",maxWidth:"70vw"},children:[l.jsxs("p",{children:[d("Public Reason:","Public Reason:")," ",l.jsx("span",{children:d("(this reason can be seen by the pilot)","(this reason can be seen by the pilot)")})]}),i.public_reason]}),l.jsxs(Mt,{children:[l.jsx(tv,{ban:i,refreshFunction:r}),l.jsx(ev,{ban:i,refreshFunction:r})]})]})},lv=T.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`,iv=T.div`
  align-content: space-between;
  display: flex;
  width: 100%;
  flex-wrap: wrap;

  > button {
    @media (max-width: 800px) {
      width: 100%;
    }
  }

  #filters {
    flex-grow: 1;

    span:first-of-type {
      font-style: italic;
      margin-right: 10px;

      @media (max-width: 800px) {
        display: block;
        margin-bottom: 5px;
      }
    }

    @media (max-width: 800px) {
      input,
      select {
        width: calc(calc(100vw - 158px) / 2);
      }
    }

    @media (max-width: 500px) {
      input,
      select {
        width: 100%;
      }
      button {
        display: block;
        width: 100%;
      }
    }
  }
`,sv=()=>{const[i,r]=Le("/incursions/api/bans"),[d,u]=w.useState({type:null,name:"",entity_type:""}),o=[{name:"Name",sortable:!0,sortFunction:(g,p)=>ky(g.entity_name,p.entity_name),grow:3,selector:g=>{switch(g.entity_type){case"Character":return g.entity_character?l.jsx(dt,{...g.entity_character}):g.entity_name;case"Corporation":return g.entity_corporation?l.jsx(Wu,{...g.entity_corporation}):g.entity_name;case"Alliance":return g.entity_alliance?l.jsx(Iu,{...g.entity_alliance}):g.entity_name;default:return g.entity_name}}},{name:"Entity Type",sortable:!0,sortFunction:(g,p)=>Hy(g.entity_type,p.entity_type),grow:1,selector:g=>g.entity_type},{name:"Expires",sortable:!0,hide:"sm",sortFunction:(g,p)=>Ly(g.revoked_at,p.revoked_at),grow:1,selector:g=>g.revoked_at?zi(new Date(g.revoked_at)):"Never"},{name:"Reason",hide:"sm",grow:6,wrap:!0,selector:g=>g.reason}],f=w.useMemo(()=>(i??[]).filter(g=>(!d.entity_type||g.entity_type.toLowerCase()===d.entity_type)&&(!d.type||d.type==="permanent"&&!g.revoked_at||d.type==="temporary"&&g.revoked_at)&&g.entity_name.toLowerCase().includes(d.name.toLowerCase())),[i,d]),m=w.useMemo(()=>l.jsxs(iv,{children:[l.jsx(Iy,{filters:d,onChange:g=>u({...g}),onClear:()=>u({type:null,name:"",entity_type:""})}),l.jsx(Py,{refreshFunction:r})]}),[d,r]);return $e("Bans"),l.jsxs(l.Fragment,{children:[l.jsx(lv,{children:l.jsx("h1",{children:"System Bans"})}),l.jsx("p",{style:{marginBottom:"10px"},children:"Players who are banned or are in a banned corporation or alliance will be prevented from authenticating or joining the waitlist."}),l.jsx(to,{textAlign:"center",verticalAlign:"middle",columns:o,data:f,defaultSortFieldId:1,expandableRows:!0,expandableRowsComponent:av,expandableRowsComponentProps:{refreshFunction:r},subHeader:!0,subHeaderComponent:m,progressPending:!i})]})},cv="/static/incursions/waitlist/static/img/fleetcomp-BQGhOhZ8.png",Yt=T.span`
  background-color: ${i=>(i.theme.colors[i.$variant??""]||{}).color||"transparent"};
  color: ${i=>(i.theme.colors[i.$variant??""]||{}).text||i.theme.colors.text};
  filter: drop-shadow(0px 1px 1px ${i=>i.theme.colors.shadow});
  padding: 0 0.74em;
  border-radius: 4px;
  height: 2em;
  font-size: 0.75em;
  display: inline-flex;
  align-items: center;
  white-space: nowrap;
`,rv=T.span`
  display: flex;
  align-items: center;
`,ia=T.div`
  margin: 0em 0.5em 0.5em 0;
  border: solid 2px ${i=>i.theme.colors.accent2};
  border-radius: 5px;
  background-color: ${i=>i.theme.colors.background};
  font-size: 1em;
  filter: drop-shadow(0px 3px 4px ${i=>i.theme.colors.shadow});
  width: 220px;
  height: 2.6em;
  &:hover:not(:disabled):not(.static) {
    border-color: ${i=>i.theme.colors.accent3};
    cursor: pointer;
  }
  @media (max-width: 480px) {
    width: 100%;
    height: 4em;
    margin: 0em 0.5em 1em 0;
  }
`;ia.Content=T.div`
  display: flex;
  height: 100%;
  align-items: center;
  color: ${i=>i.theme.colors.text};
  img {
    border-radius: 3px 0px 0px 3px;
    margin-right: 0.5em;
    align-self: flex-start;
  }
`;ia.Icon=T.div`
  display: flex;
  flex-wrap: wrap;
  margin-right: 0.2em;
  width: fit-content;
  padding: 0em 0.4em 0em;
  @media (max-width: 480px) {
    font-size: 1.3em;
  }
`;const Bi=T.div`
  width: 480px;
  @media (max-width: 580px) {
    width: 100%;
  }
`;Bi.Title=T.div`
  border-bottom: 3px solid;
  padding-bottom: 5px;
  margin-bottom: 1em;
  display: flex;
  border-color: ${i=>i.theme.colors.accent3};
`;const no=["HQ-FC","TRAINEE","DPS","LOGI","ALT","VINDI","AMULET","WARPSPEED","HYBRID","ELITE","ELITE-GOLD"],Ni={TRAINEE:{type:"shield",color:"neutral",letter:"T",name:"Training FC"},TRAINER:{type:"shield",color:"purple",letter:"T",name:"FC Trainer"},LEADERSHIP:{type:"shield",color:"purple",letter:"DN",name:"leadership"},DPS:{type:"shield",color:"yellow",letter:"T",name:"DPS"},LOGI:{type:"shield",color:"red",letter:"L",name:"Logi Specialist"},ALT:{type:"shield",color:"green",letter:"A",name:"Alt approved"},VINDI:{type:"shield",color:"blue",letter:"!",name:"Vindication"},UNKNOWN:{type:"shield",color:"neutral",letter:"?",name:null}},An=({type:i="UNKNOWN",height:r="1.2em"})=>{const d=Ni[i]??Ni.UNKNOWN;return d.type==="shield"?l.jsx(Yu,{...d,h:r,title:d.name??""}):l.jsx("img",{src:d.href,title:d.name??"",alt:d.name??"",style:{height:r}})};function Yu({color:i,letter:r,title:d,h:u="1.2em"}){const o=w.useContext(Oa);return l.jsx(rv,{title:d,children:l.jsx("svg",{style:{height:u,filter:`drop-shadow(0px 1px 1px ${o.colors.shadow})`},viewBox:"0 0 26.5 27.8",xmlns:"http://www.w3.org/2000/svg",children:l.jsxs("g",{children:[l.jsx("path",{style:{fill:o.colors.tdfShields[i]},d:"m 13.229167,0 c 0,0 6.085417,0.79375 13.229167,3.96875 0,0 -0.79375,10.054167 -3.961217,15.955009 -2.275956,4.239997 -6.622116,7.857491 -9.26795,7.857491 M 13.229167,0 C 13.229167,0 7.14375,0.79375 0,3.96875 c 0,0 0.79375,10.054167 3.9612174,15.955009 2.2759552,4.239997 6.6221156,7.857491 9.2679496,7.857491"}),l.jsx("text",{style:{fontSize:"20px",fontWeight:"700",textAnchor:"middle",fill:o.colors.tdfShields.text,textRendering:"geometricPrecision"},x:"13.25",y:"20.5",children:r})]})})})}function ix({tags:i,height:r="40px"}){const u=ue.sortBy(i,o=>no.indexOf(o)).map(o=>o in Ni&&l.jsx("div",{style:{marginRight:"0.2em"},children:l.jsx(An,{type:o,height:r})},o));return l.jsx("div",{style:{display:"flex",marginBottom:"0.6em",flexWrap:"wrap"},children:u})}const uc=T.div`
  margin: 0 0 0.5em;
  display: flex;
  background-color: ${({theme:i,$variant:r})=>{var d;return(d=i.colors[r])==null?void 0:d.color}};
  color: ${({theme:i,$variant:r})=>{var d;return((d=i.colors[r])==null?void 0:d.text)??i.colors.text}};
  border-radius: 5px;
  width: ${({width:i})=>i??"fit-content"};
  filter: drop-shadow(0px 4px 5px ${({theme:i})=>i.colors.shadow});
  padding: 0.1em 0.5em 0.2em;
  vertical-align: middle;
  word-break: break-word;
`,ic=T.div`
  background-color: ${({theme:i})=>i.colors.accent1};
  border-radius: 20px;
  border: solid 1px ${({theme:i})=>i.colors.accent2};
  padding: 0.4em;
  font-size: min(calc(9px + 0.4vw), 14px);
`;function uv({variant:i="secondary",width:r="fit-content",children:d}){return l.jsxs(uc,{$variant:i,width:r,children:[l.jsx("div",{style:{marginRight:"0.5em"},children:l.jsx(ie,{icon:qm})}),d]})}const sx=["high","medium","low","rig","other","drone","cargo"],sc={};let cc=null;T.div`
  display: flex;
  @media (max-width: 480px) {
    flex-wrap: wrap;
  }
`;const Aa=T.div`
  display: flex;
  align-items: center;
  font-size: 1.2em;
  font-weight: 600;
  margin-bottom: 0.5em;

  @media (max-width: 480px) {
    font-size: 1em;
  }
`;Aa.Image=T.img`
  height: 2em;
  width: 2em;
  margin-right: 2em;

  @media (max-width: 480px) {
    margin-right: 0.5em;
  }
`;Aa.Name=T.span`
  @media (max-width: 480px) {
    overflow-wrap: anywhere;
  }
`;Aa.Copy=T.div`
  margin-left: auto;
  margin-right: 2em;
  cursor: pointer;
  font-size: 0.8em;
`;T.div`
  margin: 1em 0;
`;const ov=T.div`
  margin-bottom: 1em;
`,De=T.div`
  display: flex;

  ${({group:i,theme:r})=>({have:"",missing:`
        background-color: ${r.colors.danger.color};
        color: ${r.colors.danger.text};
        text-decoration: line-through;
      `,extra:`
        background-color: ${r.colors.success.color};
        color: ${r.colors.success.text};
      `,downgraded_orig:`
        background-color: ${r.colors.warning.color};
        color: ${r.colors.warning.text};
        text-decoration: line-through;
      `,downgraded_new:`
        background-color: ${r.colors.warning.color};
        color: ${r.colors.warning.text};
      `,upgraded_orig:`
        background-color: ${r.colors.success.color};
        color: ${r.colors.success.text};
        text-decoration: line-through;
      `,upgraded_new:`
        background-color: ${r.colors.success.color};
        color: ${r.colors.success.text};
      `})[i||"have"]}

  > * {
    margin-right: 0.5em;
  }
`;De.Image=T.img`
  height: 1.5em;
  width: 1.5em;
`;De.Count=T.span`
  min-width: 1em;

  @media (max-width: 480px) {
    font-size: 0.7em;
  }
`;De.ModuleName=T.span`
  @media (max-width: 480px) {
    font-size: 0.8em;
  }
`;async function dv(i){const r=i.split(",");cc||(cc=He("/incursions/api/module/preload","get").then(o=>o).catch(()=>(cc=null,{})));const d=await cc;Object.entries(d).forEach(([o,f])=>{sc[o]=f});const u=r.filter(o=>!(o in sc)&&/^\d+_?$/.test(o)).map(o=>parseInt(o.replace(/_+$/,"")));if(u.length>0){const f=await He("/incursions/api/module/info","post",{body:{ids:u}});Object.entries(f).forEach(([m,g])=>{sc[m]=g})}return Object.fromEntries(r.map(o=>[o,sc[o]??null]))}function fv(i){const[r,d]=w.useState({}),u=i.sort().join(",");return w.useEffect(()=>{let o=!1;return dv(u).then(f=>{o||d(f)}),()=>{o=!0}},[u]),r}function hv(i){const[r,...d]=i.split(":"),u=new Set,o={};return u.add(r),d.forEach(f=>{if(!f)return;const[m,g]=f.split(";");u.add(m),o[m]=(o[m]||0)+parseInt(g)}),[r,Array.from(u),o]}function mv(i){if(!i)return[];const r=new Set;return["missing","extra","cargo_missing"].forEach(d=>Object.keys(i[d]||{}).forEach(u=>r.add(u))),["downgraded","upgraded"].forEach(d=>Object.entries(i[d]||{}).forEach(([u,o])=>{r.add(u),Object.keys(o).forEach(f=>r.add(f))})),Array.from(r)}function Ti(i,r){var d;return i.endsWith("_")?"cargo":((d=r[i])==null?void 0:d.slot)??"cargo"}function xv(i,r,d){const u=Object.fromEntries(sx.map(o=>[o,{have:{},match:{},missing:{},extra:{},downgraded:{},upgraded:{}}]));if(Object.entries(i).forEach(([o,f])=>{const m=Ti(o,d);u[m].have[o]=f,u[m].match[o]=f}),r){for(const[o,f]of Object.entries((r==null?void 0:r.missing)||{}))u[Ti(o,d)].missing[o]=f;for(const[o,f]of Object.entries((r==null?void 0:r.extra)||{})){const m=Ti(o,d);m!=="drone"&&(u[m].match[o]=(u[m].match[o]||0)-f),u[m].extra[o]=f}for(const[o,f]of Object.entries((r==null?void 0:r.downgraded)||{})){const m=Ti(o,d);for(const[g,p]of Object.entries(f))u[m].match[g]=(u[m].match[g]||0)-p,u[m].downgraded[o]||(u[m].downgraded[o]={}),u[m].downgraded[o][g]=p}for(const[o,f]of Object.entries((r==null?void 0:r.upgraded)||{})){const m=Ti(o,d);for(const[g,p]of Object.entries(f))u[m].match[g]=(u[m].match[g]||0)-p,u[m].upgraded[o]||(u[m].upgraded[o]={}),u[m].upgraded[o][g]=p}}return u}const gv=({isDiff:i,groups:r,moduleInfo:d})=>{const u=i?["match","missing","extra"]:["have"];function o(f){return f.replace(/_+$/,"")}return l.jsxs(ov,{children:[u.map(f=>Object.entries(r[f]||{}).filter(([m,g])=>{if(f!=="match"||g!==0)return!0;const p=Object.values(r.downgraded).some(j=>m in j),y=Object.values(r.upgraded||{}).some(j=>m in j);return!(p||y)}).map(([m,g])=>{const p=o(m),y=d[p];return l.jsxs(De,{group:f,children:[l.jsx(De.Image,{src:`https://images.evetech.net/types/${p}/icon?size=64`,alt:(y==null?void 0:y.name)||m}),l.jsx(De.Count,{children:g}),l.jsx(De.ModuleName,{children:(y==null?void 0:y.name)||m})]},`${f}-${m}`)})),i&&Object.entries(r.downgraded).flatMap(([f,m])=>Object.entries(m).map(([g,p])=>{var y,j,E,O;return l.jsxs(K.Fragment,{children:[l.jsxs(De,{group:"downgraded_orig",children:[l.jsx(De.Image,{src:`https://images.evetech.net/types/${f.replace(/_+$/,"")}/icon?size=64`,alt:((y=d[f])==null?void 0:y.name)||f}),l.jsx(De.Count,{children:p}),l.jsx(De.ModuleName,{children:((j=d[f])==null?void 0:j.name)||f})]}),l.jsxs(De,{group:"downgraded_new",children:[l.jsx(De.Image,{src:`https://images.evetech.net/types/${g.replace(/_+$/,"")}/icon?size=64`,alt:((E=d[g])==null?void 0:E.name)||g}),l.jsx(De.Count,{children:p}),l.jsx(De.ModuleName,{children:((O=d[g])==null?void 0:O.name)||g})]})]},`${f}-${g}`)})),i&&Object.entries(r.upgraded||{}).flatMap(([f,m])=>Object.entries(m).map(([g,p])=>{var y,j,E,O;return l.jsxs(K.Fragment,{children:[l.jsxs(De,{group:"downgraded_orig",children:[l.jsx(De.Image,{src:`https://images.evetech.net/types/${f.replace(/_+$/,"")}/icon?size=64`,alt:((y=d[f])==null?void 0:y.name)||f}),l.jsx(De.Count,{children:p}),l.jsx(De.ModuleName,{children:((j=d[f])==null?void 0:j.name)||f})]}),l.jsxs(De,{group:"downgraded_new",children:[l.jsx(De.Image,{src:`https://images.evetech.net/types/${g.replace(/_+$/,"")}/icon?size=64`,alt:((E=d[g])==null?void 0:E.name)||g}),l.jsx(De.Count,{children:p}),l.jsx(De.ModuleName,{children:((O=d[g])==null?void 0:O.name)||g})]})]},`upgrade-${f}-${g}`)}))]})},ao=({dna:i,analysis:r=null,name:d})=>{const{t:u}=k(),o=w.useContext(oe),[f,m,g]=w.useMemo(()=>hv(i),[i]),p=fv([...m,...mv(r)]),y=w.useMemo(()=>xv(g,r,p),[g,r,p]);if(!p[f])return l.jsx("em",{children:u("Loading fit info")});const j=()=>{const E=`[${p[f].name}, ${p[f].name}]

`+sx.map(O=>Object.entries(y[O].have).map(([M,L])=>{var q,U;return O==="cargo"||O==="drone"?`${((q=p[M])==null?void 0:q.name)??M} x${L}`:Array(L).fill(((U=p[M])==null?void 0:U.name)??M).join(`
`)}).join(`
`)).filter(Boolean).join(`

`);Cn(o,navigator.clipboard.writeText(E).then(()=>u("Copied to clipboard")))};return l.jsxs("div",{children:[l.jsxs(Aa,{children:[l.jsx(Aa.Image,{src:`https://images.evetech.net/types/${f}/icon?size=64`,alt:p[f].name}),l.jsx(Aa.Name,{children:d||(r==null?void 0:r.name)}),l.jsx(Aa.Copy,{onClick:j,title:u("Copy to clipboard"),children:l.jsx(ie,{icon:$m})})]}),r&&!r.name&&l.jsx("div",{children:l.jsx(Yt,{$variant:"danger",children:u("Fit could not be automatically checked!")})}),Object.entries(y).map(([E,O])=>l.jsx("div",{children:l.jsx(gv,{isDiff:!!r,groups:O,moduleInfo:p})},E))]})},cx=({implants:i,character_name:r,...d})=>{const u=`670:${i.map(o=>`${o};1`).join(":")}::`;return l.jsx(ao,{dna:u,name:r,...d})},lo=({fit:i})=>{var r;return l.jsxs("div",{style:{display:"flex",flexWrap:"wrap"},children:[l.jsx(ao,{dna:i.dna,analysis:i.fit_analysis||{}}),i.implants&&l.jsx(cx,{implants:i.implants,character_name:((r=i.character)==null?void 0:r.character_name)??"Implants"})]})},pv=["xs","sm","md","lg","xl","offset"],Sl=T(({xs:i,sm:r,md:d,lg:u,xl:o,offset:f,children:m,...g})=>l.jsx(Jp,{xs:i,sm:r,md:d,lg:u,xl:o,offset:f,...g,children:m})).withConfig({shouldForwardProp:(i,r)=>!pv.includes(i)&&r(i)})``,Di={Table:T.div`
    margin-bottom: 2em;
  `};Di.Table.Name=T.h3`
  border-bottom: solid 2px ${({theme:i})=>i.colors.accent2};
  font-weight: bolder;
  padding: 0.75em;
`;Di.Table.Row=T.div`
  display: flex;
  padding: 0.5em 0.75em;
  border-bottom: solid 1px ${({theme:i})=>i.colors.accent2};

  &:last-child {
    border-bottom: none;
  }
  &:nth-child(odd) {
    background-color: ${({theme:i})=>i.colors.accent1};
  }
  > :last-child {
    margin-left: auto;
  }
`;const yv=T.div`
  height: 36px;
`,rx=["Armor","Shields","Gunnery","Missiles","Neural Enhancement","Spaceship Command","Drones","Rigging"],vv=new Set(rx),jv=({current:i,skill:r})=>{if(i===5)return l.jsx(Yt,{$variant:"success",children:i});let d=null;for(const[u,o]of[["gold","success"],["elite","primary"],["min","secondary"]])if(u in r){if(i>=r[u])return l.jsxs(Yt,{$variant:o,children:[i,d]});d=` / ${r[u]}`}for(const[u,o]of[["min","danger"],["elite","warning"],["gold","secondary"]])if(u in r)return l.jsxs(Yt,{$variant:o,children:[i,d]});return null};function bv({title:i,current:r,requirements:d,ids:u,category:o,filterMin:f}){const m=o.flatMap(g=>{if(!(g in d))return[];const p=d[g],y=r[g]??0;return f&&(!p.min||p.min<=y)?[]:l.jsxs(Di.Table.Row,{children:[u[g]," ",l.jsx(jv,{current:y,skill:p})]},g)});return m.length?l.jsx(Sl,{xs:4,sm:4,md:2,children:l.jsxs(Di.Table,{children:[l.jsx(Di.Table.Name,{children:i}),m]})}):null}function Sv({mySkills:i,shipName:r,filterMin:d}){const{t:u}=k();if(!i||!i.requirements||!i.categories||!i.ids)return l.jsx("em",{children:u("Loading skill information")});const o=ue.invert(i.ids);if(!(r in i.requirements))return l.jsx("em",{children:u("No skill information found")});const f=[...rx];return ue.forEach(ue.keys(i.categories),m=>{vv.has(m)||f.push(m)}),l.jsx(hc,{children:f.map(m=>l.jsx(bv,{title:u(m),current:i.current,requirements:i.requirements[r],category:i.categories[m],ids:o,filterMin:d},m))})}function io({characterId:i,ship:r,setShip:d=null,filterMin:u=!1}){const{t:o}=k(),[f]=Le(`/incursions/api/skills/${i}`);return l.jsxs(l.Fragment,{children:[d&&l.jsxs(Mt,{style:{marginBottom:"1em"},children:[l.jsx(Te,{children:["Vindicator","Kronos","Paladin"].map(m=>l.jsx(Y,{$active:r===m,onClick:()=>d(m),children:o(m)},m))}),l.jsx(Te,{children:["Guardian","Nestor"].map(m=>l.jsx(Y,{$active:r===m,onClick:()=>d(m),children:o(m)},m))}),l.jsx(Te,{children:["Eos","Damnation"].map(m=>l.jsx(Y,{$active:r===m,onClick:()=>d(m),children:o(m)},m))})]}),l.jsxs("div",{style:{marginBottom:"1em"},children:[o("Legend"),":",l.jsx(Yt,{$variant:"danger",children:o("Does Not Meet Requirements")}),l.jsx(Yt,{$variant:"secondary",children:o("Minimum")}),l.jsx(Yt,{$variant:"primary",children:o("Suggested")}),l.jsx(Yt,{$variant:"success",children:o("#Swag")})]}),l.jsx(yv,{children:(r==="Nestor"||r==="Guardian"||r==="Oneiros")&&l.jsx(uv,{children:o("Basic tier skills are required for logistics.")})}),f?l.jsx(Sv,{mySkills:f,shipName:r,filterMin:u}):l.jsx("p",{children:o("Loading skill information")})]})}const wv=({relativeTo:i,isAlt:r})=>{const[d,u]=w.useState(Date.now());w.useEffect(()=>{const m=setInterval(()=>{u(Date.now())},6e4);return()=>clearInterval(m)},[]);const o=new Date(i).getTime(),f=Math.round((d-o)/1e3/60);return r?l.jsx("span",{title:`${f} min`,children:l.jsx(Yt,{variant:"danger",children:"ALT"})}):l.jsxs(Yt,{variant:"secondary",children:[f," min"]})},ux=i=>Qe("/incursions/api/waitlist/approve",{json:{id:i}}),ox=(i,r)=>Qe("/incursions/api/waitlist/reject",{json:{id:i,review_comment:r}}),_v=i=>Qe("/incursions/api/waitlist/remove_fit",{json:{id:i}}),Tv=(i,r)=>Qe("/incursions/api/open_window",{json:{target_id:i,character_id:r}}),Xe=T.div`
  border: solid 2px ${i=>i.theme.colors[i.$variant].color};
  background-color: ${i=>i.theme.colors[i.$variant].color};
  color: ${i=>i.theme.colors[i.$variant].text};
  border-radius: 5px;
  font-size: 0.9em;
  filter: drop-shadow(0px 4px 5px ${i=>i.theme.colors.shadow});
  min-width: 245px;

  a {
    color: inherit;
    text-decoration: none;
  }
`;Xe.Head=T.div`
  display: flex;
  padding: 0.2em 0.2em 0.3em 0.5em;
  align-items: center;

  a {
    font-weight: 600;
  }
`;Xe.Head.Badges=T.div`
  margin-left: auto;
  display: flex;
  flex-shrink: 0;
  align-items: center;

  > * {
    margin-left: 0.25em;
  }

  > *:last-child {
    margin-left: 0.5em;
  }

  > span {
    display: flex;
    align-items: center;
  }

  img {
    height: 1.3em;
  }
`;Xe.Content=T.div`
  display: flex;
  background-color: ${i=>i.theme.colors.background};
  align-items: center;
  color: ${i=>i.theme.colors.text};

  img {
    margin-right: 0.5em;
    align-self: flex-start;
  }

  a {
    align-items: center;
    display: flex;
    cursor: pointer;
    width: 100%;
  }
`;Xe.FooterGroup=T.div`
  > *:last-child {
    border-radius: 0 0 4px 4px;
  }
`;Xe.Footer=T.div`
  display: flex;
  background-color: ${i=>i.theme.colors.accent1};
  color: ${i=>i.theme.colors.text};
  text-align: center;

  a:hover {
    background-color: ${i=>i.theme.colors.accent2};
    cursor: pointer;
  }

  > * {
    flex-grow: 1;
    flex-basis: 0;
  }
`;Xe.ReviewComment=T.div`
  padding: 0.5em;
  margin: 0.5em;
  width: 100%;
  text-align: center;
  background-color: ${i=>i.theme.colors.secondary.color};
  border-radius: 5px;
  color: ${i=>i.theme.colors.secondary.text};
  word-break: break-word;
`;Xe.ReviewComment.Header=T.div`
  border-bottom: 1px solid;
  margin-bottom: 1em;
  font-weight: bold;
`;function Cv({fit:i,onAction:r}){const d=K.useContext(ze),u=K.useContext(oe),[o,f]=K.useState(!1);return i.dna&&i.ship?l.jsxs(l.Fragment,{children:[o?l.jsx(qe,{open:!0,setOpen:f,children:l.jsxs(Ce,{children:[(d.access["incursions.waitlist_manage_waitlist"]||d.access["incursions.waitlist_manage_waitlist_approve_fits"])&&l.jsxs(Mt,{style:{marginBlock:"1em",marginTop:"0px"},children:[l.jsx(Y,{$variant:"success",style:{minWidth:"95px"},onClick:()=>{f(!1),re(u,ux(i.id)).then(r)},children:"Approve"}),l.jsx(Y,{$variant:"danger",style:{minWidth:"95px"},onClick:()=>{var m=prompt("Why is the fit being rejected? (Will be displayed to pilot)");m&&(f(!1),re(u,ox(i.id,m)).then(r))},children:"Reject"})]}),l.jsx(lo,{fit:i}),i.tags.includes("STARTER")?l.jsxs(l.Fragment,{children:[l.jsx(Me,{children:"Starter skills"}),l.jsx(io,{characterId:i.character.character_id,ship:i.ship.name,filterMin:!0})]}):null]})}):null,l.jsxs("a",{onClick:()=>f(!0),children:[l.jsx("img",{style:{height:"44px"},src:`https://images.evetech.net/types/${i.ship.id}/icon?size=64`,alt:i.ship.name}),l.jsx("span",{style:{flexShrink:1},children:i.ship.name})]})]}):i.ship?l.jsxs(l.Fragment,{children:[l.jsx("img",{style:{height:"44px"},src:`https://images.evetech.net/types/${i.ship.id}/icon?size=64`,alt:i.ship.name}),l.jsx("span",{children:i.ship.name})]}):l.jsxs(l.Fragment,{children:[l.jsx("img",{style:{height:"44px"},src:"https://images.evetech.net/types/670/icon?size=64",alt:""})," ",l.jsx("span",{children:"Ship"})]})}function Av({characterId:i,ship:r}){const{t:d}=k(),[u,o]=w.useState(!1),[f,m]=w.useState(r);return l.jsxs(l.Fragment,{children:[l.jsx("a",{title:d("View Skills"),onClick:()=>o(!0),children:l.jsx(ie,{icon:E0})}),u&&l.jsx(qe,{open:!0,setOpen:o,children:l.jsx(Ce,{children:l.jsx(K.Suspense,{fallback:l.jsx("p",{children:d("Loading skill information")}),children:l.jsx(io,{characterId:i,ship:f,setShip:m})})})})]})}function Xu({number:i}){const r=w.useContext(Oa);return l.jsx("span",{style:{verticalAlign:"middle"},children:l.jsx("svg",{style:{height:"1em"},viewBox:"0 0 50 50",xmlns:"http://www.w3.org/2000/svg",children:l.jsxs("g",{children:[l.jsx("circle",{style:{verticalAlign:"middle",fill:r.colors.text},cy:"25",cx:"25",r:"24"}),l.jsx("text",{style:{fontSize:"2.6em",fontWeight:"600",textAnchor:"middle",fill:r.colors.accent1,textRendering:"geometricPrecision"},x:"25",y:"38",children:i})]})})})}function Ev({fitId:i,onAction:r}){var E,O,M,L;const d=w.useContext(Oa),u=w.useContext(oe),[o,f]=w.useState(),[m,g]=w.useReducer(q=>q+1,0),{t:p}=k(),y={success:(O=(E=d==null?void 0:d.colors)==null?void 0:E.success)==null?void 0:O.color,failed:(L=(M=d==null?void 0:d.colors)==null?void 0:M.danger)==null?void 0:L.color},j=async()=>{f("pending"),g(),re(u,Qe("/incursions/api/waitlist/invite",{json:{fit:i}}).then(()=>{f("success"),r()}).catch(q=>{throw f("failed"),q}))};return l.jsx("a",{title:p("Invite to Fleet"),onClick:j,style:{cursor:o==="pending"?"not-allowed":void 0,backgroundColor:y[o??""]??void 0,transition:"background-color 300ms linear"},children:m<2?l.jsx(ie,{fixedWidth:!0,icon:o!=="pending"?Ym:D0,spin:o==="pending"}):l.jsx(Xu,{number:m})})}function _m({from:i,message:r}){return l.jsxs(l.Fragment,{children:[l.jsx(Xe.ReviewComment.Header,{children:i}),l.jsx("div",{children:r})]})}function Dv({characterId:i,id:r}){const{t:d}=k(),[u]=Le(`/incursions/api/notes?character_id=${i}`);return!u||!u.notes?l.jsx(jt,{to:`/pilot?character_id=${r}`,children:l.jsx(Xu,{number:0})}):l.jsx(jt,{to:`/pilot?character_id=${r}`,children:l.jsx(Xu,{number:u.notes.length})})}function ki({entry:i,fit:r,onAction:d}){var L,q;const{t:u}=k(),o=w.useContext(ze),f=w.useContext(oe),m=r.is_alt,g=i.character?i.character.character_name:u("Hidden"),p=((L=i.character)==null?void 0:L.character_id)===o.current.character_id,y=ue.sortBy(r.tags,U=>no.indexOf(U)),j=[],E=y.map(U=>U in Ni?l.jsx(An,{type:U},U):(j.push(U),null)),O=r.approved?null:l.jsx("span",{title:u("Pending Approval"),children:l.jsx(ie,{icon:C0})}),M=r.approved?p?"success":"secondary":r.review_comment?"danger":p||o.access["incursions.waitlist_manage_waitlist"]||o.access["incursions.waitlist_manage_waitlist_approve_fits"]?"warning":"secondary";return l.jsxs(Xe,{$variant:M,children:[l.jsxs(Xe.Head,{children:[l.jsx("span",{children:g}),l.jsxs(Xe.Head.Badges,{children:[E,O,l.jsx(wv,{relativeTo:i.joined_at,isAlt:m})]})]}),l.jsx(Xe.Content,{children:l.jsx(Cv,{fit:r,onAction:d})}),l.jsx(Xe.Content,{children:l.jsx("div",{style:{flexWrap:"wrap"},children:j.map(U=>l.jsx(Yt,{children:U},U))})}),r.review_comment&&l.jsx(Xe.Content,{children:l.jsx(Xe.ReviewComment,{children:l.jsx(_m,{from:u("FC"),message:r.review_comment})})}),r.messagexup&&l.jsx(Xe.Content,{children:l.jsx(Xe.ReviewComment,{children:l.jsx(_m,{from:u("Pilot"),message:r.messagexup})})}),l.jsxs(Xe.FooterGroup,{children:[l.jsxs(Xe.Footer,{children:[i.can_remove&&l.jsx("a",{title:u("Remove from Waitlist"),onClick:()=>re(f,_v(r.id)).then(d),children:l.jsx(ie,{icon:A0})}),o.access["incursions.waitlist_esi_show_info"]&&l.jsx("a",{title:u("Show Info In-Game"),onClick:()=>re(f,Tv(r.character.character_id,o.current.character_id)),children:l.jsx(ie,{icon:Ri})}),o.access["incursions.waitlist_skills_view"]&&l.jsx(Av,{characterId:r.character.character_id,ship:((q=r.ship)==null?void 0:q.name)??""}),(o.access["incursions.waitlist_pilot_view"]||o.access["incursions.waitlist_notes_view"]||o.access["incursions.waitlist_notes_manage"])&&l.jsx(Dv,{characterId:r.character.character_id,authContext:o,id:r.character.character_id}),ue.isFinite(r.hours_in_fleet)&&l.jsxs("span",{title:u("Hours in Fleet"),children:[r.hours_in_fleet,"h"]}),(o.access["incursions.waitlist_manage_waitlist"]||o.access["incursions.waitlist_manage_waitlist_approve_fits"])&&l.jsxs(l.Fragment,{children:[!r.approved&&l.jsx("a",{title:u("Reject Fit"),onClick:()=>{const U=prompt(u("Rejection Reason"));U&&re(f,ox(r.id,U)).then(d)},children:l.jsx(ie,{icon:Zu})}),r.approved?l.jsx(Ev,{fitId:r.id,onAction:d}):l.jsx("a",{title:u("Approve Fit"),onClick:()=>re(f,ux(r.id)).then(d),children:l.jsx(ie,{icon:Gm})})]})]}),!m&&ue.isFinite(r.hours_in_fleet)&&r.hours_in_fleet<1&&l.jsx(Xe.Footer,{children:l.jsx("span",{children:u("NEW")})})]})]})}const oc=T.div`
  background-color: ${i=>i.theme.colors.accent1};
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  justify-content: space-between;
  padding: 0 1em;
  border-radius: 10px;
  box-shadow: 2px 2px 3px ${i=>i.theme.colors.shadow};
  > h2 {
    font-size: 1.2em;
    font-weight: 600;
    padding: 0.2em;
  }
  > div {
    display: flex;
    opacity: 0.7;
    > span {
      flex: 1;
      display: inline-flex;
      align-items: center;
      padding: 0.2em;
      img {
        width: 1.5em;
        height: 1.5em;
        border-radius: 2px;
        margin-right: 0.2em;
      }
    }
  }
`,Ov=T(oc)`
  border-radius: 5px;
  border: solid 1px ${i=>i.theme.colors.accent2};
  padding: 0 0.2em;
  > h2 {
    font-size: initial;
    font-weight: initial;
  }
`;function Mv({name:i,shipCountsArr:r}){return l.jsxs(l.Fragment,{children:[l.jsx("h2",{children:i}),l.jsx("div",{children:r.map(([d,u])=>l.jsxs("span",{children:[l.jsx("img",{src:`https://images.evetech.net/types/${u.id}/icon?size=64`,alt:u.name}),d]},u.id))})]})}function so({name:i,fleetComposition:r,altCol:d=!0}){if(!(r!=null&&r.members))return!d&&i==="Alts"?null:l.jsx(oc,{children:l.jsx("h2",{children:i})});const u=r.members.filter(p=>p.wl_category===i);if(!d&&i==="Alts"&&u.length===0)return null;const o={},f={};for(const p of u)o[p.ship.id]=p.ship,f[p.ship.id]=(f[p.ship.id]||0)+1;const m=Object.entries(f).map(([p,y])=>[y,o[parseInt(p)]]).sort((p,y)=>y[0]-p[0]),g=!d&&i==="Alts"?Ov:oc;return l.jsx(g,{children:l.jsx(Mv,{name:i,shipCountsArr:m})})}const dc=T.div`
  display: flex;
  @media (max-width: 480px) {
    flex-wrap: wrap;
    width: 100%;
  }
`;dc.Category=T.div`
  flex-grow: 1;
  flex-basis: 0;
  padding: 0.5em;
  > div {
    margin-bottom: 1.5em;
  }
  @media (max-width: 480px) {
    width: 100%;
    flex-basis: unset;
  }
`;function zv({waitlist:i,onAction:r,fleetComposition:d,altCol:u=!1}){const o=[],f={};return i.categories.forEach(m=>{m==="Alts"&&!u||(f[m]=o.length,o.push([m,[]]))}),i.waitlist.forEach(m=>{m.fits.forEach(g=>{const p=u&&g.is_alt?"Alts":g.category,y=f[p];y!==void 0&&o[y][1].push(l.jsx("div",{children:l.jsx(ki,{entry:m,fit:g,onAction:r})},g.id))})}),l.jsx(dc,{children:o.map(([m,g])=>l.jsxs(dc.Category,{children:[l.jsx(so,{name:m,fleetComposition:d,altCol:u}),g]},m))})}const Bv=T.div`
  display: flex;
  flex-wrap: wrap;
  > div {
    padding: 0.5em;
  }
`;function Nv({waitlist:i,onAction:r}){return l.jsx(Bv,{children:i.waitlist.map(d=>d.fits.map(u=>l.jsx("div",{children:l.jsx(ki,{entry:d,fit:u,onAction:r})},u.id)))})}const Qu=T.div``;Qu.Entry=T.div`
  display: flex;
  flex-wrap: wrap;
  margin-bottom: 1em;
  > div {
    padding: 0.5em;
  }
`;function Rv({waitlist:i,onAction:r}){return l.jsx(Qu,{children:i.waitlist.map(d=>l.jsx(Qu.Entry,{children:d.fits.map(u=>l.jsx("div",{children:l.jsx(ki,{entry:d,fit:u,onAction:r})},u.id))},d.id))})}const Uv=T.table`
  width: 100%;
  table-layout: fixed;
  text-align: left;
  > thead > tr > th {
    width: 1%;
  }
  th,
  td {
    padding: 0.5em;
  }
`;function kv({waitlist:i,onAction:r,fleetComposition:d}){const u=[],o={};return i.categories.forEach(f=>{o[f]=u.length,u.push([f,[]])}),l.jsx(Uv,{children:l.jsxs("thead",{children:[l.jsx("tr",{children:u.map(([f])=>l.jsx("th",{children:l.jsx(so,{name:f,fleetComposition:d})},f))}),i.waitlist.map(f=>{const m=u.map(()=>[]);return f.fits.forEach(g=>{const p=g.is_alt?"Alts":g.category,y=o[p];y!==void 0&&m[y].push(l.jsx("div",{children:l.jsx(ki,{entry:f,fit:g,onAction:r})},g.id))}),l.jsx("tr",{children:m.map((g,p)=>l.jsx("td",{children:g},p))},f.id)})]})})}const Vu=T.div`
  overflow-x: auto;
`;Vu.Category=T.div`
  padding: 0.5em 0.5em;
  display: flex;
  > div {
    margin: 0 0.75em;
  }
`;function Lv({waitlist:i,onAction:r,fleetComposition:d}){const u=[],o={};return i.categories.forEach(f=>{o[f]=u.length,u.push([f,[]])}),i.waitlist.forEach(f=>{f.fits.forEach(m=>{const g=m.is_alt?"Alts":m.category,p=o[g];p!==void 0&&u[p][1].push(l.jsx("div",{children:l.jsx(ki,{entry:f,fit:m,onAction:r})},m.id))})}),l.jsx(Vu,{children:u.map(([f,m])=>l.jsxs("div",{children:[l.jsx(so,{name:f,fleetComposition:d}),l.jsx(Vu.Category,{children:m})]},f))})}const Hv=["Paladin","Kronos","Golem","Vargur"],dx=["Eos","Damnation","Claymore","Vulture","Sleipnir","Astarte"];function qv({characterId:i}){const[r]=Ju(`/incursions/api/pilot/info?character_id=${i}`);return l.jsx(ix,{tags:r==null?void 0:r.tags,height:"14px"})}function $v({members:i,warnActive:r}){const{t:d}=k(),u=i.map(o=>o.ship.name).filter(o=>!dx.includes(o));return l.jsx(l.Fragment,{children:i.map(o=>l.jsxs(Oe,{noAlternating:!0,children:[l.jsx(Tn,{}),l.jsx(ty,{warn:u.length>2&&r?"yellow":void 0,children:o.role==="squad_commander"&&"★"}),l.jsx(Tn,{children:l.jsx(jt,{exact:!0,to:`/pilot?character_id=${o.character_id}`,children:o.character_name})}),l.jsx(Tn,{children:d(o.ship.name)}),l.jsx(Tn,{children:l.jsx("div",{style:{display:"flex",justifyContent:"space-between"},children:l.jsx(qv,{characterId:o.character_id})})})]},o.character_id))})}function Gv({members:i,squadname:r,warnActive:d}){const{t:u}=k();return i.sort((o,f)=>o.role==="squad_commander"?-1:f.role==="squad_commander"?1:0),l.jsxs(l.Fragment,{children:[l.jsxs(Oe,{noAlternating:!0,children:[l.jsx(Tn,{}),l.jsxs(Tn,{children:[u(r),i.length>0&&` (${i.length})`]}),l.jsx(Tn,{}),l.jsx(Tn,{}),l.jsx(Tn,{})]},r),l.jsx($v,{members:i,warnActive:d})]})}function Tm({characterId:i,memberlist:r,showFull:d=!0}){const{t:u}=k(),o={Marauder:0,LogiNestor:0,LogiLoki:0,LogiGuardian:0,LogiBasilisk:0,Vindicator:0,Booster:0},f={};return r==null||r.forEach(m=>{f[m.ship.name]=(f[m.ship.name]||0)+1,dx.includes(m.ship.name)&&o.Booster++,Hv.includes(m.ship.name)&&o.Marauder++,m.ship.name==="Vindicator"&&o.Vindicator++,m.ship.name==="Nestor"&&o.LogiNestor++,m.ship.name==="Loki"&&o.LogiLoki++,m.ship.name==="Guardian"&&o.LogiGuardian++,m.ship.name==="Basilisk"&&o.LogiBasilisk++}),l.jsxs("div",{style:d?{}:{display:"flex",justifyContent:"center"},children:[d&&l.jsx(Me,{children:u("Fleet Summary")}),l.jsxs(Te,{style:{marginBottom:"1em"},children:[l.jsxs(ic,{children:[u("Marauders"),":",l.jsx("br",{}),o.Marauder]}),l.jsxs(ic,{children:[u("Logi N/L + G/B"),":",l.jsx("br",{}),o.LogiNestor,"/",o.LogiLoki," + ",o.LogiGuardian,"/",o.LogiBasilisk]}),l.jsxs(ic,{children:[u("Vindicators"),":",l.jsx("br",{}),o.Vindicator]}),l.jsxs(ic,{children:[u("Boosters"),":",l.jsx("br",{}),o.Booster]})]}),d&&l.jsxs(Dn,{children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(Fe,{children:u("Ship")}),l.jsx(Fe,{children:"#"})]})}),l.jsx(On,{children:ue.sortBy(ue.entries(f),[1]).map(([m,g])=>l.jsxs(Oe,{children:[l.jsx(I,{children:u(m)}),l.jsx(I,{children:g})]},m))})]})]})}function Yv(i,r,d,u){const o=K.useContext(_l),{t:f}=k(),m=K.useContext(oe);K.useEffect(()=>{if(!o)return;const g=()=>{He("/incursions/api/fleet/fleetcomp","get",{params:{character_id:i}}).then(r).catch(y=>{d(j=>j+1),u&&typeof y=="string"&&y.toLowerCase().includes("fleet")&&(u(!1),ln(m,{title:f("Error"),message:f("Failed to update fleet data. Fleet stats disabled."),variant:"danger"}))})},p=y=>{const j=JSON.parse(y.data);(j==null?void 0:j.event)==="fleet_comp"&&g()};return o.addEventListener("fleet_comp",p),o.addEventListener("open",g),()=>{o.removeEventListener("fleet_comp",p),o.removeEventListener("open",g)}},[i,o,m,f,r,d,u])}function Xv(i){let r=i.boss?1:0;for(const d of i.squads)r+=d.members.length;return r}function fx({fleetpage:i=!0,setStatTempActive:r=null}){const{t:d}=k(),o=K.useContext(ze).current.character_id,[f,m]=K.useState(null),[g,p]=K.useState(0);return Yv(o,m,p,i?null:r),f?(f.wings.forEach(y=>{y.squads.sort((j,E)=>j.id-E.id)}),l.jsxs(dc.Category,{children:[!i&&l.jsx(oc,{children:l.jsx("h2",{children:d("Members")})}),l.jsxs("div",{style:{display:"flex",flexWrap:"wrap"},children:[l.jsxs("div",{children:[i&&l.jsx(Me,{children:d("Members")}),!i&&l.jsx(Tm,{characterId:o,showFull:!1,memberlist:f.members}),l.jsx(Dn,{style:{fontSize:"12px"},fullWidth:!i,children:l.jsx(On,{children:f.wings.map((y,j)=>l.jsxs(K.Fragment,{children:[l.jsxs(Oe,{background:!0,noAlternating:!0,children:[l.jsxs(I,{style:{fontWeight:"bold",width:"40px",whiteSpace:"nowrap"},children:[d(y.name.toUpperCase())," (",Xv(y),")"]}),l.jsx(I,{style:{width:"80px"}}),l.jsx(I,{}),l.jsx(I,{style:{width:"70px"}}),l.jsx(I,{style:{width:"75px"}})]}),y.squads.map((E,O)=>l.jsx(Gv,{squadname:E.name,members:E.members,warnActive:O>2&&j===0},E.name))]},y.name))})})]}),i&&l.jsx("div",{style:{marginLeft:"4em"},children:l.jsx(Tm,{characterId:o,showFull:!0,memberlist:f.members})})]})]})):null}function Qv(){const[i,r]=w.useState(!1),[d,u]=w.useState(!1),o=w.useContext(ze),f=w.useContext(oe),[m,g]=w.useState(null),{t:p}=k();return w.useEffect(()=>{He("/incursions/api/fleet/status","get").then(g).catch(y=>re(f,Promise.reject(y)))},[f]),w.useEffect(()=>{window.Notification&&Notification.permission==="default"&&Notification.requestPermission()},[]),$e(p("Fleet")),l.jsxs(l.Fragment,{children:[l.jsxs(Mt,{children:[l.jsx(Te,{children:l.jsx(an,{to:"/fc/fleet/register",children:p("Configure fleet")})}),l.jsx(Te,{children:l.jsx(an,{as:"a",href:"/incursions/char/add_fc",children:p("ESI re-auth as FC")})}),l.jsxs(Te,{children:[l.jsx(Y,{$variant:"success",onClick:()=>Cn(f,He("/incursions/api/waitlist/set_open","post",{body:{waitlist_id:1,open:!0}})),children:p("Open waitlist")}),l.jsx(Y,{onClick:()=>Cn(f,He("/incursions/api/waitlist/set_open","post",{body:{waitlist_id:1,open:!1}})),children:p("Close waitlist")}),l.jsx(Y,{onClick:()=>u(!0),children:p("Empty waitlist")})]}),l.jsx(Te,{children:l.jsx(Y,{$variant:"danger",onClick:()=>r(!0),children:p("Kick everyone from fleet")})})]}),l.jsxs(ct,{children:[l.jsx("p",{children:p("Make sure you re-auth via ESI, then create an in-game fleet with your comp. Click the 'Configure fleet' button, and select the five squads that the tool will invite people into. Then open the waitlist, allowing people to X up.")}),l.jsx("p",{children:p("To hand over the fleet, transfer the star (Boss role). Then the new FC should go via 'Configure fleet' again, as if it was a new fleet.")}),((m==null?void 0:m.fleets)??[]).map(y=>l.jsxs("div",{children:["STATUS: Fleet ",y.id,", boss ",y.boss.character_name]},y.id))]}),o.access["incursions.waitlist_history_view"]&&l.jsx(Mt,{children:l.jsx(Te,{children:l.jsx(an,{to:"/fc/fleet/history",children:p("Fleet comp history")})})}),l.jsx(fx,{}),l.jsx(mm,{open:i,setOpen:r,title:p("Kick everyone from fleet"),onConfirm:()=>Cn(f,He("/incursions/api/fleet/close","post",{body:{character_id:o.current.character_id}})).finally(()=>r(!1)),children:p("Are you sure?")}),l.jsx(mm,{open:d,setOpen:u,title:p("Empty waitlist"),onConfirm:()=>Cn(f,He("/incursions/api/waitlist/empty","post",{body:{waitlist_id:1}})).finally(()=>u(!1)),children:p("Are you sure?")})]})}function Vv(){const i=w.useContext(ze),r=w.useContext(oe),[d,u]=w.useState(null),[o,f]=w.useState(null),[m,g]=w.useState({}),{t:p}=k(),y=i.current.character_id;w.useEffect(()=>{u(null),He("/incursions/api/fleet/info","get",{params:{character_id:y}}).then(u).catch(E=>re(r,Promise.reject(E))),f(null),He("/incursions/api/categories","get").then(E=>f(E.categories)).catch(E=>re(r,Promise.reject(E)))},[y,r]),w.useEffect(()=>{if(!o||!d)return;const E={...m};let O=!1;for(const M of o)if(!(M.id in m))for(const L of d.wings)for(const q of L.squads){const U=q.name.toLowerCase();(U.includes(M.name.toLowerCase())||U.includes(String(M.id)))&&(E[M.id]=[L.id,q.id],O=!0)}O&&g(E)},[d,o,m]);const j=()=>{const E={character_id:y,fleet_id:d.fleet_id,assignments:m};Cn(r,He("/incursions/api/fleet/register","post",{body:E}))};return!d||!o?l.jsx("em",{children:p("Loading fleet information.., Please be patient, this can take up to a minute")}):l.jsxs(l.Fragment,{children:[l.jsx("div",{style:{marginBottom:"1em"},children:p("Will be automatically filled if the squad names in your fleet match.")}),l.jsxs("div",{style:{display:"flex"},children:[l.jsx(Zv,{categories:o,wings:d.wings,value:m,onChange:g}),l.jsx("img",{style:{marginLeft:"3em"},src:cv,alt:p("For auto filling, make sure the squad names match!")})]}),l.jsx(Y,{$variant:"primary",onClick:j,children:p("Continue")})]})}function Zv({categories:i,wings:r,value:d,onChange:u}){const{t:o}=k(),f=r.flatMap(m=>m.squads.map(g=>({name:`${m.name} - ${g.name}`,id:`${m.id},${g.id}`})));return l.jsx(ct,{children:i.map(m=>{var g;return l.jsxs("p",{children:[l.jsxs("label",{className:"label",children:[o(m.name),l.jsx("br",{})]}),l.jsxs(Da,{value:((g=d[m.id])==null?void 0:g.join(","))??"",onChange:p=>{const[y,j]=p.target.value.split(",").map(Number);u({...d,[m.id]:[y,j]})},children:[l.jsx("option",{}),f.map(p=>l.jsx("option",{value:p.id,children:p.name},p.id))]})]},m.id)})})}function Kv(){const[i,r]=K.useState(""),[d,u]=K.useState(""),{t:o}=k(),f=i&&d?new Date(`${i}T${d}Z`):null,m=f?f.getTime()/1e3:null,[g]=Le(m?`/incursions/api/history/fleet-comp?time=${m}`:null);return $e(o("Fleet History")),l.jsxs(ct,{children:[l.jsx("h2",{children:o("Fleet history lookup")}),l.jsxs(Te,{children:[l.jsx(En,{type:"date",value:i,onChange:p=>r(p.target.value)}),l.jsx(En,{type:"time",value:d,onChange:p=>u(p.target.value)})]}),f?l.jsx("div",{children:l.jsx("em",{children:f.toString()})}):null,g&&l.jsx("h2",{children:o("Results")}),g&&ue.map(g.fleets,(p,y)=>l.jsxs("div",{children:[l.jsxs("h3",{children:[o("Fleet")," ",y]}),l.jsxs(Dn,{fullWidth:!0,children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(Fe,{children:o("Pilot")}),l.jsx(Fe,{children:o("Ship")}),l.jsx(Fe,{children:o("Time")})]})}),l.jsx(On,{children:p.map(j=>l.jsxs(Oe,{children:[l.jsxs(I,{children:[j.character_name,j.is_boss&&l.jsxs(l.Fragment,{children:[" ",l.jsx(ie,{icon:O0})]})]}),l.jsx(I,{children:j.ship.name}),l.jsxs(I,{children:[wl(new Date(j.logged_at))," (",la(j.time_in_fleet),")"]})]},j.character_id))})]})]},y)),g&&ue.isEmpty(g.fleets)&&l.jsx("em",{children:o("Nothing found!")})]})}const co=T.div`
  margin: 0.4em 0;
  margin-right: 1em;
  width: 330px;

  @media (max-width: 480px) {
    width: 100%;
    margin-right: 0;
  }
`,Jv=T.div`
  padding-bottom: 0.5em;
  background-color: ${({theme:i})=>i.colors.accent1};
  filter: drop-shadow(0px 1px 1px ${({theme:i})=>i.colors.shadow});
  border-radius: 5px;
  height: 100%;
  border: solid 1px ${({theme:i,$variant:r})=>{var d;return((d=i.colors[r])==null?void 0:d.color)??"transparent"}};

  &:hover {
    border: solid 1px ${({theme:i})=>i.colors.accent2};
  }
`,Fv=T.h3`
  font-weight: 600;
  padding: 0.2em 0.5em;
`,Wv=T.div`
  padding: 0.5em 0.5em 0em;
`,hx=T.div`
  display: flex;
  align-items: stretch;
  flex-wrap: wrap;
`;function mx({variant:i,title:r,size:d,children:u,...o}){return l.jsxs(Jv,{$variant:i,size:d,...o,children:[l.jsx(Fv,{children:r}),l.jsx(Wv,{children:u})]})}const Ci={},Iv=T(ct)`
  max-width: 800px;
`;function Pv(i){return i.split("/").pop()}function Cm(){const i=K.useContext(oe),r=sn(),d=Pv(r.pathname),[u,o]=K.useState(null),f=`./${d}`,m=`${f}/guide.md`,{t:g}=k();K.useEffect(()=>{if(o(null),!(m in Ci))return;const y=document.title;return re(i,fetch(Ci[m]).then(j=>j.text()).then(j=>{o(j),Pu(tx(j))})),()=>document.title=y},[i,m]);const p=y=>{const j=`${f}/${y}`;return j in Ci?Ci[j].default:y};return Ci[m]?u?l.jsx(Iv,{style:{maxWidth:"800px"},children:l.jsx(Ui,{transformImageUri:p,transformLinkUri:null,children:u})}):l.jsx(l.Fragment,{children:l.jsx("em",{children:g("Loading...")})}):l.jsx("div",{children:g("client : a{{loc}}a",{loc:d})})}function vl({icon:i,slug:r,name:d,children:u}){const{t:o}=k();return l.jsx(co,{children:l.jsx(jt,{style:{textDecoration:"inherit",color:"inherit"},exact:!0,to:`/fc/${r}`,children:l.jsx(mx,{title:l.jsxs(l.Fragment,{children:[l.jsx(ie,{fixedWidth:!0,icon:i})," ",o(d)]}),children:l.jsx("p",{children:o(u)})})})})}function ej(){const i=K.useContext(ze),{t:r}=k();return $e(r("FC Menu")),l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:r("FC Dashboard")}),l.jsxs(hx,{children:[i&&i.access["incursions.waitlist_announcements_manage"]&&l.jsx(vl,{slug:"announcements",name:r("Announcements"),icon:Hm}),i&&(i.access["incursions.waitlist_bans_view"]||i.access["incursions.waitlist_bans_manage"])&&l.jsx(vl,{slug:"bans",name:r("Bans"),icon:xc}),i&&(i.access["incursions.waitlist_badges_view"]||i.access["incursions.waitlist_badges_manage"])&&l.jsx(vl,{slug:"badges",name:r("Badges"),icon:M0}),i&&i.access["incursions.waitlist_documentation_view"]&&l.jsx(vl,{slug:"documentation",name:r("FC Documentation"),icon:z0}),i&&i.access["incursions.waitlist_documentation_view"]&&l.jsx(vl,{slug:"trainee",name:r("FC Training"),icon:Ku}),i&&i.access["incursions.waitlist_stats_view"]&&l.jsx(vl,{slug:"stats",name:r("Statistics"),icon:B0})]})]})}function tj(){const{t:i}=k();$e(i("Add Note"));const r=w.useContext(oe),[d,u]=w.useState(""),[o,f]=w.useState(!1),[m,g]=w.useState(null),p=new URLSearchParams(sn().search),y=parseInt(p.get("character_id")??"",10),j=mc();if(w.useEffect(()=>{y&&re(r,I0(y).then(g))},[y,r]),!y)return l.jsx("em",{children:i("Missing character ID")});const E=L=>{u(L.target.value)},O=async L=>{L.preventDefault(),f(!0),re(r,P0(y,d).then(()=>j(`/pilot?character_id=${y}`)).finally(()=>f(!1)))},M=()=>{j(-1)};return l.jsxs(l.Fragment,{children:[l.jsxs(sa,{children:[i("Add note"),m&&`: ${m.character.character_name}`]}),l.jsx(Zt,{style:{width:"100%"},onChange:E,value:d,rows:5,cols:60}),l.jsx("p",{children:l.jsx("em",{children:i("Remember that notes cannot be removed!")})}),l.jsxs(Te,{children:[l.jsx(Y,{$variant:"success",disabled:d.length<20||d.length>5e3||o,onClick:O,children:i("Save")}),l.jsx(Y,{onClick:M,children:i("Never mind")})]})]})}function ro(){const i=sn(),r=mc(),d=i.search,u=w.useMemo(()=>{const f=new URLSearchParams(d),m={};for(const[g,p]of f.entries())m[g]=p;return m},[d]),o=w.useCallback((f,m,g=!1)=>{const p=new URLSearchParams(d);m===null?p.delete(f):p.set(f,m),r({search:`?${p.toString()}`},{replace:g})},[d,r]);return[u,o]}const Am=T.div`
  margin-left: 40px;
  margin-bottom: 5px;
  &:first-of-type {
    min-height: 50px;
  }
  &:nth-of-type(2) {
    min-height: 100px;
  }
  @media (min-width: 400px) {
    min-width: 310px;
  }
  @media (max-width: 451px) {
    margin-left: 3px;
    span {
      display: block;
    }
    br {
      display: none;
    }
  }
`;function xx({character:i,refreshData:r}){const[d,u]=w.useState(!1);return l.jsxs(l.Fragment,{children:[l.jsx(Y,{onClick:()=>u(!0),children:"Badges"}),d&&l.jsx(nj,{character:i,isOpen:d,setOpen:u,refreshData:r})]})}const nj=({character:i,isOpen:r,setOpen:d,refreshData:u})=>{const{t:o}=k(),f=w.useContext(oe),[m,g]=w.useState(),[p,y]=w.useState(!1),j=async()=>{try{const[U,G]=await Promise.all([He("/incursions/api/badges","get"),He("/incursions/api/pilot/info","get",{params:{character_id:i.character_id}})]),Q=G.tags??[],be=U.map(te=>({...te,default:Q.includes(te.name),checked:Q.includes(te.name)}));g(be)}catch(U){re(f,Promise.reject(U))}};w.useEffect(()=>{r&&j()},[r]);const E=U=>He("/incursions/api/badges/{badge_id}/members","post",{params:{badge_id:U},body:{character_id:i.character_id}}),O=U=>He("/incursions/api/badges/{badge_id}/members/{character_id}","delete",{params:{badge_id:U,character_id:i.character_id}}),M=async()=>{if(!m)return;y(!0);const U=m.filter(Q=>Q.default&&!Q.checked).map(Q=>Cn(f,O(Q.id))),G=m.filter(Q=>!Q.default&&Q.checked).map(Q=>Cn(f,E(Q.id)));await Promise.all([...U,...G]),y(!1),j(),u&&u()},L=(U,G)=>{if(!m)return;const Q=[...m];Q[G]={...Q[G],checked:U.target.checked},g(Q)},q=()=>{const U=(m==null?void 0:m.filter(Q=>Q.default).map(Q=>Q.name))??[];return ue.sortBy(U,Q=>no.indexOf(Q)).map(Q=>Q in Ni&&l.jsx("span",{style:{marginRight:"5px",display:"inline-block"},children:l.jsx(An,{type:Q})},Q))};return l.jsx(qe,{open:r,setOpen:d,children:l.jsxs(Ce,{children:[l.jsx(Me,{style:{marginBottom:"5px"},children:l.jsx(dt,{...i,avatarSize:32,noLink:!0})}),l.jsx(Am,{children:m?l.jsxs(l.Fragment,{children:[l.jsx("p",{children:o("badge.current","Current Badges:")}),l.jsx("span",{children:q()})]}):l.jsx("small",{style:{fontStyle:"italic",fontSize:"smaller"},children:o("badge.loading","Loading...")})}),l.jsx(Am,{children:m==null?void 0:m.map((U,G)=>l.jsxs("span",{children:[G%3===0&&l.jsx("br",{}),l.jsxs("label",{style:{marginRight:"20px",marginBottom:"15px",display:"inline-block"},htmlFor:`badge-${G}`,children:[l.jsx("input",{id:`badge-${G}`,type:"checkbox",checked:U.checked,onChange:Q=>L(Q,G)}),U.name]})]},G))}),l.jsxs(pc,{children:[l.jsx(Y,{$variant:"success",onClick:M,disabled:p,children:o("form.confirm","Confirm")}),l.jsx(Y,{onClick:()=>d(!1),children:o("form.close","Close")})]})]})})};function aj(){const i=K.useContext(ze),{t:r}=k();var[{query:d},u]=ro();const o=m=>{u("query",m||null,!0)},[f]=Le(d&&d.length>=3?"/incursions/api/search?"+new URLSearchParams({query:d}):null);return $e(r("Search")),l.jsxs(l.Fragment,{children:[l.jsx("div",{style:{marginBottom:"1em"},children:l.jsxs("label",{children:[l.jsx("strong",{children:r("Search term:")}),l.jsx("br",{}),l.jsx(En,{value:d??"",onChange:m=>o(m.target.value)})]})}),f==null?null:f.results.length?l.jsxs(Dn,{fullWidth:!0,children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(Fe,{children:r("Name")}),l.jsx(Fe,{children:r("Character ID")}),l.jsx(Fe,{style:{width:"50%"}})]})}),l.jsx(On,{children:f.results.map(m=>l.jsxs(Oe,{children:[l.jsx(I,{children:m.character_name}),l.jsx(I,{children:m.character_id}),l.jsx(I,{children:l.jsxs(Mt,{marginb:"0em",children:[l.jsxs(Te,{children:[l.jsx(an,{to:"/skills?character_id="+m.character_id,children:r("Skills")}),l.jsx(an,{to:"/pilot?character_id="+m.character_id,children:r("Information")})]}),l.jsx(Te,{children:(i.access["incursions.waitlist_badges_view"]||i.access["incursions.waitlist_badges_manage"])&&l.jsx(xx,{character:m})})]})})]},m.character_id))})]}):l.jsx("em",{children:r("No results")})]})}km.register(a0,l0,i0,s0,c0,r0,u0,o0,d0);km.register(...f0);const na=T(Sl).attrs({md:4})`
  max-height: 350px;
`;function Em(i,r){let d=1546047137;for(let m=0;m<r.length;m++)d=r.charCodeAt(m)+((d<<5)-d);d=d&2147483647;const u=d%360,o=(d>>10)%60+30,f=Math.round(i.colors.lumFactor*50);return`hsla(${u}, ${o}%, ${f}%, 1)`}function uo(i,r){return ue.merge({},{maintainAspectRatio:!1,animation:!1,color:i.colors.text,backgroundColor:i.colors.accent1,borderColor:i.colors.accent2,plugins:{title:{color:i.colors.text}},scales:{x:{ticks:{color:i.colors.text},grid:{color:i.colors.accent2}},y:{ticks:{color:i.colors.text},grid:{color:i.colors.accent2}}}},r||{})}function oo(i,r,d){const u=ue.cloneDeep(r);if(u.datasets)for(const o of u.datasets){for(const f of["backgroundColor","borderColor"])o[f]||(d?o[f]=u.labels.map(m=>Em(i,m)):o[f]=Em(i,o.label||""));o.fill===void 0&&(o.fill=!0)}return u}function fo({options:i,data:r,...d}){const u=K.useContext(Oa);return l.jsx(m0,{options:uo(u,i),data:oo(u,r,!1),...d})}function ho({options:i,data:r,...d}){const u=K.useContext(Oa);return l.jsx(h0,{options:uo(u,i),data:oo(u,r,!1),...d})}function gx({options:i,data:r,...d}){const u=K.useContext(Oa);return l.jsx(x0,{options:uo(u,i),data:oo(u,r,!0),...d})}function Li(i){const r=Object.keys(i).sort(),d=r.map(u=>i[u]);return{labels:r,data:d}}function yc(i){const r=Li(i),d={};for(let u=0;u<r.labels.length;u++)for(const[o,f]of Object.entries(r.data[u]))d[o]||(d[o]=new Array(r.labels.length).fill(null)),d[o][u]=f;return{labels:r.labels,series:d}}function lj({data:i}){const{t:r}=k(),d=Li(i);return l.jsx(ho,{data:{labels:d.labels,datasets:[{label:r("Hours"),data:d.data.map(u=>Math.round(u/3600))}]},options:{plugins:{title:{display:!0,text:r("Total fleet time")}}}})}function ij({data:i}){const{t:r}=k(),d=Li(i);return l.jsx(ho,{data:{labels:d.labels,datasets:[{label:r("Pilots"),data:d.data}]},options:{plugins:{title:{display:!0,text:r("Pilots seen in fleet")}}}})}function sj({data:i}){const{t:r}=k(),d=yc(i);return l.jsx(fo,{data:{labels:d.labels,datasets:Object.entries(d.series).map(([u,o])=>({label:r(u),data:o.map(f=>Math.round(f/3600))}))},options:{scales:{x:{stacked:!0},y:{stacked:!0}},plugins:{title:{display:!0,text:r("Time in fleet by ship")}}}})}function cj({data:i}){const{t:r}=k(),d=yc(i);return l.jsx(ho,{data:{labels:d.labels,datasets:Object.entries(d.series).map(([u,o])=>({label:r(u),data:o.map(f=>f||0)}))},options:{plugins:{title:{display:!0,text:r("X'es by ship")}}}})}function rj({data:i}){const{t:r}=k(),d=yc(i);return l.jsx(fo,{data:{labels:d.labels,datasets:Object.entries(d.series).map(([u,o])=>({label:r(u),data:o.map(f=>f||0)}))},options:{plugins:{title:{display:!0,text:r("Distribution of time in fleet")}}}})}function uj({data:i}){const{t:r}=k(),d=yc(i);return l.jsx(fo,{data:{labels:d.labels,datasets:Object.entries(d.series).map(([u,o])=>({label:r(u),data:o.map(f=>Math.round((f||0)*1e3)/10)}))},options:{plugins:{title:{display:!0,text:r("Time vs X'es in percentages (28d)")}}}})}function oj({data:i}){const{t:r}=k(),d=Li(i);return l.jsx(gx,{data:{labels:d.labels.map(u=>r(u)),datasets:[{data:d.data}]},options:{plugins:{title:{display:!0,text:r("X'es by ship (28d)")}}}})}function dj({data:i}){const{t:r}=k(),d=Li(i);return l.jsx(gx,{data:{labels:d.labels.map(u=>r(u)),datasets:[{data:d.data.map(u=>Math.round((u||0)/3600))}]},options:{plugins:{title:{display:!0,text:r("Time in fleet by ship (28d)")}}}})}function fj(){const{t:i}=k();$e(i("Statistics"));const[r]=Le("/incursions/api/stats");return r?l.jsxs(hc,{children:[l.jsx(na,{children:l.jsx(lj,{data:r.fleet_seconds_by_month})}),l.jsx(na,{children:l.jsx(ij,{data:r.pilots_by_month})}),l.jsx(na,{children:l.jsx(sj,{data:r.fleet_seconds_by_ship_by_month})}),l.jsx(na,{children:l.jsx(cj,{data:r.xes_by_ship_by_month})}),l.jsx(na,{children:l.jsx(rj,{data:r.time_spent_in_fleet_by_month})}),l.jsx(na,{children:l.jsx(uj,{data:r.x_vs_time_by_ship_28d})}),l.jsx(na,{children:l.jsx(oj,{data:r.xes_by_ship_28d})}),l.jsx(na,{children:l.jsx(dj,{data:r.fleet_seconds_by_ship_28d})})]}):l.jsx("em",{children:i("Loading statistics...")})}const hj=T.ul`
  position: absolute;
  width: 100%;
  background: ${({theme:i})=>{var r;return(r=i.colors)==null?void 0:r.accent1}};
  z-index: 500;
  border: 1px solid #999;
  border-top-width: 0;
  list-style: none;
  margin-top: 0;
  overflow-y: auto;
  padding-left: 0;

  > li {
    padding: 0.5rem;

    &.active,
    &:hover {
      color: ${({theme:i})=>{var r;return(r=i.active)==null?void 0:r.text}};
      cursor: pointer;
      font-weight: 700;
    }
  }
`,mj=T.div`
  color: ${({theme:i})=>{var r,d;return(d=(r=i.colors)==null?void 0:r.secondary)==null?void 0:d.text}};
  padding: 0.5rem;
  font-style: italic;
`,xj=({id:i="pilot-search",onChange:r,style:d,resetSearch:u,hideNotFound:o=!1})=>{const{t:f}=k(),[m,g]=w.useState(0),[p,y]=w.useState(!1),[j,E]=w.useState([]),[O,M]=w.useState(""),[L,q]=w.useState(""),U=W=>{q(W),M(W)},[G]=Le(L&&L.length>=3?`/incursions/api/search?${new URLSearchParams({query:L})}`:null);w.useEffect(()=>{let W=!1;const de=(G==null?void 0:G.results.filter(We=>(We.character_name.toLowerCase()===O.toLowerCase()&&(r(We),M(We.character_name),g(0),W=!0),We.character_name.toLowerCase().includes(O.toLowerCase()))))??[];E(de),y(!W)},[G,O,r]),w.useEffect(()=>{M(""),E([]),y(!1),g(0)},[u]);const Q=W=>{g(0),y(!1),M(W.currentTarget.innerText);const de=j.find(We=>We.character_name.toLowerCase()===W.currentTarget.innerText.toLowerCase());de&&r(de)},be=W=>{if(j.length)if(W.key==="Enter"){W.preventDefault();const de=j[m];de&&(r(de),M(de.character_name),g(0),y(!1))}else W.key==="ArrowUp"?(W.preventDefault(),g(de=>Math.max(0,de-1))):W.key==="ArrowDown"&&(W.preventDefault(),g(de=>Math.min(j.length-1,de+1)))},te=()=>!p||!O?null:j.length?l.jsx(hj,{children:j.map((W,de)=>l.jsx("li",{className:de===m?"active":void 0,onClick:Q,children:W.character_name},W.character_id))}):o?null:l.jsx(mj,{children:f("Could not find {{character_name}} in the database, sorry.",{character_name:O})});return l.jsxs("div",{style:{position:"relative"},children:[l.jsx(En,{id:i,type:"text",value:O,onChange:W=>U(W.target.value),onKeyDown:be,style:d,autoComplete:"off"}),te()]})},Dm=T.div`
  margin: 15px 0px;
`,gj=T.p`
  margin-bottom: 20px;
`,pj=({badgeOptions:i=[],isOpen:r,setOpen:d,refreshFunction:u})=>{const{t:o}=k(),f=w.useContext(oe),[m,g]=w.useState(0),[p,y]=w.useState(void 0),[j,E]=w.useState(void 0),[O,M]=w.useState(!1),L=async U=>{if(U.preventDefault(),!j||isNaN(j))return ln(f,{title:o("Error:"),message:o("You need to search for a pilot..."),variant:"danger"});M(!0),await re(f,Qe(`/incursions/api/badges/${p}/members`,{method:"POST",json:{character_id:j}}).then(()=>{u(),q()}).finally(()=>M(!1)))},q=()=>{var U;y(((U=i==null?void 0:i[0])==null?void 0:U.id)??void 0),E(void 0),d(!1),g(G=>G+1)};return w.useEffect(()=>{!p&&i.length>0&&y(i[0].id)},[i,p]),l.jsx(qe,{open:r,setOpen:d,children:l.jsxs(Ce,{style:{overflowY:"hidden"},children:[l.jsx(Me,{children:o("Assign a Specialist Badge")}),l.jsxs("form",{onSubmit:L,children:[l.jsxs(Dm,{children:[l.jsx(Je,{htmlFor:"pilot-search",required:!0,children:o("Search for a pilot:")}),l.jsx(xj,{required:!0,resetSearch:m,style:{width:"100%"},onChange:U=>E(U.character_id),hideNotFound:!0})]}),l.jsxs(Dm,{children:[l.jsx(Je,{htmlFor:"badge-select",required:!0,children:o("Select badge type:")}),l.jsx(Da,{id:"badge-select",value:p,onChange:U=>y(parseInt(U.target.value)),style:{width:"100%",appearance:"auto"},required:!0,children:i.map(U=>l.jsx("option",{value:U.id,children:U.name},U.id))})]}),l.jsx(Y,{$variant:"success",disabled:O,children:o("Confirm")})]})]})})},yj=i=>{const{t:r}=k(),[d,u]=w.useState(!1);return l.jsxs(l.Fragment,{children:[l.jsx(Y,{$variant:"danger",onClick:()=>u(!0),children:r("Revoke")}),l.jsx(vj,{isOpen:d,setOpen:u,...i})]})},vj=({badge:i,character:r,isOpen:d,setOpen:u,refreshFunction:o})=>{const{t:f}=k(),m=w.useContext(oe),[g,p]=w.useState(!1),y=async()=>{g||(p(!0),await re(m,Qe(`/incursions/api/badges/${i.id}/members/${r.character_id}`,{method:"DELETE"}).then(()=>{o(),u(!1)}).finally(()=>p(!1))))};return l.jsx(qe,{open:d,setOpen:u,children:l.jsxs(Ce,{children:[l.jsx(Me,{children:f("Revoke {{badge}}",{badge:i.name})}),l.jsxs(gj,{children:[f("From"),": ",l.jsx(dt,{...r,noLink:!0,avatar:!1})]}),l.jsxs(pc,{size:"90px",children:[l.jsx(Y,{$variant:"secondary",onClick:()=>u(!1),children:f("Cancel")}),l.jsx(Y,{$variant:"danger",onClick:y,disabled:g,children:f("Confirm")})]})]})})},jj=T.div`
  padding-bottom: 10px;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-content: space-between;

  h1 {
    font-size: 32px;
  }
`,bj=T.div`
  align-content: space-between;
  display: flex;
  width: 100%;
  flex-wrap: wrap;

  > button {
    @media (max-width: 800px) {
      width: 100%;
    }
  }

  #filters {
    flex-grow: 1;

    span:first-of-type {
      font-style: italic;
      margin-right: 10px;

      @media (max-width: 800px) {
        display: block;
        margin-bottom: 5px;
      }
    }

    @media (max-width: 800px) {
      input,
      select {
        width: calc(calc(100vw - 158px) / 2);
      }
    }

    @media (max-width: 500px) {
      input,
      select {
        width: 100%;
      }
      button {
        display: block;
        width: 100%;
      }
    }
  }
`,Hu=(i,r)=>i.character_name.toLowerCase().localeCompare(r.character_name.toLowerCase()),Sj=({badgeOptions:i,filters:r,onChange:d,onClear:u})=>{const{t:o}=k();return l.jsxs("div",{id:"filters",children:[l.jsx("span",{children:o("Filter results by...")}),l.jsxs(Da,{value:(r==null?void 0:r.type)??"",onChange:f=>d({...r,type:f.target.value==="-1"?null:parseInt(f.target.value)}),style:{marginRight:"10px",marginBottom:"10px",appearance:"auto"},children:[l.jsx("option",{value:-1,children:o("any type...")}),i.map(f=>l.jsxs("option",{value:f.id,children:[f.name," (",f.member_count.toLocaleString(),")"]},f.id))]}),l.jsx(En,{value:r.name??"",onChange:f=>d({...r,name:f.target.value}),placeholder:o("pilot name"),style:{marginRight:"10px",marginBottom:"10px"}}),l.jsx(Y,{$variant:"primary",onClick:u,style:{marginBottom:"10px"},children:o("Clear")})]})},wj=()=>{const[i,r]=Le("/incursions/api/badges"),[d,u]=w.useState(null),[o,f]=w.useState(!1),[m,g]=w.useState({type:null,name:""}),{t:p}=k();w.useEffect(()=>{i&&Promise.all(i.map(O=>Qe(`/incursions/api/badges/${O.id}/members`,{}).catch(()=>[]))).then(O=>{u(O.flat().filter(Boolean))})},[i]);const y=[{name:p("Pilot Name"),sortable:!0,sortFunction:(O,M)=>Hu(O.character,M.character),grow:2,selector:O=>l.jsx(dt,{...O.character})},{name:p("Badge"),sortable:!0,sortFunction:(O,M)=>Hu(O.badge,M.badge),grow:1,selector:O=>l.jsx(An,{type:O.badge.name,height:"1.8em"})},{name:p("Granted By"),sortable:!0,sortFunction:(O,M)=>Hu(O.granted_by,M.granted_by),hide:"md",grow:2,selector:O=>l.jsx(dt,{...O.granted_by})},{name:p("Granted At"),hide:"sm",grow:2,selector:O=>wl(new Date(O.granted_at))},{name:"",grow:1,minWidth:"95",selector:O=>l.jsx(yj,{badge:O.badge,character:O.character,refreshFunction:r})}],j=w.useMemo(()=>l.jsxs(bj,{children:[l.jsx(Sj,{badgeOptions:i??[],filters:m,onChange:O=>g(O),onClear:()=>g({type:null,name:""})}),l.jsxs(Y,{$variant:"primary",onClick:()=>f(!0),style:{marginBottom:"10px"},children:[l.jsx(ie,{fixedWidth:!0,icon:Ym,style:{marginRight:"10px"}}),p("Assign Badge")]})]}),[m,i,p]),E=(d??[]).filter(O=>O&&O.character&&(!m.type||O.badge.id===m.type)&&O.character.character_name.toLowerCase().includes(m.name.toLowerCase()));return $e(p("Specialist Badges")),l.jsxs(l.Fragment,{children:[l.jsx(jj,{children:l.jsx("h1",{children:p("Specialist Badges")})}),l.jsxs("p",{style:{marginBottom:"10px"},children:[p("You can find the badge guide")," ",l.jsx(fc,{to:"/badges",children:p("here")}),"."]}),l.jsx(to,{columns:y,data:E,defaultSortFieldId:1,subHeader:!0,subHeaderComponent:j,progressPending:!d}),l.jsx(pj,{badgeOptions:i??[],isOpen:o,setOpen:f,refreshFunction:r})]})},Om="/static/incursions/waitlist/static/img/w-S0yXGjWr.png";function px(i,r){Cn(i,navigator.clipboard.writeText(r).then(()=>"Copied to clipboard"))}function _j({type:i}){const r=K.useContext(oe),{t:d}=k();var u;switch(i){case"Amulet":u=["Mid-grade Amulet Alpha","Mid-grade Amulet Beta","Mid-grade Amulet Gamma","Mid-grade Amulet Delta","Mid-grade Amulet Epsilon"];break;case"Ascendancy":u=["High-grade Ascendancy Alpha","High-grade Ascendancy Beta","High-grade Ascendancy Gamma","High-grade Ascendancy Delta","High-grade Ascendancy Epsilon"];break;case"None":u=[];break;default:u=[]}return l.jsx(l.Fragment,{children:l.jsxs(Dn,{style:{width:"100%"},children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(ey,{}),l.jsx(Fe,{children:d("DEFAULT")}),l.jsx(Fe,{children:d("ALTERNATIVE (not required)")})]})}),l.jsxs(On,{children:[u.map((o,f)=>l.jsx(Tj,{toast:r,slot:f+1,implant:o},f)),l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsx("b",{children:d("Slot 6")})}),i==="Amulet"?l.jsx(I,{children:l.jsx(Ke,{toast:r,item:"Mid-Grade Amulet Omega"})}):i==="Ascendancy"?l.jsxs(I,{children:[l.jsx(Ke,{toast:r,item:"WS-518"})," ",d("+18% warp speed")]}):l.jsxs(I,{children:[l.jsx(Ke,{toast:r,item:"High-grade Ascendancy Omega"})," ",d("+21% warp speed")]})]}),l.jsx(Cj,{toastContext:r})]})]})})}function Tj({toast:i,slot:r,implant:d}){const{t:u}=k();return l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsxs("b",{children:[u("Slot")," ",r]})}),l.jsx(I,{children:l.jsx(Ke,{toast:i,item:d})}),l.jsx(I,{})]})}function Ke({toast:i,item:r}){return l.jsx(py,{onClick:()=>{px(i,r)},children:r})}function Cj({toastContext:i}){const{t:r}=k();return l.jsxs(l.Fragment,{children:[l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsx("b",{children:r("Slot 7")})}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"Ogdin's Eye Coordination Enhancer"})," ",r("+6% Tracking (Often Cheaper!)")]}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"MR-705"})," ",r("+5% Tracking"),l.jsx("br",{}),l.jsx("b",{children:r("Logi:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"RA-705"})," ",r("-5% Cap use for remote reps")]})]}),l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsx("b",{children:r("Slot 8")})}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"EM-805"})," ",r("+5% Capacitor")]}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"Zor's Custom Navigation Hyper-Link"})," ",r("+5% MWD/AB Speed"),l.jsx("br",{}),l.jsx("b",{children:r("Vindicator:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"MR-805"})," ",r("+5% Web range")]})]}),l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsx("b",{children:r("Slot 9")})}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"RF-905"})," ",r("+5% rate of fire for all turrets")]}),l.jsxs(I,{children:[l.jsx(Ke,{toast:i,item:"SS-905"})," ",r("+5% damage for all turrets"),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"Pashan's Turret Customization Mindlink"})," ",r("+7% rate of fire for all turrets")]})]}),l.jsxs(Oe,{children:[l.jsx(I,{children:l.jsx("b",{children:r("Slot 10")})}),l.jsxs(I,{children:[l.jsx("b",{children:r("Kronos/Vindicator:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"LH-1005"})," ",r("+5% Hybrid weapon damage"),l.jsx("br",{}),l.jsx("b",{children:r("Paladin:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"LE-1005"})," ",r("+5% Energy weapon damage"),l.jsx("br",{}),l.jsx("b",{children:r("Vargur:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"LP-1005"})," ",r("+5% Projectile weapon damage")]}),l.jsxs(I,{children:[l.jsx("b",{children:r("Paladin:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"Pashan's Turret Handling Mindlink"})," ",r("+7% energy weapon damage"),l.jsx("br",{}),l.jsx("b",{children:r("Logi:")}),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"HG-1005"})," ",r("+5% Armor hitpoints"),l.jsx("br",{}),l.jsx(Ke,{toast:i,item:"HG-1008"})," ",r("+8% Armor hitpoints"),l.jsx("br",{})]})]})]})}const Oi=T.div`
  border: solid 2px ${i=>i.theme.colors.accent2};
  background-color: ${i=>i.theme.colors.background};
  border-radius: 5px;
  font-size: 0.9em;
  filter: drop-shadow(0px 3px 4px ${i=>i.theme.colors.shadow});
  width: 380px;
  &:hover:not(:disabled):not(.static) {
    border-color: ${i=>i.theme.colors.accent3};
    cursor: pointer;
  }
  @media (max-width: 480px) {
    width: 100%;
  }
`;Oi.Content=T.div`
  display: flex;
  align-items: center;
  color: ${i=>i.theme.colors.text};
  p {
    @media (max-width: 480px) {
      font-size: 3.1vw;
    }
  }
  img {
    border-radius: 3px 0px 0px 3px;
    margin-right: 0.5em;
    align-self: flex-start;
  }
`;Oi.Content.Badges=T.div`
  margin-left: auto;
  display: flex;
  align-items: center;
  > *:last-child {
    margin-right: 0.5em;
  }
  img {
    height: 1.3em;
  }
  @media (max-width: 480px) {
    font-size: 1em;
    > *:last-child {
      margin-right: 0.4em;
    }
  }
`;const Mi=T.div`
  display: flex;
  flex-wrap: wrap;
  width: 100%;
  @media (max-width: 480px) {
    justify-content: center;
  }
`;function rc({data:i,tier:r}){const{t:d}=k();var u=[],o=[],f=[],m={},g,p;return r==="Antigank"?p=i.fittingdata:p=ue.sortBy(i.fittingdata,function(y){return y.name.indexOf("HYBRID")}),ue.forEach(i.logi_rules,y=>{f.push(y)}),ue.forEach(i.notes,y=>{m[y.name]=y.description??""}),p.forEach(y=>{if(y.dna&&y.name&&y.tier===r&&!(r!=="Antigank"&&y.name.toLowerCase().indexOf("antigank")!==-1)){const j=y.dna.split(":",1)[0];y.name in m?g=m[y.name]:g=null,f.includes(parseInt(j))?o.push(l.jsx(Mm,{fit:y,id:j,note:g},y.name)):u.push(l.jsx(Mm,{fit:y,id:j,note:g},y.name))}}),r==="Other"?l.jsx(l.Fragment,{children:l.jsxs("div",{children:[l.jsx("div",{style:{padding:"1em 0 0.4em"},children:l.jsx("p",{children:d("These ships are never used as main characters in fleet.")})}),l.jsx(Me,{children:d("Secondary Support Ships")}),l.jsx(Mi,{children:u})]})}):l.jsx(l.Fragment,{children:l.jsxs("div",{children:[l.jsx("div",{style:{padding:"1em 0 0.4em"},children:r in m?l.jsx(Ui,{children:m[r]}):l.jsx("br",{})}),u.length!==0&&l.jsxs(l.Fragment,{children:[l.jsx(Me,{children:d("DPS")}),l.jsx(Mi,{children:u})]}),l.jsx("br",{}),o.length!==0&&l.jsxs(l.Fragment,{children:[l.jsx(Me,{children:d("LOGISTICS")}),l.jsx(Mi,{children:o})]})]})})}function Mm({fit:i,id:r,note:d}){const[u,o]=K.useState(!1),{t:f}=k();return l.jsxs(l.Fragment,{children:[u?l.jsx(qe,{open:!0,setOpen:o,children:l.jsxs(Ce,{style:{maxWidth:"500px"},children:[l.jsx("div",{style:{display:"flex"},children:l.jsx("div",{style:{margin:"0 0.5em"},children:l.jsx(ao,{dna:i.dna,name:i.name})})}),d?l.jsx(uc,{$variant:"secondary",children:l.jsx(Ui,{children:d})}):null,i.implant_set==="Amulet"?l.jsx(uc,{$variant:"danger",children:l.jsx("p",{children:f("HYBRID FIT! This fit requires at least Amulet 1 - 5. See implants above")})}):i.implant_set==="Ascendancy "?l.jsx(uc,{$variant:"danger",children:l.jsx("p",{children:f("ASCENDANCY FIT! This fit requires at least Ascendancy 1 - 5 & WS-618. See implants above")})}):null]})}):null,l.jsx(Ce,{mpadding:"0.2em",style:{margin:"0.5em 0"},children:l.jsx(Oi,{$variant:"input",children:l.jsx("a",{onClick:()=>o(!0),children:l.jsxs(Oi.Content,{children:[l.jsx("img",{style:{height:"64px"},src:`https://images.evetech.net/types/${r}/icon`,alt:i.name}),l.jsx("p",{children:i.name}),l.jsxs(Oi.Content.Badges,{children:[d?l.jsx(ie,{icon:qm}):null,i.implant_set==="Amulet"?l.jsx(Yu,{color:"red",letter:"A",title:f("Amulet Implants")}):i.implant_set==="Ascendancy "?l.jsx(Yu,{color:"red",letter:"W",title:f("Ascendancy Implants")}):null]})]})})})})]})}function Aj(){return l.jsxs(l.Fragment,{children:[l.jsx(Mi,{style:{justifyContent:"initial"},children:l.jsx(zm,{name:"Amulet",img:Om})}),l.jsx(Mi,{style:{justifyContent:"initial"},children:l.jsx(zm,{name:"Ascendancy",img:Om})})]})}function zm({name:i,img:r}){const[d,u]=K.useState(!1),{t:o}=k();return l.jsxs(l.Fragment,{children:[d?l.jsx(qe,{open:!0,setOpen:u,children:l.jsxs(Ce,{style:{width:"100%"},children:[l.jsx(Bi,{style:{width:"100%"},children:l.jsxs(Bi.Title,{children:[l.jsx("div",{children:l.jsx("img",{src:r,alt:i,style:{width:"1.8em",marginRight:"0.5em"}})}),l.jsxs(Me,{children:[o(i),"  "]})]})}),l.jsx("br",{}),l.jsx("br",{}),l.jsx(_j,{type:i})]})}):null,l.jsx(ia,{children:l.jsx("a",{onClick:()=>u(!0),children:l.jsxs(ia.Content,{children:[l.jsx(ia.Icon,{children:l.jsx("img",{src:r,alt:i,style:{width:"1.5em"}})}),o(i)]})})})]})}function Ej(){const i=new URLSearchParams(sn().search),r=mc(),d=i.get("Tier")||"Armor",u=o=>{i.set("Tier",o),r({search:`?${i.toString()}`})};return l.jsx(Dj,{tier:d,setTier:u})}function Dj({tier:i,setTier:r=null}){const{t:d}=k();$e(d(`${i} Fits`));const[u]=Le("/incursions/api/fittings");return u===null?l.jsx("em",{children:d("Loading fits...")}):l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:d("FITS")}),r!=null&&l.jsx(Mt,{style:{marginBottom:"0.5em"},children:l.jsxs(Te,{children:[l.jsx(Y,{$active:i==="Basic",onClick:()=>r("Basic"),children:d("Basic")}),l.jsx(Y,{$active:i==="Mainline",onClick:()=>r("Mainline"),children:d("Mainline")}),l.jsx(Y,{$active:i==="Alt",onClick:()=>r("Alt"),children:d("Alt")}),l.jsx(Y,{$active:i==="Other",onClick:()=>r("Other"),children:d("Other")})]})}),l.jsx(Aj,{}),i==="Basic"?l.jsx(rc,{data:u,tier:"Basic"}):i==="Mainline"?l.jsx(rc,{data:u,tier:"Mainline"}):i==="Alt"?l.jsx(rc,{data:u,tier:"Alt"}):i==="Other"?l.jsx(rc,{data:u,tier:"Other"}):null]})}const Bm=T.div`
  display: flex;
  flex-wrap: wrap;
  margin-top: 1em;
`,Oj={};function jl({name:i,icon:r,children:d}){const[u,o]=K.useState(!1);return l.jsxs(l.Fragment,{children:[u?l.jsx(qe,{open:!0,setOpen:o,children:l.jsx(Ce,{children:l.jsxs(Bi,{children:[l.jsxs(Bi.Title,{children:[l.jsx("div",{style:{display:"flex",alignItems:"center"},children:l.jsx(An,{type:r,height:"40px"})}),l.jsxs(Me,{children:[i,"  "]})]}),d]})})}):null,l.jsx(ia,{children:l.jsx("a",{onClick:()=>o(!0),children:l.jsxs(ia.Content,{children:[l.jsx(ia.Icon,{children:l.jsx(An,{type:r,height:"50px"})}),i]})})})]})}function Mj(){$e("Badges");const[i,r]=K.useState(!1);return l.jsxs(l.Fragment,{children:[i?l.jsx(qe,{open:!0,setOpen:r,children:l.jsx(Ce,{style:{width:"100%"},children:l.jsx("img",{src:Oj["./examplediscord.png"],alt:"examplediscord",style:{width:"100%"}})})}):null,l.jsxs(ct,{style:{marginBottom:"2em"},children:[l.jsx("h1",{children:"Badges"}),l.jsxs("p",{children:["To get the T, A, or ! badge, use the",l.jsx("a",{href:"https://discord.com/channels/930000021083005028/930014112635826196/1287232984495423570",target:"_blank",rel:"noopener noreferrer",style:{marginLeft:"0.5em"},children:"ticket"})," ","system on Discord. Make sure your screenshot is saved on an image hosting website & shows the highlighted areas as per the",l.jsx(Im,{onClick:()=>r(!0),style:{marginLeft:"0.5em"},children:"example"})]}),l.jsx(Me,{children:"Pilot Badge"}),l.jsxs(Bm,{children:[l.jsx(jl,{name:"DPS",icon:"DPS",children:"The DPS Badge is given to a pilot that has met the main DPS Values on the fitting page. You must have implant slots 9 & 10 to get this badge."}),l.jsx(jl,{name:"Logi",icon:"LOGI",children:"The Logi Badge is given out by an FC that has vouched for your logi performance. It is not required to fly Logi."}),l.jsxs(jl,{name:"Alt Approved",icon:"ALT",children:["The Alt Approved Badge is given to a pilot that has met the DPS Values for alts on the fitting page. Your main or T badge must have a ",l.jsx("b",{children:"full"})," implant set before you can apply for this badge and recieve your guaranteed alt spot."]}),l.jsx(jl,{name:"VINDICATION!",icon:"VINDI",children:"The VINDICATION badge is given to a pilot that has met the DPS and Web values on the fitting page."})]}),l.jsx(Me,{children:"Commander Badges"}),l.jsxs(Bm,{children:[l.jsx(jl,{name:"Training FC",icon:"TRAINEE",children:"Trainee isk bringers"}),l.jsx(jl,{name:"Fleet Commander",icon:"HQ-FC",children:"Isk bringers"})]})]})]})}const Ai={},zj=T(ct)`
  max-width: 800px;
`,Bj=T.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 150px;
  background-color: ${i=>i.theme.colors.accent1};
  border-radius: 5px;
  cursor: pointer;
  &:hover {
    border: solid 1px ${i=>i.theme.colors.accent2};
  }
  @media (max-width: 600px) {
    width: 100%;
  }
  box-shadow: 3px 3px 1px ${i=>i.theme.colors.shadow};
`,Nj=T.img`
  height: 40px;
  margin-bottom: 5px;
`,Rj=T.span`
  font-size: 20px;
`,Uj=T.span`
  font-size: 14px;
  color: gray;
`,kj=T.div`
  display: flex;
  align-items: stretch;
  flex-wrap: wrap;
  border-top: 2px solid;
  padding-top: 5em;
  border-color: ${i=>i.theme.colors.accent2};
`,qu=({imageSrc:i,slug:r,title:d,subtitle:u,children:o})=>l.jsx(co,{children:l.jsx(jt,{style:{textDecoration:"inherit",color:"inherit"},to:`${r}`,children:l.jsxs(Bj,{children:[l.jsxs("div",{style:{display:"flex",height:"40px"},children:[o,i&&l.jsx(Nj,{src:i})]}),l.jsx(Rj,{children:d}),l.jsx(Uj,{children:u})]})})});function Lj(){const i=K.useContext(oe),{guideName:r}=Fp(),[d,u]=K.useState(null),o=`./${r}`,f=`${o}/guide.md`;K.useEffect(()=>{if(u(null),!(f in Ai))return;let g=document.title;return re(i,fetch(Ai[f]).then(p=>p.text()).then(p=>{u(p),Pu(tx(p))})),()=>document.title=g},[i,f]);const m=g=>{const p=`${o}/${g}`;return p in Ai?Ai[p]:g};return Ai[f]?d?l.jsx(zj,{style:{maxWidth:"800px"},children:l.jsx(Ui,{transformImageUri:m,transformLinkUri:null,children:d})}):l.jsx(l.Fragment,{children:l.jsx("em",{children:"Loading..."})}):l.jsxs(l.Fragment,{children:[l.jsx("strong",{children:"Not found!"})," The guide could not be loaded."]})}function Hj(){return $e("Guides"),l.jsxs(l.Fragment,{children:[l.jsx(sa,{style:{marginLeft:"40%",marginBottom:"1em"},children:"Guides"}),l.jsxs(kj,{style:{justifyContent:"space-around"},children:[l.jsx(qu,{imageSrc:"https://images.evetech.net/types/14268/icon",title:"DDD Guide",subtitle:"get GUD & Read",slug:"guide/ddd"}),l.jsxs(qu,{title:"Badges",subtitle:"Showing off u GUD",slug:"badges",children:[l.jsx(An,{type:"DPS",height:"30px"}),l.jsx(An,{type:"LOGI",height:"30px"}),l.jsx(An,{type:"ALT",height:"30px"})]}),l.jsx(qu,{imageSrc:"https://images.evetech.net/types/33400/icon",title:"Marauder Guide",subtitle:"Count to 2 and you gucci",slug:"guide/marauder"})]})]})}function qj(){return l.jsx(Mj,{})}const $j=()=>{const{t:i}=k();return l.jsxs(l.Fragment,{children:[l.jsx(Te,{style:{marginTop:"5em"},children:l.jsx(an,{to:"/legal",children:i("nav.legal","Legal")})}),l.jsx(ct,{children:l.jsxs(nn,{children:[l.jsx(nn.Head,{style:{marginBottom:"1em"},children:i("home.welcomeMessage","Welcome to a fork of TLA Waitlist, embedded into Alliance Auth. This App is still a work in progress and not every API call is implemented yet.")}),l.jsx(nn.Paragraph,{})]})})]})};function yx(i){const{i18n:r}=k();return d=>d==null?null:d.toLocaleString(r.language,{maximumFractionDigits:2,...i})}function Gj(i){var r=[];for(const o of i)$u.encode(Math.round(o),r,r.length);var d=85;for(const o of r)d^=o;return r.push(d),r=Lm.Buffer.from(r),r.toString("base64").replaceAll("+","-").replaceAll("/","_").replaceAll("=","")}function Yj(i){var r=Lm.Buffer.from(i,"base64"),d=0,u=0;for(const f of r)u^=f;if(u!==85)throw new Error("Checksum mismatch!");for(var o=[];d<r.byteLength-1;)o.push($u.decode(r,d)),d+=$u.decode.bytes;return o}function Xj(i){return"1"+Gj([i.isk,i.lp,i.sites,i.startTime,i.endTime-i.startTime,i.minTime,i.maxTime,i.chars,i.firstSitePayout])}function Qj(i){if(i[0]==="1"){const r=Yj(i.slice(1));return{isk:r[0],lp:r[1],sites:r[2],startTime:r[3],endTime:r[3]+r[4],minTime:r[5],maxTime:r[6],chars:r[7],firstSitePayout:r[8]||315e5}}else throw new Error("Cannot decode input")}function Vj(){var i={};for(const[d,u,o,f]of[["Mothership (HS)",63e6,14e3,80],["Mothership (LS/NS)",9e7,2e4,120],["HQ (HS)",315e5,7e3,40],["HQ (LS/NS)",45e6,1e4,60],["AS (HS)",182e5,3500,20],["AS (LS/NS)",26e6,5e3,30],["VG (HS)",10395e3,1400,10],["VG (LS/NS)",15e6,2e3,15],["Scout",35e5,400,5]])for(var r=0;r<11;r++){const m=1-.0725*r-.0025*r**2,g=Math.round(u*m);if(i[g])throw new Error("Two sites give the same payout?!");i[g]={siteType:d,payout:g,lp:Math.round(o*m),normalPayout:u,normalLp:o,onGrid:r?f+r:null}}return i}const Zj=Vj();function Kj(i){var r=[];for(const j of i.split(`
`)){var[d,u,o,,f]=j.split(/\t|\s{2,}/);if(!u||!f||!o||!o.match(/ISK/)||!(u.match(/reward payout/i)&&f.match(/concord/i)))continue;o=o.replace(/[.,]\d{2} /," "),o=o.replace(/\D/g,""),o=Math.round(parseFloat(o));const[E,O]=d.split(/ /),M=`${E.replaceAll(".","-")}T${O}Z`,L=new Date(M);r.push({time:L,value:o})}r=ue.sortBy(r,["time","value"]);var m=null,g=1,p=[],y={isk:0,lp:0,sites:0,chars:1,raw:[]};for(const j of r){m?m.getTime()!==j.time.getTime()?(p.push((j.time.getTime()-m.getTime())/1e3),m=j.time,g=1,y.sites+=1):(g+=1,y.chars<g&&(y.chars=g)):(m=j.time,y.sites+=1),y.isk+=j.value;const E=Zj[j.value];E&&(y.lp+=E.lp),y.raw.push({time:j.time.getTime()/1e3,isk:j.value,lp:E?E.lp:null,onGrid:E?E.onGrid:null})}return p.length<1?null:(y.minTime=Math.min(...p),y.maxTime=Math.max(...p),y.startTime=Math.min(...y.raw.map(j=>j.time)),y.endTime=Math.max(...y.raw.map(j=>j.time)),y.firstSitePayout=y.raw.find(j=>j.time===y.startTime).isk,y)}function Jj(){const[i,r]=K.useState(""),d=Kj(i),u=d?Xj(d):null,{t:o}=k(),f=yx();return $e(o("ISK/h")),l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:o("ISK/h calculator")}),l.jsxs("div",{style:{display:"flex"},children:[l.jsxs("div",{style:{flex:1,padding:"0.5em"},children:[l.jsx("em",{children:o("Go to your in-game wallet, select all incursion payouts, and hit Ctrl-C. Then, paste them here. Note: this calculator currently only works for English EVE clients.")}),l.jsx(Zt,{value:i,onChange:m=>r(m.target.value),rows:"10",style:{width:"100%"}}),l.jsx("div",{style:{padding:"1em"},children:l.jsx(vx,{dataStr:u})})]}),d&&l.jsx("div",{style:{flex:2,padding:"0.5em"},children:l.jsxs(Dn,{fullWidth:!0,children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(Fe,{children:o("Time")}),l.jsx(Fe,{children:o("ISK")}),l.jsx(Fe,{children:o("LP")}),l.jsx(Fe,{children:o("On grid")})]})}),l.jsx(On,{children:d.raw.map((m,g)=>l.jsxs(Oe,{children:[l.jsx(I,{children:wl(new Date(m.time*1e3))}),l.jsx(I,{children:f(m.isk)}),l.jsx(I,{children:f(m.lp)}),l.jsx(I,{children:f(m.onGrid)})]},g))})]})})]})]})}function Fj(){const r=new URLSearchParams(sn().search).get("d")||"",{t:d}=k();return l.jsxs(l.Fragment,{children:[l.jsx("div",{children:l.jsx(an,{exact:!0,to:"/isk-h/calc",children:d("Calculator")})}),l.jsx("div",{style:{display:"flex",justifyContent:"center"},children:l.jsx(vx,{dataStr:r})})]})}const Wj=T.div`
  ${i=>`
    max-width: 500px;
    border-radius: 10px;
    text-align: center;
    border: solid 1px ${i.theme.colors.accent4};

    > h1 {
      margin-top: 0.5em;
      font-size: 2em;
      font-weight: 600;
      filter: drop-shadow(0px 1px 1px ${i.theme.colors.shadow});
    }
    > h2 {
      font-size: 1.5em;
      font-weight: 600;
    }
    > * {
      padding-left: 1em;
      padding-right: 1em;
    }

    hr {
      border: 0;
      margin-top: 0.75em;
    }
    p:last-child {
      border-top: solid 1px ${i.theme.colors.accent3};
      font-size: 0.8em;
      margin-top: 1em;
      margin-bottom: 0.3em;
    padding-top: 0.3em;
    &:hover:not(:disabled):not(.static) {
    color: ${i.theme.colors.accent4};
    cursor: pointer;
    }
    }
    a {
      color: ${i.theme.colors.text};
      text-decoration: none;
    }
  `}
`;function vx({dataStr:i}){const r=K.useContext(oe),{t:d}=k(),u=yx();if(!i)return null;var o;try{o=Qj(i)}catch{return l.jsx("em",{children:d("Failed to load results")})}const f=o.endTime-o.startTime,m=Math.round((o.isk-o.firstSitePayout)/(f/3600)),g=`${window.location.origin}/incursions/waitlist/isk-h?d=${encodeURIComponent(i)}`;return l.jsx(l.Fragment,{children:l.jsxs(Wj,{children:[l.jsxs("h1",{children:[u(m)," ",d("ISK/h")]}),l.jsxs("h2",{children:[u(o.isk)," ISK + ",u(o.lp)," LP"]}),l.jsx("hr",{}),l.jsxs("p",{children:[u(o.sites)," ",d("sites completed")]}),o.chars>1&&l.jsxs("p",{children:[u(o.chars)," ",d("characters included in payout calculation")]}),l.jsx("hr",{}),l.jsxs("p",{children:[la(o.minTime)," ~ ",la(o.maxTime)," (",d("average")," ",la(Math.round(f/(o.sites-1))),")"]}),l.jsxs("p",{children:[wl(new Date(o.startTime*1e3))," ++ ",la(f)]}),l.jsx("p",{onClick:()=>{px(r,g)},children:g})]})})}const Ij=()=>{const{t:i}=k();return $e(i("legal.title","Legal Notice")),l.jsxs(ct,{children:[l.jsx("h2",{children:i("legal.ccpTitle","CCP Copyright Notice")}),l.jsx("p",{children:i("legal.ccpText","EVE Online and the EVE logo are the registered trademarks of CCP hf. All rights are reserved worldwide. All other trademarks are the property of their respective owners. EVE Online, the EVE logo, EVE and all associated logos and designs are the intellectual property of CCP hf. All artwork, screenshots, characters, vehicles, storylines, world facts or other recognizable features of the intellectual property relating to these trademarks are likewise the intellectual property of CCP hf. CCP hf. has granted permission to the Alliance Auth team to use EVE Online and all associated logos and designs for promotional and information purposes on its website but does not endorse, and is not in any way affiliated with, the Alliance Auth team. CCP is in no way responsible for the content on or functioning of this website, nor can it be liable for any damage arising from the use of this website.")}),l.jsxs("p",{children:[i("legal.aaNotice","The source code for AA Incursions and this Waitlist Module is available under the MIT license. The source code and full text for this license can be found "),l.jsx("a",{href:"https://gitlab.com/tactical-supremacy/aa-incursions",children:i("legal.aaLinkText","here")}),"."]}),l.jsxs("p",{children:[i("legal.tlaNotice","This Waitlist Module is a fork of TLA Waitlist, which is also available under the MIT license. The source code and full text for this license can be found "),l.jsx("a",{href:"https://github.com/luna-duclos/tla-waitlist",children:i("legal.tlaLinkText","here")}),"."]})]})},Pj="/static/incursions/waitlist/media/dead.jpg",e1=T.div`
  margin: 0 0 0.5em;
  display: flex;
  background-color: ${i=>i.theme.colors.secondary.color};
  color: ${i=>i.theme.colors.secondary.text};
  width: 100%;
  filter: drop-shadow(0px 4px 5px ${i=>i.theme.colors.shadow});
  padding: 0.1em 0.5em 0.5em;
  align-items: center;
  word-break: break-word;

  svg {
    font-size: 32px;
    margin: 5px;
    flex-shrink: 1;
  }

  div {
    flex-grow: 3;

    h3 {
      font-size: 1.5em;
      font-weight: 600;
    }
  }

  a {
    color: white;
  }
`;T.div`
  svg:first-of-type {
    font-size: 50px;
    display: block;
    margin: 10vh auto 20px auto;
  }
  h1 {
    font-size: 1.6em;
    text-align: center;
    margin-bottom: 12px;
  }
  p {
    display: block;
    margin: 0 auto 15px auto;
    max-width: 500px;
    text-align: center;
  }
`;T.div`
  position: absolute;
  height: 100vh;
  width: 100vw;
  top: 0;
  left: 0;
  z-index: 10;
  background: url(${Pj}) no-repeat;
  background-size: cover;
  color: #d5d5d5;

  h1 {
    text-align: center;
    margin-top: 30vh;
    font-size: revert;
    font-weight: bolder;
  }

  p {
    text-align: center;
    max-width: 300px;
    margin-left: auto;
    margin-right: auto;
  }
`;const t1=({bans:i})=>{var f,m,g,p;const{t:r}=k(),d=w.useContext(ze),u=i==null?void 0:i.find(y=>!y.revoked_at||new Date(y.revoked_at)>new Date);return!(((f=d==null?void 0:d.access)==null?void 0:f["incursions.waitlist_bans_view"])||((m=d==null?void 0:d.access)==null?void 0:m["incursions.waitlist_bans_manage"]))||!u?null:l.jsxs(e1,{children:[l.jsx(ie,{fixedWidth:!0,icon:xc}),l.jsxs("div",{children:[l.jsx("h3",{children:r("{{category}} Suspended",{category:(g=u.entity)==null?void 0:g.category})}),l.jsx("p",{children:r("Issued on: {{date}} by {{issuer}}.",{date:zi(new Date(u.issued_at)),issuer:((p=u.issued_by)==null?void 0:p.name)??""})}),u.revoked_at&&l.jsx("p",{children:r("Expires in {{time}}.",{time:gc(new Date(u.revoked_at))})}),l.jsx("p",{children:u.reason})]})]})};function n1({summary:i}){const{t:r}=k();if(!i)return null;if(!i.length)return l.jsx("em",{children:r("Never seen before")});const d=ue.sum(i.map(({time_in_fleet:u})=>u));return l.jsx(Dn,{fullWidth:!0,edgeLine:!0,style:{marginBottom:"2em"},children:l.jsxs(On,{children:[l.jsxs(Oe,{children:[l.jsx(Fe,{children:r("Total")}),l.jsx(Fe,{children:la(d)})]}),i.map(({ship:u,time_in_fleet:o})=>l.jsxs(Oe,{children:[l.jsx(I,{children:r(u.name)}),l.jsx(I,{children:la(o)})]},u.id))]})})}const a1=T.div`
  span {
    display: none;
  }

  div {
    display: inline-block;
    height: 2rem;
    width: 2rem !important;
    vertical-align: text-bottom;
    margin: 15px auto;

    background-color: ${({theme:i})=>i.colors.accent3};
    border-radius: 50%;
    opacity: 0;
    animation: spinner-grow 0.75s linear infinite;
    -webkit-animation: spinner-grow 0.75s linear infinite;
  }

  @keyframes spinner-grow {
    0% {
      transform: scale(0);
    }
    50% {
      opacity: 1;
      transform: none;
    }
  }
`,l1=()=>{const{t:i}=k();return l.jsxs(a1,{children:[l.jsx("div",{}),l.jsx("span",{children:i("Loading...")})]})},Nm=T.div`
  margin-bottom: 25px;

  div {
    padding: 5px;
    width: 100%;
  }

  button {
    padding: 5px;
    font-size: 10px;
    margin-left: 5px;
  }
`;async function i1(i,r){return await Qe("/incursions/api/open_window",{json:{target_id:i,character_id:r}})}const s1=i=>{const r=w.useContext(ze);return r!=null&&r.access["incursions.waitlist_alts_view"]?l.jsx(c1,{characterId:i.character}):null},c1=({characterId:i=0})=>{const r=w.useContext(ze),{t:d}=k(),u=i!==0?`/incursions/api/pilot/alts?character_id=${i}`:null,[o]=Le(u);return i===0?l.jsxs(Nm,{children:[l.jsx(Me,{children:d("Known Alt Characters")}),l.jsx("em",{style:{fontSize:"smaller"},children:d("No character selected.")})]}):l.jsxs(Nm,{children:[l.jsxs(Me,{children:[d("Known Alt Characters"),l.jsx(ie,{fixedWidth:!0,icon:N0,style:{marginLeft:"5px"},title:d("Only characters that the pilot has linked are shown below. Characters are unlinked when the user clicks logout.")})]}),o?o.length>0?o.map((f,m)=>l.jsxs("div",{children:[l.jsx(dt,{...f}),l.jsx(Y,{title:d("Open Show Info Window"),onClick:()=>re(oe,i1(f.character_id,r.current.character_id)),children:l.jsx(ie,{fixedWidth:!0,icon:Ri})})]},m)):l.jsx("em",{style:{fontSize:"smaller"},children:d("Pilot has no known alts.")}):l.jsx(l1,{})]})},r1=T.a`
  cursor: pointer;
  text-decoration: underline;
`,Ea=T.div`
  display: flex;

  border-bottom: solid 1px ${i=>i.theme.colors.accent2};
  &:first-child {
    border-top: solid 1px ${i=>i.theme.colors.accent2};
  }
  &:nth-child(odd) {
    background-color: ${i=>i.theme.colors.accent1};
  }
`;Ea.Time=T.div`
  flex: 0 0 200px;
  padding: 0.5em;
  @media (max-width: 480px) {
    width: 40%;
    flex: unset;
  }
`;Ea.Icon=T.div`
  flex: 0 0 auto;
  padding: 0.5em;
`;Ea.Content=T.div`
  flex: 1;
  padding: 0.5em;
`;function Hi({time:i,icon:r,children:d}){return l.jsxs(Ea,{children:[l.jsx(Ea.Icon,{children:r&&l.jsx(ie,{fixedWidth:!0,icon:r})}),l.jsx(Ea.Time,{children:wl(new Date(i*1e3))}),l.jsx(Ea.Content,{children:d})]})}function u1({issued_at:i,issued_by:r,reason:d,public_reason:u,revoked_at:o,revoked_by:f}){const{t:m}=k(),g=!o;return l.jsx(Hi,{time:i,icon:xc,children:l.jsxs(ct,{children:[l.jsxs("p",{children:[m(g?"Permanent":"Temporary")," ",m("ban"),", ",m("issued by"),":"," ",l.jsx(dt,{...r,avatar:!1}),"."]}),!g&&!f&&l.jsxs("p",{children:[m("Expires"),": ",gc(new Date(o*1e3)),"."]}),!g&&f&&l.jsxs("p",{children:[m("Revoked by"),": ",l.jsx(dt,{...f,avatar:!1})," ",m("on the")," ",zi(new Date(o*1e3)),"."]}),l.jsxs("p",{style:{marginBottom:"2px",fontWeight:"600"},children:[m("Reason"),":"]}),l.jsx("p",{children:d}),u&&l.jsxs(l.Fragment,{children:[l.jsx("p",{style:{marginBottom:"2px",fontWeight:"600"},children:m("Public Reason")}),l.jsx("p",{children:u})]})]})})}function o1({logged_at:i,ship:r,dna:d,implants:u}){const[o,f]=K.useState(!1);return l.jsxs(Hi,{time:i,icon:Xm,children:[o&&l.jsx(qe,{open:!0,setOpen:f,children:l.jsx(Ce,{style:{display:"flex"},children:l.jsx(lo,{fit:{dna:d,implants:u,fit_analysis:{name:r.name}}})})}),l.jsx(r1,{onClick:()=>f(!0),children:r.name})]})}function d1({logged_at:i,ship:r,time_in_fleet:d}){return l.jsxs(Hi,{time:i,icon:Qm,children:[l.jsx("span",{style:{display:"inline-block",minWidth:"40%",marginRight:"0.5em"},children:r.name}),l.jsx("span",{children:la(d)})]})}function f1({logged_at:i,name:r,old_level:d,new_level:u}){const{t:o}=k();var f=d>u?"danger":d===u?"":"success";return l.jsxs(Hi,{time:i,icon:Ku,children:[l.jsx("span",{style:{display:"inline-block",minWidth:"40%",marginRight:"0.5em"},children:o(r)}),l.jsxs(Yt,{$variant:f,children:[d," -> ",u]})]})}function h1({logged_at:i,author:r,note:d}){const{t:u}=k();return l.jsx(Hi,{time:i,icon:Vm,children:l.jsxs(ct,{children:[l.jsxs("p",{children:[u("Note written by")," ",l.jsx("strong",{children:r.name})]}),l.jsx(Rm,{children:d})]})})}const m1=T.div`
  margin-bottom: 2em;
`;function x1({filter:i,banHistory:r,fleetHistory:d,skillHistory:u,xupHistory:o,notes:f}){const{t:m}=k();var g=[],p=0;for(const M of r||[])p++,g.push({key:`ban-${p}`,entry:M,time:M.issued_at,type:"ban"});p=0;for(const M of o||[])p++,g.push({time:M.logged_at,type:"fit",entry:M,key:`fit-${p}`});p=0;for(const M of d||[])p++,g.push({time:M.logged_at,endTime:M.logged_at+M.time_in_fleet,type:"fleet",entry:M,key:`fleet-${p}`});p=0;for(const M of u||[])p++,g.push({time:M.logged_at,type:"skill",entry:M,key:`skill-${p}`});p=0;for(const M of f||[])p++,g.push({time:M.logged_at,type:"note",entry:M,key:`note-${p}`});i!==null&&(g=g.filter(M=>i(M.type))),g=ue.sortBy(g,["time"]);var y=[],j=null,E=null;for(const{time:M,entry:L,type:q,endTime:U,key:G}of g)(j===null||E<M)&&(j=[],y.push({key:M,group:j})),E=(U||M)+3*3600,q==="ban"?j.push(l.jsx(u1,{...L},G)):q==="fit"?j.push(l.jsx(o1,{...L},G)):q==="fleet"?j.push(l.jsx(d1,{...L},G)):q==="skill"?j.push(l.jsx(f1,{...L},G)):q==="note"&&j.push(l.jsx(h1,{...L},G));var O=[];y.reverse();for(const{group:M,key:L}of y)M.reverse(),O.push(l.jsx(m1,{children:M},L));return O.length?l.jsx("div",{children:O}):l.jsx("div",{children:l.jsx("em",{children:m("No logged history")})})}function g1({filter:i,banHistory:r,fleetHistory:d,skillHistory:u,xupHistory:o,notes:f}){return l.jsx(x1,{filter:i,banHistory:r,fleetHistory:d,skillHistory:u,xupHistory:o,notes:f})}const p1=T.span`
  font-size: 0.75em;
  margin-left: 2em;

  a {
    cursor: pointer;
    padding: 0 0.2em;
  }
`;async function y1(i,r){return await Qe("/incursions/api/open_window",{json:{target_id:i,character_id:r}})}function v1(){const i=K.useContext(ze),{t:r}=k();return i?l.jsx(b1,{authContext:i}):l.jsxs(ct,{children:[l.jsx("b",{children:r("Login Required!")}),l.jsx("p",{children:r("This page will show you your own Fleet statistics like x-up's, fleet times and skill changes.")})]})}const j1=T.div`
  display: flex;
  align-items: center;
  padding-bottom: 30px;

  @media (max-width: 400px) {
    flex-direction: column;
  }

  img {
    border-radius: 50%;
    height: 100px;
    width: 100px;
    margin-right: 10px;
    vertical-align: bottom;

    @media (max-width: 400px) {
      margin-right: 0px;
    }
  }

  div:first-of-type {
    display: flex;
    flex-direction: column;

    div:first-of-type {
      display: flex;
      flex-direction: row;

      @media (max-width: 400px) {
        flex-direction: column;
        padding-bottom: 15px;

        h1 {
          text-align: center;
        }
      }

      h1 {
        font-size: 1.9em;
        margin-right: 10px;
      }
    }
  }
`;function b1({authContext:i}){const{t:r}=k();var u=new URLSearchParams(sn().search).get("character_id")||i.current.character_id;const[o,f]=K.useState(null),[m,g]=Le(`/incursions/api/pilot/info?character_id=${u}`),[p]=Le(`/incursions/api/history/fleet?character_id=${u}`),[y]=Le(i.access["incursions.waitlist_bans_view"]||i.access["incursions.waitlist_bans_manage"]?`/incursions/api/bans/${u}`:null),[j]=Le(`/incursions/api/history/xup?character_id=${u}`),[E]=Le(`/incursions/api/history/skills?character_id=${u}`),[O]=Le(i.access["incursions.waitlist_notes_view"]||i.access["incursions.waitlist_notes_manage"]?`/incursions/api/notes?character_id=${u}`:null);return $e(r("Pilot")),l.jsxs(l.Fragment,{children:[(i.access["incursions.waitlist_bans_view"]||i.access["incursions.waitlist_bans_manage"])&&l.jsx(t1,{bans:y}),l.jsxs(j1,{children:[(m==null?void 0:m.character.character_id)!==1&&l.jsx("img",{src:`https://images.evetech.net/characters/${m==null?void 0:m.character.character_id}/portrait?size=128`,alt:r("Character Portrait")}),l.jsxs("div",{children:[l.jsx("div",{children:l.jsx("h1",{children:m==null?void 0:m.character.character_name})}),l.jsx(ix,{style:{flexWrap:"flex"},tags:m==null?void 0:m.tags})]})]}),i.account_id!==u&&l.jsxs(Te,{style:{marginBottom:"20px"},children:[i.access["incursions.waitlist_notes_manage"]&&l.jsx(an,{to:`/fc/notes/add?character_id=${u}`,children:r("Write note")}),i.access["incursions.waitlist_badges_manage"]&&l.jsx(xx,{character:m??{id:parseInt(u),name:""},refreshData:g}),i.access["incursions.waitlist_esi_show_info"]&&l.jsxs(Y,{title:r("Open Show Info Window"),onClick:()=>re(oe,y1(m.id,i.current.character_id)),children:[r("Show Info")," ",l.jsx(ie,{fixedWidth:!0,icon:Ri})]})]}),l.jsxs(hc,{children:[l.jsxs(Sl,{xs:4,md:6,children:[l.jsxs(Me,{children:[r("History"),l.jsxs(p1,{children:[l.jsx("a",{onClick:()=>f(null),style:{marginRight:"0.5em"},title:r("Clear Filters"),children:l.jsx(ie,{fixedWidth:!0,icon:Zu})}),l.jsx("a",{onClick:()=>f("skill"),title:r("Skill History"),children:l.jsx(ie,{fixedWidth:!0,icon:Ku})}),l.jsx("a",{onClick:()=>f("fit"),title:r("X-UP History"),children:l.jsx(ie,{fixedWidth:!0,icon:Xm})}),l.jsx("a",{onClick:()=>f("fleet"),title:r("Fleet History"),children:l.jsx(ie,{fixedWidth:!0,icon:Qm})}),(i.access["incursions.waitlist_notes_view"]||i.access["incursions.waitlist_notes_manage"])&&l.jsx("a",{onClick:()=>f("note"),title:r("Pilot Notes"),children:l.jsx(ie,{fixedWidth:!0,icon:Vm})}),(i.access["incursions.waitlist_bans_view"]||i.access["incursions.waitlist_bans_manage"])&&l.jsx("a",{onClick:()=>f("ban"),title:r("Character Ban History"),children:l.jsx(ie,{fixedWidth:!0,icon:xc})})]})]}),l.jsx(g1,{filter:o?M=>M===o:null,banHistory:y,fleetHistory:p&&p.activity,skillHistory:E&&E.history,xupHistory:j&&j.xups,notes:O&&O.notes})]}),l.jsxs(Sl,{xs:4,md:2,children:[l.jsx(Me,{children:r("Time in fleet")}),l.jsx(n1,{summary:p&&p.summary}),l.jsx(s1,{character:m==null?void 0:m.character.character_id})]})]})]})}const S1="/static/incursions/waitlist/media/skillqueue.png";function w1(){const i=K.useContext(ze),{t:r}=k();return i?l.jsx(_1,{authContext:i}):l.jsxs(ct,{children:[l.jsx("b",{children:r("Login Required!")}),l.jsx("p",{children:r("This page will show copyable skill plan tables comparing to your current skills with checkmarks next to already completed skills.")})]})}function _1({authContext:i}){const[{plan:r}]=ro(),[d]=Le("/incursions/api/skills/plans"),[u]=Le(`/incursions/api/skills/${i.current.character_id}`),{t:o}=k();if(!d||!u)return l.jsx("em",{children:o("Loading...")});if(r){const f=ue.find(d.plans,m=>m.source.name===r);return f?l.jsx(C1,{plan:f,mySkills:u}):l.jsx("em",{children:o("Plan not found")})}return l.jsx(E1,{plans:d.plans,mySkills:u})}function jx(i){if(i===1)return"I";if(i===2)return"II";if(i===3)return"III";if(i===4)return"IV";if(i===5)return"V";throw new Error("Unlikely skill numeral")}function T1(i,r){return i.map(([d,u])=>`${r[d]||"MISSING SKILL"} ${jx(u)}`).join(`
`)}function C1({plan:i,mySkills:r}){const d=K.useContext(oe),[u,o]=K.useState(!1),{t:f}=k();var m=[],g=ue.invert(r.ids);return ue.forEach(i.levels,([p,y])=>{const j=g[p],E=r.current[p];m.push(l.jsxs(Oe,{children:[l.jsxs(I,{children:[j||f("MISSING SKILL")," ",jx(y)]}),l.jsx(I,{children:E>=y?l.jsx(ie,{icon:Gm}):null})]},`${p} ${y}`))}),$e(zy(i.source.name)),l.jsxs(hc,{children:[l.jsxs(Sl,{xs:4,md:4,children:[l.jsx(Mt,{children:l.jsx(jt,{exact:!0,to:"/skills/plans",style:{textDecoration:"inherit",color:"inherit"},children:l.jsx(Y,{children:f("Back")})})}),l.jsxs(ct,{children:[l.jsx("h2",{children:i.source.name}),l.jsx("p",{children:i.source.description}),l.jsx("div",{style:{marginTop:"2em"},children:i.ships.map(p=>l.jsx("img",{src:`https://images.evetech.net/types/${p.id}/render?size=128`,style:{maxWidth:"128px",margin:"0.5em"},alt:p.name,title:p.name},p.id))})]})]}),l.jsxs(Sl,{xs:4,md:4,children:[l.jsxs("p",{style:{marginBottom:"1em"},children:[l.jsx(Y,{onClick:()=>{F0(d,navigator.clipboard.writeText(T1(i.levels,g)).then(()=>f("Copied to clipboard")))},children:l.jsx(ie,{icon:$m})})," ",l.jsx("a",{style:{textDecoration:"underline",cursor:"pointer"},onClick:()=>o(!0),children:f("How do I use this?")})]}),l.jsxs(Dn,{children:[l.jsx(Ma,{children:l.jsxs(Oe,{children:[l.jsx(Fe,{children:f("Skill")}),l.jsx(Fe,{})]})}),l.jsx(On,{children:m})]})]}),l.jsx(qe,{open:u,setOpen:o,children:l.jsx("img",{alt:f("Explanation for using the skill queue"),src:S1})})]})}const A1=T.div`
  border: solid 2px ${i=>i.theme.colors.secondary.color};
  line-height: 0;
  padding: 0.1em;
  justify-content: center;
  border-radius: 5px;
  max-width: fit-content;
  img {
    margin: 1px;
    border-radius: 3px;
    max-width: 31px;
  }
`;function E1({plans:i,mySkills:r}){const{t:d}=k();return $e(d("Skill Plans")),l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:d("Skill plans")}),l.jsx(hx,{children:i.map(u=>l.jsx(co,{children:l.jsx(jt,{exact:!0,to:`/skills/plans?plan=${u.source.name}`,style:{textDecoration:"inherit",color:"inherit"},children:l.jsxs(mx,{title:u.source.name,children:[l.jsx(A1,{children:u.ships.map(o=>l.jsx("img",{src:`https://images.evetech.net/types/${o.id}/icon?size=64`,alt:o.name,title:o.name},o.id))}),l.jsx("p",{children:u.source.description})]})})},u.source.name))})]})}function D1(){const{t:i}=k(),r=K.useContext(ze);return r?l.jsx(O1,{authContext:r}):l.jsxs(ct,{children:[l.jsx("b",{children:i("Login Required!")}),l.jsx("p",{children:i("This page will show tables with TDF related skills comparing to your current skills with a color indicating the progres tier that skill is at.")})]})}function O1({authContext:i}){const{t:r}=k(),d=new URLSearchParams(sn().search),u=mc();var o=d.get("character_id")||i.current.character_id,f=d.get("ship")||"Vindicator";const[m]=Le(`/incursions/api/pilot/info?character_id=${o}`),g=p=>{d.set("ship",p),u({search:`?${d.toString()}`})};return $e(r("{{ship}} Skills",{ship:f})),l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:m?r("Skills for {{name}}",{name:m.character.character_name}):r("Skills")}),l.jsx(io,{characterId:o,ship:f,setShip:g})]})}const M1="[Paladin, Paladin]...".trim(),z1="bringing 1 alt".trim(),B1=T.div`
  display: flex;
  @media (max-width: 1100px) {
    display: block;
  }
`,bx=({setXupOpen:i})=>{$e("X-up");const{t:r}=k(),d=w.useContext(oe),u=w.useContext(ze),f=new URLSearchParams(sn().search).get("wl"),[m,g]=w.useState(""),[p,y]=w.useState(""),[j,E]=w.useState(!1),[O,M]=w.useState(!1),[L]=Ju(`/incursions/api/implants?character_id=${u.current.character_id}`),q=!1,U=w.useMemo(()=>100-p.length,[p]),G=w.useCallback(async()=>{E(!0),re(d,R1({character:u.current.character_id,eft:m,toastContext:d,waitlistId:f,alt:q,messagexup:p}).then(()=>M(!0))).finally(()=>E(!1))},[m,p,u,d,f,q]);return f?O?l.jsx(N1,{waitlistId:f,setOpen:M,setXupOpen:i}):l.jsxs(B1,{children:[l.jsxs(ct,{style:{flex:1},children:[l.jsx("h2",{children:r("X-up with fit(s)")}),l.jsx(Zt,{placeholder:M1,rows:15,onChange:Q=>g(Q.target.value),value:m,style:{width:"100%",marginBottom:"1em"}}),l.jsxs("div",{style:{marginBottom:"1em"},children:[l.jsx("h2",{children:r("X-up message (optional)")}),l.jsx(Zt,{placeholder:z1,rows:1,onChange:Q=>y(Q.target.value),value:p,style:{width:"100%"}}),l.jsxs("div",{children:[r("Characters left"),": ",U>=0?U:r("Too long")]})]}),l.jsxs(Te,{children:[l.jsx(Y,{static:!0,children:u.current.character_name}),l.jsx(Y,{$variant:"success",onClick:G,disabled:m.trim().length<50||!m.startsWith("[")||j||p.length>100,children:r("X-up")})]})]}),l.jsx(Ce,{style:{flex:1,marginTop:"1em"},children:L&&l.jsx(cx,{implants:L.implants,name:`${u.current.character_name}'s capsule`})})]}):l.jsx("em",{children:r("Missing waitlist information")})},N1=({waitlistId:i,setOpen:r,setXupOpen:d})=>{const{t:u}=k(),o=w.useContext(ze),[f]=Ju("/incursions/api/waitlist");if(!f)return l.jsx("em",{children:u("Loading")});const m=f.waitlist.find(g=>{var p;return((p=g.character)==null?void 0:p.character_id)===o.current.character_id});return l.jsxs(l.Fragment,{children:[l.jsx(sa,{children:u("Fit review")}),l.jsx("em",{children:u("You are now on the waitlist! These are the fits you x-ed up with, please check to make sure you have everything and adjust your fit if needed.")}),m==null?void 0:m.fits.map(g=>l.jsx(Ce,{children:l.jsx(lo,{fit:g})},g.id)),l.jsxs(Mt,{children:[l.jsx(Y,{$variant:"primary",onClick:()=>d(!1),children:u("Yes, looks good")}),l.jsx(Y,{$variant:"secondary",onClick:()=>r(!1),children:u("No, go back to update my fit")})]})]})};async function R1({character:i,eft:r,toastContext:d,waitlistId:u,alt:o,messagexup:f}){const m={eft:r,character_id:i,waitlist_id:parseInt(u),is_alt:o,messagexup:f};await He("/incursions/api/waitlist/xup","post",{body:m}),ln(d,{title:"Added to waitlist.",message:"Your X has been added to the waitlist!",variant:"success"}),window.Notification&&Notification.requestPermission()}function U1(i){return i.waitlist.map(r=>{const d=[],u={};if(!r.character)return"";for(const o of r.fits){if(!o.character)continue;let f=u[o.character.character_id];f||(f={character:o.character,fits:[]},d.push(f),u[o.character.character_id]=f),f.fits.push(o)}return d.map(o=>{const f=`<a href="showinfo:1377//${o.character.character_id}">${o.character.name}</a>`,m=o.fits.map(g=>{const p=g.approved?"":", CHECK FIT";return`${g.ship.name[0]}${p}`});return f+" "+m.join(", ")}).join(" | ")}).join(`
`)}function k1({waitlist:i}){const{t:r}=k();return l.jsxs(ct,{children:[l.jsx("h2",{children:r("Notepad waitlist")}),l.jsxs("p",{children:[l.jsx("strong",{children:r("What is this?!")})," ",r("When ESI is having trouble, the Invite button may not always work. To invite manually, or to switch to a channel-based waitlist, you can copy the existing waitlist into a notepad or channel MOTD by copying the code below. It will make the names linkable so that they can be invited by dragging into the fleet composition.")]}),l.jsx(Zt,{readOnly:!0,style:{width:"100%"},rows:15,children:U1(i)})]})}const L1=g0`
  to {
    transform: rotate(360deg);
  }
`,H1=T.div`
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
`,q1=T.div`
  width: 4rem;
  height: 4rem;
  border-radius: 50%;
  border: 0.2rem solid ${i=>i.theme.colors.accent1};
  border-top-color: ${i=>i.theme.colors.text};
  animation: ${L1} 1.5s linear infinite;
  box-shadow: 0px -12px 8px -5px ${i=>i.theme.colors.text}40;
`,$1=()=>{const[i,r]=w.useState(!1),{t:d}=k();return l.jsxs(nn,{style:{width:"100%"},children:[l.jsx(nn.Head,{style:{marginBottom:"1em"},children:d("We apologize, the waitlist is currently closed.")}),l.jsx(nn.Paragraph,{style:{width:"50%"},children:d("Thank you for your patience. A fleet commander will be available shortly. Please stand by...")}),l.jsxs(nn.Paragraph,{style:{width:"50%"},children:[l.jsx(H1,{children:l.jsx(q1,{})}),l.jsx("div",{style:{display:"flex",alignItems:"center",justifyContent:"center",marginTop:"1.5em"},children:l.jsx(Te,{children:l.jsx(Y,{onClick:()=>r(!0),children:d("Click here to Ping FC's for Fleet")})})})]}),i&&l.jsx("iframe",{title:"Never Gonna Give You Up",width:"560",height:"315",src:"https://www.youtube-nocookie.com/embed/dQw4w9WgXcQ?autoplay=1&controls=0",frameBorder:"0",allow:"autoplay; encrypted-media; picture-in-picture",allowFullScreen:!0})]})},G1=T.div`
  width: 100%;
`,Y1=T.div`
  display: flex;
  width: 100%;
  justify-content: center;
  margin-top: 1em;
  @media (max-width: 1100px) {
    flex-wrap: wrap;
  }
`,X1=T.div`
  width: 70%;
  @media (max-width: 970px) {
    width: 100%;
  }
`;function Sx(i,r){let d=null,u=null;const o=()=>{if(u=setTimeout(o,r),d){const[f,m]=d;d=null,i.apply(f,m)}};return u=setTimeout(o,r*Math.random()),[function(...f){d=[this,arguments]},()=>{u&&clearTimeout(u)}]}async function Q1(i){await Qe("/incursions/api/waitlist/remove_x",{json:{id:i}})}function V1(i){const r=w.useContext(_l),[d,u]=Le("/incursions/api/waitlist");return w.useEffect(()=>{if(!r)return;const[o,f]=Sx(u,2e3),m=g=>{JSON.parse(g.data).waitlist_id===i&&o()};return r.addEventListener("waitlist_update",m),r.addEventListener("open",o),()=>{f(),r.removeEventListener("waitlist_update",m),r.removeEventListener("open",o)}},[u,r,i]),[d,u]}function Z1(){const i=w.useContext(ze),r=w.useContext(_l),[d,u]=w.useState(null),o=w.useCallback(()=>{if(!i.access["incursions.waitlist_fleet_view"]){u(null);return}He("/incursions/api/fleet/members","get",{params:{character_id:i.current.character_id}}).then(u).catch(()=>u(null))},[i]);return w.useEffect(()=>{o()},[o]),w.useEffect(()=>{if(!r)return;const[f,m]=Sx(o,2e3);return r.addEventListener("comp_update",f),r.addEventListener("open",f),()=>{m(),r.removeEventListener("comp_update",f),r.removeEventListener("open",f)}},[o,r]),d}function K1(){var be;const{t:i}=k(),r=w.useContext(ze),d=w.useContext(oe),[u,o]=ro(),[f,m]=w.useState(((be=window.localStorage)==null?void 0:be.getItem("FleetStat"))==="true"),[g,p]=w.useState(!0),[y,j]=w.useState(!1),E=w.useMemo(()=>parseInt(u.wl),[u.wl]),[O,M]=V1(E),L=Z1(),q=u.mode||"columns";if($e(i("Waitlist")),w.useEffect(()=>{E||o("wl",1)},[E,o]),w.useEffect(()=>{p(!0)},[r.current.character_id]),!E)return null;if(O===null)return l.jsx("em",{children:i("Loading waitlist information.")});if(!O.open)return l.jsx($1,{});var U=ue.find(O.waitlist,te=>te.character&&te.character.character_id===r.current.character_id);const G=()=>{var W;const te=!f;m(te),(W=window.localStorage)==null||W.setItem("FleetStat",JSON.stringify(te))},Q=te=>{o("mode",te)};return l.jsxs(l.Fragment,{children:[l.jsx(Ca,{children:l.jsxs(Mt,{children:[l.jsxs(Te,{children:[y&&l.jsx(qe,{open:!0,setOpen:j,fill:"true",children:l.jsx(G1,{children:l.jsx(Ce,{children:l.jsx(bx,{setXupOpen:j})})})}),l.jsx(Im,{$variant:U?void 0:"primary",onClick:()=>j(!0),children:i(U?"Update fit(s)":"Join waitlist")}),l.jsx(Y,{$variant:U?"danger":void 0,onClick:()=>re(d,Q1(U.id)),disabled:!U,children:i("Leave waitlist")})]}),r.access["incursions.waitlist_manage_waitlist"]&&l.jsxs(l.Fragment,{children:[l.jsx(Te,{children:["columns","matrix","compact","linear","rows"].map(te=>l.jsx(Y,{active:q===te,onClick:()=>Q(te),children:i(te.charAt(0).toUpperCase()+te.slice(1))},te))}),l.jsx(Te,{children:l.jsx(Y,{active:q==="notepad",onClick:()=>Q("notepad"),children:i("Notepad")})}),l.jsx(Te,{children:l.jsx(Y,{onClick:G,children:i(f?"Disable Fleet Stats":"Enable Fleet Stats")})})]})]})}),l.jsx(Ca,{children:l.jsxs(Y1,{children:[l.jsxs(X1,{children:[q==="columns"&&l.jsx(zv,{waitlist:O,onAction:M,fleetComposition:L,authContext:r,showMembers:f}),q==="compact"&&l.jsx(Nv,{waitlist:O,onAction:M}),q==="linear"&&l.jsx(Rv,{waitlist:O,onAction:M}),q==="matrix"&&l.jsx(kv,{waitlist:O,onAction:M,fleetComposition:L}),q==="rows"&&l.jsx(Lv,{waitlist:O,onAction:M,fleetComposition:L}),q==="notepad"&&l.jsx(k1,{waitlist:O,onAction:M})]}),f&&g&&r.access["incursions.waitlist_fleet_view"]&&l.jsx(fx,{fleetpage:!1,setStatTempActive:p})]})})]})}const vt=({component:i,loginRequired:r=!1,access:d=null})=>{const u=w.useContext(ze);return!r&&!d?i:u?d&&!(Array.isArray(d)?d:[d]).some(m=>{var g;return(g=u.access)==null?void 0:g[m]})?l.jsx(Ry,{}):i:l.jsx(Ny,{})};function J1(){return l.jsxs(Wp,{children:[l.jsx(je,{path:"/",element:l.jsx($j,{})}),l.jsx(je,{path:"/fits",element:l.jsx(Ej,{})}),l.jsx(je,{path:"/isk-h",element:l.jsx(Fj,{})}),l.jsx(je,{path:"/isk-h/calc",element:l.jsx(Jj,{})}),l.jsx(je,{path:"/pilot",element:l.jsx(v1,{})}),l.jsx(je,{path:"/skills",element:l.jsx(D1,{})}),l.jsx(je,{path:"/skills/plans",element:l.jsx(w1,{})}),l.jsx(je,{path:"/badges",element:l.jsx(qj,{})}),l.jsx(je,{path:"/guide",element:l.jsx(Hj,{})}),l.jsx(je,{path:"/guide/:guideName",element:l.jsx(Lj,{})}),l.jsx(je,{path:"/legal",element:l.jsx(Ij,{})}),l.jsx(je,{path:"/waitlist",element:l.jsx(vt,{component:l.jsx(K1,{}),loginRequired:!0})}),l.jsx(je,{path:"/xup",element:l.jsx(vt,{component:l.jsx(bx,{}),loginRequired:!0})}),l.jsx(je,{path:"/fc",element:l.jsx(vt,{component:l.jsx(ej,{}),access:["incursions.waitlist_manage_waitlist","incursions.waitlist_badges_view","incursions.waitlist_badges_manage","incursions.waitlist_bans_view","incursions.waitlist_bans_manage","incursions.waitlist_documentation_view","incursions.waitlist_history_view","incursions.waitlist_stats_view","incursions.waitlist_search","incursions.waitlist_notes_manage"]})}),l.jsx(je,{path:"/fc/announcements",element:l.jsx(vt,{component:l.jsx(Qy,{}),access:"incursions.waitlist_announcements_manage"})}),l.jsx(je,{path:"/fc/badges",element:l.jsx(vt,{component:l.jsx(wj,{}),access:["incursions.waitlist_badges_view","incursions.waitlist_badges_manage"]})}),l.jsx(je,{path:"/fc/bans",element:l.jsx(vt,{component:l.jsx(sv,{}),access:["incursions.waitlist_bans_view","incursions.waitlist_bans_manage"]})}),l.jsx(je,{path:"/fc/documentation",element:l.jsx(vt,{component:l.jsx(Cm,{}),access:"incursions.waitlist_documentation_view"})}),l.jsx(je,{path:"/fc/fleet",element:l.jsx(vt,{component:l.jsx(Qv,{}),access:"incursions.waitlist_manage_waitlist"})}),l.jsx(je,{path:"/fc/fleet/register",element:l.jsx(vt,{component:l.jsx(Vv,{}),access:"incursions.waitlist_manage_waitlist"})}),l.jsx(je,{path:"/fc/fleet/history",element:l.jsx(vt,{component:l.jsx(Kv,{}),access:"incursions.waitlist_history_view"})}),l.jsx(je,{path:"/fc/notes/add",element:l.jsx(vt,{component:l.jsx(tj,{}),access:"incursions.waitlist_notes_manage"})}),l.jsx(je,{path:"/fc/search",element:l.jsx(vt,{component:l.jsx(aj,{}),access:"incursions.waitlist_search"})}),l.jsx(je,{path:"/fc/stats",element:l.jsx(vt,{component:l.jsx(fj,{}),access:"incursions.waitlist_stats_view"})}),l.jsx(je,{path:"/fc/trainee",element:l.jsx(vt,{component:l.jsx(Cm,{}),access:"incursions.waitlist_documentation_view"})}),l.jsx(je,{path:"*",element:l.jsx(Uy,{})})]})}const F1=p0`
  html {
    text-rendering: optimizeLegibility;
    font-size: 16px;
    min-width: 300px;
  }
  body {
    min-height: 100vh;
    background-color: ${i=>i.theme.colors.background};
    color: ${i=>i.theme.colors.text};
    font-family: ${i=>i.theme.font.family};
    line-height: 1.5;
    font-weight: 400;
    overflow-y: scroll;

    ${i=>i.sticker&&i.theme.sticker&&`
        &:before {
          content: '';
          pointer-events: none;
          position: fixed;
          z-index: 100;
          width: 100%;
          height: 100%;
          background-position: 100% 100%;
          background-repeat: no-repeat;
          opacity: 1;
          background-size: 18%;
          background-image: url(${i.theme.sticker});
        }
    `}
  }

  em, i {
    font-style: italic;
  }
  strong, b {
    font-weight: bold;
  }
`;class W1 extends w.Component{constructor(d){var f,m;super(d);Nu(this,"addToast",d=>{this.setState({toasts:[...this.state.toasts,d]})});Nu(this,"changeCharacter",d=>{if(!this.state.auth)return;const u={...this.state.auth},o=u.characters.find(f=>f.character_id===d);o&&(u.current=o,this.setState({auth:u}),localStorage.setItem("selectedCharacter",d.toString()))});const u=(f=window.localStorage)==null?void 0:f.getItem("theme"),o=(m=window.localStorage)==null?void 0:m.getItem("Sticker");this.state={auth:null,toasts:[],events:null,eventErrors:0,theme:u&&st[u]?u:"Light",sticker:o!=="false"}}componentDidMount(){dy(d=>this.setState({auth:d}))}componentDidUpdate(){if(this.state.auth&&!this.state.events){const d=new EventSource("/incursions/api/sse/stream");d.addEventListener("open",()=>{this.setState({eventErrors:0})}),d.addEventListener("error",()=>{d.close(),setTimeout(()=>{this.setState(u=>({events:null,eventErrors:u.eventErrors+1}))},this.state.eventErrors*5e3+Math.random()*1e4)}),this.setState({events:d})}}render(){return l.jsx(K.StrictMode,{children:l.jsxs(y0,{theme:st[this.state.theme],children:[l.jsx(F1,{sticker:this.state.sticker}),l.jsx(oe.Provider,{value:this.addToast,children:l.jsx(_l.Provider,{value:this.state.events,children:l.jsx(ze.Provider,{value:this.state.auth,children:l.jsx(Ip,{basename:"/incursions/waitlist",children:l.jsxs(Pp,{children:[l.jsx(Ca,{children:l.jsx(Oy,{onChangeCharacter:this.changeCharacter,theme:this.state.theme,setTheme:d=>{this.setState({theme:d}),localStorage.setItem("theme",d)},sticker:this.state.sticker,setSticker:d=>{this.setState({sticker:d}),localStorage.setItem("Sticker",d.toString())}})}),l.jsx(Ca,{children:l.jsx(oy,{})}),l.jsx(Ca,{children:l.jsx(J1,{})}),l.jsx(Ca,{children:l.jsx(J0,{toasts:this.state.toasts,setToasts:d=>this.setState({toasts:d})})})]})})})})})]})})}}const I1=document.getElementById("root"),P1=Q0.createRoot(I1);P1.render(l.jsx(K.StrictMode,{children:l.jsx(Ca,{children:l.jsx(W1,{})})}));
//# sourceMappingURL=index-CC_K4hbO.js.map
